import { IdTokenClaims } from "oidc-client-ts";
/**
 * Persists oidc clientId and issuer in local storage
 * Only set after successful authentication
 * @param clientId
 * @param issuer
 * @param idToken
 * @param idTokenClaims
 */
export declare const persistOidcAuthenticatedSettings: (clientId: string, issuer: string, idToken: string) => void;
/**
 * Retrieve stored oidc issuer from local storage
 * When user has token from OIDC issuer, this will be set
 * @returns issuer or undefined
 */
export declare const getStoredOidcTokenIssuer: () => string | undefined;
/**
 * Retrieves stored oidc client id from local storage
 * @returns clientId
 * @throws when clientId is not found in local storage
 */
export declare const getStoredOidcClientId: () => string;
/**
 * Retrieve stored id token claims from stored id token or local storage
 * @returns idTokenClaims or undefined
 */
export declare const getStoredOidcIdTokenClaims: () => IdTokenClaims | undefined;
/**
 * Retrieve stored id token from local storage
 * @returns idToken or undefined
 */
export declare const getStoredOidcIdToken: () => string | undefined;
