import { MatrixClient } from "matrix-js-sdk/src/matrix";
import { Member, ThreepidMember } from "./direct-messages";
/**
 * Tries to resolve the ThreepidMembers to DirectoryMembers.
 *
 * @param members - List of members to resolve
 * @returns {Promise<Member[]>} Same list with ThreepidMembers replaced by DirectoryMembers if succesfully resolved
 */
export declare const resolveThreePids: (members: Member[], client: MatrixClient) => Promise<Member[]>;
/**
 * Tries to look up the ThreepidMembers.
 *
 * @param threePids - List of 3rd-party members to look up
 * @returns  List of resolved 3rd-party IDs with their MXIDs
 */
export declare const lookupThreePids: (threePids: ThreepidMember[], client: MatrixClient) => Promise<{
    threePidId: string;
    mxid: string;
}[]>;
/**
 * Tries to look up the MXIDs and profiles of the ThreepidMembers.
 *
 * @param threePids - List of 3rd-prty members to look up
 * @returns List of resolved 3rd-party members with their MXIDs and profile (if found)
 */
export declare const lookupThreePidProfiles: (threePids: ThreepidMember[], client: MatrixClient) => Promise<{
    threePidId: string;
    mxid: string;
    profile: null | {
        avatar_url?: string;
        displayname?: string;
    };
}[]>;
