import React, { PureComponent, RefCallback, RefObject } from "react";
import { IFieldState, IValidationResult } from "../elements/Validation";
import { TranslationKey } from "../../../languageHandler";
import Field, { IInputProps } from "../elements/Field";
interface IProps extends Omit<IInputProps, "onValidate" | "element"> {
    autoFocus?: boolean;
    id?: string;
    className?: string;
    minScore: 0 | 1 | 2 | 3 | 4;
    value: string;
    fieldRef?: RefCallback<Field> | RefObject<Field>;
    userInputs?: string[];
    label: TranslationKey;
    labelEnterPassword: TranslationKey;
    labelStrongPassword: TranslationKey;
    labelAllowedButUnsafe: TranslationKey;
    onChange(ev: React.FormEvent<HTMLElement>): void;
    onValidate?(result: IValidationResult): void;
}
declare class PassphraseField extends PureComponent<IProps> {
    static defaultProps: {
        label: "a11y_jump_first_unread_room" | "cannot_invite_without_identity_server" | "cannot_reach_homeserver" | "cannot_reach_homeserver_detail" | "cant_load_page" | "chat_card_back_action_label" | "console_dev_note" | "console_scam_warning" | "console_wait" | "dialog_close_label" | "empty_room" | "empty_room_was_name" | "error_app_open_in_another_tab" | "error_app_open_in_another_tab_title" | "error_app_opened_in_another_window" | "error_database_closed_title" | "error_user_not_logged_in" | "failed_load_async_component" | "in_space" | "in_space1_and_space2" | "in_space_and_n_other_spaces" | "info_tooltip_title" | "inviting_user1_and_user2" | "inviting_user_and_n_others" | "items_and_n_others" | "language_dropdown_label" | "member_list_back_action_label" | "message_edit_dialog_title" | "migrating_crypto" | "name_and_id" | "no_more_results" | "room_summary_card_back_action_label" | "thread_view_back_action_label" | "truncated_list_n_more" | "unsupported_server_description" | "unsupported_server_title" | "upload_failed_generic" | "upload_failed_size" | "upload_failed_title" | "emoji|categories" | "emoji|category_activities" | "emoji|category_animals_nature" | "emoji|category_flags" | "emoji|category_food_drink" | "emoji|category_frequently_used" | "emoji|category_objects" | "emoji|category_smileys_people" | "emoji|category_symbols" | "emoji|category_travel_places" | "emoji|quick_reactions" | "time|left" | "time|about_day_ago" | "time|about_hour_ago" | "time|about_minute_ago" | "time|date_at_time" | "time|few_seconds_ago" | "time|hours_minutes_seconds_left" | "time|in_about_day" | "time|in_about_hour" | "time|in_about_minute" | "time|in_few_seconds" | "time|in_n_days" | "time|in_n_hours" | "time|in_n_minutes" | "time|minutes_seconds_left" | "time|n_days_ago" | "time|n_hours_ago" | "time|n_minutes_ago" | "time|seconds_left" | "time|short_days" | "time|short_days_hours_minutes_seconds" | "time|short_hours" | "time|short_hours_minutes_seconds" | "time|short_minutes" | "time|short_minutes_seconds" | "time|short_seconds" | "error|sync" | "error|unknown" | "error|admin_contact" | "error|connection" | "error|admin_contact_short" | "error|dialog_description_default" | "error|download_media" | "error|edit_history_unsupported" | "error|failed_copy" | "error|hs_blocked" | "error|mau" | "error|mixed_content" | "error|non_urgent_echo_failure_toast" | "error|resource_limits" | "error|something_went_wrong" | "error|storage_evicted_description_1" | "error|storage_evicted_description_2" | "error|storage_evicted_title" | "error|tls" | "error|unknown_error_code" | "error|update_power_level" | "error|session_restore|title" | "error|session_restore|clear_storage_button" | "error|session_restore|clear_storage_description" | "error|session_restore|description_1" | "error|session_restore|description_2" | "error|session_restore|description_3" | "feedback|sent" | "feedback|can_contact_label" | "feedback|comment_label" | "feedback|existing_issue_link" | "feedback|may_contact_label" | "feedback|platform_username" | "feedback|pro_type" | "feedback|send_feedback_action" | "timeline|m.sticker" | "timeline|m.poll.start" | "timeline|io.element.widgets.layout" | "timeline|m.room.topic" | "timeline|m.room.tombstone" | "timeline|creation_summary_dm" | "timeline|creation_summary_room" | "timeline|disambiguated_profile" | "timeline|download_action_decrypting" | "timeline|download_action_downloading" | "timeline|download_failed" | "timeline|download_failed_description" | "timeline|error_no_renderer" | "timeline|error_rendering_message" | "timeline|historical_messages_unavailable" | "timeline|in_room_name" | "timeline|late_event_separator" | "timeline|message_timestamp_received_at" | "timeline|message_timestamp_sent_at" | "timeline|no_permission_messages_before_invite" | "timeline|no_permission_messages_before_join" | "timeline|pending_moderation" | "timeline|pending_moderation_reason" | "timeline|read_receipt_title" | "timeline|read_receipts_label" | "timeline|redaction" | "timeline|self_redaction" | "timeline|send_state_encrypting" | "timeline|send_state_failed" | "timeline|send_state_sending" | "timeline|send_state_sent" | "timeline|thread_info_basic" | "timeline|undecryptable_tooltip" | "timeline|summary|left" | "timeline|summary|invited" | "timeline|summary|joined" | "timeline|summary|format" | "timeline|summary|redacted" | "timeline|summary|banned" | "timeline|summary|banned_multiple" | "timeline|summary|changed_avatar" | "timeline|summary|changed_avatar_multiple" | "timeline|summary|changed_name" | "timeline|summary|changed_name_multiple" | "timeline|summary|hidden_event" | "timeline|summary|hidden_event_multiple" | "timeline|summary|invite_withdrawn" | "timeline|summary|invite_withdrawn_multiple" | "timeline|summary|invited_multiple" | "timeline|summary|joined_and_left" | "timeline|summary|joined_and_left_multiple" | "timeline|summary|joined_multiple" | "timeline|summary|kicked" | "timeline|summary|kicked_multiple" | "timeline|summary|left_multiple" | "timeline|summary|no_change" | "timeline|summary|no_change_multiple" | "timeline|summary|pinned_events" | "timeline|summary|pinned_events_multiple" | "timeline|summary|redacted_multiple" | "timeline|summary|rejected_invite" | "timeline|summary|rejected_invite_multiple" | "timeline|summary|rejoined" | "timeline|summary|rejoined_multiple" | "timeline|summary|server_acls" | "timeline|summary|server_acls_multiple" | "timeline|summary|unbanned" | "timeline|summary|unbanned_multiple" | "timeline|m.widget|removed" | "timeline|m.widget|added" | "timeline|m.widget|jitsi_ended" | "timeline|m.widget|jitsi_join_right_prompt" | "timeline|m.widget|jitsi_join_top_prompt" | "timeline|m.widget|jitsi_started" | "timeline|m.widget|jitsi_updated" | "timeline|m.widget|modified" | "timeline|m.poll.end|ended" | "timeline|m.poll.end|sender_ended" | "timeline|m.location|location" | "timeline|m.location|full" | "timeline|m.location|self_location" | "timeline|m.beacon_info|view_live_location" | "timeline|m.room.history_visibility|shared" | "timeline|m.room.history_visibility|unknown" | "timeline|m.room.history_visibility|invited" | "timeline|m.room.history_visibility|joined" | "timeline|m.room.history_visibility|world_readable" | "timeline|m.key.verification.request|user_wants_to_verify" | "timeline|m.key.verification.request|you_started" | "timeline|m.video|error_decrypting" | "timeline|io.element.voice_broadcast_info|user" | "timeline|io.element.voice_broadcast_info|you" | "timeline|m.room.power_levels|changed" | "timeline|m.room.power_levels|user_from_to" | "timeline|m.call|video_call_ended" | "timeline|m.call|video_call_started" | "timeline|m.call|video_call_started_text" | "timeline|m.call|video_call_started_unsupported" | "timeline|m.room.canonical_alias|set" | "timeline|m.room.canonical_alias|removed" | "timeline|m.room.canonical_alias|changed" | "timeline|m.room.canonical_alias|alt_added" | "timeline|m.room.canonical_alias|alt_removed" | "timeline|m.room.canonical_alias|changed_alternative" | "timeline|m.room.canonical_alias|changed_main_and_alternative" | "timeline|m.room.create|continuation" | "timeline|m.room.create|see_older_messages" | "timeline|m.room.create|unknown_predecessor" | "timeline|m.room.create|unknown_predecessor_guess_server" | "timeline|m.room.join_rules|public" | "timeline|m.room.join_rules|unknown" | "timeline|m.room.join_rules|invite" | "timeline|m.room.join_rules|knock" | "timeline|m.room.join_rules|restricted" | "timeline|m.room.join_rules|restricted_settings" | "timeline|m.room.member|join" | "timeline|m.room.member|left" | "timeline|m.room.member|invite" | "timeline|m.room.member|ban" | "timeline|m.room.member|kick" | "timeline|m.room.member|no_change" | "timeline|m.room.member|accepted_3pid_invite" | "timeline|m.room.member|accepted_invite" | "timeline|m.room.member|ban_reason" | "timeline|m.room.member|change_avatar" | "timeline|m.room.member|change_name" | "timeline|m.room.member|change_name_avatar" | "timeline|m.room.member|kick_reason" | "timeline|m.room.member|left_reason" | "timeline|m.room.member|reject_invite" | "timeline|m.room.member|remove_avatar" | "timeline|m.room.member|remove_name" | "timeline|m.room.member|set_avatar" | "timeline|m.room.member|set_name" | "timeline|m.room.member|unban" | "timeline|m.room.member|withdrew_invite" | "timeline|m.room.member|withdrew_invite_reason" | "timeline|m.room.third_party_invite|sent" | "timeline|m.room.third_party_invite|revoked" | "timeline|m.room.name|set" | "timeline|m.room.name|remove" | "timeline|m.room.name|change" | "timeline|m.room.avatar|removed" | "timeline|m.room.avatar|changed" | "timeline|m.room.avatar|changed_img" | "timeline|m.room.avatar|lightbox_title" | "timeline|m.room.pinned_events|changed" | "timeline|m.room.pinned_events|changed_link" | "timeline|m.room.pinned_events|pinned" | "timeline|m.room.pinned_events|pinned_link" | "timeline|m.room.pinned_events|unpinned" | "timeline|m.room.pinned_events|unpinned_link" | "timeline|m.room.encryption|disabled" | "timeline|m.room.encryption|enabled" | "timeline|m.room.encryption|disable_attempt" | "timeline|m.room.encryption|enabled_dm" | "timeline|m.room.encryption|enabled_local" | "timeline|m.room.encryption|parameters_changed" | "timeline|m.room.encryption|unsupported" | "timeline|m.room.guest_access|unknown" | "timeline|m.room.guest_access|can_join" | "timeline|m.room.guest_access|forbidden" | "timeline|m.room.server_acl|set" | "timeline|m.room.server_acl|changed" | "timeline|m.room.server_acl|all_servers_banned" | "timeline|m.call.invite|answered_elsewhere" | "timeline|m.call.invite|call_back_prompt" | "timeline|m.call.invite|declined" | "timeline|m.call.invite|failed_connect_media" | "timeline|m.call.invite|failed_connection" | "timeline|m.call.invite|failed_opponent_media" | "timeline|m.call.invite|missed_call" | "timeline|m.call.invite|no_answer" | "timeline|m.call.invite|unknown_error" | "timeline|m.call.invite|unknown_failure" | "timeline|m.call.invite|unknown_state" | "timeline|m.call.invite|video_call" | "timeline|m.call.invite|video_call_unsupported" | "timeline|m.call.invite|voice_call" | "timeline|m.call.invite|voice_call_unsupported" | "timeline|m.call.hangup|dm" | "timeline|m.image|error" | "timeline|m.image|sent" | "timeline|m.image|error_decrypting" | "timeline|m.image|error_downloading" | "timeline|m.image|show_image" | "timeline|m.file|error_decrypting" | "timeline|m.file|decrypt_label" | "timeline|m.file|download_label" | "timeline|m.file|error_invalid" | "timeline|m.audio|error_downloading_audio" | "timeline|m.audio|error_processing_audio" | "timeline|m.audio|error_processing_voice_message" | "timeline|m.audio|unnamed_audio" | "timeline|context_menu|report" | "timeline|context_menu|collapse_reply_thread" | "timeline|context_menu|external_url" | "timeline|context_menu|open_in_osm" | "timeline|context_menu|resent_unsent_reactions" | "timeline|context_menu|show_url_preview" | "timeline|context_menu|view_related_event" | "timeline|context_menu|view_source" | "timeline|decryption_failure|blocked" | "timeline|decryption_failure|historical_event_no_key_backup" | "timeline|decryption_failure|historical_event_unverified_device" | "timeline|decryption_failure|historical_event_user_not_joined" | "timeline|decryption_failure|unable_to_decrypt" | "timeline|edits|tooltip_label" | "timeline|edits|tooltip_sub" | "timeline|edits|tooltip_title" | "timeline|load_error|title" | "timeline|load_error|no_permission" | "timeline|load_error|unable_to_find" | "timeline|m.poll|count_of_votes" | "timeline|mab|label" | "timeline|mab|collapse_reply_chain" | "timeline|mab|copy_link_thread" | "timeline|mab|expand_reply_chain" | "timeline|mab|view_in_room" | "timeline|mjolnir|changed_rule_glob" | "timeline|mjolnir|changed_rule_rooms" | "timeline|mjolnir|changed_rule_servers" | "timeline|mjolnir|changed_rule_users" | "timeline|mjolnir|created_rule" | "timeline|mjolnir|created_rule_rooms" | "timeline|mjolnir|created_rule_servers" | "timeline|mjolnir|created_rule_users" | "timeline|mjolnir|message_hidden" | "timeline|mjolnir|removed_rule" | "timeline|mjolnir|removed_rule_rooms" | "timeline|mjolnir|removed_rule_servers" | "timeline|mjolnir|removed_rule_users" | "timeline|mjolnir|updated_invalid_rule" | "timeline|mjolnir|updated_rule" | "timeline|mjolnir|updated_rule_rooms" | "timeline|mjolnir|updated_rule_servers" | "timeline|mjolnir|updated_rule_users" | "timeline|reactions|label" | "timeline|reactions|add_reaction_prompt" | "timeline|reactions|custom_reaction_fallback_label" | "timeline|reactions|tooltip_caption" | "timeline|redacted|tooltip" | "timeline|reply|error_loading" | "timeline|reply|in_reply_to" | "timeline|reply|in_reply_to_for_export" | "timeline|scalar_starter_link|dialog_description" | "timeline|scalar_starter_link|dialog_title" | "timeline|typing_indicator|more_users" | "timeline|typing_indicator|one_user" | "timeline|typing_indicator|two_users" | "timeline|url_preview|close" | "timeline|url_preview|show_n_more" | "notifications|default" | "notifications|all_messages" | "notifications|all_messages_description" | "notifications|class_global" | "notifications|class_other" | "notifications|email_pusher_app_display_name" | "notifications|enable_prompt_toast_description" | "notifications|enable_prompt_toast_title" | "notifications|enable_prompt_toast_title_from_message_send" | "notifications|error_change_title" | "notifications|keyword" | "notifications|keyword_new" | "notifications|level_activity" | "notifications|level_highlight" | "notifications|level_muted" | "notifications|level_none" | "notifications|level_notification" | "notifications|level_unsent" | "notifications|mark_all_read" | "notifications|mentions_and_keywords" | "notifications|mentions_and_keywords_description" | "notifications|mentions_keywords" | "notifications|message_didnt_send" | "notifications|mute_description" | "action|search" | "action|join" | "action|add" | "action|show" | "action|pause" | "action|play" | "action|stop" | "action|reload" | "action|start" | "action|view" | "action|cancel" | "action|remove" | "action|clear" | "action|copy" | "action|verify" | "action|complete" | "action|change" | "action|click" | "action|close" | "action|reset" | "action|submit" | "action|forward" | "action|next" | "action|done" | "action|resume" | "action|refresh" | "action|disconnect" | "action|update" | "action|confirm" | "action|ok" | "action|invite" | "action|leave" | "action|ignore" | "action|register" | "action|reject" | "action|delete" | "action|pin" | "action|download" | "action|upload" | "action|save" | "action|apply" | "action|call" | "action|collapse" | "action|accept" | "action|yes" | "action|no" | "action|go" | "action|upgrade" | "action|rename" | "action|continue" | "action|skip" | "action|disable" | "action|enable" | "action|report_content" | "action|share" | "action|upload_file" | "action|reply" | "action|set_avatar" | "action|unban" | "action|view_source" | "action|add_existing_room" | "action|add_people" | "action|approve" | "action|ask_to_join" | "action|back" | "action|click_to_copy" | "action|copy_link" | "action|create" | "action|create_a_room" | "action|decline" | "action|deny" | "action|dismiss" | "action|edit" | "action|enter_fullscreen" | "action|exit_fullscreeen" | "action|expand" | "action|explore_public_rooms" | "action|explore_rooms" | "action|export" | "action|go_back" | "action|got_it" | "action|hide_advanced" | "action|hold" | "action|import" | "action|invite_to_space" | "action|invites_list" | "action|learn_more" | "action|leave_room" | "action|logout" | "action|manage" | "action|maximise" | "action|mention" | "action|minimise" | "action|new_room" | "action|new_video_room" | "action|proceed" | "action|quote" | "action|react" | "action|reply_in_thread" | "action|resend" | "action|restore" | "action|retry" | "action|review" | "action|revoke" | "action|send_report" | "action|show_advanced" | "action|show_all" | "action|sign_in" | "action|sign_out" | "action|start_chat" | "action|start_new_chat" | "action|subscribe" | "action|transfer" | "action|trust" | "action|try_again" | "action|unignore" | "action|unpin" | "action|unsubscribe" | "action|view_all" | "action|view_list" | "action|view_message" | "action|zoom_in" | "action|zoom_out" | "forward|sending" | "forward|sent" | "forward|filter_placeholder" | "forward|message_preview_heading" | "forward|no_perms_title" | "forward|open_room" | "forward|send_label" | "auth|sso" | "auth|3pid_in_use" | "auth|account_clash" | "auth|account_clash_previous_account" | "auth|account_deactivated" | "auth|autodiscovery_generic_failure" | "auth|autodiscovery_hs_incompatible" | "auth|autodiscovery_invalid" | "auth|autodiscovery_invalid_hs" | "auth|autodiscovery_invalid_hs_base_url" | "auth|autodiscovery_invalid_is" | "auth|autodiscovery_invalid_is_base_url" | "auth|autodiscovery_invalid_is_response" | "auth|autodiscovery_invalid_json" | "auth|autodiscovery_no_well_known" | "auth|autodiscovery_unexpected_error_hs" | "auth|autodiscovery_unexpected_error_is" | "auth|captcha_description" | "auth|change_password_action" | "auth|change_password_confirm_invalid" | "auth|change_password_confirm_label" | "auth|change_password_current_label" | "auth|change_password_empty" | "auth|change_password_error" | "auth|change_password_mismatch" | "auth|change_password_new_label" | "auth|check_email_explainer" | "auth|check_email_resend_prompt" | "auth|check_email_resend_tooltip" | "auth|check_email_wrong_email_button" | "auth|check_email_wrong_email_prompt" | "auth|continue_with_idp" | "auth|continue_with_sso" | "auth|country_dropdown" | "auth|create_account_prompt" | "auth|create_account_title" | "auth|email_discovery_text" | "auth|email_field_label" | "auth|email_field_label_invalid" | "auth|email_field_label_required" | "auth|email_help_text" | "auth|email_phone_discovery_text" | "auth|enter_email_explainer" | "auth|enter_email_heading" | "auth|failed_connect_identity_server" | "auth|failed_connect_identity_server_other" | "auth|failed_connect_identity_server_register" | "auth|failed_connect_identity_server_reset_password" | "auth|failed_homeserver_discovery" | "auth|failed_query_registration_methods" | "auth|failed_soft_logout_auth" | "auth|failed_soft_logout_homeserver" | "auth|footer_powered_by_matrix" | "auth|forgot_password_email_invalid" | "auth|forgot_password_email_required" | "auth|forgot_password_prompt" | "auth|forgot_password_send_email" | "auth|identifier_label" | "auth|incorrect_credentials" | "auth|incorrect_credentials_detail" | "auth|incorrect_password" | "auth|log_in_new_account" | "auth|misconfigured_body" | "auth|misconfigured_title" | "auth|msisdn_field_description" | "auth|msisdn_field_label" | "auth|msisdn_field_number_invalid" | "auth|msisdn_field_required_invalid" | "auth|no_hs_url_provided" | "auth|password_field_keep_going_prompt" | "auth|password_field_label" | "auth|password_field_strong_label" | "auth|password_field_weak_label" | "auth|phone_label" | "auth|phone_optional_label" | "auth|register_action" | "auth|registration_disabled" | "auth|registration_msisdn_field_required_invalid" | "auth|registration_successful" | "auth|registration_username_in_use" | "auth|registration_username_unable_check" | "auth|registration_username_validation" | "auth|reset_password_action" | "auth|reset_password_button" | "auth|reset_password_email_field_description" | "auth|reset_password_email_field_required_invalid" | "auth|reset_password_email_not_associated" | "auth|reset_password_email_not_found_title" | "auth|reset_password_title" | "auth|server_picker_custom" | "auth|server_picker_description" | "auth|server_picker_description_matrix.org" | "auth|server_picker_dialog_title" | "auth|server_picker_explainer" | "auth|server_picker_failed_validate_homeserver" | "auth|server_picker_intro" | "auth|server_picker_invalid_url" | "auth|server_picker_learn_more" | "auth|server_picker_matrix.org" | "auth|server_picker_required" | "auth|server_picker_title" | "auth|server_picker_title_default" | "auth|server_picker_title_registration" | "auth|session_logged_out_description" | "auth|session_logged_out_title" | "auth|set_email_prompt" | "auth|sign_in_description" | "auth|sign_in_instead" | "auth|sign_in_instead_prompt" | "auth|sign_in_or_register" | "auth|sign_in_or_register_description" | "auth|sign_in_prompt" | "auth|sign_in_with_sso" | "auth|signing_in" | "auth|soft_logout_heading" | "auth|soft_logout_intro_password" | "auth|soft_logout_intro_sso" | "auth|soft_logout_intro_unsupported_auth" | "auth|soft_logout_subheading" | "auth|soft_logout_warning" | "auth|sso_failed_missing_storage" | "auth|sso_or_username_password" | "auth|sync_footer_subtitle" | "auth|syncing" | "auth|unsupported_auth" | "auth|unsupported_auth_email" | "auth|unsupported_auth_msisdn" | "auth|username_field_required_invalid" | "auth|username_in_use" | "auth|verify_email_explainer" | "auth|verify_email_heading" | "auth|logout_dialog|description" | "auth|logout_dialog|megolm_export" | "auth|logout_dialog|setup_key_backup_title" | "auth|logout_dialog|setup_secure_backup_description_1" | "auth|logout_dialog|setup_secure_backup_description_2" | "auth|logout_dialog|skip_key_backup" | "auth|logout_dialog|use_key_backup" | "auth|oidc|error_title" | "auth|oidc|generic_auth_error" | "auth|oidc|logout_redirect_warning" | "auth|oidc|missing_or_invalid_stored_state" | "auth|qr_code_login|approve_access_warning" | "auth|qr_code_login|check_code_explainer" | "auth|qr_code_login|check_code_heading" | "auth|qr_code_login|check_code_input_label" | "auth|qr_code_login|check_code_mismatch" | "auth|qr_code_login|completing_setup" | "auth|qr_code_login|confirm_code_match" | "auth|qr_code_login|error_etag_missing" | "auth|qr_code_login|error_expired" | "auth|qr_code_login|error_expired_title" | "auth|qr_code_login|error_insecure_channel_detected" | "auth|qr_code_login|error_insecure_channel_detected_instructions" | "auth|qr_code_login|error_insecure_channel_detected_instructions_1" | "auth|qr_code_login|error_insecure_channel_detected_instructions_2" | "auth|qr_code_login|error_insecure_channel_detected_instructions_3" | "auth|qr_code_login|error_insecure_channel_detected_title" | "auth|qr_code_login|error_other_device_already_signed_in" | "auth|qr_code_login|error_other_device_already_signed_in_title" | "auth|qr_code_login|error_rate_limited" | "auth|qr_code_login|error_unexpected" | "auth|qr_code_login|error_unsupported_protocol" | "auth|qr_code_login|error_unsupported_protocol_title" | "auth|qr_code_login|error_user_cancelled" | "auth|qr_code_login|error_user_cancelled_title" | "auth|qr_code_login|error_user_declined" | "auth|qr_code_login|error_user_declined_title" | "auth|qr_code_login|follow_remaining_instructions" | "auth|qr_code_login|open_element_other_device" | "auth|qr_code_login|point_the_camera" | "auth|qr_code_login|scan_code_instruction" | "auth|qr_code_login|scan_qr_code" | "auth|qr_code_login|security_code" | "auth|qr_code_login|security_code_prompt" | "auth|qr_code_login|select_qr_code" | "auth|qr_code_login|sign_in_new_device" | "auth|qr_code_login|waiting_for_device" | "auth|registration|continue_without_email_description" | "auth|registration|continue_without_email_field_label" | "auth|registration|continue_without_email_title" | "auth|reset_password|confirm_new_password" | "auth|reset_password|devices_logout_success" | "auth|reset_password|other_devices_logout_warning_1" | "auth|reset_password|other_devices_logout_warning_2" | "auth|reset_password|password_not_entered" | "auth|reset_password|passwords_mismatch" | "auth|reset_password|rate_limit_error" | "auth|reset_password|rate_limit_error_with_time" | "auth|reset_password|reset_successful" | "auth|reset_password|return_to_login" | "auth|reset_password|sign_out_other_devices" | "auth|set_email|description" | "auth|set_email|verification_pending_description" | "auth|set_email|verification_pending_title" | "auth|soft_logout|clear_data_button" | "auth|soft_logout|clear_data_description" | "auth|soft_logout|clear_data_title" | "auth|uia|code" | "auth|uia|email" | "auth|uia|msisdn" | "auth|uia|terms" | "auth|uia|email_auth_header" | "auth|uia|email_resend_prompt" | "auth|uia|email_resent" | "auth|uia|fallback_button" | "auth|uia|msisdn_token_incorrect" | "auth|uia|msisdn_token_prompt" | "auth|uia|password_prompt" | "auth|uia|recaptcha_missing_params" | "auth|uia|registration_token_label" | "auth|uia|registration_token_prompt" | "auth|uia|sso_body" | "auth|uia|sso_failed" | "auth|uia|sso_postauth_body" | "auth|uia|sso_postauth_title" | "auth|uia|sso_preauth_body" | "auth|uia|sso_title" | "auth|uia|terms_invalid" | "update|checking" | "update|unavailable" | "update|changelog" | "update|check_action" | "update|downloading" | "update|error_encountered" | "update|error_unable_load_commit" | "update|new_version_available" | "update|no_update" | "update|release_notes_toast_title" | "update|see_changes_button" | "update|toast_description" | "update|toast_title" | "room|show_labs_settings" | "room|kick_reason" | "room|3pid_invite_email_not_found_account" | "room|3pid_invite_email_not_found_account_room" | "room|3pid_invite_error_description" | "room|3pid_invite_error_invite_action" | "room|3pid_invite_error_invite_subtitle" | "room|3pid_invite_error_public_subtitle" | "room|3pid_invite_error_title" | "room|3pid_invite_error_title_room" | "room|3pid_invite_no_is_subtitle" | "room|banned_by" | "room|banned_from_room_by" | "room|creating_room_text" | "room|dm_invite_action" | "room|dm_invite_subtitle" | "room|dm_invite_title" | "room|drop_file_prompt" | "room|edit_topic" | "room|error_3pid_invite_email_lookup" | "room|error_cancel_knock_title" | "room|error_join_403" | "room|error_join_404_1" | "room|error_join_404_2" | "room|error_join_404_invite" | "room|error_join_404_invite_same_hs" | "room|error_join_connection" | "room|error_join_incompatible_version_1" | "room|error_join_incompatible_version_2" | "room|error_join_title" | "room|error_jump_to_date" | "room|error_jump_to_date_connection" | "room|error_jump_to_date_details" | "room|error_jump_to_date_not_found" | "room|error_jump_to_date_send_logs_prompt" | "room|error_jump_to_date_title" | "room|face_pile_summary" | "room|face_pile_tooltip_label" | "room|face_pile_tooltip_shortcut" | "room|face_pile_tooltip_shortcut_joined" | "room|failed_reject_invite" | "room|forget_room" | "room|forget_space" | "room|header_face_pile_tooltip" | "room|header_untrusted_label" | "room|inaccessible" | "room|inaccessible_name" | "room|inaccessible_subtitle_1" | "room|inaccessible_subtitle_2" | "room|invite_email_mismatch_suggestion" | "room|invite_reject_ignore" | "room|invite_sent_to_email" | "room|invite_sent_to_email_room" | "room|invite_subtitle" | "room|invite_this_room" | "room|invite_title" | "room|inviter_unknown" | "room|invites_you_text" | "room|join_button_account" | "room|join_failed_enable_video_rooms" | "room|join_failed_needs_invite" | "room|join_the_discussion" | "room|join_title" | "room|join_title_account" | "room|joining" | "room|joining_room" | "room|joining_space" | "room|jump_read_marker" | "room|jump_to_bottom_button" | "room|jump_to_date" | "room|jump_to_date_beginning" | "room|jump_to_date_prompt" | "room|kicked_by" | "room|kicked_from_room_by" | "room|knock_cancel_action" | "room|knock_denied_subtitle" | "room|knock_denied_title" | "room|knock_message_field_placeholder" | "room|knock_prompt" | "room|knock_prompt_name" | "room|knock_send_action" | "room|knock_sent" | "room|knock_sent_subtitle" | "room|knock_subtitle" | "room|leave_error_title" | "room|leave_server_notices_description" | "room|leave_server_notices_title" | "room|leave_unexpected_error" | "room|link_email_to_receive_3pid_invite" | "room|loading_preview" | "room|no_peek_join_prompt" | "room|no_peek_no_name_join_prompt" | "room|not_found_subtitle" | "room|not_found_title" | "room|not_found_title_name" | "room|peek_join_prompt" | "room|read_topic" | "room|rejecting" | "room|rejoin_button" | "room|unknown_status_code_for_timeline_jump" | "room|unread_notifications_predecessor" | "room|upgrade_error_description" | "room|upgrade_error_title" | "room|upgrade_warning_bar" | "room|upgrade_warning_bar_admins" | "room|upgrade_warning_bar_unstable" | "room|upgrade_warning_bar_upgraded" | "room|view_failed_enable_video_rooms" | "room|waiting_for_join_subtitle" | "room|waiting_for_join_title" | "room|search|summary" | "room|search|placeholder" | "room|search|all_rooms_button" | "room|search|result_count" | "room|search|this_room_button" | "room|header|close_call_button" | "room|header|forget_room_button" | "room|header|hide_widgets_button" | "room|header|n_people_asking_to_join" | "room|header|release_announcement_description" | "room|header|release_announcement_header" | "room|header|room_is_public" | "room|header|show_widgets_button" | "room|header|video_call_button_ec" | "room|header|video_call_button_jitsi" | "room|header|video_call_button_legacy" | "room|header|video_call_ec_change_layout" | "room|header|video_call_ec_layout_freedom" | "room|header|video_call_ec_layout_spotlight" | "room|header|video_room_view_chat_button" | "room|upload|uploading_multiple_file" | "room|upload|uploading_single_file" | "room|context_menu|title" | "room|context_menu|forget" | "room|context_menu|copy_link" | "room|context_menu|favourite" | "room|context_menu|low_priority" | "room|context_menu|mark_read" | "room|context_menu|mark_unread" | "room|context_menu|mentions_only" | "room|context_menu|notifications_default" | "room|context_menu|notifications_mute" | "room|context_menu|unfavourite" | "room|intro|topic" | "room|intro|dm_caption" | "room|intro|enable_encryption_prompt" | "room|intro|encrypted_3pid_dm_pending_join" | "room|intro|no_avatar_label" | "room|intro|no_topic" | "room|intro|private_unencrypted_warning" | "room|intro|room_invite" | "room|intro|send_message_start_dm" | "room|intro|start_of_dm_history" | "room|intro|start_of_room" | "room|intro|topic_edit" | "room|intro|unencrypted_warning" | "room|intro|user_created" | "room|intro|you_created" | "room|pinned_message_banner|title" | "room|pinned_message_banner|description" | "room|pinned_message_banner|button_close_list" | "room|pinned_message_banner|button_view_all" | "room|pinned_message_banner|go_to_message" | "room|status_bar|delete_all" | "room|status_bar|exceeded_resource_limit" | "room|status_bar|homeserver_blocked" | "room|status_bar|monthly_user_limit_reached" | "room|status_bar|requires_consent_agreement" | "room|status_bar|retry_all" | "room|status_bar|select_messages_to_retry" | "room|status_bar|server_connectivity_lost_description" | "room|status_bar|server_connectivity_lost_title" | "room|status_bar|some_messages_not_sent" | "invite|ask_anyway_description" | "invite|ask_anyway_label" | "invite|ask_anyway_never_warn_label" | "invite|email_caption" | "invite|email_limit_one" | "invite|email_use_default_is" | "invite|email_use_is" | "invite|error_already_invited_room" | "invite|error_already_invited_space" | "invite|error_already_joined_room" | "invite|error_already_joined_space" | "invite|error_bad_state" | "invite|error_dm" | "invite|error_find_room" | "invite|error_find_user_description" | "invite|error_find_user_title" | "invite|error_invite" | "invite|error_permissions_room" | "invite|error_permissions_space" | "invite|error_profile_undisclosed" | "invite|error_transfer_multiple_target" | "invite|error_unfederated_room" | "invite|error_unfederated_space" | "invite|error_unknown" | "invite|error_user_not_found" | "invite|error_version_unsupported_room" | "invite|error_version_unsupported_space" | "invite|failed_generic" | "invite|failed_title" | "invite|invalid_address" | "invite|name_email_mxid_share_room" | "invite|name_email_mxid_share_space" | "invite|name_mxid_share_room" | "invite|name_mxid_share_space" | "invite|recents_section" | "invite|room_failed_partial" | "invite|room_failed_partial_title" | "invite|room_failed_title" | "invite|send_link_prompt" | "invite|start_conversation_name_email_mxid_prompt" | "invite|start_conversation_name_mxid_prompt" | "invite|suggestions_disclaimer" | "invite|suggestions_disclaimer_prompt" | "invite|suggestions_section" | "invite|to_room" | "invite|to_space" | "invite|transfer_dial_pad_tab" | "invite|transfer_user_directory_tab" | "invite|unable_find_profiles_description_default" | "invite|unable_find_profiles_invite_label_default" | "invite|unable_find_profiles_invite_never_warn_label_default" | "invite|unable_find_profiles_title" | "invite|unban_first_title" | "presence|idle" | "presence|offline" | "presence|online" | "presence|unknown" | "presence|away" | "presence|busy" | "presence|idle_for" | "presence|offline_for" | "presence|online_for" | "presence|unknown_for" | "presence|unreachable" | "redact|error" | "redact|confirm_button" | "redact|confirm_description" | "redact|confirm_description_state" | "redact|ongoing" | "redact|reason_label" | "encryption|unsupported" | "encryption|bootstrap_title" | "encryption|cancel_entering_passphrase_description" | "encryption|cancel_entering_passphrase_title" | "encryption|confirm_encryption_setup_body" | "encryption|confirm_encryption_setup_title" | "encryption|cross_signing_not_ready" | "encryption|cross_signing_ready" | "encryption|cross_signing_ready_no_backup" | "encryption|cross_signing_room_normal" | "encryption|cross_signing_room_verified" | "encryption|cross_signing_room_warning" | "encryption|cross_signing_unsupported" | "encryption|cross_signing_untrusted" | "encryption|cross_signing_user_normal" | "encryption|cross_signing_user_verified" | "encryption|cross_signing_user_warning" | "encryption|event_shield_reason_authenticity_not_guaranteed" | "encryption|event_shield_reason_mismatched_sender_key" | "encryption|event_shield_reason_unknown_device" | "encryption|event_shield_reason_unsigned_device" | "encryption|event_shield_reason_unverified_identity" | "encryption|export_unsupported" | "encryption|import_invalid_keyfile" | "encryption|import_invalid_passphrase" | "encryption|incompatible_database_description" | "encryption|incompatible_database_disable" | "encryption|incompatible_database_sign_out_description" | "encryption|incompatible_database_title" | "encryption|key_signature_upload_cancelled" | "encryption|key_signature_upload_completed" | "encryption|key_signature_upload_failed" | "encryption|key_signature_upload_failed_body" | "encryption|key_signature_upload_failed_cross_signing_key_signature" | "encryption|key_signature_upload_failed_device_cross_signing_key_signature" | "encryption|key_signature_upload_failed_key_signature" | "encryption|key_signature_upload_failed_master_key_signature" | "encryption|key_signature_upload_failed_title" | "encryption|key_signature_upload_success_title" | "encryption|not_supported" | "encryption|old_version_detected_description" | "encryption|old_version_detected_title" | "encryption|reset_all_button" | "encryption|set_up_toast_description" | "encryption|set_up_toast_title" | "encryption|unable_to_setup_keys_error" | "encryption|upgrade_toast_title" | "encryption|verification_requested_toast_title" | "encryption|verify_toast_description" | "encryption|verify_toast_title" | "encryption|access_secret_storage_dialog|separator" | "encryption|access_secret_storage_dialog|enter_phrase_or_key_prompt" | "encryption|access_secret_storage_dialog|reset_title" | "encryption|access_secret_storage_dialog|reset_warning_1" | "encryption|access_secret_storage_dialog|reset_warning_2" | "encryption|access_secret_storage_dialog|restoring" | "encryption|access_secret_storage_dialog|security_key_title" | "encryption|access_secret_storage_dialog|security_phrase_incorrect_error" | "encryption|access_secret_storage_dialog|security_phrase_title" | "encryption|access_secret_storage_dialog|use_security_key_prompt" | "encryption|access_secret_storage_dialog|key_validation_text|invalid_security_key" | "encryption|access_secret_storage_dialog|key_validation_text|recovery_key_is_correct" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_file_type" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_security_key" | "encryption|destroy_cross_signing_dialog|title" | "encryption|destroy_cross_signing_dialog|warning" | "encryption|destroy_cross_signing_dialog|primary_button_text" | "encryption|messages_not_secure|title" | "encryption|messages_not_secure|heading" | "encryption|messages_not_secure|cause_1" | "encryption|messages_not_secure|cause_2" | "encryption|messages_not_secure|cause_3" | "encryption|messages_not_secure|cause_4" | "encryption|new_recovery_method_detected|title" | "encryption|new_recovery_method_detected|warning" | "encryption|new_recovery_method_detected|description_1" | "encryption|new_recovery_method_detected|description_2" | "encryption|recovery_method_removed|title" | "encryption|recovery_method_removed|warning" | "encryption|recovery_method_removed|description_1" | "encryption|recovery_method_removed|description_2" | "encryption|setup_secure_backup|title" | "encryption|setup_secure_backup|explainer" | "encryption|udd|title" | "encryption|udd|interactive_verification_button" | "encryption|udd|manual_verification_button" | "encryption|udd|other_ask_verify_text" | "encryption|udd|other_new_session_text" | "encryption|udd|own_ask_verify_text" | "encryption|udd|own_new_session_text" | "encryption|verification|cancelled" | "encryption|verification|explainer" | "encryption|verification|accepting" | "encryption|verification|cancelled_self" | "encryption|verification|cancelled_user" | "encryption|verification|cancelling" | "encryption|verification|complete_action" | "encryption|verification|complete_description" | "encryption|verification|complete_title" | "encryption|verification|error_starting_description" | "encryption|verification|error_starting_title" | "encryption|verification|in_person" | "encryption|verification|incoming_sas_device_dialog_text_1" | "encryption|verification|incoming_sas_device_dialog_text_2" | "encryption|verification|incoming_sas_dialog_title" | "encryption|verification|incoming_sas_dialog_waiting" | "encryption|verification|incoming_sas_user_dialog_text_1" | "encryption|verification|incoming_sas_user_dialog_text_2" | "encryption|verification|manual_device_verification_device_id_label" | "encryption|verification|manual_device_verification_device_key_label" | "encryption|verification|manual_device_verification_device_name_label" | "encryption|verification|manual_device_verification_footer" | "encryption|verification|manual_device_verification_self_text" | "encryption|verification|manual_device_verification_user_text" | "encryption|verification|no_key_or_device" | "encryption|verification|no_support_qr_emoji" | "encryption|verification|other_party_cancelled" | "encryption|verification|prompt_encrypted" | "encryption|verification|prompt_self" | "encryption|verification|prompt_unencrypted" | "encryption|verification|prompt_user" | "encryption|verification|qr_or_sas" | "encryption|verification|qr_or_sas_header" | "encryption|verification|qr_prompt" | "encryption|verification|qr_reciprocate_same_shield_device" | "encryption|verification|qr_reciprocate_same_shield_user" | "encryption|verification|request_toast_accept" | "encryption|verification|request_toast_accept_user" | "encryption|verification|request_toast_decline_counter" | "encryption|verification|request_toast_detail" | "encryption|verification|reset_proceed_prompt" | "encryption|verification|sas_caption_self" | "encryption|verification|sas_caption_user" | "encryption|verification|sas_description" | "encryption|verification|sas_emoji_caption_self" | "encryption|verification|sas_emoji_caption_user" | "encryption|verification|sas_match" | "encryption|verification|sas_no_match" | "encryption|verification|sas_prompt" | "encryption|verification|scan_qr" | "encryption|verification|scan_qr_explainer" | "encryption|verification|self_verification_hint" | "encryption|verification|start_button" | "encryption|verification|successful_device" | "encryption|verification|successful_own_device" | "encryption|verification|successful_user" | "encryption|verification|timed_out" | "encryption|verification|unsupported_method" | "encryption|verification|unverified_session_toast_accept" | "encryption|verification|unverified_session_toast_title" | "encryption|verification|unverified_sessions_toast_description" | "encryption|verification|unverified_sessions_toast_reject" | "encryption|verification|unverified_sessions_toast_title" | "encryption|verification|verification_description" | "encryption|verification|verification_dialog_title_device" | "encryption|verification|verification_dialog_title_user" | "encryption|verification|verification_skip_warning" | "encryption|verification|verification_success_with_backup" | "encryption|verification|verification_success_without_backup" | "encryption|verification|verify_emoji" | "encryption|verification|verify_emoji_prompt" | "encryption|verification|verify_emoji_prompt_qr" | "encryption|verification|verify_later" | "encryption|verification|verify_reset_warning_1" | "encryption|verification|verify_reset_warning_2" | "encryption|verification|verify_using_device" | "encryption|verification|verify_using_key" | "encryption|verification|verify_using_key_or_phrase" | "encryption|verification|waiting_for_user_accept" | "encryption|verification|waiting_other_device" | "encryption|verification|waiting_other_device_details" | "encryption|verification|waiting_other_user" | "encryption|verification|after_new_login|device_verified" | "encryption|verification|after_new_login|reset_confirmation" | "encryption|verification|after_new_login|skip_verification" | "encryption|verification|after_new_login|unable_to_verify" | "encryption|verification|after_new_login|verify_this_device" | "threads|mark_all_read" | "threads|all_threads" | "threads|all_threads_description" | "threads|count_of_reply" | "threads|empty_description" | "threads|empty_title" | "threads|error_start_thread_existing_relation" | "threads|my_threads" | "threads|my_threads_description" | "threads|open_thread" | "threads|show_thread_filter" | "space|invite" | "space|joining_space" | "space|failed_load_rooms" | "space|failed_remove_rooms" | "space|incompatible_server_hierarchy" | "space|invite_description" | "space|invite_link" | "space|invite_this_space" | "space|landing_welcome" | "space|leave_dialog_action" | "space|leave_dialog_description" | "space|leave_dialog_only_admin_room_warning" | "space|leave_dialog_only_admin_warning" | "space|leave_dialog_option_all" | "space|leave_dialog_option_intro" | "space|leave_dialog_option_none" | "space|leave_dialog_option_specific" | "space|leave_dialog_public_rejoin_warning" | "space|leave_dialog_title" | "space|mark_suggested" | "space|no_search_result_hint" | "space|room_filter_placeholder" | "space|search_children" | "space|search_placeholder" | "space|select_room_below" | "space|share_public" | "space|suggested" | "space|suggested_tooltip" | "space|title_when_query_available" | "space|title_when_query_unavailable" | "space|unmark_suggested" | "space|user_lacks_permission" | "space|context_menu|home" | "space|context_menu|options" | "space|context_menu|devtools_open_timeline" | "space|context_menu|explore" | "space|context_menu|manage_and_explore" | "space|add_existing_room_space|create" | "space|add_existing_room_space|create_prompt" | "space|add_existing_room_space|dm_heading" | "space|add_existing_room_space|error_heading" | "space|add_existing_room_space|progress_text" | "space|add_existing_room_space|space_dropdown_label" | "space|add_existing_room_space|space_dropdown_title" | "space|add_existing_room_space|subspace_moved_note" | "space|add_existing_subspace|filter_placeholder" | "space|add_existing_subspace|create_prompt" | "space|add_existing_subspace|space_dropdown_title" | "space|add_existing_subspace|create_button" | "space|preferences|sections_section" | "space|preferences|show_people_in_space" | "spaces|error_no_permission_add_room" | "spaces|error_no_permission_add_space" | "spaces|error_no_permission_create_room" | "spaces|error_no_permission_invite" | "common|emoji" | "common|name" | "common|attachment" | "common|beta" | "common|error" | "common|message" | "common|feedback" | "common|location" | "common|timeline" | "common|advanced" | "common|cancel" | "common|appearance" | "common|mute" | "common|unmute" | "common|private" | "common|public" | "common|loading" | "common|video" | "common|image" | "common|encrypted" | "common|offline" | "common|off" | "common|on" | "common|username" | "common|home" | "common|options" | "common|success" | "common|description" | "common|user" | "common|profile" | "common|password" | "common|access_token" | "common|capabilities" | "common|room" | "common|matrix" | "common|joined" | "common|presence" | "common|rooms" | "common|thread" | "common|unavailable" | "common|verified" | "common|device" | "common|version" | "common|application" | "common|trusted" | "common|threads" | "common|guest" | "common|server" | "common|save" | "common|space" | "common|dark" | "common|light" | "common|help" | "common|spaces" | "common|legal" | "common|security" | "common|warning" | "common|settings" | "common|android" | "common|ios" | "common|labs" | "common|theme" | "common|edited" | "common|analytics" | "common|credits" | "common|identity_server" | "common|integration_manager" | "common|reactions" | "common|view_message" | "common|low_priority" | "common|preferences" | "common|accessibility" | "common|all_rooms" | "common|and_n_others" | "common|are_you_sure" | "common|authentication" | "common|avatar" | "common|camera" | "common|cameras" | "common|copied" | "common|cross_signing" | "common|deselect_all" | "common|email_address" | "common|encryption_enabled" | "common|extensions" | "common|faq" | "common|favourites" | "common|filter_results" | "common|forward_message" | "common|general" | "common|go_to_settings" | "common|historical" | "common|homeserver" | "common|lobby" | "common|message_layout" | "common|microphone" | "common|model" | "common|modern" | "common|n_members" | "common|n_rooms" | "common|no_results" | "common|no_results_found" | "common|not_trusted" | "common|orphan_rooms" | "common|people" | "common|preview_message" | "common|privacy" | "common|private_room" | "common|private_space" | "common|public_room" | "common|public_space" | "common|qr_code" | "common|random" | "common|report_a_bug" | "common|room_name" | "common|saved" | "common|saving" | "common|secure_backup" | "common|select_all" | "common|setup_secure_messages" | "common|show_more" | "common|someone" | "common|sticker" | "common|stickerpack" | "common|suggestions" | "common|support" | "common|system_alerts" | "common|unencrypted" | "common|unnamed_room" | "common|unnamed_space" | "common|unsent" | "common|unverified" | "common|updating" | "common|user_avatar" | "common|verification_cancelled" | "common|video_room" | "common|welcome" | "settings|warning" | "settings|notifications|mentions_keywords" | "settings|all_rooms_home" | "settings|all_rooms_home_description" | "settings|always_show_message_timestamps" | "settings|automatic_language_detection_syntax_highlight" | "settings|autoplay_gifs" | "settings|autoplay_videos" | "settings|big_emoji" | "settings|code_block_expand_default" | "settings|code_block_line_numbers" | "settings|disable_historical_profile" | "settings|emoji_autocomplete" | "settings|enable_markdown" | "settings|enable_markdown_description" | "settings|image_thumbnails" | "settings|inline_url_previews_default" | "settings|inline_url_previews_room" | "settings|inline_url_previews_room_account" | "settings|insert_trailing_colon_mentions" | "settings|jump_to_bottom_on_send" | "settings|prompt_invite" | "settings|replace_plain_emoji" | "settings|send_read_receipts" | "settings|send_read_receipts_unsupported" | "settings|send_typing_notifications" | "settings|show_avatar_changes" | "settings|show_breadcrumbs" | "settings|show_chat_effects" | "settings|show_displayname_changes" | "settings|show_join_leave" | "settings|show_nsfw_content" | "settings|show_read_receipts" | "settings|show_redaction_placeholder" | "settings|show_stickers_button" | "settings|show_typing_notifications" | "settings|showbold" | "settings|start_automatically" | "settings|tac_only_notifications" | "settings|use_12_hour_format" | "settings|use_command_enter_send_message" | "settings|use_command_f_search" | "settings|use_control_enter_send_message" | "settings|use_control_f_search" | "settings|warn_quit" | "settings|notifications|voip" | "settings|notifications|error_loading" | "settings|notifications|dialog_title" | "settings|notifications|error_title" | "settings|notifications|default_setting_description" | "settings|notifications|default_setting_section" | "settings|notifications|desktop_notification_message_preview" | "settings|notifications|email_description" | "settings|notifications|email_section" | "settings|notifications|email_select" | "settings|notifications|enable_audible_notifications_session" | "settings|notifications|enable_desktop_notifications_session" | "settings|notifications|enable_email_notifications" | "settings|notifications|enable_notifications_account" | "settings|notifications|enable_notifications_account_detail" | "settings|notifications|enable_notifications_device" | "settings|notifications|error_permissions_denied" | "settings|notifications|error_permissions_missing" | "settings|notifications|error_saving" | "settings|notifications|error_saving_detail" | "settings|notifications|error_updating" | "settings|notifications|invites" | "settings|notifications|keywords" | "settings|notifications|keywords_prompt" | "settings|notifications|labs_notice_prompt" | "settings|notifications|mentions_keywords_only" | "settings|notifications|messages_containing_keywords" | "settings|notifications|noisy" | "settings|notifications|notices" | "settings|notifications|notify_at_room" | "settings|notifications|notify_keyword" | "settings|notifications|notify_mention" | "settings|notifications|other_section" | "settings|notifications|people_mentions_keywords" | "settings|notifications|play_sound_for_description" | "settings|notifications|play_sound_for_section" | "settings|notifications|push_targets" | "settings|notifications|quick_actions_mark_all_read" | "settings|notifications|quick_actions_reset" | "settings|notifications|quick_actions_section" | "settings|notifications|room_activity" | "settings|notifications|rule_call" | "settings|notifications|rule_contains_display_name" | "settings|notifications|rule_contains_user_name" | "settings|notifications|rule_encrypted" | "settings|notifications|rule_encrypted_room_one_to_one" | "settings|notifications|rule_invite_for_me" | "settings|notifications|rule_message" | "settings|notifications|rule_room_one_to_one" | "settings|notifications|rule_roomnotif" | "settings|notifications|rule_suppress_notices" | "settings|notifications|rule_tombstone" | "settings|notifications|show_message_desktop_notification" | "settings|appearance|dialog_title" | "settings|appearance|bundled_emoji_font" | "settings|appearance|compact_layout" | "settings|appearance|compact_layout_description" | "settings|appearance|custom_font" | "settings|appearance|custom_font_description" | "settings|appearance|custom_font_name" | "settings|appearance|custom_font_size" | "settings|appearance|custom_theme_add" | "settings|appearance|custom_theme_downloading" | "settings|appearance|custom_theme_error_downloading" | "settings|appearance|custom_theme_help" | "settings|appearance|custom_theme_invalid" | "settings|appearance|font_size" | "settings|appearance|font_size_default" | "settings|appearance|high_contrast" | "settings|appearance|image_size_default" | "settings|appearance|image_size_large" | "settings|appearance|layout_bubbles" | "settings|appearance|layout_irc" | "settings|appearance|match_system_theme" | "settings|appearance|timeline_image_size" | "settings|account|title" | "settings|account|dialog_title" | "settings|sessions|url" | "settings|sessions|title" | "settings|sessions|browser" | "settings|sessions|session_id" | "settings|sessions|dialog_title" | "settings|sessions|sign_out" | "settings|sessions|best_security_note" | "settings|sessions|confirm_sign_out" | "settings|sessions|confirm_sign_out_body" | "settings|sessions|confirm_sign_out_continue" | "settings|sessions|confirm_sign_out_sso" | "settings|sessions|current_session" | "settings|sessions|desktop_session" | "settings|sessions|details_heading" | "settings|sessions|device_unverified_description" | "settings|sessions|device_unverified_description_current" | "settings|sessions|device_verified_description" | "settings|sessions|device_verified_description_current" | "settings|sessions|error_pusher_state" | "settings|sessions|error_set_name" | "settings|sessions|filter_all" | "settings|sessions|filter_inactive" | "settings|sessions|filter_inactive_description" | "settings|sessions|filter_label" | "settings|sessions|filter_unverified_description" | "settings|sessions|filter_verified_description" | "settings|sessions|hide_details" | "settings|sessions|inactive_days" | "settings|sessions|inactive_sessions" | "settings|sessions|inactive_sessions_explainer_1" | "settings|sessions|inactive_sessions_explainer_2" | "settings|sessions|inactive_sessions_list_description" | "settings|sessions|ip" | "settings|sessions|last_activity" | "settings|sessions|mobile_session" | "settings|sessions|n_sessions_selected" | "settings|sessions|no_inactive_sessions" | "settings|sessions|no_sessions" | "settings|sessions|no_unverified_sessions" | "settings|sessions|no_verified_sessions" | "settings|sessions|os" | "settings|sessions|other_sessions_heading" | "settings|sessions|push_heading" | "settings|sessions|push_subheading" | "settings|sessions|push_toggle" | "settings|sessions|rename_form_caption" | "settings|sessions|rename_form_heading" | "settings|sessions|rename_form_learn_more" | "settings|sessions|rename_form_learn_more_description_1" | "settings|sessions|rename_form_learn_more_description_2" | "settings|sessions|security_recommendations" | "settings|sessions|security_recommendations_description" | "settings|sessions|show_details" | "settings|sessions|sign_in_with_qr" | "settings|sessions|sign_in_with_qr_button" | "settings|sessions|sign_in_with_qr_description" | "settings|sessions|sign_out_all_other_sessions" | "settings|sessions|sign_out_confirm_description" | "settings|sessions|sign_out_n_sessions" | "settings|sessions|unknown_session" | "settings|sessions|unverified_session" | "settings|sessions|unverified_session_explainer_1" | "settings|sessions|unverified_session_explainer_2" | "settings|sessions|unverified_session_explainer_3" | "settings|sessions|unverified_sessions" | "settings|sessions|unverified_sessions_explainer_1" | "settings|sessions|unverified_sessions_explainer_2" | "settings|sessions|unverified_sessions_list_description" | "settings|sessions|verified_session" | "settings|sessions|verified_sessions" | "settings|sessions|verified_sessions_explainer_1" | "settings|sessions|verified_sessions_explainer_2" | "settings|sessions|verified_sessions_list_description" | "settings|sessions|verify_session" | "settings|sessions|web_session" | "settings|security|session_id" | "settings|security|session_key" | "settings|security|dialog_title" | "settings|security|4s_public_key_in_account_data" | "settings|security|4s_public_key_status" | "settings|security|analytics_description" | "settings|security|backup_key_cached_status" | "settings|security|backup_key_stored_status" | "settings|security|backup_key_unexpected_type" | "settings|security|backup_key_well_formed" | "settings|security|backup_keys_description" | "settings|security|bulk_options_accept_all_invites" | "settings|security|bulk_options_reject_all_invites" | "settings|security|bulk_options_section" | "settings|security|cross_signing_cached" | "settings|security|cross_signing_homeserver_support" | "settings|security|cross_signing_homeserver_support_exists" | "settings|security|cross_signing_in_4s" | "settings|security|cross_signing_in_memory" | "settings|security|cross_signing_master_private_Key" | "settings|security|cross_signing_not_cached" | "settings|security|cross_signing_not_found" | "settings|security|cross_signing_not_in_4s" | "settings|security|cross_signing_not_stored" | "settings|security|cross_signing_private_keys" | "settings|security|cross_signing_public_keys" | "settings|security|cross_signing_self_signing_private_key" | "settings|security|cross_signing_user_signing_private_key" | "settings|security|cryptography_section" | "settings|security|dehydrated_device_description" | "settings|security|dehydrated_device_enabled" | "settings|security|delete_backup" | "settings|security|delete_backup_confirm_description" | "settings|security|e2ee_default_disabled_warning" | "settings|security|enable_message_search" | "settings|security|encryption_section" | "settings|security|error_loading_key_backup_status" | "settings|security|export_megolm_keys" | "settings|security|ignore_users_empty" | "settings|security|ignore_users_section" | "settings|security|import_megolm_keys" | "settings|security|key_backup_active" | "settings|security|key_backup_active_version" | "settings|security|key_backup_active_version_none" | "settings|security|key_backup_algorithm" | "settings|security|key_backup_can_be_restored" | "settings|security|key_backup_complete" | "settings|security|key_backup_connect" | "settings|security|key_backup_connect_prompt" | "settings|security|key_backup_in_progress" | "settings|security|key_backup_inactive" | "settings|security|key_backup_inactive_warning" | "settings|security|key_backup_latest_version" | "settings|security|message_search_disable_warning" | "settings|security|message_search_disabled" | "settings|security|message_search_enabled" | "settings|security|message_search_failed" | "settings|security|message_search_indexed_messages" | "settings|security|message_search_indexed_rooms" | "settings|security|message_search_indexing" | "settings|security|message_search_indexing_idle" | "settings|security|message_search_intro" | "settings|security|message_search_room_progress" | "settings|security|message_search_section" | "settings|security|message_search_sleep_time" | "settings|security|message_search_space_used" | "settings|security|message_search_unsupported" | "settings|security|message_search_unsupported_web" | "settings|security|record_session_details" | "settings|security|restore_key_backup" | "settings|security|secret_storage_not_ready" | "settings|security|secret_storage_ready" | "settings|security|secret_storage_status" | "settings|security|send_analytics" | "settings|security|strict_encryption" | "settings|voip|title" | "settings|voip|dialog_title" | "settings|voip|allow_p2p" | "settings|voip|allow_p2p_description" | "settings|voip|audio_input_empty" | "settings|voip|audio_output" | "settings|voip|audio_output_empty" | "settings|voip|auto_gain_control" | "settings|voip|connection_section" | "settings|voip|echo_cancellation" | "settings|voip|enable_fallback_ice_server" | "settings|voip|enable_fallback_ice_server_description" | "settings|voip|mirror_local_feed" | "settings|voip|missing_permissions_prompt" | "settings|voip|noise_suppression" | "settings|voip|request_permissions" | "settings|voip|video_input_empty" | "settings|voip|video_section" | "settings|voip|voice_agc" | "settings|voip|voice_processing" | "settings|voip|voice_section" | "settings|labs|dialog_title" | "settings|keyboard|title" | "settings|keyboard|dialog_title" | "settings|labs_mjolnir|dialog_title" | "settings|preferences|dialog_title" | "settings|preferences|Electron.enableHardwareAcceleration" | "settings|preferences|always_show_menu_bar" | "settings|preferences|autocomplete_delay" | "settings|preferences|code_blocks_heading" | "settings|preferences|compact_modern" | "settings|preferences|composer_heading" | "settings|preferences|default_timezone" | "settings|preferences|enable_hardware_acceleration" | "settings|preferences|enable_tray_icon" | "settings|preferences|keyboard_heading" | "settings|preferences|keyboard_view_shortcuts_button" | "settings|preferences|media_heading" | "settings|preferences|presence_description" | "settings|preferences|rm_lifetime" | "settings|preferences|rm_lifetime_offscreen" | "settings|preferences|room_directory_heading" | "settings|preferences|room_list_heading" | "settings|preferences|show_avatars_pills" | "settings|preferences|show_checklist_shortcuts" | "settings|preferences|show_polls_button" | "settings|preferences|surround_text" | "settings|preferences|time_heading" | "settings|preferences|user_timezone" | "settings|general|username" | "settings|general|display_name" | "settings|general|account_management_section" | "settings|general|account_section" | "settings|general|add_email_dialog_title" | "settings|general|add_email_failed_verification" | "settings|general|add_email_instructions" | "settings|general|add_msisdn_confirm_body" | "settings|general|add_msisdn_confirm_button" | "settings|general|add_msisdn_confirm_sso_button" | "settings|general|add_msisdn_dialog_title" | "settings|general|add_msisdn_instructions" | "settings|general|add_msisdn_misconfigured" | "settings|general|allow_spellcheck" | "settings|general|application_language" | "settings|general|application_language_reload_hint" | "settings|general|avatar_remove_progress" | "settings|general|avatar_save_progress" | "settings|general|avatar_upload_error_text" | "settings|general|avatar_upload_error_text_generic" | "settings|general|avatar_upload_error_title" | "settings|general|confirm_adding_email_body" | "settings|general|confirm_adding_email_title" | "settings|general|deactivate_confirm_body" | "settings|general|deactivate_confirm_body_sso" | "settings|general|deactivate_confirm_content" | "settings|general|deactivate_confirm_content_1" | "settings|general|deactivate_confirm_content_2" | "settings|general|deactivate_confirm_content_3" | "settings|general|deactivate_confirm_content_4" | "settings|general|deactivate_confirm_content_5" | "settings|general|deactivate_confirm_content_6" | "settings|general|deactivate_confirm_continue" | "settings|general|deactivate_confirm_erase_label" | "settings|general|deactivate_section" | "settings|general|deactivate_warning" | "settings|general|discovery_email_empty" | "settings|general|discovery_email_verification_instructions" | "settings|general|discovery_msisdn_empty" | "settings|general|discovery_needs_terms" | "settings|general|discovery_needs_terms_title" | "settings|general|display_name_error" | "settings|general|email_address_in_use" | "settings|general|email_address_label" | "settings|general|email_not_verified" | "settings|general|email_verification_instructions" | "settings|general|emails_heading" | "settings|general|error_add_email" | "settings|general|error_deactivate_communication" | "settings|general|error_deactivate_invalid_auth" | "settings|general|error_deactivate_no_auth" | "settings|general|error_email_verification" | "settings|general|error_invalid_email" | "settings|general|error_invalid_email_detail" | "settings|general|error_msisdn_verification" | "settings|general|error_password_change_403" | "settings|general|error_password_change_http" | "settings|general|error_password_change_title" | "settings|general|error_password_change_unknown" | "settings|general|error_remove_3pid" | "settings|general|error_revoke_email_discovery" | "settings|general|error_revoke_msisdn_discovery" | "settings|general|error_share_email_discovery" | "settings|general|error_share_msisdn_discovery" | "settings|general|identity_server_no_token" | "settings|general|identity_server_not_set" | "settings|general|language_section" | "settings|general|msisdn_in_use" | "settings|general|msisdn_label" | "settings|general|msisdn_verification_field_label" | "settings|general|msisdn_verification_instructions" | "settings|general|msisdns_heading" | "settings|general|name_placeholder" | "settings|general|oidc_manage_button" | "settings|general|password_change_section" | "settings|general|password_change_success" | "settings|general|personal_info" | "settings|general|profile_subtitle" | "settings|general|profile_subtitle_oidc" | "settings|general|remove_email_prompt" | "settings|general|remove_msisdn_prompt" | "settings|general|spell_check_locale_placeholder" | "settings|general|unable_to_load_emails" | "settings|general|unable_to_load_msisdns" | "settings|discovery|title" | "settings|key_backup|backup_in_progress" | "settings|key_backup|backup_starting" | "settings|key_backup|backup_success" | "settings|key_backup|cannot_create_backup" | "settings|key_backup|create_title" | "settings|key_backup|setup_secure_backup|description" | "settings|key_backup|setup_secure_backup|backup_setup_success_description" | "settings|key_backup|setup_secure_backup|backup_setup_success_title" | "settings|key_backup|setup_secure_backup|cancel_warning" | "settings|key_backup|setup_secure_backup|confirm_security_phrase" | "settings|key_backup|setup_secure_backup|download_or_copy" | "settings|key_backup|setup_secure_backup|enter_phrase_description" | "settings|key_backup|setup_secure_backup|enter_phrase_title" | "settings|key_backup|setup_secure_backup|enter_phrase_to_confirm" | "settings|key_backup|setup_secure_backup|generate_security_key_description" | "settings|key_backup|setup_secure_backup|generate_security_key_title" | "settings|key_backup|setup_secure_backup|pass_phrase_match_failed" | "settings|key_backup|setup_secure_backup|pass_phrase_match_success" | "settings|key_backup|setup_secure_backup|phrase_strong_enough" | "settings|key_backup|setup_secure_backup|requires_key_restore" | "settings|key_backup|setup_secure_backup|requires_password_confirmation" | "settings|key_backup|setup_secure_backup|requires_server_authentication" | "settings|key_backup|setup_secure_backup|secret_storage_query_failure" | "settings|key_backup|setup_secure_backup|security_key_safety_reminder" | "settings|key_backup|setup_secure_backup|session_upgrade_description" | "settings|key_backup|setup_secure_backup|set_phrase_again" | "settings|key_backup|setup_secure_backup|settings_reminder" | "settings|key_backup|setup_secure_backup|title_confirm_phrase" | "settings|key_backup|setup_secure_backup|title_save_key" | "settings|key_backup|setup_secure_backup|title_set_phrase" | "settings|key_backup|setup_secure_backup|title_upgrade_encryption" | "settings|key_backup|setup_secure_backup|unable_to_setup" | "settings|key_backup|setup_secure_backup|use_different_passphrase" | "settings|key_backup|setup_secure_backup|use_phrase_only_you_know" | "settings|key_export_import|phrase_strong_enough" | "settings|key_export_import|confirm_passphrase" | "settings|key_export_import|enter_passphrase" | "settings|key_export_import|export_description_1" | "settings|key_export_import|export_description_2" | "settings|key_export_import|export_title" | "settings|key_export_import|file_to_import" | "settings|key_export_import|import_description_1" | "settings|key_export_import|import_description_2" | "settings|key_export_import|import_title" | "settings|key_export_import|phrase_cannot_be_empty" | "settings|key_export_import|phrase_must_match" | "settings|sidebar|title" | "settings|sidebar|dialog_title" | "settings|sidebar|metaspaces_favourites_description" | "settings|sidebar|metaspaces_home_all_rooms" | "settings|sidebar|metaspaces_home_all_rooms_description" | "settings|sidebar|metaspaces_home_description" | "settings|sidebar|metaspaces_orphans" | "settings|sidebar|metaspaces_orphans_description" | "settings|sidebar|metaspaces_people_description" | "settings|sidebar|metaspaces_subsection" | "settings|sidebar|metaspaces_video_rooms" | "settings|sidebar|metaspaces_video_rooms_description" | "settings|sidebar|metaspaces_video_rooms_description_invite_extension" | "settings|sidebar|spaces_explainer" | "voip|connecting" | "voip|hangup" | "voip|answered_elsewhere" | "voip|user_busy" | "voip|element_call" | "voip|unsupported_browser" | "voip|video_call_started" | "voip|unsupported" | "voip|video_call" | "voip|voice_call" | "voip|expand" | "voip|maximise" | "voip|already_in_call" | "voip|already_in_call_person" | "voip|answered_elsewhere_description" | "voip|call_failed" | "voip|call_failed_description" | "voip|call_failed_media" | "voip|call_failed_media_applications" | "voip|call_failed_media_connected" | "voip|call_failed_media_permissions" | "voip|call_failed_microphone" | "voip|call_held" | "voip|call_held_resume" | "voip|call_held_switch" | "voip|call_toast_unknown_room" | "voip|camera_disabled" | "voip|camera_enabled" | "voip|cannot_call_yourself_description" | "voip|change_input_device" | "voip|close_lobby" | "voip|connection_lost" | "voip|connection_lost_description" | "voip|consulting" | "voip|default_device" | "voip|dial" | "voip|dialpad" | "voip|disable_camera" | "voip|disable_microphone" | "voip|disabled_no_one_here" | "voip|disabled_no_perms_start_video_call" | "voip|disabled_no_perms_start_voice_call" | "voip|disabled_ongoing_call" | "voip|enable_camera" | "voip|enable_microphone" | "voip|failed_call_live_broadcast_description" | "voip|failed_call_live_broadcast_title" | "voip|get_call_link" | "voip|hide_sidebar_button" | "voip|input_devices" | "voip|jitsi_call" | "voip|join_button_tooltip_call_full" | "voip|join_button_tooltip_connecting" | "voip|legacy_call" | "voip|maximise_call" | "voip|minimise_call" | "voip|misconfigured_server" | "voip|misconfigured_server_description" | "voip|misconfigured_server_fallback" | "voip|misconfigured_server_fallback_accept" | "voip|more_button" | "voip|msisdn_lookup_failed" | "voip|msisdn_lookup_failed_description" | "voip|msisdn_transfer_failed" | "voip|n_people_joined" | "voip|no_audio_input_description" | "voip|no_audio_input_title" | "voip|no_media_perms_description" | "voip|no_media_perms_title" | "voip|no_permission_conference" | "voip|no_permission_conference_description" | "voip|on_hold" | "voip|output_devices" | "voip|screenshare_monitor" | "voip|screenshare_title" | "voip|screenshare_window" | "voip|show_sidebar_button" | "voip|silence" | "voip|silenced" | "voip|start_screenshare" | "voip|stop_screenshare" | "voip|too_many_calls" | "voip|too_many_calls_description" | "voip|transfer_consult_first_label" | "voip|transfer_failed" | "voip|transfer_failed_description" | "voip|unable_to_access_audio_input_description" | "voip|unable_to_access_audio_input_title" | "voip|unable_to_access_media" | "voip|unable_to_access_microphone" | "voip|unknown_caller" | "voip|unknown_person" | "voip|unsilence" | "voip|user_busy_description" | "voip|user_is_presenting" | "voip|video_call_using" | "voip|you_are_presenting" | "voip|metaspace_video_rooms|conference_room_section" | "voice_broadcast|pause" | "voice_broadcast|play" | "voice_broadcast|action" | "voice_broadcast|resume" | "voice_broadcast|live" | "voice_broadcast|failed_generic" | "voice_broadcast|30s_backward" | "voice_broadcast|30s_forward" | "voice_broadcast|buffering" | "voice_broadcast|confirm_listen_affirm" | "voice_broadcast|confirm_listen_description" | "voice_broadcast|confirm_listen_title" | "voice_broadcast|confirm_stop_affirm" | "voice_broadcast|confirm_stop_description" | "voice_broadcast|confirm_stop_title" | "voice_broadcast|connection_error" | "voice_broadcast|failed_already_recording_description" | "voice_broadcast|failed_already_recording_title" | "voice_broadcast|failed_decrypt" | "voice_broadcast|failed_insufficient_permission_description" | "voice_broadcast|failed_insufficient_permission_title" | "voice_broadcast|failed_no_connection_description" | "voice_broadcast|failed_no_connection_title" | "voice_broadcast|failed_others_already_recording_description" | "voice_broadcast|failed_others_already_recording_title" | "voice_broadcast|go_live" | "labs|notifications" | "labs|dehydration" | "labs|voice_broadcast" | "labs|mjolnir" | "labs|ask_to_join" | "labs|jump_to_date" | "labs|allow_screen_share_only_mode" | "labs|automatic_debug_logs" | "labs|automatic_debug_logs_decryption" | "labs|automatic_debug_logs_key_backup" | "labs|beta_description" | "labs|beta_feature" | "labs|beta_feedback_leave_button" | "labs|beta_feedback_title" | "labs|beta_section" | "labs|bridge_state" | "labs|bridge_state_channel" | "labs|bridge_state_creator" | "labs|bridge_state_manager" | "labs|bridge_state_workspace" | "labs|click_for_info" | "labs|currently_experimental" | "labs|custom_themes" | "labs|dynamic_room_predecessors" | "labs|dynamic_room_predecessors_description" | "labs|element_call_video_rooms" | "labs|experimental_description" | "labs|experimental_section" | "labs|feature_disable_call_per_sender_encryption" | "labs|feature_wysiwyg_composer_description" | "labs|group_calls" | "labs|group_developer" | "labs|group_encryption" | "labs|group_experimental" | "labs|group_messaging" | "labs|group_moderation" | "labs|group_profile" | "labs|group_rooms" | "labs|group_spaces" | "labs|group_themes" | "labs|group_threads" | "labs|group_ui" | "labs|group_voip" | "labs|group_widgets" | "labs|hidebold" | "labs|html_topic" | "labs|join_beta" | "labs|join_beta_reload" | "labs|jump_to_date_msc_support" | "labs|latex_maths" | "labs|leave_beta" | "labs|leave_beta_reload" | "labs|location_share_live" | "labs|location_share_live_description" | "labs|msc3531_hide_messages_pending_moderation" | "labs|new_room_decoration_ui" | "labs|new_room_decoration_ui_beta_caption" | "labs|new_room_decoration_ui_beta_title" | "labs|notification_settings" | "labs|notification_settings_beta_caption" | "labs|notification_settings_beta_title" | "labs|oidc_native_flow" | "labs|oidc_native_flow_description" | "labs|pinning" | "labs|release_announcement" | "labs|render_reaction_images" | "labs|render_reaction_images_description" | "labs|report_to_moderators" | "labs|report_to_moderators_description" | "labs|sliding_sync" | "labs|sliding_sync_description" | "labs|sliding_sync_disabled_notice" | "labs|sliding_sync_server_no_support" | "labs|under_active_development" | "labs|unrealiable_e2e" | "labs|video_rooms" | "labs|video_rooms_a_new_way_to_chat" | "labs|video_rooms_always_on_voip_channels" | "labs|video_rooms_beta" | "labs|video_rooms_faq1_answer" | "labs|video_rooms_faq1_question" | "labs|video_rooms_faq2_answer" | "labs|video_rooms_faq2_question" | "labs|video_rooms_feedbackSubheading" | "labs|voice_broadcast_force_small_chunks" | "labs|wysiwyg_composer" | "theme|light_high_contrast" | "theme|match_system" | "a11y|recent_rooms" | "a11y|emoji_picker" | "a11y|user_menu" | "a11y|room_name" | "a11y|jump_first_invite" | "a11y|message_composer" | "a11y|n_unread_messages" | "a11y|n_unread_messages_mentions" | "a11y|room_status_bar" | "a11y|seek_bar_label" | "a11y|unread_messages" | "analytics|learn_more" | "analytics|accept_button" | "analytics|bullet_1" | "analytics|bullet_2" | "analytics|consent_migration" | "analytics|disable_prompt" | "analytics|enable_prompt" | "analytics|privacy_policy" | "analytics|pseudonymous_usage_data" | "analytics|shared_data_heading" | "bug_reporting|title" | "bug_reporting|description" | "bug_reporting|unsupported_browser" | "bug_reporting|additional_context" | "bug_reporting|before_submitting" | "bug_reporting|collecting_information" | "bug_reporting|collecting_logs" | "bug_reporting|create_new_issue" | "bug_reporting|download_logs" | "bug_reporting|downloading_logs" | "bug_reporting|error_empty" | "bug_reporting|failed_send_logs" | "bug_reporting|github_issue" | "bug_reporting|introduction" | "bug_reporting|log_request" | "bug_reporting|logs_sent" | "bug_reporting|matrix_security_issue" | "bug_reporting|preparing_download" | "bug_reporting|preparing_logs" | "bug_reporting|send_logs" | "bug_reporting|submit_debug_logs" | "bug_reporting|textarea_label" | "bug_reporting|thank_you" | "bug_reporting|uploading_logs" | "bug_reporting|waiting_for_server" | "chat_effects|confetti_description" | "chat_effects|confetti_message" | "chat_effects|fireworks_description" | "chat_effects|fireworks_message" | "chat_effects|hearts_description" | "chat_effects|hearts_message" | "chat_effects|rainfall_description" | "chat_effects|rainfall_message" | "chat_effects|snowfall_description" | "chat_effects|snowfall_message" | "chat_effects|spaceinvaders_description" | "chat_effects|spaceinvaders_message" | "composer|placeholder" | "composer|close_sticker_picker" | "composer|edit_composer_label" | "composer|format_bold" | "composer|format_code_block" | "composer|format_decrease_indent" | "composer|format_increase_indent" | "composer|format_inline_code" | "composer|format_insert_link" | "composer|format_italic" | "composer|format_italics" | "composer|format_link" | "composer|format_ordered_list" | "composer|format_strikethrough" | "composer|format_underline" | "composer|format_unordered_list" | "composer|formatting_toolbar_label" | "composer|mode_plain" | "composer|mode_rich_text" | "composer|no_perms_notice" | "composer|placeholder_encrypted" | "composer|placeholder_reply" | "composer|placeholder_reply_encrypted" | "composer|placeholder_thread" | "composer|placeholder_thread_encrypted" | "composer|poll_button" | "composer|poll_button_no_perms_description" | "composer|poll_button_no_perms_title" | "composer|replying_title" | "composer|room_upgraded_link" | "composer|room_upgraded_notice" | "composer|send_button_title" | "composer|send_button_voice_message" | "composer|send_voice_message" | "composer|stop_voice_message" | "composer|voice_message_button" | "composer|autocomplete|@room_description" | "composer|autocomplete|command_a11y" | "composer|autocomplete|command_description" | "composer|autocomplete|emoji_a11y" | "composer|autocomplete|notification_a11y" | "composer|autocomplete|notification_description" | "composer|autocomplete|room_a11y" | "composer|autocomplete|space_a11y" | "composer|autocomplete|user_a11y" | "composer|autocomplete|user_description" | "composer|link_modal|link_field_label" | "composer|link_modal|text_field_label" | "composer|link_modal|title_create" | "composer|link_modal|title_edit" | "create_room|error_title" | "create_room|action_create_room" | "create_room|action_create_video_room" | "create_room|encrypted_video_room_warning" | "create_room|encrypted_warning" | "create_room|encryption_forced" | "create_room|encryption_label" | "create_room|generic_error" | "create_room|join_rule_change_notice" | "create_room|join_rule_invite" | "create_room|join_rule_invite_label" | "create_room|join_rule_knock_label" | "create_room|join_rule_public_label" | "create_room|join_rule_public_parent_space_label" | "create_room|join_rule_restricted" | "create_room|join_rule_restricted_label" | "create_room|name_validation_required" | "create_room|room_visibility_label" | "create_room|title_private_room" | "create_room|title_public_room" | "create_room|title_video_room" | "create_room|topic_label" | "create_room|unfederated" | "create_room|unfederated_label_default_off" | "create_room|unfederated_label_default_on" | "create_room|unsupported_version" | "create_space|label" | "create_space|explainer" | "create_space|private_space" | "create_space|add_details_prompt" | "create_space|add_details_prompt_2" | "create_space|add_existing_rooms_description" | "create_space|add_existing_rooms_heading" | "create_space|address_label" | "create_space|address_placeholder" | "create_space|creating" | "create_space|creating_rooms" | "create_space|done_action" | "create_space|done_action_first_room" | "create_space|failed_create_initial_rooms" | "create_space|failed_invite_users" | "create_space|invite_teammates_by_username" | "create_space|invite_teammates_description" | "create_space|invite_teammates_heading" | "create_space|inviting_users" | "create_space|name_required" | "create_space|personal_space" | "create_space|personal_space_description" | "create_space|private_description" | "create_space|private_heading" | "create_space|private_personal_description" | "create_space|private_personal_heading" | "create_space|private_space_description" | "create_space|public_description" | "create_space|public_heading" | "create_space|search_public_button" | "create_space|setup_rooms_community_description" | "create_space|setup_rooms_community_heading" | "create_space|setup_rooms_description" | "create_space|setup_rooms_private_description" | "create_space|setup_rooms_private_heading" | "create_space|share_description" | "create_space|share_heading" | "create_space|skip_action" | "create_space|subspace_adding" | "create_space|subspace_beta_notice" | "create_space|subspace_dropdown_title" | "create_space|subspace_existing_space_prompt" | "create_space|subspace_join_rule_invite_description" | "create_space|subspace_join_rule_invite_only" | "create_space|subspace_join_rule_label" | "create_space|subspace_join_rule_public_description" | "create_space|subspace_join_rule_restricted_description" | "credits|default_cover_photo" | "credits|twemoji" | "credits|twemoji_colr" | "devtools|id" | "devtools|value" | "devtools|title" | "devtools|timeout" | "devtools|state_key" | "devtools|room_id" | "devtools|event_id" | "devtools|event_type" | "devtools|methods" | "devtools|phase" | "devtools|spaces" | "devtools|toolbox" | "devtools|event_content" | "devtools|active_widgets" | "devtools|category_other" | "devtools|category_room" | "devtools|caution_colon" | "devtools|client_versions" | "devtools|developer_mode" | "devtools|developer_tools" | "devtools|edit_setting" | "devtools|edit_values" | "devtools|empty_string" | "devtools|event_sent" | "devtools|explore_account_data" | "devtools|explore_room_account_data" | "devtools|explore_room_state" | "devtools|failed_to_find_widget" | "devtools|failed_to_load" | "devtools|failed_to_save" | "devtools|failed_to_send" | "devtools|invalid_json" | "devtools|level" | "devtools|low_bandwidth_mode" | "devtools|low_bandwidth_mode_description" | "devtools|main_timeline" | "devtools|no_receipt_found" | "devtools|no_verification_requests_found" | "devtools|notification_state" | "devtools|notifications_debug" | "devtools|number_of_users" | "devtools|original_event_source" | "devtools|other_user" | "devtools|phase_cancelled" | "devtools|phase_ready" | "devtools|phase_requested" | "devtools|phase_started" | "devtools|phase_transaction" | "devtools|room_encrypted" | "devtools|room_not_encrypted" | "devtools|room_notifications_dot" | "devtools|room_notifications_highlight" | "devtools|room_notifications_last_event" | "devtools|room_notifications_sender" | "devtools|room_notifications_thread_id" | "devtools|room_notifications_total" | "devtools|room_notifications_type" | "devtools|room_status" | "devtools|room_unread_status_count" | "devtools|save_setting_values" | "devtools|see_history" | "devtools|send_custom_account_data_event" | "devtools|send_custom_room_account_data_event" | "devtools|send_custom_state_event" | "devtools|send_custom_timeline_event" | "devtools|server_info" | "devtools|server_versions" | "devtools|settable_global" | "devtools|settable_room" | "devtools|setting_colon" | "devtools|setting_definition" | "devtools|setting_id" | "devtools|settings_explorer" | "devtools|show_hidden_events" | "devtools|thread_root_id" | "devtools|threads_timeline" | "devtools|timeout_none" | "devtools|toggle_event" | "devtools|use_at_own_risk" | "devtools|user_read_up_to" | "devtools|user_read_up_to_ignore_synthetic" | "devtools|user_read_up_to_private" | "devtools|user_read_up_to_private_ignore_synthetic" | "devtools|value_colon" | "devtools|value_in_this_room" | "devtools|value_this_room_colon" | "devtools|values_explicit" | "devtools|values_explicit_colon" | "devtools|values_explicit_room" | "devtools|values_explicit_this_room_colon" | "devtools|verification_explorer" | "devtools|view_servers_in_room" | "devtools|view_source_decrypted_event_source" | "devtools|view_source_decrypted_event_source_unavailable" | "devtools|widget_screenshots" | "emoji_picker|cancel_search_label" | "error_database_closed_description|for_desktop" | "error_database_closed_description|for_web" | "error_dialog|error_loading_user_profile" | "error_dialog|forget_room_failed" | "error_dialog|copy_room_link_failed|title" | "error_dialog|copy_room_link_failed|description" | "error_dialog|search_failed|title" | "error_dialog|search_failed|server_unavailable" | "event_preview|m.sticker" | "event_preview|m.text" | "event_preview|m.emote" | "event_preview|io.element.voice_broadcast_info|user" | "event_preview|io.element.voice_broadcast_info|you" | "event_preview|m.reaction|user" | "event_preview|m.reaction|you" | "event_preview|m.call.invite|user" | "event_preview|m.call.invite|you" | "event_preview|m.call.invite|dm_receive" | "event_preview|m.call.invite|dm_send" | "event_preview|m.call.answer|user" | "event_preview|m.call.answer|you" | "event_preview|m.call.answer|dm" | "event_preview|m.call.hangup|user" | "event_preview|m.call.hangup|you" | "export_chat|html" | "export_chat|title" | "export_chat|text" | "export_chat|json" | "export_chat|messages" | "export_chat|format" | "export_chat|cancelled" | "export_chat|topic" | "export_chat|cancelled_detail" | "export_chat|confirm_stop" | "export_chat|creating_html" | "export_chat|creating_output" | "export_chat|creator_summary" | "export_chat|current_timeline" | "export_chat|enter_number_between_min_max" | "export_chat|error_fetching_file" | "export_chat|export_info" | "export_chat|export_successful" | "export_chat|exported_n_events_in_time" | "export_chat|exporting_your_data" | "export_chat|fetched_n_events" | "export_chat|fetched_n_events_in_time" | "export_chat|fetched_n_events_with_total" | "export_chat|fetching_events" | "export_chat|file_attached" | "export_chat|from_the_beginning" | "export_chat|generating_zip" | "export_chat|html_title" | "export_chat|include_attachments" | "export_chat|media_omitted" | "export_chat|media_omitted_file_size" | "export_chat|next_page" | "export_chat|num_messages" | "export_chat|num_messages_min_max" | "export_chat|number_of_messages" | "export_chat|previous_page" | "export_chat|processing" | "export_chat|processing_event_n" | "export_chat|select_option" | "export_chat|size_limit" | "export_chat|size_limit_min_max" | "export_chat|size_limit_postfix" | "export_chat|starting_export" | "export_chat|successful" | "export_chat|successful_detail" | "export_chat|unload_confirm" | "file_panel|empty_description" | "file_panel|empty_heading" | "file_panel|guest_note" | "file_panel|peek_note" | "identity_server|url" | "identity_server|change" | "identity_server|checking" | "identity_server|disconnect" | "identity_server|error_invalid" | "identity_server|suggestions" | "identity_server|change_prompt" | "identity_server|change_server_prompt" | "identity_server|description_connected" | "identity_server|description_disconnected" | "identity_server|description_optional" | "identity_server|disconnect_anyway" | "identity_server|disconnect_offline_warning" | "identity_server|disconnect_personal_data_warning_1" | "identity_server|disconnect_personal_data_warning_2" | "identity_server|disconnect_server" | "identity_server|disconnect_warning" | "identity_server|do_not_use" | "identity_server|error_connection" | "identity_server|error_invalid_or_terms" | "identity_server|no_terms" | "identity_server|suggestions_1" | "identity_server|suggestions_2" | "identity_server|suggestions_3" | "identity_server|url_field_label" | "identity_server|url_not_https" | "integration_manager|connecting" | "integration_manager|explainer" | "integration_manager|error_connecting" | "integration_manager|error_connecting_heading" | "integration_manager|manage_title" | "integration_manager|use_im" | "integration_manager|use_im_default" | "integrations|disabled_dialog_description" | "integrations|disabled_dialog_title" | "integrations|impossible_dialog_description" | "integrations|impossible_dialog_title" | "keyboard|number" | "keyboard|search" | "keyboard|shift" | "keyboard|end" | "keyboard|home" | "keyboard|enter" | "keyboard|space" | "keyboard|alt" | "keyboard|control" | "keyboard|toggle_space_panel" | "keyboard|upload_file" | "keyboard|activate_button" | "keyboard|autocomplete_cancel" | "keyboard|autocomplete_force" | "keyboard|autocomplete_navigate_next" | "keyboard|autocomplete_navigate_prev" | "keyboard|backspace" | "keyboard|cancel_reply" | "keyboard|category_autocomplete" | "keyboard|category_calls" | "keyboard|category_navigation" | "keyboard|category_room_list" | "keyboard|close_dialog_menu" | "keyboard|composer_jump_end" | "keyboard|composer_jump_start" | "keyboard|composer_navigate_next_history" | "keyboard|composer_navigate_prev_history" | "keyboard|composer_new_line" | "keyboard|composer_redo" | "keyboard|composer_toggle_bold" | "keyboard|composer_toggle_code_block" | "keyboard|composer_toggle_italics" | "keyboard|composer_toggle_link" | "keyboard|composer_toggle_quote" | "keyboard|composer_undo" | "keyboard|dismiss_read_marker_and_jump_bottom" | "keyboard|escape" | "keyboard|go_home_view" | "keyboard|jump_first_message" | "keyboard|jump_last_message" | "keyboard|jump_room_search" | "keyboard|jump_to_read_marker" | "keyboard|keyboard_shortcuts_tab" | "keyboard|navigate_next_history" | "keyboard|navigate_next_message_edit" | "keyboard|navigate_prev_history" | "keyboard|navigate_prev_message_edit" | "keyboard|next_landmark" | "keyboard|next_room" | "keyboard|next_unread_room" | "keyboard|open_user_settings" | "keyboard|page_down" | "keyboard|page_up" | "keyboard|prev_landmark" | "keyboard|prev_room" | "keyboard|prev_unread_room" | "keyboard|room_list_collapse_section" | "keyboard|room_list_expand_section" | "keyboard|room_list_navigate_down" | "keyboard|room_list_navigate_up" | "keyboard|room_list_select_room" | "keyboard|scroll_down_timeline" | "keyboard|scroll_up_timeline" | "keyboard|send_sticker" | "keyboard|switch_to_space" | "keyboard|toggle_hidden_events" | "keyboard|toggle_microphone_mute" | "keyboard|toggle_right_panel" | "keyboard|toggle_top_left_menu" | "keyboard|toggle_webcam_mute" | "labs_mjolnir|title" | "labs_mjolnir|something_went_wrong" | "labs_mjolnir|ban_reason" | "labs_mjolnir|room_name" | "labs_mjolnir|advanced_warning" | "labs_mjolnir|error_adding_ignore" | "labs_mjolnir|error_adding_list_description" | "labs_mjolnir|error_adding_list_title" | "labs_mjolnir|error_removing_ignore" | "labs_mjolnir|error_removing_list_description" | "labs_mjolnir|error_removing_list_title" | "labs_mjolnir|explainer_1" | "labs_mjolnir|explainer_2" | "labs_mjolnir|lists" | "labs_mjolnir|lists_description_1" | "labs_mjolnir|lists_description_2" | "labs_mjolnir|lists_heading" | "labs_mjolnir|lists_new_label" | "labs_mjolnir|no_lists" | "labs_mjolnir|personal_description" | "labs_mjolnir|personal_empty" | "labs_mjolnir|personal_heading" | "labs_mjolnir|personal_new_label" | "labs_mjolnir|personal_new_placeholder" | "labs_mjolnir|personal_section" | "labs_mjolnir|room_topic" | "labs_mjolnir|rules_empty" | "labs_mjolnir|rules_server" | "labs_mjolnir|rules_title" | "labs_mjolnir|rules_user" | "labs_mjolnir|view_rules" | "leave_room_dialog|last_person_warning" | "leave_room_dialog|leave_room_question" | "leave_room_dialog|leave_space_question" | "leave_room_dialog|room_leave_admin_warning" | "leave_room_dialog|room_leave_mod_warning" | "leave_room_dialog|room_rejoin_warning" | "leave_room_dialog|space_rejoin_warning" | "left_panel|open_dial_pad" | "lightbox|title" | "lightbox|rotate_left" | "lightbox|rotate_right" | "location_sharing|failed_generic" | "location_sharing|MapStyleUrlNotConfigured" | "location_sharing|MapStyleUrlNotReachable" | "location_sharing|WebGLNotEnabled" | "location_sharing|click_drop_pin" | "location_sharing|click_move_pin" | "location_sharing|close_sidebar" | "location_sharing|error_fetch_location" | "location_sharing|error_no_perms_description" | "location_sharing|error_no_perms_title" | "location_sharing|error_send_description" | "location_sharing|error_send_title" | "location_sharing|error_sharing_live_location" | "location_sharing|error_sharing_live_location_try_again" | "location_sharing|error_stopping_live_location" | "location_sharing|error_stopping_live_location_try_again" | "location_sharing|expand_map" | "location_sharing|failed_load_map" | "location_sharing|failed_permission" | "location_sharing|failed_timeout" | "location_sharing|failed_unknown" | "location_sharing|find_my_location" | "location_sharing|live_description" | "location_sharing|live_enable_description" | "location_sharing|live_enable_heading" | "location_sharing|live_location_active" | "location_sharing|live_location_enabled" | "location_sharing|live_location_ended" | "location_sharing|live_location_error" | "location_sharing|live_locations_empty" | "location_sharing|live_share_button" | "location_sharing|live_toggle_label" | "location_sharing|live_until" | "location_sharing|live_update_time" | "location_sharing|loading_live_location" | "location_sharing|location_not_available" | "location_sharing|map_feedback" | "location_sharing|mapbox_logo" | "location_sharing|reset_bearing" | "location_sharing|share_button" | "location_sharing|share_type_live" | "location_sharing|share_type_own" | "location_sharing|share_type_pin" | "location_sharing|share_type_prompt" | "location_sharing|stop_and_close" | "location_sharing|toggle_attribution" | "member_list|filter_placeholder" | "member_list|invite_button_no_perms_tooltip" | "member_list|invited_list_heading" | "member_list|power_label" | "mobile_guide|toast_description" | "mobile_guide|toast_title" | "mobile_guide|toast_accept" | "notif_panel|empty_description" | "notif_panel|empty_heading" | "notifier|io.element.voice_broadcast_chunk" | "notifier|m.key.verification.request" | "onboarding|create_room" | "onboarding|explore_rooms" | "onboarding|no_avatar_label" | "onboarding|apple_trademarks" | "onboarding|community_messaging_action" | "onboarding|community_messaging_description" | "onboarding|community_messaging_title" | "onboarding|complete_these" | "onboarding|download_app" | "onboarding|download_app_action" | "onboarding|download_app_description" | "onboarding|download_app_store" | "onboarding|download_brand" | "onboarding|download_brand_desktop" | "onboarding|download_f_droid" | "onboarding|download_google_play" | "onboarding|enable_notifications" | "onboarding|enable_notifications_action" | "onboarding|enable_notifications_description" | "onboarding|find_community_members" | "onboarding|find_coworkers" | "onboarding|find_friends" | "onboarding|find_friends_action" | "onboarding|find_friends_description" | "onboarding|find_people" | "onboarding|free_e2ee_messaging_unlimited_voip" | "onboarding|get_stuff_done" | "onboarding|google_trademarks" | "onboarding|has_avatar_label" | "onboarding|intro_byline" | "onboarding|intro_welcome" | "onboarding|only_n_steps_to_go" | "onboarding|personal_messaging_action" | "onboarding|personal_messaging_title" | "onboarding|qr_or_app_links" | "onboarding|send_dm" | "onboarding|set_up_profile" | "onboarding|set_up_profile_action" | "onboarding|set_up_profile_description" | "onboarding|use_case_community_messaging" | "onboarding|use_case_heading1" | "onboarding|use_case_heading2" | "onboarding|use_case_heading3" | "onboarding|use_case_personal_messaging" | "onboarding|use_case_work_messaging" | "onboarding|welcome_detail" | "onboarding|welcome_to_brand" | "onboarding|welcome_user" | "onboarding|work_messaging_action" | "onboarding|work_messaging_title" | "onboarding|you_did_it" | "onboarding|you_made_it" | "pill|permalink_other_room" | "pill|permalink_this_room" | "poll|topic_label" | "poll|create_poll_action" | "poll|create_poll_title" | "poll|disclosed_notes" | "poll|edit_poll_title" | "poll|end_description" | "poll|end_message" | "poll|end_message_no_votes" | "poll|end_title" | "poll|error_ending_description" | "poll|error_ending_title" | "poll|error_voting_description" | "poll|error_voting_title" | "poll|failed_send_poll_description" | "poll|failed_send_poll_title" | "poll|notes" | "poll|options_add_button" | "poll|options_heading" | "poll|options_label" | "poll|options_placeholder" | "poll|topic_heading" | "poll|topic_placeholder" | "poll|total_decryption_errors" | "poll|total_n_votes" | "poll|total_n_votes_voted" | "poll|total_no_votes" | "poll|total_not_ended" | "poll|type_closed" | "poll|type_heading" | "poll|type_open" | "poll|unable_edit_description" | "poll|unable_edit_title" | "power_level|default" | "power_level|custom" | "power_level|label" | "power_level|restricted" | "power_level|admin" | "power_level|custom_level" | "power_level|mod" | "power_level|moderator" | "quick_settings|title" | "quick_settings|all_settings" | "quick_settings|metaspace_section" | "quick_settings|sidebar_settings" | "quit_warning|call_in_progress" | "quit_warning|file_upload_in_progress" | "reject_invitation_dialog|failed" | "reject_invitation_dialog|title" | "reject_invitation_dialog|confirmation" | "report_content|description" | "report_content|disagree" | "report_content|error_create_room_moderation_bot" | "report_content|hide_messages_from_user" | "report_content|ignore_user" | "report_content|illegal_content" | "report_content|missing_reason" | "report_content|nature" | "report_content|nature_disagreement" | "report_content|nature_illegal" | "report_content|nature_nonstandard_admin" | "report_content|nature_nonstandard_admin_encrypted" | "report_content|nature_other" | "report_content|nature_spam" | "report_content|nature_toxic" | "report_content|other_label" | "report_content|report_content_to_homeserver" | "report_content|report_entire_room" | "report_content|spam_or_propaganda" | "report_content|toxic_behaviour" | "restore_key_backup_dialog|enter_phrase_description" | "restore_key_backup_dialog|enter_phrase_title" | "restore_key_backup_dialog|count_of_decryption_failures" | "restore_key_backup_dialog|count_of_successfully_restored_keys" | "restore_key_backup_dialog|enter_key_description" | "restore_key_backup_dialog|enter_key_title" | "restore_key_backup_dialog|incorrect_security_phrase_dialog" | "restore_key_backup_dialog|incorrect_security_phrase_title" | "restore_key_backup_dialog|key_backup_warning" | "restore_key_backup_dialog|key_fetch_in_progress" | "restore_key_backup_dialog|key_forgotten_text" | "restore_key_backup_dialog|key_is_invalid" | "restore_key_backup_dialog|key_is_valid" | "restore_key_backup_dialog|keys_restored_title" | "restore_key_backup_dialog|load_error_content" | "restore_key_backup_dialog|load_keys_progress" | "restore_key_backup_dialog|no_backup_error" | "restore_key_backup_dialog|phrase_forgotten_text" | "restore_key_backup_dialog|recovery_key_mismatch_description" | "restore_key_backup_dialog|recovery_key_mismatch_title" | "restore_key_backup_dialog|restore_failed_error" | "right_panel|info" | "right_panel|add_integrations" | "right_panel|add_topic" | "right_panel|export_chat_button" | "right_panel|extensions_empty_description" | "right_panel|extensions_empty_title" | "right_panel|files_button" | "right_panel|pinned_messages_button" | "right_panel|polls_button" | "right_panel|widgets_section" | "right_panel|poll|loading" | "right_panel|poll|active_heading" | "right_panel|poll|empty_active" | "right_panel|poll|empty_active_load_more" | "right_panel|poll|empty_active_load_more_n_days" | "right_panel|poll|empty_past" | "right_panel|poll|empty_past_load_more" | "right_panel|poll|empty_past_load_more_n_days" | "right_panel|poll|final_result" | "right_panel|poll|load_more" | "right_panel|poll|past_heading" | "right_panel|poll|view_in_timeline" | "right_panel|poll|view_poll" | "right_panel|pinned_messages|view" | "right_panel|pinned_messages|header" | "right_panel|pinned_messages|menu" | "right_panel|pinned_messages|title" | "right_panel|pinned_messages|empty_description" | "right_panel|pinned_messages|empty_title" | "right_panel|pinned_messages|limits" | "right_panel|pinned_messages|reply_thread" | "right_panel|pinned_messages|unpin_all|button" | "right_panel|pinned_messages|unpin_all|content" | "right_panel|pinned_messages|unpin_all|title" | "right_panel|room_summary_card|title" | "right_panel|thread_list|context_menu_label" | "right_panel|video_room_chat|title" | "room_list|show_n_more" | "room_list|add_room_label" | "room_list|add_space_label" | "room_list|breadcrumbs_empty" | "room_list|breadcrumbs_label" | "room_list|failed_add_tag" | "room_list|failed_remove_tag" | "room_list|failed_set_dm_tag" | "room_list|home_menu_label" | "room_list|join_public_room_label" | "room_list|joining_rooms_status" | "room_list|notification_options" | "room_list|redacting_messages_status" | "room_list|show_less" | "room_list|show_previews" | "room_list|sort_by" | "room_list|sort_by_activity" | "room_list|sort_by_alphabet" | "room_list|sort_unread_first" | "room_list|space_menu_label" | "room_list|sublist_options" | "room_list|suggested_rooms_heading" | "room_settings|title" | "room_settings|security|strict_encryption" | "room_settings|alias_not_specified" | "room_settings|delete_avatar_label" | "room_settings|upload_avatar_label" | "room_settings|advanced|room_id" | "room_settings|advanced|room_version" | "room_settings|advanced|unfederated" | "room_settings|advanced|error_upgrade_description" | "room_settings|advanced|error_upgrade_title" | "room_settings|advanced|information_section_room" | "room_settings|advanced|information_section_space" | "room_settings|advanced|room_predecessor" | "room_settings|advanced|room_upgrade_button" | "room_settings|advanced|room_upgrade_warning" | "room_settings|advanced|room_version_section" | "room_settings|advanced|space_predecessor" | "room_settings|advanced|space_upgrade_button" | "room_settings|advanced|upgrade_button" | "room_settings|advanced|upgrade_dialog_description" | "room_settings|advanced|upgrade_dialog_description_1" | "room_settings|advanced|upgrade_dialog_description_2" | "room_settings|advanced|upgrade_dialog_description_3" | "room_settings|advanced|upgrade_dialog_description_4" | "room_settings|advanced|upgrade_dialog_title" | "room_settings|advanced|upgrade_dwarning_ialog_title_public" | "room_settings|advanced|upgrade_warning_dialog_description" | "room_settings|advanced|upgrade_warning_dialog_explainer" | "room_settings|advanced|upgrade_warning_dialog_footer" | "room_settings|advanced|upgrade_warning_dialog_invite_label" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt_link" | "room_settings|advanced|upgrade_warning_dialog_title" | "room_settings|advanced|upgrade_warning_dialog_title_private" | "room_settings|notifications|browse_button" | "room_settings|notifications|custom_sound_prompt" | "room_settings|notifications|notification_sound" | "room_settings|notifications|settings_link" | "room_settings|notifications|sounds_section" | "room_settings|notifications|upload_sound_label" | "room_settings|notifications|uploaded_sound" | "room_settings|visibility|title" | "room_settings|visibility|alias_section" | "room_settings|visibility|error_failed_save" | "room_settings|visibility|error_update_guest_access" | "room_settings|visibility|error_update_history_visibility" | "room_settings|visibility|guest_access_explainer" | "room_settings|visibility|guest_access_explainer_public_space" | "room_settings|visibility|guest_access_label" | "room_settings|visibility|history_visibility_anyone_space" | "room_settings|visibility|history_visibility_anyone_space_description" | "room_settings|visibility|history_visibility_anyone_space_recommendation" | "room_settings|security|title" | "room_settings|security|encryption_forced" | "room_settings|security|join_rule_invite" | "room_settings|security|join_rule_restricted" | "room_settings|security|enable_encryption_confirm_description" | "room_settings|security|enable_encryption_confirm_title" | "room_settings|security|enable_encryption_public_room_confirm_description_1" | "room_settings|security|enable_encryption_public_room_confirm_description_2" | "room_settings|security|enable_encryption_public_room_confirm_title" | "room_settings|security|encrypted_room_public_confirm_description_1" | "room_settings|security|encrypted_room_public_confirm_description_2" | "room_settings|security|encrypted_room_public_confirm_title" | "room_settings|security|encryption_permanent" | "room_settings|security|error_join_rule_change_title" | "room_settings|security|error_join_rule_change_unknown" | "room_settings|security|guest_access_warning" | "room_settings|security|history_visibility_invited" | "room_settings|security|history_visibility_joined" | "room_settings|security|history_visibility_legend" | "room_settings|security|history_visibility_shared" | "room_settings|security|history_visibility_warning" | "room_settings|security|history_visibility_world_readable" | "room_settings|security|join_rule_description" | "room_settings|security|join_rule_invite_description" | "room_settings|security|join_rule_knock" | "room_settings|security|join_rule_knock_description" | "room_settings|security|join_rule_public_description" | "room_settings|security|join_rule_restricted_description" | "room_settings|security|join_rule_restricted_description_active_space" | "room_settings|security|join_rule_restricted_description_prompt" | "room_settings|security|join_rule_restricted_description_spaces" | "room_settings|security|join_rule_restricted_dialog_description" | "room_settings|security|join_rule_restricted_dialog_empty_warning" | "room_settings|security|join_rule_restricted_dialog_filter_placeholder" | "room_settings|security|join_rule_restricted_dialog_heading_known" | "room_settings|security|join_rule_restricted_dialog_heading_other" | "room_settings|security|join_rule_restricted_dialog_heading_room" | "room_settings|security|join_rule_restricted_dialog_heading_space" | "room_settings|security|join_rule_restricted_dialog_heading_unknown" | "room_settings|security|join_rule_restricted_dialog_title" | "room_settings|security|join_rule_restricted_n_more" | "room_settings|security|join_rule_restricted_summary" | "room_settings|security|join_rule_restricted_upgrade_description" | "room_settings|security|join_rule_restricted_upgrade_warning" | "room_settings|security|join_rule_upgrade_awaiting_room" | "room_settings|security|join_rule_upgrade_required" | "room_settings|security|join_rule_upgrade_sending_invites" | "room_settings|security|join_rule_upgrade_updating_spaces" | "room_settings|security|join_rule_upgrade_upgrading_room" | "room_settings|security|public_without_alias_warning" | "room_settings|security|publish_room" | "room_settings|security|publish_space" | "room_settings|voip|call_type_section" | "room_settings|voip|enable_element_call_caption" | "room_settings|voip|enable_element_call_label" | "room_settings|voip|enable_element_call_no_permissions_tooltip" | "room_settings|general|save" | "room_settings|general|other_section" | "room_settings|general|alias_field_has_domain_invalid" | "room_settings|general|alias_field_has_localpart_invalid" | "room_settings|general|alias_field_matches_invalid" | "room_settings|general|alias_field_placeholder_default" | "room_settings|general|alias_field_required_invalid" | "room_settings|general|alias_field_safe_localpart_invalid" | "room_settings|general|alias_field_taken_invalid" | "room_settings|general|alias_field_taken_invalid_domain" | "room_settings|general|alias_field_taken_valid" | "room_settings|general|alias_heading" | "room_settings|general|aliases_items_label" | "room_settings|general|aliases_no_items_label" | "room_settings|general|aliases_section" | "room_settings|general|avatar_field_label" | "room_settings|general|canonical_alias_field_label" | "room_settings|general|default_url_previews_off" | "room_settings|general|default_url_previews_on" | "room_settings|general|description_space" | "room_settings|general|error_creating_alias_description" | "room_settings|general|error_creating_alias_title" | "room_settings|general|error_deleting_alias_description" | "room_settings|general|error_deleting_alias_description_forbidden" | "room_settings|general|error_deleting_alias_title" | "room_settings|general|error_save_space_settings" | "room_settings|general|error_updating_alias_description" | "room_settings|general|error_updating_canonical_alias_description" | "room_settings|general|error_updating_canonical_alias_title" | "room_settings|general|leave_space" | "room_settings|general|local_alias_field_label" | "room_settings|general|local_aliases_explainer_room" | "room_settings|general|local_aliases_explainer_space" | "room_settings|general|local_aliases_section" | "room_settings|general|name_field_label" | "room_settings|general|new_alias_placeholder" | "room_settings|general|no_aliases_room" | "room_settings|general|no_aliases_space" | "room_settings|general|publish_toggle" | "room_settings|general|published_aliases_description" | "room_settings|general|published_aliases_explainer_room" | "room_settings|general|published_aliases_explainer_space" | "room_settings|general|published_aliases_section" | "room_settings|general|topic_field_label" | "room_settings|general|url_preview_encryption_warning" | "room_settings|general|url_preview_explainer" | "room_settings|general|url_previews_section" | "room_settings|general|user_url_previews_default_off" | "room_settings|general|user_url_previews_default_on" | "room_settings|people|knock_empty" | "room_settings|people|knock_section" | "room_settings|people|see_less" | "room_settings|people|see_more" | "room_settings|access|title" | "room_settings|access|description_space" | "room_settings|bridges|title" | "room_settings|bridges|description" | "room_settings|bridges|empty" | "room_settings|permissions|title" | "room_settings|permissions|m.widget" | "room_settings|permissions|invite" | "room_settings|permissions|ban" | "room_settings|permissions|users_default" | "room_settings|permissions|events_default" | "room_settings|permissions|state_default" | "room_settings|permissions|kick" | "room_settings|permissions|redact" | "room_settings|permissions|m.room.history_visibility" | "room_settings|permissions|io.element.voice_broadcast_info" | "room_settings|permissions|m.reaction" | "room_settings|permissions|m.room.power_levels" | "room_settings|permissions|m.call" | "room_settings|permissions|m.room.canonical_alias" | "room_settings|permissions|m.room.name" | "room_settings|permissions|m.room.topic" | "room_settings|permissions|m.room.avatar" | "room_settings|permissions|m.room.pinned_events" | "room_settings|permissions|m.room.encryption" | "room_settings|permissions|m.room.server_acl" | "room_settings|permissions|m.room.tombstone" | "room_settings|permissions|m.space.child" | "room_settings|permissions|m.room.redaction" | "room_settings|permissions|ban_reason" | "room_settings|permissions|banned_by" | "room_settings|permissions|add_privileged_user_description" | "room_settings|permissions|add_privileged_user_filter_placeholder" | "room_settings|permissions|add_privileged_user_heading" | "room_settings|permissions|banned_users_section" | "room_settings|permissions|error_changing_pl_description" | "room_settings|permissions|error_changing_pl_reqs_description" | "room_settings|permissions|error_changing_pl_reqs_title" | "room_settings|permissions|error_changing_pl_title" | "room_settings|permissions|error_unbanning" | "room_settings|permissions|m.call.member" | "room_settings|permissions|m.room.avatar_space" | "room_settings|permissions|m.room.canonical_alias_space" | "room_settings|permissions|m.room.name_space" | "room_settings|permissions|m.room.topic_space" | "room_settings|permissions|muted_users_section" | "room_settings|permissions|no_privileged_users" | "room_settings|permissions|notifications.room" | "room_settings|permissions|permissions_section" | "room_settings|permissions|permissions_section_description_room" | "room_settings|permissions|permissions_section_description_space" | "room_settings|permissions|privileged_users_section" | "room_settings|permissions|send_event_type" | "scalar|error_create" | "scalar|error_membership" | "scalar|error_missing_room_id" | "scalar|error_missing_room_id_request" | "scalar|error_missing_user_id_request" | "scalar|error_permission" | "scalar|error_power_level_invalid" | "scalar|error_room_not_visible" | "scalar|error_room_unknown" | "scalar|error_send_request" | "scalar|failed_read_event" | "scalar|failed_send_event" | "server_offline|title" | "server_offline|description" | "server_offline|description_1" | "server_offline|description_2" | "server_offline|description_3" | "server_offline|description_4" | "server_offline|description_5" | "server_offline|description_6" | "server_offline|description_7" | "server_offline|description_8" | "server_offline|empty_timeline" | "server_offline|recent_changes_heading" | "seshat|reset_title" | "seshat|error_initialising" | "seshat|reset_button" | "seshat|reset_description" | "seshat|reset_explainer" | "seshat|warning_kind_files" | "seshat|warning_kind_files_app" | "seshat|warning_kind_search" | "seshat|warning_kind_search_app" | "setting|help_about|title" | "setting|help_about|versions" | "setting|help_about|identity_server" | "setting|help_about|dialog_title" | "setting|help_about|homeserver" | "setting|help_about|access_token_detail" | "setting|help_about|brand_version" | "setting|help_about|clear_cache_reload" | "setting|help_about|crypto_version" | "setting|help_about|help_link" | "share|link_title" | "share|permalink_message" | "share|permalink_most_recent" | "share|share_call" | "share|share_call_subtitle" | "share|title_link" | "share|title_message" | "share|title_room" | "share|title_user" | "slash_command|join" | "slash_command|view" | "slash_command|remove" | "slash_command|verify" | "slash_command|html" | "slash_command|query" | "slash_command|invite" | "slash_command|ban" | "slash_command|ignore" | "slash_command|topic" | "slash_command|help" | "slash_command|devtools" | "slash_command|unban" | "slash_command|unignore" | "slash_command|category_other" | "slash_command|addwidget" | "slash_command|addwidget_iframe_missing_src" | "slash_command|addwidget_invalid_protocol" | "slash_command|addwidget_missing_url" | "slash_command|addwidget_no_permissions" | "slash_command|category_actions" | "slash_command|category_admin" | "slash_command|category_advanced" | "slash_command|category_effects" | "slash_command|category_messages" | "slash_command|command_error" | "slash_command|converttodm" | "slash_command|converttoroom" | "slash_command|could_not_find_room" | "slash_command|deop" | "slash_command|discardsession" | "slash_command|error_invalid_rendering_type" | "slash_command|error_invalid_room" | "slash_command|error_invalid_runfn" | "slash_command|error_invalid_user_in_room" | "slash_command|help_dialog_title" | "slash_command|holdcall" | "slash_command|ignore_dialog_description" | "slash_command|ignore_dialog_title" | "slash_command|invite_3pid_needs_is_error" | "slash_command|invite_3pid_use_default_is_title" | "slash_command|invite_3pid_use_default_is_title_description" | "slash_command|invite_failed" | "slash_command|jumptodate" | "slash_command|jumptodate_invalid_input" | "slash_command|lenny" | "slash_command|me" | "slash_command|msg" | "slash_command|myavatar" | "slash_command|myroomavatar" | "slash_command|myroomnick" | "slash_command|nick" | "slash_command|no_active_call" | "slash_command|op" | "slash_command|part_unknown_alias" | "slash_command|plain" | "slash_command|query_not_found_phone_number" | "slash_command|rageshake" | "slash_command|rainbow" | "slash_command|rainbowme" | "slash_command|remakeolm" | "slash_command|roomavatar" | "slash_command|roomname" | "slash_command|server_error" | "slash_command|server_error_detail" | "slash_command|shrug" | "slash_command|spoiler" | "slash_command|tableflip" | "slash_command|topic_none" | "slash_command|topic_room_error" | "slash_command|tovirtual" | "slash_command|tovirtual_not_found" | "slash_command|unflip" | "slash_command|unholdcall" | "slash_command|unignore_dialog_description" | "slash_command|unignore_dialog_title" | "slash_command|unknown_command" | "slash_command|unknown_command_button" | "slash_command|unknown_command_detail" | "slash_command|unknown_command_help" | "slash_command|unknown_command_hint" | "slash_command|upgraderoom" | "slash_command|upgraderoom_permission_error" | "slash_command|usage" | "slash_command|verify_mismatch" | "slash_command|verify_nop" | "slash_command|verify_nop_warning_mismatch" | "slash_command|verify_success_description" | "slash_command|verify_success_title" | "slash_command|verify_unknown_pair" | "slash_command|whois" | "space_settings|title" | "spotlight|public_rooms|network_dropdown_add_dialog_description" | "spotlight|public_rooms|network_dropdown_add_dialog_placeholder" | "spotlight|public_rooms|network_dropdown_add_dialog_title" | "spotlight|public_rooms|network_dropdown_add_server_option" | "spotlight|public_rooms|network_dropdown_available_invalid" | "spotlight|public_rooms|network_dropdown_available_invalid_forbidden" | "spotlight|public_rooms|network_dropdown_available_valid" | "spotlight|public_rooms|network_dropdown_remove_server_adornment" | "spotlight|public_rooms|network_dropdown_required_invalid" | "spotlight|public_rooms|network_dropdown_selected_label" | "spotlight|public_rooms|network_dropdown_selected_label_instance" | "spotlight|public_rooms|network_dropdown_your_server_description" | "spotlight_dialog|cant_find_person_helpful_hint" | "spotlight_dialog|cant_find_room_helpful_hint" | "spotlight_dialog|copy_link_text" | "spotlight_dialog|count_of_members" | "spotlight_dialog|create_new_room_button" | "spotlight_dialog|failed_querying_public_rooms" | "spotlight_dialog|failed_querying_public_spaces" | "spotlight_dialog|group_chat_section_title" | "spotlight_dialog|heading_with_query" | "spotlight_dialog|heading_without_query" | "spotlight_dialog|join_button_text" | "spotlight_dialog|keyboard_scroll_hint" | "spotlight_dialog|message_search_section_title" | "spotlight_dialog|other_rooms_in_space" | "spotlight_dialog|public_rooms_label" | "spotlight_dialog|public_spaces_label" | "spotlight_dialog|recent_searches_section_title" | "spotlight_dialog|recently_viewed_section_title" | "spotlight_dialog|remove_filter" | "spotlight_dialog|result_may_be_hidden_privacy_warning" | "spotlight_dialog|result_may_be_hidden_warning" | "spotlight_dialog|search_dialog" | "spotlight_dialog|search_messages_hint" | "spotlight_dialog|spaces_title" | "spotlight_dialog|start_group_chat_button" | "stickers|empty" | "stickers|empty_add_prompt" | "terms|integration_manager" | "terms|intro" | "terms|column_document" | "terms|column_service" | "terms|column_summary" | "terms|identity_server_no_terms_description_1" | "terms|identity_server_no_terms_description_2" | "terms|identity_server_no_terms_title" | "terms|inline_intro_text" | "terms|summary_identity_server_1" | "terms|summary_identity_server_2" | "terms|tac_button" | "terms|tac_description" | "terms|tac_title" | "terms|tos" | "threads_activity_centre|header" | "threads_activity_centre|release_announcement_description" | "threads_activity_centre|release_announcement_header" | "threads_activity_centre|no_rooms_with_threads_notifs" | "threads_activity_centre|no_rooms_with_unread_threads" | "unsupported_browser|title" | "unsupported_browser|description" | "update_room_access_modal|title" | "update_room_access_modal|description" | "update_room_access_modal|no_change" | "update_room_access_modal|dont_change_description" | "upload_file|title" | "upload_file|error_title" | "upload_file|cancel_all_button" | "upload_file|error_file_too_large" | "upload_file|error_files_too_large" | "upload_file|error_some_files_too_large" | "upload_file|title_progress" | "upload_file|upload_all_button" | "upload_file|upload_n_others_button" | "user_info|redact|confirm_button" | "user_info|dehydrated_device_enabled" | "user_info|room_encrypted" | "user_info|share_button" | "user_info|admin_tools_section" | "user_info|ban_button_room" | "user_info|ban_button_space" | "user_info|ban_room_confirm_title" | "user_info|ban_space_everything" | "user_info|ban_space_specific" | "user_info|count_of_sessions" | "user_info|count_of_verified_sessions" | "user_info|deactivate_confirm_action" | "user_info|deactivate_confirm_description" | "user_info|deactivate_confirm_title" | "user_info|demote_button" | "user_info|demote_self_confirm_description_space" | "user_info|demote_self_confirm_room" | "user_info|demote_self_confirm_title" | "user_info|disinvite_button_room" | "user_info|disinvite_button_room_name" | "user_info|disinvite_button_space" | "user_info|edit_own_devices" | "user_info|error_ban_user" | "user_info|error_deactivate" | "user_info|error_kicking_user" | "user_info|error_mute_user" | "user_info|error_revoke_3pid_invite_description" | "user_info|error_revoke_3pid_invite_title" | "user_info|hide_sessions" | "user_info|hide_verified_sessions" | "user_info|ignore_button" | "user_info|ignore_confirm_description" | "user_info|ignore_confirm_title" | "user_info|invited_by" | "user_info|jump_to_rr_button" | "user_info|kick_button_room" | "user_info|kick_button_room_name" | "user_info|kick_button_space" | "user_info|kick_button_space_everything" | "user_info|kick_space_specific" | "user_info|kick_space_warning" | "user_info|promote_warning" | "user_info|redact_button" | "user_info|revoke_invite" | "user_info|room_encrypted_detail" | "user_info|room_unencrypted" | "user_info|room_unencrypted_detail" | "user_info|send_message" | "user_info|unban_button_room" | "user_info|unban_button_space" | "user_info|unban_room_confirm_title" | "user_info|unban_space_everything" | "user_info|unban_space_specific" | "user_info|unban_space_warning" | "user_info|unignore_button" | "user_info|verify_button" | "user_info|verify_explainer" | "user_info|redact|confirm_description_1" | "user_info|redact|confirm_description_2" | "user_info|redact|confirm_keep_state_explainer" | "user_info|redact|confirm_keep_state_label" | "user_info|redact|confirm_title" | "user_info|redact|no_recent_messages_description" | "user_info|redact|no_recent_messages_title" | "user_menu|settings" | "user_menu|link_new_device" | "user_menu|link_new_device_not_supported" | "user_menu|link_new_device_not_supported_caption" | "user_menu|switch_theme_dark" | "user_menu|switch_theme_light" | "voice_message|cant_start_broadcast_description" | "voice_message|cant_start_broadcast_title" | "widget|error_loading" | "widget|unencrypted_warning" | "widget|added_by" | "widget|close_to_view_right_panel" | "widget|cookie_warning" | "widget|error_hangup_description" | "widget|error_hangup_title" | "widget|error_mixed_content" | "widget|error_need_invite_permission" | "widget|error_need_kick_permission" | "widget|error_need_to_be_logged_in" | "widget|error_unable_start_audio_stream_description" | "widget|error_unable_start_audio_stream_title" | "widget|modal_data_warning" | "widget|modal_title_default" | "widget|no_name" | "widget|popout" | "widget|set_room_layout" | "widget|shared_data_avatar" | "widget|shared_data_device_id" | "widget|shared_data_lang" | "widget|shared_data_mxid" | "widget|shared_data_name" | "widget|shared_data_room_id" | "widget|shared_data_theme" | "widget|shared_data_url" | "widget|shared_data_warning" | "widget|shared_data_warning_im" | "widget|shared_data_widget_id" | "widget|unmaximise" | "widget|unpin_to_view_right_panel" | "widget|context_menu|remove" | "widget|context_menu|screenshot" | "widget|context_menu|delete" | "widget|context_menu|revoke" | "widget|context_menu|delete_warning" | "widget|context_menu|move_left" | "widget|context_menu|move_right" | "widget|context_menu|start_audio_stream" | "widget|capabilities_dialog|title" | "widget|capabilities_dialog|content_starting_text" | "widget|capabilities_dialog|decline_all_permission" | "widget|capabilities_dialog|remember_Selection" | "widget|capability|capability" | "widget|capability|always_on_screen_generic" | "widget|capability|always_on_screen_viewing_another_room" | "widget|capability|any_room" | "widget|capability|byline_empty_state_key" | "widget|capability|byline_state_key" | "widget|capability|change_avatar_active_room" | "widget|capability|change_avatar_this_room" | "widget|capability|change_name_active_room" | "widget|capability|change_name_this_room" | "widget|capability|change_topic_active_room" | "widget|capability|change_topic_this_room" | "widget|capability|receive_membership_active_room" | "widget|capability|receive_membership_this_room" | "widget|capability|remove_ban_invite_leave_active_room" | "widget|capability|remove_ban_invite_leave_this_room" | "widget|capability|see_avatar_change_active_room" | "widget|capability|see_avatar_change_this_room" | "widget|capability|see_event_type_sent_active_room" | "widget|capability|see_event_type_sent_this_room" | "widget|capability|see_images_sent_active_room" | "widget|capability|see_images_sent_this_room" | "widget|capability|see_messages_sent_active_room" | "widget|capability|see_messages_sent_this_room" | "widget|capability|see_msgtype_sent_active_room" | "widget|capability|see_msgtype_sent_this_room" | "widget|capability|see_name_change_active_room" | "widget|capability|see_name_change_this_room" | "widget|capability|see_sent_emotes_active_room" | "widget|capability|see_sent_emotes_this_room" | "widget|capability|see_sent_files_active_room" | "widget|capability|see_sent_files_this_room" | "widget|capability|see_sticker_posted_active_room" | "widget|capability|see_sticker_posted_this_room" | "widget|capability|see_text_messages_sent_active_room" | "widget|capability|see_text_messages_sent_this_room" | "widget|capability|see_topic_change_active_room" | "widget|capability|see_topic_change_this_room" | "widget|capability|see_videos_sent_active_room" | "widget|capability|see_videos_sent_this_room" | "widget|capability|send_emotes_active_room" | "widget|capability|send_emotes_this_room" | "widget|capability|send_event_type_active_room" | "widget|capability|send_event_type_this_room" | "widget|capability|send_files_active_room" | "widget|capability|send_files_this_room" | "widget|capability|send_images_active_room" | "widget|capability|send_images_this_room" | "widget|capability|send_messages_active_room" | "widget|capability|send_messages_this_room" | "widget|capability|send_msgtype_active_room" | "widget|capability|send_msgtype_this_room" | "widget|capability|send_stickers_active_room" | "widget|capability|send_stickers_active_room_as_you" | "widget|capability|send_stickers_this_room" | "widget|capability|send_stickers_this_room_as_you" | "widget|capability|send_text_messages_active_room" | "widget|capability|send_text_messages_this_room" | "widget|capability|send_videos_active_room" | "widget|capability|send_videos_this_room" | "widget|capability|specific_room" | "widget|capability|switch_room" | "widget|capability|switch_room_message_user" | "widget|open_id_permissions_dialog|title" | "widget|open_id_permissions_dialog|remember_selection" | "widget|open_id_permissions_dialog|starting_text" | "zxcvbn|suggestions|allUppercase" | "zxcvbn|suggestions|anotherWord" | "zxcvbn|suggestions|associatedYears" | "zxcvbn|suggestions|capitalization" | "zxcvbn|suggestions|dates" | "zxcvbn|suggestions|l33t" | "zxcvbn|suggestions|longerKeyboardPattern" | "zxcvbn|suggestions|noNeed" | "zxcvbn|suggestions|pwned" | "zxcvbn|suggestions|recentYears" | "zxcvbn|suggestions|repeated" | "zxcvbn|suggestions|reverseWords" | "zxcvbn|suggestions|sequences" | "zxcvbn|suggestions|useWords" | "zxcvbn|warnings|common" | "zxcvbn|warnings|dates" | "zxcvbn|warnings|pwned" | "zxcvbn|warnings|recentYears" | "zxcvbn|warnings|sequences" | "zxcvbn|warnings|commonNames" | "zxcvbn|warnings|extendedRepeat" | "zxcvbn|warnings|keyPattern" | "zxcvbn|warnings|namesByThemselves" | "zxcvbn|warnings|similarToCommon" | "zxcvbn|warnings|simpleRepeat" | "zxcvbn|warnings|straightRow" | "zxcvbn|warnings|topHundred" | "zxcvbn|warnings|topTen" | "zxcvbn|warnings|userInputs" | "zxcvbn|warnings|wordByItself";
        labelEnterPassword: "a11y_jump_first_unread_room" | "cannot_invite_without_identity_server" | "cannot_reach_homeserver" | "cannot_reach_homeserver_detail" | "cant_load_page" | "chat_card_back_action_label" | "console_dev_note" | "console_scam_warning" | "console_wait" | "dialog_close_label" | "empty_room" | "empty_room_was_name" | "error_app_open_in_another_tab" | "error_app_open_in_another_tab_title" | "error_app_opened_in_another_window" | "error_database_closed_title" | "error_user_not_logged_in" | "failed_load_async_component" | "in_space" | "in_space1_and_space2" | "in_space_and_n_other_spaces" | "info_tooltip_title" | "inviting_user1_and_user2" | "inviting_user_and_n_others" | "items_and_n_others" | "language_dropdown_label" | "member_list_back_action_label" | "message_edit_dialog_title" | "migrating_crypto" | "name_and_id" | "no_more_results" | "room_summary_card_back_action_label" | "thread_view_back_action_label" | "truncated_list_n_more" | "unsupported_server_description" | "unsupported_server_title" | "upload_failed_generic" | "upload_failed_size" | "upload_failed_title" | "emoji|categories" | "emoji|category_activities" | "emoji|category_animals_nature" | "emoji|category_flags" | "emoji|category_food_drink" | "emoji|category_frequently_used" | "emoji|category_objects" | "emoji|category_smileys_people" | "emoji|category_symbols" | "emoji|category_travel_places" | "emoji|quick_reactions" | "time|left" | "time|about_day_ago" | "time|about_hour_ago" | "time|about_minute_ago" | "time|date_at_time" | "time|few_seconds_ago" | "time|hours_minutes_seconds_left" | "time|in_about_day" | "time|in_about_hour" | "time|in_about_minute" | "time|in_few_seconds" | "time|in_n_days" | "time|in_n_hours" | "time|in_n_minutes" | "time|minutes_seconds_left" | "time|n_days_ago" | "time|n_hours_ago" | "time|n_minutes_ago" | "time|seconds_left" | "time|short_days" | "time|short_days_hours_minutes_seconds" | "time|short_hours" | "time|short_hours_minutes_seconds" | "time|short_minutes" | "time|short_minutes_seconds" | "time|short_seconds" | "error|sync" | "error|unknown" | "error|admin_contact" | "error|connection" | "error|admin_contact_short" | "error|dialog_description_default" | "error|download_media" | "error|edit_history_unsupported" | "error|failed_copy" | "error|hs_blocked" | "error|mau" | "error|mixed_content" | "error|non_urgent_echo_failure_toast" | "error|resource_limits" | "error|something_went_wrong" | "error|storage_evicted_description_1" | "error|storage_evicted_description_2" | "error|storage_evicted_title" | "error|tls" | "error|unknown_error_code" | "error|update_power_level" | "error|session_restore|title" | "error|session_restore|clear_storage_button" | "error|session_restore|clear_storage_description" | "error|session_restore|description_1" | "error|session_restore|description_2" | "error|session_restore|description_3" | "feedback|sent" | "feedback|can_contact_label" | "feedback|comment_label" | "feedback|existing_issue_link" | "feedback|may_contact_label" | "feedback|platform_username" | "feedback|pro_type" | "feedback|send_feedback_action" | "timeline|m.sticker" | "timeline|m.poll.start" | "timeline|io.element.widgets.layout" | "timeline|m.room.topic" | "timeline|m.room.tombstone" | "timeline|creation_summary_dm" | "timeline|creation_summary_room" | "timeline|disambiguated_profile" | "timeline|download_action_decrypting" | "timeline|download_action_downloading" | "timeline|download_failed" | "timeline|download_failed_description" | "timeline|error_no_renderer" | "timeline|error_rendering_message" | "timeline|historical_messages_unavailable" | "timeline|in_room_name" | "timeline|late_event_separator" | "timeline|message_timestamp_received_at" | "timeline|message_timestamp_sent_at" | "timeline|no_permission_messages_before_invite" | "timeline|no_permission_messages_before_join" | "timeline|pending_moderation" | "timeline|pending_moderation_reason" | "timeline|read_receipt_title" | "timeline|read_receipts_label" | "timeline|redaction" | "timeline|self_redaction" | "timeline|send_state_encrypting" | "timeline|send_state_failed" | "timeline|send_state_sending" | "timeline|send_state_sent" | "timeline|thread_info_basic" | "timeline|undecryptable_tooltip" | "timeline|summary|left" | "timeline|summary|invited" | "timeline|summary|joined" | "timeline|summary|format" | "timeline|summary|redacted" | "timeline|summary|banned" | "timeline|summary|banned_multiple" | "timeline|summary|changed_avatar" | "timeline|summary|changed_avatar_multiple" | "timeline|summary|changed_name" | "timeline|summary|changed_name_multiple" | "timeline|summary|hidden_event" | "timeline|summary|hidden_event_multiple" | "timeline|summary|invite_withdrawn" | "timeline|summary|invite_withdrawn_multiple" | "timeline|summary|invited_multiple" | "timeline|summary|joined_and_left" | "timeline|summary|joined_and_left_multiple" | "timeline|summary|joined_multiple" | "timeline|summary|kicked" | "timeline|summary|kicked_multiple" | "timeline|summary|left_multiple" | "timeline|summary|no_change" | "timeline|summary|no_change_multiple" | "timeline|summary|pinned_events" | "timeline|summary|pinned_events_multiple" | "timeline|summary|redacted_multiple" | "timeline|summary|rejected_invite" | "timeline|summary|rejected_invite_multiple" | "timeline|summary|rejoined" | "timeline|summary|rejoined_multiple" | "timeline|summary|server_acls" | "timeline|summary|server_acls_multiple" | "timeline|summary|unbanned" | "timeline|summary|unbanned_multiple" | "timeline|m.widget|removed" | "timeline|m.widget|added" | "timeline|m.widget|jitsi_ended" | "timeline|m.widget|jitsi_join_right_prompt" | "timeline|m.widget|jitsi_join_top_prompt" | "timeline|m.widget|jitsi_started" | "timeline|m.widget|jitsi_updated" | "timeline|m.widget|modified" | "timeline|m.poll.end|ended" | "timeline|m.poll.end|sender_ended" | "timeline|m.location|location" | "timeline|m.location|full" | "timeline|m.location|self_location" | "timeline|m.beacon_info|view_live_location" | "timeline|m.room.history_visibility|shared" | "timeline|m.room.history_visibility|unknown" | "timeline|m.room.history_visibility|invited" | "timeline|m.room.history_visibility|joined" | "timeline|m.room.history_visibility|world_readable" | "timeline|m.key.verification.request|user_wants_to_verify" | "timeline|m.key.verification.request|you_started" | "timeline|m.video|error_decrypting" | "timeline|io.element.voice_broadcast_info|user" | "timeline|io.element.voice_broadcast_info|you" | "timeline|m.room.power_levels|changed" | "timeline|m.room.power_levels|user_from_to" | "timeline|m.call|video_call_ended" | "timeline|m.call|video_call_started" | "timeline|m.call|video_call_started_text" | "timeline|m.call|video_call_started_unsupported" | "timeline|m.room.canonical_alias|set" | "timeline|m.room.canonical_alias|removed" | "timeline|m.room.canonical_alias|changed" | "timeline|m.room.canonical_alias|alt_added" | "timeline|m.room.canonical_alias|alt_removed" | "timeline|m.room.canonical_alias|changed_alternative" | "timeline|m.room.canonical_alias|changed_main_and_alternative" | "timeline|m.room.create|continuation" | "timeline|m.room.create|see_older_messages" | "timeline|m.room.create|unknown_predecessor" | "timeline|m.room.create|unknown_predecessor_guess_server" | "timeline|m.room.join_rules|public" | "timeline|m.room.join_rules|unknown" | "timeline|m.room.join_rules|invite" | "timeline|m.room.join_rules|knock" | "timeline|m.room.join_rules|restricted" | "timeline|m.room.join_rules|restricted_settings" | "timeline|m.room.member|join" | "timeline|m.room.member|left" | "timeline|m.room.member|invite" | "timeline|m.room.member|ban" | "timeline|m.room.member|kick" | "timeline|m.room.member|no_change" | "timeline|m.room.member|accepted_3pid_invite" | "timeline|m.room.member|accepted_invite" | "timeline|m.room.member|ban_reason" | "timeline|m.room.member|change_avatar" | "timeline|m.room.member|change_name" | "timeline|m.room.member|change_name_avatar" | "timeline|m.room.member|kick_reason" | "timeline|m.room.member|left_reason" | "timeline|m.room.member|reject_invite" | "timeline|m.room.member|remove_avatar" | "timeline|m.room.member|remove_name" | "timeline|m.room.member|set_avatar" | "timeline|m.room.member|set_name" | "timeline|m.room.member|unban" | "timeline|m.room.member|withdrew_invite" | "timeline|m.room.member|withdrew_invite_reason" | "timeline|m.room.third_party_invite|sent" | "timeline|m.room.third_party_invite|revoked" | "timeline|m.room.name|set" | "timeline|m.room.name|remove" | "timeline|m.room.name|change" | "timeline|m.room.avatar|removed" | "timeline|m.room.avatar|changed" | "timeline|m.room.avatar|changed_img" | "timeline|m.room.avatar|lightbox_title" | "timeline|m.room.pinned_events|changed" | "timeline|m.room.pinned_events|changed_link" | "timeline|m.room.pinned_events|pinned" | "timeline|m.room.pinned_events|pinned_link" | "timeline|m.room.pinned_events|unpinned" | "timeline|m.room.pinned_events|unpinned_link" | "timeline|m.room.encryption|disabled" | "timeline|m.room.encryption|enabled" | "timeline|m.room.encryption|disable_attempt" | "timeline|m.room.encryption|enabled_dm" | "timeline|m.room.encryption|enabled_local" | "timeline|m.room.encryption|parameters_changed" | "timeline|m.room.encryption|unsupported" | "timeline|m.room.guest_access|unknown" | "timeline|m.room.guest_access|can_join" | "timeline|m.room.guest_access|forbidden" | "timeline|m.room.server_acl|set" | "timeline|m.room.server_acl|changed" | "timeline|m.room.server_acl|all_servers_banned" | "timeline|m.call.invite|answered_elsewhere" | "timeline|m.call.invite|call_back_prompt" | "timeline|m.call.invite|declined" | "timeline|m.call.invite|failed_connect_media" | "timeline|m.call.invite|failed_connection" | "timeline|m.call.invite|failed_opponent_media" | "timeline|m.call.invite|missed_call" | "timeline|m.call.invite|no_answer" | "timeline|m.call.invite|unknown_error" | "timeline|m.call.invite|unknown_failure" | "timeline|m.call.invite|unknown_state" | "timeline|m.call.invite|video_call" | "timeline|m.call.invite|video_call_unsupported" | "timeline|m.call.invite|voice_call" | "timeline|m.call.invite|voice_call_unsupported" | "timeline|m.call.hangup|dm" | "timeline|m.image|error" | "timeline|m.image|sent" | "timeline|m.image|error_decrypting" | "timeline|m.image|error_downloading" | "timeline|m.image|show_image" | "timeline|m.file|error_decrypting" | "timeline|m.file|decrypt_label" | "timeline|m.file|download_label" | "timeline|m.file|error_invalid" | "timeline|m.audio|error_downloading_audio" | "timeline|m.audio|error_processing_audio" | "timeline|m.audio|error_processing_voice_message" | "timeline|m.audio|unnamed_audio" | "timeline|context_menu|report" | "timeline|context_menu|collapse_reply_thread" | "timeline|context_menu|external_url" | "timeline|context_menu|open_in_osm" | "timeline|context_menu|resent_unsent_reactions" | "timeline|context_menu|show_url_preview" | "timeline|context_menu|view_related_event" | "timeline|context_menu|view_source" | "timeline|decryption_failure|blocked" | "timeline|decryption_failure|historical_event_no_key_backup" | "timeline|decryption_failure|historical_event_unverified_device" | "timeline|decryption_failure|historical_event_user_not_joined" | "timeline|decryption_failure|unable_to_decrypt" | "timeline|edits|tooltip_label" | "timeline|edits|tooltip_sub" | "timeline|edits|tooltip_title" | "timeline|load_error|title" | "timeline|load_error|no_permission" | "timeline|load_error|unable_to_find" | "timeline|m.poll|count_of_votes" | "timeline|mab|label" | "timeline|mab|collapse_reply_chain" | "timeline|mab|copy_link_thread" | "timeline|mab|expand_reply_chain" | "timeline|mab|view_in_room" | "timeline|mjolnir|changed_rule_glob" | "timeline|mjolnir|changed_rule_rooms" | "timeline|mjolnir|changed_rule_servers" | "timeline|mjolnir|changed_rule_users" | "timeline|mjolnir|created_rule" | "timeline|mjolnir|created_rule_rooms" | "timeline|mjolnir|created_rule_servers" | "timeline|mjolnir|created_rule_users" | "timeline|mjolnir|message_hidden" | "timeline|mjolnir|removed_rule" | "timeline|mjolnir|removed_rule_rooms" | "timeline|mjolnir|removed_rule_servers" | "timeline|mjolnir|removed_rule_users" | "timeline|mjolnir|updated_invalid_rule" | "timeline|mjolnir|updated_rule" | "timeline|mjolnir|updated_rule_rooms" | "timeline|mjolnir|updated_rule_servers" | "timeline|mjolnir|updated_rule_users" | "timeline|reactions|label" | "timeline|reactions|add_reaction_prompt" | "timeline|reactions|custom_reaction_fallback_label" | "timeline|reactions|tooltip_caption" | "timeline|redacted|tooltip" | "timeline|reply|error_loading" | "timeline|reply|in_reply_to" | "timeline|reply|in_reply_to_for_export" | "timeline|scalar_starter_link|dialog_description" | "timeline|scalar_starter_link|dialog_title" | "timeline|typing_indicator|more_users" | "timeline|typing_indicator|one_user" | "timeline|typing_indicator|two_users" | "timeline|url_preview|close" | "timeline|url_preview|show_n_more" | "notifications|default" | "notifications|all_messages" | "notifications|all_messages_description" | "notifications|class_global" | "notifications|class_other" | "notifications|email_pusher_app_display_name" | "notifications|enable_prompt_toast_description" | "notifications|enable_prompt_toast_title" | "notifications|enable_prompt_toast_title_from_message_send" | "notifications|error_change_title" | "notifications|keyword" | "notifications|keyword_new" | "notifications|level_activity" | "notifications|level_highlight" | "notifications|level_muted" | "notifications|level_none" | "notifications|level_notification" | "notifications|level_unsent" | "notifications|mark_all_read" | "notifications|mentions_and_keywords" | "notifications|mentions_and_keywords_description" | "notifications|mentions_keywords" | "notifications|message_didnt_send" | "notifications|mute_description" | "action|search" | "action|join" | "action|add" | "action|show" | "action|pause" | "action|play" | "action|stop" | "action|reload" | "action|start" | "action|view" | "action|cancel" | "action|remove" | "action|clear" | "action|copy" | "action|verify" | "action|complete" | "action|change" | "action|click" | "action|close" | "action|reset" | "action|submit" | "action|forward" | "action|next" | "action|done" | "action|resume" | "action|refresh" | "action|disconnect" | "action|update" | "action|confirm" | "action|ok" | "action|invite" | "action|leave" | "action|ignore" | "action|register" | "action|reject" | "action|delete" | "action|pin" | "action|download" | "action|upload" | "action|save" | "action|apply" | "action|call" | "action|collapse" | "action|accept" | "action|yes" | "action|no" | "action|go" | "action|upgrade" | "action|rename" | "action|continue" | "action|skip" | "action|disable" | "action|enable" | "action|report_content" | "action|share" | "action|upload_file" | "action|reply" | "action|set_avatar" | "action|unban" | "action|view_source" | "action|add_existing_room" | "action|add_people" | "action|approve" | "action|ask_to_join" | "action|back" | "action|click_to_copy" | "action|copy_link" | "action|create" | "action|create_a_room" | "action|decline" | "action|deny" | "action|dismiss" | "action|edit" | "action|enter_fullscreen" | "action|exit_fullscreeen" | "action|expand" | "action|explore_public_rooms" | "action|explore_rooms" | "action|export" | "action|go_back" | "action|got_it" | "action|hide_advanced" | "action|hold" | "action|import" | "action|invite_to_space" | "action|invites_list" | "action|learn_more" | "action|leave_room" | "action|logout" | "action|manage" | "action|maximise" | "action|mention" | "action|minimise" | "action|new_room" | "action|new_video_room" | "action|proceed" | "action|quote" | "action|react" | "action|reply_in_thread" | "action|resend" | "action|restore" | "action|retry" | "action|review" | "action|revoke" | "action|send_report" | "action|show_advanced" | "action|show_all" | "action|sign_in" | "action|sign_out" | "action|start_chat" | "action|start_new_chat" | "action|subscribe" | "action|transfer" | "action|trust" | "action|try_again" | "action|unignore" | "action|unpin" | "action|unsubscribe" | "action|view_all" | "action|view_list" | "action|view_message" | "action|zoom_in" | "action|zoom_out" | "forward|sending" | "forward|sent" | "forward|filter_placeholder" | "forward|message_preview_heading" | "forward|no_perms_title" | "forward|open_room" | "forward|send_label" | "auth|sso" | "auth|3pid_in_use" | "auth|account_clash" | "auth|account_clash_previous_account" | "auth|account_deactivated" | "auth|autodiscovery_generic_failure" | "auth|autodiscovery_hs_incompatible" | "auth|autodiscovery_invalid" | "auth|autodiscovery_invalid_hs" | "auth|autodiscovery_invalid_hs_base_url" | "auth|autodiscovery_invalid_is" | "auth|autodiscovery_invalid_is_base_url" | "auth|autodiscovery_invalid_is_response" | "auth|autodiscovery_invalid_json" | "auth|autodiscovery_no_well_known" | "auth|autodiscovery_unexpected_error_hs" | "auth|autodiscovery_unexpected_error_is" | "auth|captcha_description" | "auth|change_password_action" | "auth|change_password_confirm_invalid" | "auth|change_password_confirm_label" | "auth|change_password_current_label" | "auth|change_password_empty" | "auth|change_password_error" | "auth|change_password_mismatch" | "auth|change_password_new_label" | "auth|check_email_explainer" | "auth|check_email_resend_prompt" | "auth|check_email_resend_tooltip" | "auth|check_email_wrong_email_button" | "auth|check_email_wrong_email_prompt" | "auth|continue_with_idp" | "auth|continue_with_sso" | "auth|country_dropdown" | "auth|create_account_prompt" | "auth|create_account_title" | "auth|email_discovery_text" | "auth|email_field_label" | "auth|email_field_label_invalid" | "auth|email_field_label_required" | "auth|email_help_text" | "auth|email_phone_discovery_text" | "auth|enter_email_explainer" | "auth|enter_email_heading" | "auth|failed_connect_identity_server" | "auth|failed_connect_identity_server_other" | "auth|failed_connect_identity_server_register" | "auth|failed_connect_identity_server_reset_password" | "auth|failed_homeserver_discovery" | "auth|failed_query_registration_methods" | "auth|failed_soft_logout_auth" | "auth|failed_soft_logout_homeserver" | "auth|footer_powered_by_matrix" | "auth|forgot_password_email_invalid" | "auth|forgot_password_email_required" | "auth|forgot_password_prompt" | "auth|forgot_password_send_email" | "auth|identifier_label" | "auth|incorrect_credentials" | "auth|incorrect_credentials_detail" | "auth|incorrect_password" | "auth|log_in_new_account" | "auth|misconfigured_body" | "auth|misconfigured_title" | "auth|msisdn_field_description" | "auth|msisdn_field_label" | "auth|msisdn_field_number_invalid" | "auth|msisdn_field_required_invalid" | "auth|no_hs_url_provided" | "auth|password_field_keep_going_prompt" | "auth|password_field_label" | "auth|password_field_strong_label" | "auth|password_field_weak_label" | "auth|phone_label" | "auth|phone_optional_label" | "auth|register_action" | "auth|registration_disabled" | "auth|registration_msisdn_field_required_invalid" | "auth|registration_successful" | "auth|registration_username_in_use" | "auth|registration_username_unable_check" | "auth|registration_username_validation" | "auth|reset_password_action" | "auth|reset_password_button" | "auth|reset_password_email_field_description" | "auth|reset_password_email_field_required_invalid" | "auth|reset_password_email_not_associated" | "auth|reset_password_email_not_found_title" | "auth|reset_password_title" | "auth|server_picker_custom" | "auth|server_picker_description" | "auth|server_picker_description_matrix.org" | "auth|server_picker_dialog_title" | "auth|server_picker_explainer" | "auth|server_picker_failed_validate_homeserver" | "auth|server_picker_intro" | "auth|server_picker_invalid_url" | "auth|server_picker_learn_more" | "auth|server_picker_matrix.org" | "auth|server_picker_required" | "auth|server_picker_title" | "auth|server_picker_title_default" | "auth|server_picker_title_registration" | "auth|session_logged_out_description" | "auth|session_logged_out_title" | "auth|set_email_prompt" | "auth|sign_in_description" | "auth|sign_in_instead" | "auth|sign_in_instead_prompt" | "auth|sign_in_or_register" | "auth|sign_in_or_register_description" | "auth|sign_in_prompt" | "auth|sign_in_with_sso" | "auth|signing_in" | "auth|soft_logout_heading" | "auth|soft_logout_intro_password" | "auth|soft_logout_intro_sso" | "auth|soft_logout_intro_unsupported_auth" | "auth|soft_logout_subheading" | "auth|soft_logout_warning" | "auth|sso_failed_missing_storage" | "auth|sso_or_username_password" | "auth|sync_footer_subtitle" | "auth|syncing" | "auth|unsupported_auth" | "auth|unsupported_auth_email" | "auth|unsupported_auth_msisdn" | "auth|username_field_required_invalid" | "auth|username_in_use" | "auth|verify_email_explainer" | "auth|verify_email_heading" | "auth|logout_dialog|description" | "auth|logout_dialog|megolm_export" | "auth|logout_dialog|setup_key_backup_title" | "auth|logout_dialog|setup_secure_backup_description_1" | "auth|logout_dialog|setup_secure_backup_description_2" | "auth|logout_dialog|skip_key_backup" | "auth|logout_dialog|use_key_backup" | "auth|oidc|error_title" | "auth|oidc|generic_auth_error" | "auth|oidc|logout_redirect_warning" | "auth|oidc|missing_or_invalid_stored_state" | "auth|qr_code_login|approve_access_warning" | "auth|qr_code_login|check_code_explainer" | "auth|qr_code_login|check_code_heading" | "auth|qr_code_login|check_code_input_label" | "auth|qr_code_login|check_code_mismatch" | "auth|qr_code_login|completing_setup" | "auth|qr_code_login|confirm_code_match" | "auth|qr_code_login|error_etag_missing" | "auth|qr_code_login|error_expired" | "auth|qr_code_login|error_expired_title" | "auth|qr_code_login|error_insecure_channel_detected" | "auth|qr_code_login|error_insecure_channel_detected_instructions" | "auth|qr_code_login|error_insecure_channel_detected_instructions_1" | "auth|qr_code_login|error_insecure_channel_detected_instructions_2" | "auth|qr_code_login|error_insecure_channel_detected_instructions_3" | "auth|qr_code_login|error_insecure_channel_detected_title" | "auth|qr_code_login|error_other_device_already_signed_in" | "auth|qr_code_login|error_other_device_already_signed_in_title" | "auth|qr_code_login|error_rate_limited" | "auth|qr_code_login|error_unexpected" | "auth|qr_code_login|error_unsupported_protocol" | "auth|qr_code_login|error_unsupported_protocol_title" | "auth|qr_code_login|error_user_cancelled" | "auth|qr_code_login|error_user_cancelled_title" | "auth|qr_code_login|error_user_declined" | "auth|qr_code_login|error_user_declined_title" | "auth|qr_code_login|follow_remaining_instructions" | "auth|qr_code_login|open_element_other_device" | "auth|qr_code_login|point_the_camera" | "auth|qr_code_login|scan_code_instruction" | "auth|qr_code_login|scan_qr_code" | "auth|qr_code_login|security_code" | "auth|qr_code_login|security_code_prompt" | "auth|qr_code_login|select_qr_code" | "auth|qr_code_login|sign_in_new_device" | "auth|qr_code_login|waiting_for_device" | "auth|registration|continue_without_email_description" | "auth|registration|continue_without_email_field_label" | "auth|registration|continue_without_email_title" | "auth|reset_password|confirm_new_password" | "auth|reset_password|devices_logout_success" | "auth|reset_password|other_devices_logout_warning_1" | "auth|reset_password|other_devices_logout_warning_2" | "auth|reset_password|password_not_entered" | "auth|reset_password|passwords_mismatch" | "auth|reset_password|rate_limit_error" | "auth|reset_password|rate_limit_error_with_time" | "auth|reset_password|reset_successful" | "auth|reset_password|return_to_login" | "auth|reset_password|sign_out_other_devices" | "auth|set_email|description" | "auth|set_email|verification_pending_description" | "auth|set_email|verification_pending_title" | "auth|soft_logout|clear_data_button" | "auth|soft_logout|clear_data_description" | "auth|soft_logout|clear_data_title" | "auth|uia|code" | "auth|uia|email" | "auth|uia|msisdn" | "auth|uia|terms" | "auth|uia|email_auth_header" | "auth|uia|email_resend_prompt" | "auth|uia|email_resent" | "auth|uia|fallback_button" | "auth|uia|msisdn_token_incorrect" | "auth|uia|msisdn_token_prompt" | "auth|uia|password_prompt" | "auth|uia|recaptcha_missing_params" | "auth|uia|registration_token_label" | "auth|uia|registration_token_prompt" | "auth|uia|sso_body" | "auth|uia|sso_failed" | "auth|uia|sso_postauth_body" | "auth|uia|sso_postauth_title" | "auth|uia|sso_preauth_body" | "auth|uia|sso_title" | "auth|uia|terms_invalid" | "update|checking" | "update|unavailable" | "update|changelog" | "update|check_action" | "update|downloading" | "update|error_encountered" | "update|error_unable_load_commit" | "update|new_version_available" | "update|no_update" | "update|release_notes_toast_title" | "update|see_changes_button" | "update|toast_description" | "update|toast_title" | "room|show_labs_settings" | "room|kick_reason" | "room|3pid_invite_email_not_found_account" | "room|3pid_invite_email_not_found_account_room" | "room|3pid_invite_error_description" | "room|3pid_invite_error_invite_action" | "room|3pid_invite_error_invite_subtitle" | "room|3pid_invite_error_public_subtitle" | "room|3pid_invite_error_title" | "room|3pid_invite_error_title_room" | "room|3pid_invite_no_is_subtitle" | "room|banned_by" | "room|banned_from_room_by" | "room|creating_room_text" | "room|dm_invite_action" | "room|dm_invite_subtitle" | "room|dm_invite_title" | "room|drop_file_prompt" | "room|edit_topic" | "room|error_3pid_invite_email_lookup" | "room|error_cancel_knock_title" | "room|error_join_403" | "room|error_join_404_1" | "room|error_join_404_2" | "room|error_join_404_invite" | "room|error_join_404_invite_same_hs" | "room|error_join_connection" | "room|error_join_incompatible_version_1" | "room|error_join_incompatible_version_2" | "room|error_join_title" | "room|error_jump_to_date" | "room|error_jump_to_date_connection" | "room|error_jump_to_date_details" | "room|error_jump_to_date_not_found" | "room|error_jump_to_date_send_logs_prompt" | "room|error_jump_to_date_title" | "room|face_pile_summary" | "room|face_pile_tooltip_label" | "room|face_pile_tooltip_shortcut" | "room|face_pile_tooltip_shortcut_joined" | "room|failed_reject_invite" | "room|forget_room" | "room|forget_space" | "room|header_face_pile_tooltip" | "room|header_untrusted_label" | "room|inaccessible" | "room|inaccessible_name" | "room|inaccessible_subtitle_1" | "room|inaccessible_subtitle_2" | "room|invite_email_mismatch_suggestion" | "room|invite_reject_ignore" | "room|invite_sent_to_email" | "room|invite_sent_to_email_room" | "room|invite_subtitle" | "room|invite_this_room" | "room|invite_title" | "room|inviter_unknown" | "room|invites_you_text" | "room|join_button_account" | "room|join_failed_enable_video_rooms" | "room|join_failed_needs_invite" | "room|join_the_discussion" | "room|join_title" | "room|join_title_account" | "room|joining" | "room|joining_room" | "room|joining_space" | "room|jump_read_marker" | "room|jump_to_bottom_button" | "room|jump_to_date" | "room|jump_to_date_beginning" | "room|jump_to_date_prompt" | "room|kicked_by" | "room|kicked_from_room_by" | "room|knock_cancel_action" | "room|knock_denied_subtitle" | "room|knock_denied_title" | "room|knock_message_field_placeholder" | "room|knock_prompt" | "room|knock_prompt_name" | "room|knock_send_action" | "room|knock_sent" | "room|knock_sent_subtitle" | "room|knock_subtitle" | "room|leave_error_title" | "room|leave_server_notices_description" | "room|leave_server_notices_title" | "room|leave_unexpected_error" | "room|link_email_to_receive_3pid_invite" | "room|loading_preview" | "room|no_peek_join_prompt" | "room|no_peek_no_name_join_prompt" | "room|not_found_subtitle" | "room|not_found_title" | "room|not_found_title_name" | "room|peek_join_prompt" | "room|read_topic" | "room|rejecting" | "room|rejoin_button" | "room|unknown_status_code_for_timeline_jump" | "room|unread_notifications_predecessor" | "room|upgrade_error_description" | "room|upgrade_error_title" | "room|upgrade_warning_bar" | "room|upgrade_warning_bar_admins" | "room|upgrade_warning_bar_unstable" | "room|upgrade_warning_bar_upgraded" | "room|view_failed_enable_video_rooms" | "room|waiting_for_join_subtitle" | "room|waiting_for_join_title" | "room|search|summary" | "room|search|placeholder" | "room|search|all_rooms_button" | "room|search|result_count" | "room|search|this_room_button" | "room|header|close_call_button" | "room|header|forget_room_button" | "room|header|hide_widgets_button" | "room|header|n_people_asking_to_join" | "room|header|release_announcement_description" | "room|header|release_announcement_header" | "room|header|room_is_public" | "room|header|show_widgets_button" | "room|header|video_call_button_ec" | "room|header|video_call_button_jitsi" | "room|header|video_call_button_legacy" | "room|header|video_call_ec_change_layout" | "room|header|video_call_ec_layout_freedom" | "room|header|video_call_ec_layout_spotlight" | "room|header|video_room_view_chat_button" | "room|upload|uploading_multiple_file" | "room|upload|uploading_single_file" | "room|context_menu|title" | "room|context_menu|forget" | "room|context_menu|copy_link" | "room|context_menu|favourite" | "room|context_menu|low_priority" | "room|context_menu|mark_read" | "room|context_menu|mark_unread" | "room|context_menu|mentions_only" | "room|context_menu|notifications_default" | "room|context_menu|notifications_mute" | "room|context_menu|unfavourite" | "room|intro|topic" | "room|intro|dm_caption" | "room|intro|enable_encryption_prompt" | "room|intro|encrypted_3pid_dm_pending_join" | "room|intro|no_avatar_label" | "room|intro|no_topic" | "room|intro|private_unencrypted_warning" | "room|intro|room_invite" | "room|intro|send_message_start_dm" | "room|intro|start_of_dm_history" | "room|intro|start_of_room" | "room|intro|topic_edit" | "room|intro|unencrypted_warning" | "room|intro|user_created" | "room|intro|you_created" | "room|pinned_message_banner|title" | "room|pinned_message_banner|description" | "room|pinned_message_banner|button_close_list" | "room|pinned_message_banner|button_view_all" | "room|pinned_message_banner|go_to_message" | "room|status_bar|delete_all" | "room|status_bar|exceeded_resource_limit" | "room|status_bar|homeserver_blocked" | "room|status_bar|monthly_user_limit_reached" | "room|status_bar|requires_consent_agreement" | "room|status_bar|retry_all" | "room|status_bar|select_messages_to_retry" | "room|status_bar|server_connectivity_lost_description" | "room|status_bar|server_connectivity_lost_title" | "room|status_bar|some_messages_not_sent" | "invite|ask_anyway_description" | "invite|ask_anyway_label" | "invite|ask_anyway_never_warn_label" | "invite|email_caption" | "invite|email_limit_one" | "invite|email_use_default_is" | "invite|email_use_is" | "invite|error_already_invited_room" | "invite|error_already_invited_space" | "invite|error_already_joined_room" | "invite|error_already_joined_space" | "invite|error_bad_state" | "invite|error_dm" | "invite|error_find_room" | "invite|error_find_user_description" | "invite|error_find_user_title" | "invite|error_invite" | "invite|error_permissions_room" | "invite|error_permissions_space" | "invite|error_profile_undisclosed" | "invite|error_transfer_multiple_target" | "invite|error_unfederated_room" | "invite|error_unfederated_space" | "invite|error_unknown" | "invite|error_user_not_found" | "invite|error_version_unsupported_room" | "invite|error_version_unsupported_space" | "invite|failed_generic" | "invite|failed_title" | "invite|invalid_address" | "invite|name_email_mxid_share_room" | "invite|name_email_mxid_share_space" | "invite|name_mxid_share_room" | "invite|name_mxid_share_space" | "invite|recents_section" | "invite|room_failed_partial" | "invite|room_failed_partial_title" | "invite|room_failed_title" | "invite|send_link_prompt" | "invite|start_conversation_name_email_mxid_prompt" | "invite|start_conversation_name_mxid_prompt" | "invite|suggestions_disclaimer" | "invite|suggestions_disclaimer_prompt" | "invite|suggestions_section" | "invite|to_room" | "invite|to_space" | "invite|transfer_dial_pad_tab" | "invite|transfer_user_directory_tab" | "invite|unable_find_profiles_description_default" | "invite|unable_find_profiles_invite_label_default" | "invite|unable_find_profiles_invite_never_warn_label_default" | "invite|unable_find_profiles_title" | "invite|unban_first_title" | "presence|idle" | "presence|offline" | "presence|online" | "presence|unknown" | "presence|away" | "presence|busy" | "presence|idle_for" | "presence|offline_for" | "presence|online_for" | "presence|unknown_for" | "presence|unreachable" | "redact|error" | "redact|confirm_button" | "redact|confirm_description" | "redact|confirm_description_state" | "redact|ongoing" | "redact|reason_label" | "encryption|unsupported" | "encryption|bootstrap_title" | "encryption|cancel_entering_passphrase_description" | "encryption|cancel_entering_passphrase_title" | "encryption|confirm_encryption_setup_body" | "encryption|confirm_encryption_setup_title" | "encryption|cross_signing_not_ready" | "encryption|cross_signing_ready" | "encryption|cross_signing_ready_no_backup" | "encryption|cross_signing_room_normal" | "encryption|cross_signing_room_verified" | "encryption|cross_signing_room_warning" | "encryption|cross_signing_unsupported" | "encryption|cross_signing_untrusted" | "encryption|cross_signing_user_normal" | "encryption|cross_signing_user_verified" | "encryption|cross_signing_user_warning" | "encryption|event_shield_reason_authenticity_not_guaranteed" | "encryption|event_shield_reason_mismatched_sender_key" | "encryption|event_shield_reason_unknown_device" | "encryption|event_shield_reason_unsigned_device" | "encryption|event_shield_reason_unverified_identity" | "encryption|export_unsupported" | "encryption|import_invalid_keyfile" | "encryption|import_invalid_passphrase" | "encryption|incompatible_database_description" | "encryption|incompatible_database_disable" | "encryption|incompatible_database_sign_out_description" | "encryption|incompatible_database_title" | "encryption|key_signature_upload_cancelled" | "encryption|key_signature_upload_completed" | "encryption|key_signature_upload_failed" | "encryption|key_signature_upload_failed_body" | "encryption|key_signature_upload_failed_cross_signing_key_signature" | "encryption|key_signature_upload_failed_device_cross_signing_key_signature" | "encryption|key_signature_upload_failed_key_signature" | "encryption|key_signature_upload_failed_master_key_signature" | "encryption|key_signature_upload_failed_title" | "encryption|key_signature_upload_success_title" | "encryption|not_supported" | "encryption|old_version_detected_description" | "encryption|old_version_detected_title" | "encryption|reset_all_button" | "encryption|set_up_toast_description" | "encryption|set_up_toast_title" | "encryption|unable_to_setup_keys_error" | "encryption|upgrade_toast_title" | "encryption|verification_requested_toast_title" | "encryption|verify_toast_description" | "encryption|verify_toast_title" | "encryption|access_secret_storage_dialog|separator" | "encryption|access_secret_storage_dialog|enter_phrase_or_key_prompt" | "encryption|access_secret_storage_dialog|reset_title" | "encryption|access_secret_storage_dialog|reset_warning_1" | "encryption|access_secret_storage_dialog|reset_warning_2" | "encryption|access_secret_storage_dialog|restoring" | "encryption|access_secret_storage_dialog|security_key_title" | "encryption|access_secret_storage_dialog|security_phrase_incorrect_error" | "encryption|access_secret_storage_dialog|security_phrase_title" | "encryption|access_secret_storage_dialog|use_security_key_prompt" | "encryption|access_secret_storage_dialog|key_validation_text|invalid_security_key" | "encryption|access_secret_storage_dialog|key_validation_text|recovery_key_is_correct" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_file_type" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_security_key" | "encryption|destroy_cross_signing_dialog|title" | "encryption|destroy_cross_signing_dialog|warning" | "encryption|destroy_cross_signing_dialog|primary_button_text" | "encryption|messages_not_secure|title" | "encryption|messages_not_secure|heading" | "encryption|messages_not_secure|cause_1" | "encryption|messages_not_secure|cause_2" | "encryption|messages_not_secure|cause_3" | "encryption|messages_not_secure|cause_4" | "encryption|new_recovery_method_detected|title" | "encryption|new_recovery_method_detected|warning" | "encryption|new_recovery_method_detected|description_1" | "encryption|new_recovery_method_detected|description_2" | "encryption|recovery_method_removed|title" | "encryption|recovery_method_removed|warning" | "encryption|recovery_method_removed|description_1" | "encryption|recovery_method_removed|description_2" | "encryption|setup_secure_backup|title" | "encryption|setup_secure_backup|explainer" | "encryption|udd|title" | "encryption|udd|interactive_verification_button" | "encryption|udd|manual_verification_button" | "encryption|udd|other_ask_verify_text" | "encryption|udd|other_new_session_text" | "encryption|udd|own_ask_verify_text" | "encryption|udd|own_new_session_text" | "encryption|verification|cancelled" | "encryption|verification|explainer" | "encryption|verification|accepting" | "encryption|verification|cancelled_self" | "encryption|verification|cancelled_user" | "encryption|verification|cancelling" | "encryption|verification|complete_action" | "encryption|verification|complete_description" | "encryption|verification|complete_title" | "encryption|verification|error_starting_description" | "encryption|verification|error_starting_title" | "encryption|verification|in_person" | "encryption|verification|incoming_sas_device_dialog_text_1" | "encryption|verification|incoming_sas_device_dialog_text_2" | "encryption|verification|incoming_sas_dialog_title" | "encryption|verification|incoming_sas_dialog_waiting" | "encryption|verification|incoming_sas_user_dialog_text_1" | "encryption|verification|incoming_sas_user_dialog_text_2" | "encryption|verification|manual_device_verification_device_id_label" | "encryption|verification|manual_device_verification_device_key_label" | "encryption|verification|manual_device_verification_device_name_label" | "encryption|verification|manual_device_verification_footer" | "encryption|verification|manual_device_verification_self_text" | "encryption|verification|manual_device_verification_user_text" | "encryption|verification|no_key_or_device" | "encryption|verification|no_support_qr_emoji" | "encryption|verification|other_party_cancelled" | "encryption|verification|prompt_encrypted" | "encryption|verification|prompt_self" | "encryption|verification|prompt_unencrypted" | "encryption|verification|prompt_user" | "encryption|verification|qr_or_sas" | "encryption|verification|qr_or_sas_header" | "encryption|verification|qr_prompt" | "encryption|verification|qr_reciprocate_same_shield_device" | "encryption|verification|qr_reciprocate_same_shield_user" | "encryption|verification|request_toast_accept" | "encryption|verification|request_toast_accept_user" | "encryption|verification|request_toast_decline_counter" | "encryption|verification|request_toast_detail" | "encryption|verification|reset_proceed_prompt" | "encryption|verification|sas_caption_self" | "encryption|verification|sas_caption_user" | "encryption|verification|sas_description" | "encryption|verification|sas_emoji_caption_self" | "encryption|verification|sas_emoji_caption_user" | "encryption|verification|sas_match" | "encryption|verification|sas_no_match" | "encryption|verification|sas_prompt" | "encryption|verification|scan_qr" | "encryption|verification|scan_qr_explainer" | "encryption|verification|self_verification_hint" | "encryption|verification|start_button" | "encryption|verification|successful_device" | "encryption|verification|successful_own_device" | "encryption|verification|successful_user" | "encryption|verification|timed_out" | "encryption|verification|unsupported_method" | "encryption|verification|unverified_session_toast_accept" | "encryption|verification|unverified_session_toast_title" | "encryption|verification|unverified_sessions_toast_description" | "encryption|verification|unverified_sessions_toast_reject" | "encryption|verification|unverified_sessions_toast_title" | "encryption|verification|verification_description" | "encryption|verification|verification_dialog_title_device" | "encryption|verification|verification_dialog_title_user" | "encryption|verification|verification_skip_warning" | "encryption|verification|verification_success_with_backup" | "encryption|verification|verification_success_without_backup" | "encryption|verification|verify_emoji" | "encryption|verification|verify_emoji_prompt" | "encryption|verification|verify_emoji_prompt_qr" | "encryption|verification|verify_later" | "encryption|verification|verify_reset_warning_1" | "encryption|verification|verify_reset_warning_2" | "encryption|verification|verify_using_device" | "encryption|verification|verify_using_key" | "encryption|verification|verify_using_key_or_phrase" | "encryption|verification|waiting_for_user_accept" | "encryption|verification|waiting_other_device" | "encryption|verification|waiting_other_device_details" | "encryption|verification|waiting_other_user" | "encryption|verification|after_new_login|device_verified" | "encryption|verification|after_new_login|reset_confirmation" | "encryption|verification|after_new_login|skip_verification" | "encryption|verification|after_new_login|unable_to_verify" | "encryption|verification|after_new_login|verify_this_device" | "threads|mark_all_read" | "threads|all_threads" | "threads|all_threads_description" | "threads|count_of_reply" | "threads|empty_description" | "threads|empty_title" | "threads|error_start_thread_existing_relation" | "threads|my_threads" | "threads|my_threads_description" | "threads|open_thread" | "threads|show_thread_filter" | "space|invite" | "space|joining_space" | "space|failed_load_rooms" | "space|failed_remove_rooms" | "space|incompatible_server_hierarchy" | "space|invite_description" | "space|invite_link" | "space|invite_this_space" | "space|landing_welcome" | "space|leave_dialog_action" | "space|leave_dialog_description" | "space|leave_dialog_only_admin_room_warning" | "space|leave_dialog_only_admin_warning" | "space|leave_dialog_option_all" | "space|leave_dialog_option_intro" | "space|leave_dialog_option_none" | "space|leave_dialog_option_specific" | "space|leave_dialog_public_rejoin_warning" | "space|leave_dialog_title" | "space|mark_suggested" | "space|no_search_result_hint" | "space|room_filter_placeholder" | "space|search_children" | "space|search_placeholder" | "space|select_room_below" | "space|share_public" | "space|suggested" | "space|suggested_tooltip" | "space|title_when_query_available" | "space|title_when_query_unavailable" | "space|unmark_suggested" | "space|user_lacks_permission" | "space|context_menu|home" | "space|context_menu|options" | "space|context_menu|devtools_open_timeline" | "space|context_menu|explore" | "space|context_menu|manage_and_explore" | "space|add_existing_room_space|create" | "space|add_existing_room_space|create_prompt" | "space|add_existing_room_space|dm_heading" | "space|add_existing_room_space|error_heading" | "space|add_existing_room_space|progress_text" | "space|add_existing_room_space|space_dropdown_label" | "space|add_existing_room_space|space_dropdown_title" | "space|add_existing_room_space|subspace_moved_note" | "space|add_existing_subspace|filter_placeholder" | "space|add_existing_subspace|create_prompt" | "space|add_existing_subspace|space_dropdown_title" | "space|add_existing_subspace|create_button" | "space|preferences|sections_section" | "space|preferences|show_people_in_space" | "spaces|error_no_permission_add_room" | "spaces|error_no_permission_add_space" | "spaces|error_no_permission_create_room" | "spaces|error_no_permission_invite" | "common|emoji" | "common|name" | "common|attachment" | "common|beta" | "common|error" | "common|message" | "common|feedback" | "common|location" | "common|timeline" | "common|advanced" | "common|cancel" | "common|appearance" | "common|mute" | "common|unmute" | "common|private" | "common|public" | "common|loading" | "common|video" | "common|image" | "common|encrypted" | "common|offline" | "common|off" | "common|on" | "common|username" | "common|home" | "common|options" | "common|success" | "common|description" | "common|user" | "common|profile" | "common|password" | "common|access_token" | "common|capabilities" | "common|room" | "common|matrix" | "common|joined" | "common|presence" | "common|rooms" | "common|thread" | "common|unavailable" | "common|verified" | "common|device" | "common|version" | "common|application" | "common|trusted" | "common|threads" | "common|guest" | "common|server" | "common|save" | "common|space" | "common|dark" | "common|light" | "common|help" | "common|spaces" | "common|legal" | "common|security" | "common|warning" | "common|settings" | "common|android" | "common|ios" | "common|labs" | "common|theme" | "common|edited" | "common|analytics" | "common|credits" | "common|identity_server" | "common|integration_manager" | "common|reactions" | "common|view_message" | "common|low_priority" | "common|preferences" | "common|accessibility" | "common|all_rooms" | "common|and_n_others" | "common|are_you_sure" | "common|authentication" | "common|avatar" | "common|camera" | "common|cameras" | "common|copied" | "common|cross_signing" | "common|deselect_all" | "common|email_address" | "common|encryption_enabled" | "common|extensions" | "common|faq" | "common|favourites" | "common|filter_results" | "common|forward_message" | "common|general" | "common|go_to_settings" | "common|historical" | "common|homeserver" | "common|lobby" | "common|message_layout" | "common|microphone" | "common|model" | "common|modern" | "common|n_members" | "common|n_rooms" | "common|no_results" | "common|no_results_found" | "common|not_trusted" | "common|orphan_rooms" | "common|people" | "common|preview_message" | "common|privacy" | "common|private_room" | "common|private_space" | "common|public_room" | "common|public_space" | "common|qr_code" | "common|random" | "common|report_a_bug" | "common|room_name" | "common|saved" | "common|saving" | "common|secure_backup" | "common|select_all" | "common|setup_secure_messages" | "common|show_more" | "common|someone" | "common|sticker" | "common|stickerpack" | "common|suggestions" | "common|support" | "common|system_alerts" | "common|unencrypted" | "common|unnamed_room" | "common|unnamed_space" | "common|unsent" | "common|unverified" | "common|updating" | "common|user_avatar" | "common|verification_cancelled" | "common|video_room" | "common|welcome" | "settings|warning" | "settings|notifications|mentions_keywords" | "settings|all_rooms_home" | "settings|all_rooms_home_description" | "settings|always_show_message_timestamps" | "settings|automatic_language_detection_syntax_highlight" | "settings|autoplay_gifs" | "settings|autoplay_videos" | "settings|big_emoji" | "settings|code_block_expand_default" | "settings|code_block_line_numbers" | "settings|disable_historical_profile" | "settings|emoji_autocomplete" | "settings|enable_markdown" | "settings|enable_markdown_description" | "settings|image_thumbnails" | "settings|inline_url_previews_default" | "settings|inline_url_previews_room" | "settings|inline_url_previews_room_account" | "settings|insert_trailing_colon_mentions" | "settings|jump_to_bottom_on_send" | "settings|prompt_invite" | "settings|replace_plain_emoji" | "settings|send_read_receipts" | "settings|send_read_receipts_unsupported" | "settings|send_typing_notifications" | "settings|show_avatar_changes" | "settings|show_breadcrumbs" | "settings|show_chat_effects" | "settings|show_displayname_changes" | "settings|show_join_leave" | "settings|show_nsfw_content" | "settings|show_read_receipts" | "settings|show_redaction_placeholder" | "settings|show_stickers_button" | "settings|show_typing_notifications" | "settings|showbold" | "settings|start_automatically" | "settings|tac_only_notifications" | "settings|use_12_hour_format" | "settings|use_command_enter_send_message" | "settings|use_command_f_search" | "settings|use_control_enter_send_message" | "settings|use_control_f_search" | "settings|warn_quit" | "settings|notifications|voip" | "settings|notifications|error_loading" | "settings|notifications|dialog_title" | "settings|notifications|error_title" | "settings|notifications|default_setting_description" | "settings|notifications|default_setting_section" | "settings|notifications|desktop_notification_message_preview" | "settings|notifications|email_description" | "settings|notifications|email_section" | "settings|notifications|email_select" | "settings|notifications|enable_audible_notifications_session" | "settings|notifications|enable_desktop_notifications_session" | "settings|notifications|enable_email_notifications" | "settings|notifications|enable_notifications_account" | "settings|notifications|enable_notifications_account_detail" | "settings|notifications|enable_notifications_device" | "settings|notifications|error_permissions_denied" | "settings|notifications|error_permissions_missing" | "settings|notifications|error_saving" | "settings|notifications|error_saving_detail" | "settings|notifications|error_updating" | "settings|notifications|invites" | "settings|notifications|keywords" | "settings|notifications|keywords_prompt" | "settings|notifications|labs_notice_prompt" | "settings|notifications|mentions_keywords_only" | "settings|notifications|messages_containing_keywords" | "settings|notifications|noisy" | "settings|notifications|notices" | "settings|notifications|notify_at_room" | "settings|notifications|notify_keyword" | "settings|notifications|notify_mention" | "settings|notifications|other_section" | "settings|notifications|people_mentions_keywords" | "settings|notifications|play_sound_for_description" | "settings|notifications|play_sound_for_section" | "settings|notifications|push_targets" | "settings|notifications|quick_actions_mark_all_read" | "settings|notifications|quick_actions_reset" | "settings|notifications|quick_actions_section" | "settings|notifications|room_activity" | "settings|notifications|rule_call" | "settings|notifications|rule_contains_display_name" | "settings|notifications|rule_contains_user_name" | "settings|notifications|rule_encrypted" | "settings|notifications|rule_encrypted_room_one_to_one" | "settings|notifications|rule_invite_for_me" | "settings|notifications|rule_message" | "settings|notifications|rule_room_one_to_one" | "settings|notifications|rule_roomnotif" | "settings|notifications|rule_suppress_notices" | "settings|notifications|rule_tombstone" | "settings|notifications|show_message_desktop_notification" | "settings|appearance|dialog_title" | "settings|appearance|bundled_emoji_font" | "settings|appearance|compact_layout" | "settings|appearance|compact_layout_description" | "settings|appearance|custom_font" | "settings|appearance|custom_font_description" | "settings|appearance|custom_font_name" | "settings|appearance|custom_font_size" | "settings|appearance|custom_theme_add" | "settings|appearance|custom_theme_downloading" | "settings|appearance|custom_theme_error_downloading" | "settings|appearance|custom_theme_help" | "settings|appearance|custom_theme_invalid" | "settings|appearance|font_size" | "settings|appearance|font_size_default" | "settings|appearance|high_contrast" | "settings|appearance|image_size_default" | "settings|appearance|image_size_large" | "settings|appearance|layout_bubbles" | "settings|appearance|layout_irc" | "settings|appearance|match_system_theme" | "settings|appearance|timeline_image_size" | "settings|account|title" | "settings|account|dialog_title" | "settings|sessions|url" | "settings|sessions|title" | "settings|sessions|browser" | "settings|sessions|session_id" | "settings|sessions|dialog_title" | "settings|sessions|sign_out" | "settings|sessions|best_security_note" | "settings|sessions|confirm_sign_out" | "settings|sessions|confirm_sign_out_body" | "settings|sessions|confirm_sign_out_continue" | "settings|sessions|confirm_sign_out_sso" | "settings|sessions|current_session" | "settings|sessions|desktop_session" | "settings|sessions|details_heading" | "settings|sessions|device_unverified_description" | "settings|sessions|device_unverified_description_current" | "settings|sessions|device_verified_description" | "settings|sessions|device_verified_description_current" | "settings|sessions|error_pusher_state" | "settings|sessions|error_set_name" | "settings|sessions|filter_all" | "settings|sessions|filter_inactive" | "settings|sessions|filter_inactive_description" | "settings|sessions|filter_label" | "settings|sessions|filter_unverified_description" | "settings|sessions|filter_verified_description" | "settings|sessions|hide_details" | "settings|sessions|inactive_days" | "settings|sessions|inactive_sessions" | "settings|sessions|inactive_sessions_explainer_1" | "settings|sessions|inactive_sessions_explainer_2" | "settings|sessions|inactive_sessions_list_description" | "settings|sessions|ip" | "settings|sessions|last_activity" | "settings|sessions|mobile_session" | "settings|sessions|n_sessions_selected" | "settings|sessions|no_inactive_sessions" | "settings|sessions|no_sessions" | "settings|sessions|no_unverified_sessions" | "settings|sessions|no_verified_sessions" | "settings|sessions|os" | "settings|sessions|other_sessions_heading" | "settings|sessions|push_heading" | "settings|sessions|push_subheading" | "settings|sessions|push_toggle" | "settings|sessions|rename_form_caption" | "settings|sessions|rename_form_heading" | "settings|sessions|rename_form_learn_more" | "settings|sessions|rename_form_learn_more_description_1" | "settings|sessions|rename_form_learn_more_description_2" | "settings|sessions|security_recommendations" | "settings|sessions|security_recommendations_description" | "settings|sessions|show_details" | "settings|sessions|sign_in_with_qr" | "settings|sessions|sign_in_with_qr_button" | "settings|sessions|sign_in_with_qr_description" | "settings|sessions|sign_out_all_other_sessions" | "settings|sessions|sign_out_confirm_description" | "settings|sessions|sign_out_n_sessions" | "settings|sessions|unknown_session" | "settings|sessions|unverified_session" | "settings|sessions|unverified_session_explainer_1" | "settings|sessions|unverified_session_explainer_2" | "settings|sessions|unverified_session_explainer_3" | "settings|sessions|unverified_sessions" | "settings|sessions|unverified_sessions_explainer_1" | "settings|sessions|unverified_sessions_explainer_2" | "settings|sessions|unverified_sessions_list_description" | "settings|sessions|verified_session" | "settings|sessions|verified_sessions" | "settings|sessions|verified_sessions_explainer_1" | "settings|sessions|verified_sessions_explainer_2" | "settings|sessions|verified_sessions_list_description" | "settings|sessions|verify_session" | "settings|sessions|web_session" | "settings|security|session_id" | "settings|security|session_key" | "settings|security|dialog_title" | "settings|security|4s_public_key_in_account_data" | "settings|security|4s_public_key_status" | "settings|security|analytics_description" | "settings|security|backup_key_cached_status" | "settings|security|backup_key_stored_status" | "settings|security|backup_key_unexpected_type" | "settings|security|backup_key_well_formed" | "settings|security|backup_keys_description" | "settings|security|bulk_options_accept_all_invites" | "settings|security|bulk_options_reject_all_invites" | "settings|security|bulk_options_section" | "settings|security|cross_signing_cached" | "settings|security|cross_signing_homeserver_support" | "settings|security|cross_signing_homeserver_support_exists" | "settings|security|cross_signing_in_4s" | "settings|security|cross_signing_in_memory" | "settings|security|cross_signing_master_private_Key" | "settings|security|cross_signing_not_cached" | "settings|security|cross_signing_not_found" | "settings|security|cross_signing_not_in_4s" | "settings|security|cross_signing_not_stored" | "settings|security|cross_signing_private_keys" | "settings|security|cross_signing_public_keys" | "settings|security|cross_signing_self_signing_private_key" | "settings|security|cross_signing_user_signing_private_key" | "settings|security|cryptography_section" | "settings|security|dehydrated_device_description" | "settings|security|dehydrated_device_enabled" | "settings|security|delete_backup" | "settings|security|delete_backup_confirm_description" | "settings|security|e2ee_default_disabled_warning" | "settings|security|enable_message_search" | "settings|security|encryption_section" | "settings|security|error_loading_key_backup_status" | "settings|security|export_megolm_keys" | "settings|security|ignore_users_empty" | "settings|security|ignore_users_section" | "settings|security|import_megolm_keys" | "settings|security|key_backup_active" | "settings|security|key_backup_active_version" | "settings|security|key_backup_active_version_none" | "settings|security|key_backup_algorithm" | "settings|security|key_backup_can_be_restored" | "settings|security|key_backup_complete" | "settings|security|key_backup_connect" | "settings|security|key_backup_connect_prompt" | "settings|security|key_backup_in_progress" | "settings|security|key_backup_inactive" | "settings|security|key_backup_inactive_warning" | "settings|security|key_backup_latest_version" | "settings|security|message_search_disable_warning" | "settings|security|message_search_disabled" | "settings|security|message_search_enabled" | "settings|security|message_search_failed" | "settings|security|message_search_indexed_messages" | "settings|security|message_search_indexed_rooms" | "settings|security|message_search_indexing" | "settings|security|message_search_indexing_idle" | "settings|security|message_search_intro" | "settings|security|message_search_room_progress" | "settings|security|message_search_section" | "settings|security|message_search_sleep_time" | "settings|security|message_search_space_used" | "settings|security|message_search_unsupported" | "settings|security|message_search_unsupported_web" | "settings|security|record_session_details" | "settings|security|restore_key_backup" | "settings|security|secret_storage_not_ready" | "settings|security|secret_storage_ready" | "settings|security|secret_storage_status" | "settings|security|send_analytics" | "settings|security|strict_encryption" | "settings|voip|title" | "settings|voip|dialog_title" | "settings|voip|allow_p2p" | "settings|voip|allow_p2p_description" | "settings|voip|audio_input_empty" | "settings|voip|audio_output" | "settings|voip|audio_output_empty" | "settings|voip|auto_gain_control" | "settings|voip|connection_section" | "settings|voip|echo_cancellation" | "settings|voip|enable_fallback_ice_server" | "settings|voip|enable_fallback_ice_server_description" | "settings|voip|mirror_local_feed" | "settings|voip|missing_permissions_prompt" | "settings|voip|noise_suppression" | "settings|voip|request_permissions" | "settings|voip|video_input_empty" | "settings|voip|video_section" | "settings|voip|voice_agc" | "settings|voip|voice_processing" | "settings|voip|voice_section" | "settings|labs|dialog_title" | "settings|keyboard|title" | "settings|keyboard|dialog_title" | "settings|labs_mjolnir|dialog_title" | "settings|preferences|dialog_title" | "settings|preferences|Electron.enableHardwareAcceleration" | "settings|preferences|always_show_menu_bar" | "settings|preferences|autocomplete_delay" | "settings|preferences|code_blocks_heading" | "settings|preferences|compact_modern" | "settings|preferences|composer_heading" | "settings|preferences|default_timezone" | "settings|preferences|enable_hardware_acceleration" | "settings|preferences|enable_tray_icon" | "settings|preferences|keyboard_heading" | "settings|preferences|keyboard_view_shortcuts_button" | "settings|preferences|media_heading" | "settings|preferences|presence_description" | "settings|preferences|rm_lifetime" | "settings|preferences|rm_lifetime_offscreen" | "settings|preferences|room_directory_heading" | "settings|preferences|room_list_heading" | "settings|preferences|show_avatars_pills" | "settings|preferences|show_checklist_shortcuts" | "settings|preferences|show_polls_button" | "settings|preferences|surround_text" | "settings|preferences|time_heading" | "settings|preferences|user_timezone" | "settings|general|username" | "settings|general|display_name" | "settings|general|account_management_section" | "settings|general|account_section" | "settings|general|add_email_dialog_title" | "settings|general|add_email_failed_verification" | "settings|general|add_email_instructions" | "settings|general|add_msisdn_confirm_body" | "settings|general|add_msisdn_confirm_button" | "settings|general|add_msisdn_confirm_sso_button" | "settings|general|add_msisdn_dialog_title" | "settings|general|add_msisdn_instructions" | "settings|general|add_msisdn_misconfigured" | "settings|general|allow_spellcheck" | "settings|general|application_language" | "settings|general|application_language_reload_hint" | "settings|general|avatar_remove_progress" | "settings|general|avatar_save_progress" | "settings|general|avatar_upload_error_text" | "settings|general|avatar_upload_error_text_generic" | "settings|general|avatar_upload_error_title" | "settings|general|confirm_adding_email_body" | "settings|general|confirm_adding_email_title" | "settings|general|deactivate_confirm_body" | "settings|general|deactivate_confirm_body_sso" | "settings|general|deactivate_confirm_content" | "settings|general|deactivate_confirm_content_1" | "settings|general|deactivate_confirm_content_2" | "settings|general|deactivate_confirm_content_3" | "settings|general|deactivate_confirm_content_4" | "settings|general|deactivate_confirm_content_5" | "settings|general|deactivate_confirm_content_6" | "settings|general|deactivate_confirm_continue" | "settings|general|deactivate_confirm_erase_label" | "settings|general|deactivate_section" | "settings|general|deactivate_warning" | "settings|general|discovery_email_empty" | "settings|general|discovery_email_verification_instructions" | "settings|general|discovery_msisdn_empty" | "settings|general|discovery_needs_terms" | "settings|general|discovery_needs_terms_title" | "settings|general|display_name_error" | "settings|general|email_address_in_use" | "settings|general|email_address_label" | "settings|general|email_not_verified" | "settings|general|email_verification_instructions" | "settings|general|emails_heading" | "settings|general|error_add_email" | "settings|general|error_deactivate_communication" | "settings|general|error_deactivate_invalid_auth" | "settings|general|error_deactivate_no_auth" | "settings|general|error_email_verification" | "settings|general|error_invalid_email" | "settings|general|error_invalid_email_detail" | "settings|general|error_msisdn_verification" | "settings|general|error_password_change_403" | "settings|general|error_password_change_http" | "settings|general|error_password_change_title" | "settings|general|error_password_change_unknown" | "settings|general|error_remove_3pid" | "settings|general|error_revoke_email_discovery" | "settings|general|error_revoke_msisdn_discovery" | "settings|general|error_share_email_discovery" | "settings|general|error_share_msisdn_discovery" | "settings|general|identity_server_no_token" | "settings|general|identity_server_not_set" | "settings|general|language_section" | "settings|general|msisdn_in_use" | "settings|general|msisdn_label" | "settings|general|msisdn_verification_field_label" | "settings|general|msisdn_verification_instructions" | "settings|general|msisdns_heading" | "settings|general|name_placeholder" | "settings|general|oidc_manage_button" | "settings|general|password_change_section" | "settings|general|password_change_success" | "settings|general|personal_info" | "settings|general|profile_subtitle" | "settings|general|profile_subtitle_oidc" | "settings|general|remove_email_prompt" | "settings|general|remove_msisdn_prompt" | "settings|general|spell_check_locale_placeholder" | "settings|general|unable_to_load_emails" | "settings|general|unable_to_load_msisdns" | "settings|discovery|title" | "settings|key_backup|backup_in_progress" | "settings|key_backup|backup_starting" | "settings|key_backup|backup_success" | "settings|key_backup|cannot_create_backup" | "settings|key_backup|create_title" | "settings|key_backup|setup_secure_backup|description" | "settings|key_backup|setup_secure_backup|backup_setup_success_description" | "settings|key_backup|setup_secure_backup|backup_setup_success_title" | "settings|key_backup|setup_secure_backup|cancel_warning" | "settings|key_backup|setup_secure_backup|confirm_security_phrase" | "settings|key_backup|setup_secure_backup|download_or_copy" | "settings|key_backup|setup_secure_backup|enter_phrase_description" | "settings|key_backup|setup_secure_backup|enter_phrase_title" | "settings|key_backup|setup_secure_backup|enter_phrase_to_confirm" | "settings|key_backup|setup_secure_backup|generate_security_key_description" | "settings|key_backup|setup_secure_backup|generate_security_key_title" | "settings|key_backup|setup_secure_backup|pass_phrase_match_failed" | "settings|key_backup|setup_secure_backup|pass_phrase_match_success" | "settings|key_backup|setup_secure_backup|phrase_strong_enough" | "settings|key_backup|setup_secure_backup|requires_key_restore" | "settings|key_backup|setup_secure_backup|requires_password_confirmation" | "settings|key_backup|setup_secure_backup|requires_server_authentication" | "settings|key_backup|setup_secure_backup|secret_storage_query_failure" | "settings|key_backup|setup_secure_backup|security_key_safety_reminder" | "settings|key_backup|setup_secure_backup|session_upgrade_description" | "settings|key_backup|setup_secure_backup|set_phrase_again" | "settings|key_backup|setup_secure_backup|settings_reminder" | "settings|key_backup|setup_secure_backup|title_confirm_phrase" | "settings|key_backup|setup_secure_backup|title_save_key" | "settings|key_backup|setup_secure_backup|title_set_phrase" | "settings|key_backup|setup_secure_backup|title_upgrade_encryption" | "settings|key_backup|setup_secure_backup|unable_to_setup" | "settings|key_backup|setup_secure_backup|use_different_passphrase" | "settings|key_backup|setup_secure_backup|use_phrase_only_you_know" | "settings|key_export_import|phrase_strong_enough" | "settings|key_export_import|confirm_passphrase" | "settings|key_export_import|enter_passphrase" | "settings|key_export_import|export_description_1" | "settings|key_export_import|export_description_2" | "settings|key_export_import|export_title" | "settings|key_export_import|file_to_import" | "settings|key_export_import|import_description_1" | "settings|key_export_import|import_description_2" | "settings|key_export_import|import_title" | "settings|key_export_import|phrase_cannot_be_empty" | "settings|key_export_import|phrase_must_match" | "settings|sidebar|title" | "settings|sidebar|dialog_title" | "settings|sidebar|metaspaces_favourites_description" | "settings|sidebar|metaspaces_home_all_rooms" | "settings|sidebar|metaspaces_home_all_rooms_description" | "settings|sidebar|metaspaces_home_description" | "settings|sidebar|metaspaces_orphans" | "settings|sidebar|metaspaces_orphans_description" | "settings|sidebar|metaspaces_people_description" | "settings|sidebar|metaspaces_subsection" | "settings|sidebar|metaspaces_video_rooms" | "settings|sidebar|metaspaces_video_rooms_description" | "settings|sidebar|metaspaces_video_rooms_description_invite_extension" | "settings|sidebar|spaces_explainer" | "voip|connecting" | "voip|hangup" | "voip|answered_elsewhere" | "voip|user_busy" | "voip|element_call" | "voip|unsupported_browser" | "voip|video_call_started" | "voip|unsupported" | "voip|video_call" | "voip|voice_call" | "voip|expand" | "voip|maximise" | "voip|already_in_call" | "voip|already_in_call_person" | "voip|answered_elsewhere_description" | "voip|call_failed" | "voip|call_failed_description" | "voip|call_failed_media" | "voip|call_failed_media_applications" | "voip|call_failed_media_connected" | "voip|call_failed_media_permissions" | "voip|call_failed_microphone" | "voip|call_held" | "voip|call_held_resume" | "voip|call_held_switch" | "voip|call_toast_unknown_room" | "voip|camera_disabled" | "voip|camera_enabled" | "voip|cannot_call_yourself_description" | "voip|change_input_device" | "voip|close_lobby" | "voip|connection_lost" | "voip|connection_lost_description" | "voip|consulting" | "voip|default_device" | "voip|dial" | "voip|dialpad" | "voip|disable_camera" | "voip|disable_microphone" | "voip|disabled_no_one_here" | "voip|disabled_no_perms_start_video_call" | "voip|disabled_no_perms_start_voice_call" | "voip|disabled_ongoing_call" | "voip|enable_camera" | "voip|enable_microphone" | "voip|failed_call_live_broadcast_description" | "voip|failed_call_live_broadcast_title" | "voip|get_call_link" | "voip|hide_sidebar_button" | "voip|input_devices" | "voip|jitsi_call" | "voip|join_button_tooltip_call_full" | "voip|join_button_tooltip_connecting" | "voip|legacy_call" | "voip|maximise_call" | "voip|minimise_call" | "voip|misconfigured_server" | "voip|misconfigured_server_description" | "voip|misconfigured_server_fallback" | "voip|misconfigured_server_fallback_accept" | "voip|more_button" | "voip|msisdn_lookup_failed" | "voip|msisdn_lookup_failed_description" | "voip|msisdn_transfer_failed" | "voip|n_people_joined" | "voip|no_audio_input_description" | "voip|no_audio_input_title" | "voip|no_media_perms_description" | "voip|no_media_perms_title" | "voip|no_permission_conference" | "voip|no_permission_conference_description" | "voip|on_hold" | "voip|output_devices" | "voip|screenshare_monitor" | "voip|screenshare_title" | "voip|screenshare_window" | "voip|show_sidebar_button" | "voip|silence" | "voip|silenced" | "voip|start_screenshare" | "voip|stop_screenshare" | "voip|too_many_calls" | "voip|too_many_calls_description" | "voip|transfer_consult_first_label" | "voip|transfer_failed" | "voip|transfer_failed_description" | "voip|unable_to_access_audio_input_description" | "voip|unable_to_access_audio_input_title" | "voip|unable_to_access_media" | "voip|unable_to_access_microphone" | "voip|unknown_caller" | "voip|unknown_person" | "voip|unsilence" | "voip|user_busy_description" | "voip|user_is_presenting" | "voip|video_call_using" | "voip|you_are_presenting" | "voip|metaspace_video_rooms|conference_room_section" | "voice_broadcast|pause" | "voice_broadcast|play" | "voice_broadcast|action" | "voice_broadcast|resume" | "voice_broadcast|live" | "voice_broadcast|failed_generic" | "voice_broadcast|30s_backward" | "voice_broadcast|30s_forward" | "voice_broadcast|buffering" | "voice_broadcast|confirm_listen_affirm" | "voice_broadcast|confirm_listen_description" | "voice_broadcast|confirm_listen_title" | "voice_broadcast|confirm_stop_affirm" | "voice_broadcast|confirm_stop_description" | "voice_broadcast|confirm_stop_title" | "voice_broadcast|connection_error" | "voice_broadcast|failed_already_recording_description" | "voice_broadcast|failed_already_recording_title" | "voice_broadcast|failed_decrypt" | "voice_broadcast|failed_insufficient_permission_description" | "voice_broadcast|failed_insufficient_permission_title" | "voice_broadcast|failed_no_connection_description" | "voice_broadcast|failed_no_connection_title" | "voice_broadcast|failed_others_already_recording_description" | "voice_broadcast|failed_others_already_recording_title" | "voice_broadcast|go_live" | "labs|notifications" | "labs|dehydration" | "labs|voice_broadcast" | "labs|mjolnir" | "labs|ask_to_join" | "labs|jump_to_date" | "labs|allow_screen_share_only_mode" | "labs|automatic_debug_logs" | "labs|automatic_debug_logs_decryption" | "labs|automatic_debug_logs_key_backup" | "labs|beta_description" | "labs|beta_feature" | "labs|beta_feedback_leave_button" | "labs|beta_feedback_title" | "labs|beta_section" | "labs|bridge_state" | "labs|bridge_state_channel" | "labs|bridge_state_creator" | "labs|bridge_state_manager" | "labs|bridge_state_workspace" | "labs|click_for_info" | "labs|currently_experimental" | "labs|custom_themes" | "labs|dynamic_room_predecessors" | "labs|dynamic_room_predecessors_description" | "labs|element_call_video_rooms" | "labs|experimental_description" | "labs|experimental_section" | "labs|feature_disable_call_per_sender_encryption" | "labs|feature_wysiwyg_composer_description" | "labs|group_calls" | "labs|group_developer" | "labs|group_encryption" | "labs|group_experimental" | "labs|group_messaging" | "labs|group_moderation" | "labs|group_profile" | "labs|group_rooms" | "labs|group_spaces" | "labs|group_themes" | "labs|group_threads" | "labs|group_ui" | "labs|group_voip" | "labs|group_widgets" | "labs|hidebold" | "labs|html_topic" | "labs|join_beta" | "labs|join_beta_reload" | "labs|jump_to_date_msc_support" | "labs|latex_maths" | "labs|leave_beta" | "labs|leave_beta_reload" | "labs|location_share_live" | "labs|location_share_live_description" | "labs|msc3531_hide_messages_pending_moderation" | "labs|new_room_decoration_ui" | "labs|new_room_decoration_ui_beta_caption" | "labs|new_room_decoration_ui_beta_title" | "labs|notification_settings" | "labs|notification_settings_beta_caption" | "labs|notification_settings_beta_title" | "labs|oidc_native_flow" | "labs|oidc_native_flow_description" | "labs|pinning" | "labs|release_announcement" | "labs|render_reaction_images" | "labs|render_reaction_images_description" | "labs|report_to_moderators" | "labs|report_to_moderators_description" | "labs|sliding_sync" | "labs|sliding_sync_description" | "labs|sliding_sync_disabled_notice" | "labs|sliding_sync_server_no_support" | "labs|under_active_development" | "labs|unrealiable_e2e" | "labs|video_rooms" | "labs|video_rooms_a_new_way_to_chat" | "labs|video_rooms_always_on_voip_channels" | "labs|video_rooms_beta" | "labs|video_rooms_faq1_answer" | "labs|video_rooms_faq1_question" | "labs|video_rooms_faq2_answer" | "labs|video_rooms_faq2_question" | "labs|video_rooms_feedbackSubheading" | "labs|voice_broadcast_force_small_chunks" | "labs|wysiwyg_composer" | "theme|light_high_contrast" | "theme|match_system" | "a11y|recent_rooms" | "a11y|emoji_picker" | "a11y|user_menu" | "a11y|room_name" | "a11y|jump_first_invite" | "a11y|message_composer" | "a11y|n_unread_messages" | "a11y|n_unread_messages_mentions" | "a11y|room_status_bar" | "a11y|seek_bar_label" | "a11y|unread_messages" | "analytics|learn_more" | "analytics|accept_button" | "analytics|bullet_1" | "analytics|bullet_2" | "analytics|consent_migration" | "analytics|disable_prompt" | "analytics|enable_prompt" | "analytics|privacy_policy" | "analytics|pseudonymous_usage_data" | "analytics|shared_data_heading" | "bug_reporting|title" | "bug_reporting|description" | "bug_reporting|unsupported_browser" | "bug_reporting|additional_context" | "bug_reporting|before_submitting" | "bug_reporting|collecting_information" | "bug_reporting|collecting_logs" | "bug_reporting|create_new_issue" | "bug_reporting|download_logs" | "bug_reporting|downloading_logs" | "bug_reporting|error_empty" | "bug_reporting|failed_send_logs" | "bug_reporting|github_issue" | "bug_reporting|introduction" | "bug_reporting|log_request" | "bug_reporting|logs_sent" | "bug_reporting|matrix_security_issue" | "bug_reporting|preparing_download" | "bug_reporting|preparing_logs" | "bug_reporting|send_logs" | "bug_reporting|submit_debug_logs" | "bug_reporting|textarea_label" | "bug_reporting|thank_you" | "bug_reporting|uploading_logs" | "bug_reporting|waiting_for_server" | "chat_effects|confetti_description" | "chat_effects|confetti_message" | "chat_effects|fireworks_description" | "chat_effects|fireworks_message" | "chat_effects|hearts_description" | "chat_effects|hearts_message" | "chat_effects|rainfall_description" | "chat_effects|rainfall_message" | "chat_effects|snowfall_description" | "chat_effects|snowfall_message" | "chat_effects|spaceinvaders_description" | "chat_effects|spaceinvaders_message" | "composer|placeholder" | "composer|close_sticker_picker" | "composer|edit_composer_label" | "composer|format_bold" | "composer|format_code_block" | "composer|format_decrease_indent" | "composer|format_increase_indent" | "composer|format_inline_code" | "composer|format_insert_link" | "composer|format_italic" | "composer|format_italics" | "composer|format_link" | "composer|format_ordered_list" | "composer|format_strikethrough" | "composer|format_underline" | "composer|format_unordered_list" | "composer|formatting_toolbar_label" | "composer|mode_plain" | "composer|mode_rich_text" | "composer|no_perms_notice" | "composer|placeholder_encrypted" | "composer|placeholder_reply" | "composer|placeholder_reply_encrypted" | "composer|placeholder_thread" | "composer|placeholder_thread_encrypted" | "composer|poll_button" | "composer|poll_button_no_perms_description" | "composer|poll_button_no_perms_title" | "composer|replying_title" | "composer|room_upgraded_link" | "composer|room_upgraded_notice" | "composer|send_button_title" | "composer|send_button_voice_message" | "composer|send_voice_message" | "composer|stop_voice_message" | "composer|voice_message_button" | "composer|autocomplete|@room_description" | "composer|autocomplete|command_a11y" | "composer|autocomplete|command_description" | "composer|autocomplete|emoji_a11y" | "composer|autocomplete|notification_a11y" | "composer|autocomplete|notification_description" | "composer|autocomplete|room_a11y" | "composer|autocomplete|space_a11y" | "composer|autocomplete|user_a11y" | "composer|autocomplete|user_description" | "composer|link_modal|link_field_label" | "composer|link_modal|text_field_label" | "composer|link_modal|title_create" | "composer|link_modal|title_edit" | "create_room|error_title" | "create_room|action_create_room" | "create_room|action_create_video_room" | "create_room|encrypted_video_room_warning" | "create_room|encrypted_warning" | "create_room|encryption_forced" | "create_room|encryption_label" | "create_room|generic_error" | "create_room|join_rule_change_notice" | "create_room|join_rule_invite" | "create_room|join_rule_invite_label" | "create_room|join_rule_knock_label" | "create_room|join_rule_public_label" | "create_room|join_rule_public_parent_space_label" | "create_room|join_rule_restricted" | "create_room|join_rule_restricted_label" | "create_room|name_validation_required" | "create_room|room_visibility_label" | "create_room|title_private_room" | "create_room|title_public_room" | "create_room|title_video_room" | "create_room|topic_label" | "create_room|unfederated" | "create_room|unfederated_label_default_off" | "create_room|unfederated_label_default_on" | "create_room|unsupported_version" | "create_space|label" | "create_space|explainer" | "create_space|private_space" | "create_space|add_details_prompt" | "create_space|add_details_prompt_2" | "create_space|add_existing_rooms_description" | "create_space|add_existing_rooms_heading" | "create_space|address_label" | "create_space|address_placeholder" | "create_space|creating" | "create_space|creating_rooms" | "create_space|done_action" | "create_space|done_action_first_room" | "create_space|failed_create_initial_rooms" | "create_space|failed_invite_users" | "create_space|invite_teammates_by_username" | "create_space|invite_teammates_description" | "create_space|invite_teammates_heading" | "create_space|inviting_users" | "create_space|name_required" | "create_space|personal_space" | "create_space|personal_space_description" | "create_space|private_description" | "create_space|private_heading" | "create_space|private_personal_description" | "create_space|private_personal_heading" | "create_space|private_space_description" | "create_space|public_description" | "create_space|public_heading" | "create_space|search_public_button" | "create_space|setup_rooms_community_description" | "create_space|setup_rooms_community_heading" | "create_space|setup_rooms_description" | "create_space|setup_rooms_private_description" | "create_space|setup_rooms_private_heading" | "create_space|share_description" | "create_space|share_heading" | "create_space|skip_action" | "create_space|subspace_adding" | "create_space|subspace_beta_notice" | "create_space|subspace_dropdown_title" | "create_space|subspace_existing_space_prompt" | "create_space|subspace_join_rule_invite_description" | "create_space|subspace_join_rule_invite_only" | "create_space|subspace_join_rule_label" | "create_space|subspace_join_rule_public_description" | "create_space|subspace_join_rule_restricted_description" | "credits|default_cover_photo" | "credits|twemoji" | "credits|twemoji_colr" | "devtools|id" | "devtools|value" | "devtools|title" | "devtools|timeout" | "devtools|state_key" | "devtools|room_id" | "devtools|event_id" | "devtools|event_type" | "devtools|methods" | "devtools|phase" | "devtools|spaces" | "devtools|toolbox" | "devtools|event_content" | "devtools|active_widgets" | "devtools|category_other" | "devtools|category_room" | "devtools|caution_colon" | "devtools|client_versions" | "devtools|developer_mode" | "devtools|developer_tools" | "devtools|edit_setting" | "devtools|edit_values" | "devtools|empty_string" | "devtools|event_sent" | "devtools|explore_account_data" | "devtools|explore_room_account_data" | "devtools|explore_room_state" | "devtools|failed_to_find_widget" | "devtools|failed_to_load" | "devtools|failed_to_save" | "devtools|failed_to_send" | "devtools|invalid_json" | "devtools|level" | "devtools|low_bandwidth_mode" | "devtools|low_bandwidth_mode_description" | "devtools|main_timeline" | "devtools|no_receipt_found" | "devtools|no_verification_requests_found" | "devtools|notification_state" | "devtools|notifications_debug" | "devtools|number_of_users" | "devtools|original_event_source" | "devtools|other_user" | "devtools|phase_cancelled" | "devtools|phase_ready" | "devtools|phase_requested" | "devtools|phase_started" | "devtools|phase_transaction" | "devtools|room_encrypted" | "devtools|room_not_encrypted" | "devtools|room_notifications_dot" | "devtools|room_notifications_highlight" | "devtools|room_notifications_last_event" | "devtools|room_notifications_sender" | "devtools|room_notifications_thread_id" | "devtools|room_notifications_total" | "devtools|room_notifications_type" | "devtools|room_status" | "devtools|room_unread_status_count" | "devtools|save_setting_values" | "devtools|see_history" | "devtools|send_custom_account_data_event" | "devtools|send_custom_room_account_data_event" | "devtools|send_custom_state_event" | "devtools|send_custom_timeline_event" | "devtools|server_info" | "devtools|server_versions" | "devtools|settable_global" | "devtools|settable_room" | "devtools|setting_colon" | "devtools|setting_definition" | "devtools|setting_id" | "devtools|settings_explorer" | "devtools|show_hidden_events" | "devtools|thread_root_id" | "devtools|threads_timeline" | "devtools|timeout_none" | "devtools|toggle_event" | "devtools|use_at_own_risk" | "devtools|user_read_up_to" | "devtools|user_read_up_to_ignore_synthetic" | "devtools|user_read_up_to_private" | "devtools|user_read_up_to_private_ignore_synthetic" | "devtools|value_colon" | "devtools|value_in_this_room" | "devtools|value_this_room_colon" | "devtools|values_explicit" | "devtools|values_explicit_colon" | "devtools|values_explicit_room" | "devtools|values_explicit_this_room_colon" | "devtools|verification_explorer" | "devtools|view_servers_in_room" | "devtools|view_source_decrypted_event_source" | "devtools|view_source_decrypted_event_source_unavailable" | "devtools|widget_screenshots" | "emoji_picker|cancel_search_label" | "error_database_closed_description|for_desktop" | "error_database_closed_description|for_web" | "error_dialog|error_loading_user_profile" | "error_dialog|forget_room_failed" | "error_dialog|copy_room_link_failed|title" | "error_dialog|copy_room_link_failed|description" | "error_dialog|search_failed|title" | "error_dialog|search_failed|server_unavailable" | "event_preview|m.sticker" | "event_preview|m.text" | "event_preview|m.emote" | "event_preview|io.element.voice_broadcast_info|user" | "event_preview|io.element.voice_broadcast_info|you" | "event_preview|m.reaction|user" | "event_preview|m.reaction|you" | "event_preview|m.call.invite|user" | "event_preview|m.call.invite|you" | "event_preview|m.call.invite|dm_receive" | "event_preview|m.call.invite|dm_send" | "event_preview|m.call.answer|user" | "event_preview|m.call.answer|you" | "event_preview|m.call.answer|dm" | "event_preview|m.call.hangup|user" | "event_preview|m.call.hangup|you" | "export_chat|html" | "export_chat|title" | "export_chat|text" | "export_chat|json" | "export_chat|messages" | "export_chat|format" | "export_chat|cancelled" | "export_chat|topic" | "export_chat|cancelled_detail" | "export_chat|confirm_stop" | "export_chat|creating_html" | "export_chat|creating_output" | "export_chat|creator_summary" | "export_chat|current_timeline" | "export_chat|enter_number_between_min_max" | "export_chat|error_fetching_file" | "export_chat|export_info" | "export_chat|export_successful" | "export_chat|exported_n_events_in_time" | "export_chat|exporting_your_data" | "export_chat|fetched_n_events" | "export_chat|fetched_n_events_in_time" | "export_chat|fetched_n_events_with_total" | "export_chat|fetching_events" | "export_chat|file_attached" | "export_chat|from_the_beginning" | "export_chat|generating_zip" | "export_chat|html_title" | "export_chat|include_attachments" | "export_chat|media_omitted" | "export_chat|media_omitted_file_size" | "export_chat|next_page" | "export_chat|num_messages" | "export_chat|num_messages_min_max" | "export_chat|number_of_messages" | "export_chat|previous_page" | "export_chat|processing" | "export_chat|processing_event_n" | "export_chat|select_option" | "export_chat|size_limit" | "export_chat|size_limit_min_max" | "export_chat|size_limit_postfix" | "export_chat|starting_export" | "export_chat|successful" | "export_chat|successful_detail" | "export_chat|unload_confirm" | "file_panel|empty_description" | "file_panel|empty_heading" | "file_panel|guest_note" | "file_panel|peek_note" | "identity_server|url" | "identity_server|change" | "identity_server|checking" | "identity_server|disconnect" | "identity_server|error_invalid" | "identity_server|suggestions" | "identity_server|change_prompt" | "identity_server|change_server_prompt" | "identity_server|description_connected" | "identity_server|description_disconnected" | "identity_server|description_optional" | "identity_server|disconnect_anyway" | "identity_server|disconnect_offline_warning" | "identity_server|disconnect_personal_data_warning_1" | "identity_server|disconnect_personal_data_warning_2" | "identity_server|disconnect_server" | "identity_server|disconnect_warning" | "identity_server|do_not_use" | "identity_server|error_connection" | "identity_server|error_invalid_or_terms" | "identity_server|no_terms" | "identity_server|suggestions_1" | "identity_server|suggestions_2" | "identity_server|suggestions_3" | "identity_server|url_field_label" | "identity_server|url_not_https" | "integration_manager|connecting" | "integration_manager|explainer" | "integration_manager|error_connecting" | "integration_manager|error_connecting_heading" | "integration_manager|manage_title" | "integration_manager|use_im" | "integration_manager|use_im_default" | "integrations|disabled_dialog_description" | "integrations|disabled_dialog_title" | "integrations|impossible_dialog_description" | "integrations|impossible_dialog_title" | "keyboard|number" | "keyboard|search" | "keyboard|shift" | "keyboard|end" | "keyboard|home" | "keyboard|enter" | "keyboard|space" | "keyboard|alt" | "keyboard|control" | "keyboard|toggle_space_panel" | "keyboard|upload_file" | "keyboard|activate_button" | "keyboard|autocomplete_cancel" | "keyboard|autocomplete_force" | "keyboard|autocomplete_navigate_next" | "keyboard|autocomplete_navigate_prev" | "keyboard|backspace" | "keyboard|cancel_reply" | "keyboard|category_autocomplete" | "keyboard|category_calls" | "keyboard|category_navigation" | "keyboard|category_room_list" | "keyboard|close_dialog_menu" | "keyboard|composer_jump_end" | "keyboard|composer_jump_start" | "keyboard|composer_navigate_next_history" | "keyboard|composer_navigate_prev_history" | "keyboard|composer_new_line" | "keyboard|composer_redo" | "keyboard|composer_toggle_bold" | "keyboard|composer_toggle_code_block" | "keyboard|composer_toggle_italics" | "keyboard|composer_toggle_link" | "keyboard|composer_toggle_quote" | "keyboard|composer_undo" | "keyboard|dismiss_read_marker_and_jump_bottom" | "keyboard|escape" | "keyboard|go_home_view" | "keyboard|jump_first_message" | "keyboard|jump_last_message" | "keyboard|jump_room_search" | "keyboard|jump_to_read_marker" | "keyboard|keyboard_shortcuts_tab" | "keyboard|navigate_next_history" | "keyboard|navigate_next_message_edit" | "keyboard|navigate_prev_history" | "keyboard|navigate_prev_message_edit" | "keyboard|next_landmark" | "keyboard|next_room" | "keyboard|next_unread_room" | "keyboard|open_user_settings" | "keyboard|page_down" | "keyboard|page_up" | "keyboard|prev_landmark" | "keyboard|prev_room" | "keyboard|prev_unread_room" | "keyboard|room_list_collapse_section" | "keyboard|room_list_expand_section" | "keyboard|room_list_navigate_down" | "keyboard|room_list_navigate_up" | "keyboard|room_list_select_room" | "keyboard|scroll_down_timeline" | "keyboard|scroll_up_timeline" | "keyboard|send_sticker" | "keyboard|switch_to_space" | "keyboard|toggle_hidden_events" | "keyboard|toggle_microphone_mute" | "keyboard|toggle_right_panel" | "keyboard|toggle_top_left_menu" | "keyboard|toggle_webcam_mute" | "labs_mjolnir|title" | "labs_mjolnir|something_went_wrong" | "labs_mjolnir|ban_reason" | "labs_mjolnir|room_name" | "labs_mjolnir|advanced_warning" | "labs_mjolnir|error_adding_ignore" | "labs_mjolnir|error_adding_list_description" | "labs_mjolnir|error_adding_list_title" | "labs_mjolnir|error_removing_ignore" | "labs_mjolnir|error_removing_list_description" | "labs_mjolnir|error_removing_list_title" | "labs_mjolnir|explainer_1" | "labs_mjolnir|explainer_2" | "labs_mjolnir|lists" | "labs_mjolnir|lists_description_1" | "labs_mjolnir|lists_description_2" | "labs_mjolnir|lists_heading" | "labs_mjolnir|lists_new_label" | "labs_mjolnir|no_lists" | "labs_mjolnir|personal_description" | "labs_mjolnir|personal_empty" | "labs_mjolnir|personal_heading" | "labs_mjolnir|personal_new_label" | "labs_mjolnir|personal_new_placeholder" | "labs_mjolnir|personal_section" | "labs_mjolnir|room_topic" | "labs_mjolnir|rules_empty" | "labs_mjolnir|rules_server" | "labs_mjolnir|rules_title" | "labs_mjolnir|rules_user" | "labs_mjolnir|view_rules" | "leave_room_dialog|last_person_warning" | "leave_room_dialog|leave_room_question" | "leave_room_dialog|leave_space_question" | "leave_room_dialog|room_leave_admin_warning" | "leave_room_dialog|room_leave_mod_warning" | "leave_room_dialog|room_rejoin_warning" | "leave_room_dialog|space_rejoin_warning" | "left_panel|open_dial_pad" | "lightbox|title" | "lightbox|rotate_left" | "lightbox|rotate_right" | "location_sharing|failed_generic" | "location_sharing|MapStyleUrlNotConfigured" | "location_sharing|MapStyleUrlNotReachable" | "location_sharing|WebGLNotEnabled" | "location_sharing|click_drop_pin" | "location_sharing|click_move_pin" | "location_sharing|close_sidebar" | "location_sharing|error_fetch_location" | "location_sharing|error_no_perms_description" | "location_sharing|error_no_perms_title" | "location_sharing|error_send_description" | "location_sharing|error_send_title" | "location_sharing|error_sharing_live_location" | "location_sharing|error_sharing_live_location_try_again" | "location_sharing|error_stopping_live_location" | "location_sharing|error_stopping_live_location_try_again" | "location_sharing|expand_map" | "location_sharing|failed_load_map" | "location_sharing|failed_permission" | "location_sharing|failed_timeout" | "location_sharing|failed_unknown" | "location_sharing|find_my_location" | "location_sharing|live_description" | "location_sharing|live_enable_description" | "location_sharing|live_enable_heading" | "location_sharing|live_location_active" | "location_sharing|live_location_enabled" | "location_sharing|live_location_ended" | "location_sharing|live_location_error" | "location_sharing|live_locations_empty" | "location_sharing|live_share_button" | "location_sharing|live_toggle_label" | "location_sharing|live_until" | "location_sharing|live_update_time" | "location_sharing|loading_live_location" | "location_sharing|location_not_available" | "location_sharing|map_feedback" | "location_sharing|mapbox_logo" | "location_sharing|reset_bearing" | "location_sharing|share_button" | "location_sharing|share_type_live" | "location_sharing|share_type_own" | "location_sharing|share_type_pin" | "location_sharing|share_type_prompt" | "location_sharing|stop_and_close" | "location_sharing|toggle_attribution" | "member_list|filter_placeholder" | "member_list|invite_button_no_perms_tooltip" | "member_list|invited_list_heading" | "member_list|power_label" | "mobile_guide|toast_description" | "mobile_guide|toast_title" | "mobile_guide|toast_accept" | "notif_panel|empty_description" | "notif_panel|empty_heading" | "notifier|io.element.voice_broadcast_chunk" | "notifier|m.key.verification.request" | "onboarding|create_room" | "onboarding|explore_rooms" | "onboarding|no_avatar_label" | "onboarding|apple_trademarks" | "onboarding|community_messaging_action" | "onboarding|community_messaging_description" | "onboarding|community_messaging_title" | "onboarding|complete_these" | "onboarding|download_app" | "onboarding|download_app_action" | "onboarding|download_app_description" | "onboarding|download_app_store" | "onboarding|download_brand" | "onboarding|download_brand_desktop" | "onboarding|download_f_droid" | "onboarding|download_google_play" | "onboarding|enable_notifications" | "onboarding|enable_notifications_action" | "onboarding|enable_notifications_description" | "onboarding|find_community_members" | "onboarding|find_coworkers" | "onboarding|find_friends" | "onboarding|find_friends_action" | "onboarding|find_friends_description" | "onboarding|find_people" | "onboarding|free_e2ee_messaging_unlimited_voip" | "onboarding|get_stuff_done" | "onboarding|google_trademarks" | "onboarding|has_avatar_label" | "onboarding|intro_byline" | "onboarding|intro_welcome" | "onboarding|only_n_steps_to_go" | "onboarding|personal_messaging_action" | "onboarding|personal_messaging_title" | "onboarding|qr_or_app_links" | "onboarding|send_dm" | "onboarding|set_up_profile" | "onboarding|set_up_profile_action" | "onboarding|set_up_profile_description" | "onboarding|use_case_community_messaging" | "onboarding|use_case_heading1" | "onboarding|use_case_heading2" | "onboarding|use_case_heading3" | "onboarding|use_case_personal_messaging" | "onboarding|use_case_work_messaging" | "onboarding|welcome_detail" | "onboarding|welcome_to_brand" | "onboarding|welcome_user" | "onboarding|work_messaging_action" | "onboarding|work_messaging_title" | "onboarding|you_did_it" | "onboarding|you_made_it" | "pill|permalink_other_room" | "pill|permalink_this_room" | "poll|topic_label" | "poll|create_poll_action" | "poll|create_poll_title" | "poll|disclosed_notes" | "poll|edit_poll_title" | "poll|end_description" | "poll|end_message" | "poll|end_message_no_votes" | "poll|end_title" | "poll|error_ending_description" | "poll|error_ending_title" | "poll|error_voting_description" | "poll|error_voting_title" | "poll|failed_send_poll_description" | "poll|failed_send_poll_title" | "poll|notes" | "poll|options_add_button" | "poll|options_heading" | "poll|options_label" | "poll|options_placeholder" | "poll|topic_heading" | "poll|topic_placeholder" | "poll|total_decryption_errors" | "poll|total_n_votes" | "poll|total_n_votes_voted" | "poll|total_no_votes" | "poll|total_not_ended" | "poll|type_closed" | "poll|type_heading" | "poll|type_open" | "poll|unable_edit_description" | "poll|unable_edit_title" | "power_level|default" | "power_level|custom" | "power_level|label" | "power_level|restricted" | "power_level|admin" | "power_level|custom_level" | "power_level|mod" | "power_level|moderator" | "quick_settings|title" | "quick_settings|all_settings" | "quick_settings|metaspace_section" | "quick_settings|sidebar_settings" | "quit_warning|call_in_progress" | "quit_warning|file_upload_in_progress" | "reject_invitation_dialog|failed" | "reject_invitation_dialog|title" | "reject_invitation_dialog|confirmation" | "report_content|description" | "report_content|disagree" | "report_content|error_create_room_moderation_bot" | "report_content|hide_messages_from_user" | "report_content|ignore_user" | "report_content|illegal_content" | "report_content|missing_reason" | "report_content|nature" | "report_content|nature_disagreement" | "report_content|nature_illegal" | "report_content|nature_nonstandard_admin" | "report_content|nature_nonstandard_admin_encrypted" | "report_content|nature_other" | "report_content|nature_spam" | "report_content|nature_toxic" | "report_content|other_label" | "report_content|report_content_to_homeserver" | "report_content|report_entire_room" | "report_content|spam_or_propaganda" | "report_content|toxic_behaviour" | "restore_key_backup_dialog|enter_phrase_description" | "restore_key_backup_dialog|enter_phrase_title" | "restore_key_backup_dialog|count_of_decryption_failures" | "restore_key_backup_dialog|count_of_successfully_restored_keys" | "restore_key_backup_dialog|enter_key_description" | "restore_key_backup_dialog|enter_key_title" | "restore_key_backup_dialog|incorrect_security_phrase_dialog" | "restore_key_backup_dialog|incorrect_security_phrase_title" | "restore_key_backup_dialog|key_backup_warning" | "restore_key_backup_dialog|key_fetch_in_progress" | "restore_key_backup_dialog|key_forgotten_text" | "restore_key_backup_dialog|key_is_invalid" | "restore_key_backup_dialog|key_is_valid" | "restore_key_backup_dialog|keys_restored_title" | "restore_key_backup_dialog|load_error_content" | "restore_key_backup_dialog|load_keys_progress" | "restore_key_backup_dialog|no_backup_error" | "restore_key_backup_dialog|phrase_forgotten_text" | "restore_key_backup_dialog|recovery_key_mismatch_description" | "restore_key_backup_dialog|recovery_key_mismatch_title" | "restore_key_backup_dialog|restore_failed_error" | "right_panel|info" | "right_panel|add_integrations" | "right_panel|add_topic" | "right_panel|export_chat_button" | "right_panel|extensions_empty_description" | "right_panel|extensions_empty_title" | "right_panel|files_button" | "right_panel|pinned_messages_button" | "right_panel|polls_button" | "right_panel|widgets_section" | "right_panel|poll|loading" | "right_panel|poll|active_heading" | "right_panel|poll|empty_active" | "right_panel|poll|empty_active_load_more" | "right_panel|poll|empty_active_load_more_n_days" | "right_panel|poll|empty_past" | "right_panel|poll|empty_past_load_more" | "right_panel|poll|empty_past_load_more_n_days" | "right_panel|poll|final_result" | "right_panel|poll|load_more" | "right_panel|poll|past_heading" | "right_panel|poll|view_in_timeline" | "right_panel|poll|view_poll" | "right_panel|pinned_messages|view" | "right_panel|pinned_messages|header" | "right_panel|pinned_messages|menu" | "right_panel|pinned_messages|title" | "right_panel|pinned_messages|empty_description" | "right_panel|pinned_messages|empty_title" | "right_panel|pinned_messages|limits" | "right_panel|pinned_messages|reply_thread" | "right_panel|pinned_messages|unpin_all|button" | "right_panel|pinned_messages|unpin_all|content" | "right_panel|pinned_messages|unpin_all|title" | "right_panel|room_summary_card|title" | "right_panel|thread_list|context_menu_label" | "right_panel|video_room_chat|title" | "room_list|show_n_more" | "room_list|add_room_label" | "room_list|add_space_label" | "room_list|breadcrumbs_empty" | "room_list|breadcrumbs_label" | "room_list|failed_add_tag" | "room_list|failed_remove_tag" | "room_list|failed_set_dm_tag" | "room_list|home_menu_label" | "room_list|join_public_room_label" | "room_list|joining_rooms_status" | "room_list|notification_options" | "room_list|redacting_messages_status" | "room_list|show_less" | "room_list|show_previews" | "room_list|sort_by" | "room_list|sort_by_activity" | "room_list|sort_by_alphabet" | "room_list|sort_unread_first" | "room_list|space_menu_label" | "room_list|sublist_options" | "room_list|suggested_rooms_heading" | "room_settings|title" | "room_settings|security|strict_encryption" | "room_settings|alias_not_specified" | "room_settings|delete_avatar_label" | "room_settings|upload_avatar_label" | "room_settings|advanced|room_id" | "room_settings|advanced|room_version" | "room_settings|advanced|unfederated" | "room_settings|advanced|error_upgrade_description" | "room_settings|advanced|error_upgrade_title" | "room_settings|advanced|information_section_room" | "room_settings|advanced|information_section_space" | "room_settings|advanced|room_predecessor" | "room_settings|advanced|room_upgrade_button" | "room_settings|advanced|room_upgrade_warning" | "room_settings|advanced|room_version_section" | "room_settings|advanced|space_predecessor" | "room_settings|advanced|space_upgrade_button" | "room_settings|advanced|upgrade_button" | "room_settings|advanced|upgrade_dialog_description" | "room_settings|advanced|upgrade_dialog_description_1" | "room_settings|advanced|upgrade_dialog_description_2" | "room_settings|advanced|upgrade_dialog_description_3" | "room_settings|advanced|upgrade_dialog_description_4" | "room_settings|advanced|upgrade_dialog_title" | "room_settings|advanced|upgrade_dwarning_ialog_title_public" | "room_settings|advanced|upgrade_warning_dialog_description" | "room_settings|advanced|upgrade_warning_dialog_explainer" | "room_settings|advanced|upgrade_warning_dialog_footer" | "room_settings|advanced|upgrade_warning_dialog_invite_label" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt_link" | "room_settings|advanced|upgrade_warning_dialog_title" | "room_settings|advanced|upgrade_warning_dialog_title_private" | "room_settings|notifications|browse_button" | "room_settings|notifications|custom_sound_prompt" | "room_settings|notifications|notification_sound" | "room_settings|notifications|settings_link" | "room_settings|notifications|sounds_section" | "room_settings|notifications|upload_sound_label" | "room_settings|notifications|uploaded_sound" | "room_settings|visibility|title" | "room_settings|visibility|alias_section" | "room_settings|visibility|error_failed_save" | "room_settings|visibility|error_update_guest_access" | "room_settings|visibility|error_update_history_visibility" | "room_settings|visibility|guest_access_explainer" | "room_settings|visibility|guest_access_explainer_public_space" | "room_settings|visibility|guest_access_label" | "room_settings|visibility|history_visibility_anyone_space" | "room_settings|visibility|history_visibility_anyone_space_description" | "room_settings|visibility|history_visibility_anyone_space_recommendation" | "room_settings|security|title" | "room_settings|security|encryption_forced" | "room_settings|security|join_rule_invite" | "room_settings|security|join_rule_restricted" | "room_settings|security|enable_encryption_confirm_description" | "room_settings|security|enable_encryption_confirm_title" | "room_settings|security|enable_encryption_public_room_confirm_description_1" | "room_settings|security|enable_encryption_public_room_confirm_description_2" | "room_settings|security|enable_encryption_public_room_confirm_title" | "room_settings|security|encrypted_room_public_confirm_description_1" | "room_settings|security|encrypted_room_public_confirm_description_2" | "room_settings|security|encrypted_room_public_confirm_title" | "room_settings|security|encryption_permanent" | "room_settings|security|error_join_rule_change_title" | "room_settings|security|error_join_rule_change_unknown" | "room_settings|security|guest_access_warning" | "room_settings|security|history_visibility_invited" | "room_settings|security|history_visibility_joined" | "room_settings|security|history_visibility_legend" | "room_settings|security|history_visibility_shared" | "room_settings|security|history_visibility_warning" | "room_settings|security|history_visibility_world_readable" | "room_settings|security|join_rule_description" | "room_settings|security|join_rule_invite_description" | "room_settings|security|join_rule_knock" | "room_settings|security|join_rule_knock_description" | "room_settings|security|join_rule_public_description" | "room_settings|security|join_rule_restricted_description" | "room_settings|security|join_rule_restricted_description_active_space" | "room_settings|security|join_rule_restricted_description_prompt" | "room_settings|security|join_rule_restricted_description_spaces" | "room_settings|security|join_rule_restricted_dialog_description" | "room_settings|security|join_rule_restricted_dialog_empty_warning" | "room_settings|security|join_rule_restricted_dialog_filter_placeholder" | "room_settings|security|join_rule_restricted_dialog_heading_known" | "room_settings|security|join_rule_restricted_dialog_heading_other" | "room_settings|security|join_rule_restricted_dialog_heading_room" | "room_settings|security|join_rule_restricted_dialog_heading_space" | "room_settings|security|join_rule_restricted_dialog_heading_unknown" | "room_settings|security|join_rule_restricted_dialog_title" | "room_settings|security|join_rule_restricted_n_more" | "room_settings|security|join_rule_restricted_summary" | "room_settings|security|join_rule_restricted_upgrade_description" | "room_settings|security|join_rule_restricted_upgrade_warning" | "room_settings|security|join_rule_upgrade_awaiting_room" | "room_settings|security|join_rule_upgrade_required" | "room_settings|security|join_rule_upgrade_sending_invites" | "room_settings|security|join_rule_upgrade_updating_spaces" | "room_settings|security|join_rule_upgrade_upgrading_room" | "room_settings|security|public_without_alias_warning" | "room_settings|security|publish_room" | "room_settings|security|publish_space" | "room_settings|voip|call_type_section" | "room_settings|voip|enable_element_call_caption" | "room_settings|voip|enable_element_call_label" | "room_settings|voip|enable_element_call_no_permissions_tooltip" | "room_settings|general|save" | "room_settings|general|other_section" | "room_settings|general|alias_field_has_domain_invalid" | "room_settings|general|alias_field_has_localpart_invalid" | "room_settings|general|alias_field_matches_invalid" | "room_settings|general|alias_field_placeholder_default" | "room_settings|general|alias_field_required_invalid" | "room_settings|general|alias_field_safe_localpart_invalid" | "room_settings|general|alias_field_taken_invalid" | "room_settings|general|alias_field_taken_invalid_domain" | "room_settings|general|alias_field_taken_valid" | "room_settings|general|alias_heading" | "room_settings|general|aliases_items_label" | "room_settings|general|aliases_no_items_label" | "room_settings|general|aliases_section" | "room_settings|general|avatar_field_label" | "room_settings|general|canonical_alias_field_label" | "room_settings|general|default_url_previews_off" | "room_settings|general|default_url_previews_on" | "room_settings|general|description_space" | "room_settings|general|error_creating_alias_description" | "room_settings|general|error_creating_alias_title" | "room_settings|general|error_deleting_alias_description" | "room_settings|general|error_deleting_alias_description_forbidden" | "room_settings|general|error_deleting_alias_title" | "room_settings|general|error_save_space_settings" | "room_settings|general|error_updating_alias_description" | "room_settings|general|error_updating_canonical_alias_description" | "room_settings|general|error_updating_canonical_alias_title" | "room_settings|general|leave_space" | "room_settings|general|local_alias_field_label" | "room_settings|general|local_aliases_explainer_room" | "room_settings|general|local_aliases_explainer_space" | "room_settings|general|local_aliases_section" | "room_settings|general|name_field_label" | "room_settings|general|new_alias_placeholder" | "room_settings|general|no_aliases_room" | "room_settings|general|no_aliases_space" | "room_settings|general|publish_toggle" | "room_settings|general|published_aliases_description" | "room_settings|general|published_aliases_explainer_room" | "room_settings|general|published_aliases_explainer_space" | "room_settings|general|published_aliases_section" | "room_settings|general|topic_field_label" | "room_settings|general|url_preview_encryption_warning" | "room_settings|general|url_preview_explainer" | "room_settings|general|url_previews_section" | "room_settings|general|user_url_previews_default_off" | "room_settings|general|user_url_previews_default_on" | "room_settings|people|knock_empty" | "room_settings|people|knock_section" | "room_settings|people|see_less" | "room_settings|people|see_more" | "room_settings|access|title" | "room_settings|access|description_space" | "room_settings|bridges|title" | "room_settings|bridges|description" | "room_settings|bridges|empty" | "room_settings|permissions|title" | "room_settings|permissions|m.widget" | "room_settings|permissions|invite" | "room_settings|permissions|ban" | "room_settings|permissions|users_default" | "room_settings|permissions|events_default" | "room_settings|permissions|state_default" | "room_settings|permissions|kick" | "room_settings|permissions|redact" | "room_settings|permissions|m.room.history_visibility" | "room_settings|permissions|io.element.voice_broadcast_info" | "room_settings|permissions|m.reaction" | "room_settings|permissions|m.room.power_levels" | "room_settings|permissions|m.call" | "room_settings|permissions|m.room.canonical_alias" | "room_settings|permissions|m.room.name" | "room_settings|permissions|m.room.topic" | "room_settings|permissions|m.room.avatar" | "room_settings|permissions|m.room.pinned_events" | "room_settings|permissions|m.room.encryption" | "room_settings|permissions|m.room.server_acl" | "room_settings|permissions|m.room.tombstone" | "room_settings|permissions|m.space.child" | "room_settings|permissions|m.room.redaction" | "room_settings|permissions|ban_reason" | "room_settings|permissions|banned_by" | "room_settings|permissions|add_privileged_user_description" | "room_settings|permissions|add_privileged_user_filter_placeholder" | "room_settings|permissions|add_privileged_user_heading" | "room_settings|permissions|banned_users_section" | "room_settings|permissions|error_changing_pl_description" | "room_settings|permissions|error_changing_pl_reqs_description" | "room_settings|permissions|error_changing_pl_reqs_title" | "room_settings|permissions|error_changing_pl_title" | "room_settings|permissions|error_unbanning" | "room_settings|permissions|m.call.member" | "room_settings|permissions|m.room.avatar_space" | "room_settings|permissions|m.room.canonical_alias_space" | "room_settings|permissions|m.room.name_space" | "room_settings|permissions|m.room.topic_space" | "room_settings|permissions|muted_users_section" | "room_settings|permissions|no_privileged_users" | "room_settings|permissions|notifications.room" | "room_settings|permissions|permissions_section" | "room_settings|permissions|permissions_section_description_room" | "room_settings|permissions|permissions_section_description_space" | "room_settings|permissions|privileged_users_section" | "room_settings|permissions|send_event_type" | "scalar|error_create" | "scalar|error_membership" | "scalar|error_missing_room_id" | "scalar|error_missing_room_id_request" | "scalar|error_missing_user_id_request" | "scalar|error_permission" | "scalar|error_power_level_invalid" | "scalar|error_room_not_visible" | "scalar|error_room_unknown" | "scalar|error_send_request" | "scalar|failed_read_event" | "scalar|failed_send_event" | "server_offline|title" | "server_offline|description" | "server_offline|description_1" | "server_offline|description_2" | "server_offline|description_3" | "server_offline|description_4" | "server_offline|description_5" | "server_offline|description_6" | "server_offline|description_7" | "server_offline|description_8" | "server_offline|empty_timeline" | "server_offline|recent_changes_heading" | "seshat|reset_title" | "seshat|error_initialising" | "seshat|reset_button" | "seshat|reset_description" | "seshat|reset_explainer" | "seshat|warning_kind_files" | "seshat|warning_kind_files_app" | "seshat|warning_kind_search" | "seshat|warning_kind_search_app" | "setting|help_about|title" | "setting|help_about|versions" | "setting|help_about|identity_server" | "setting|help_about|dialog_title" | "setting|help_about|homeserver" | "setting|help_about|access_token_detail" | "setting|help_about|brand_version" | "setting|help_about|clear_cache_reload" | "setting|help_about|crypto_version" | "setting|help_about|help_link" | "share|link_title" | "share|permalink_message" | "share|permalink_most_recent" | "share|share_call" | "share|share_call_subtitle" | "share|title_link" | "share|title_message" | "share|title_room" | "share|title_user" | "slash_command|join" | "slash_command|view" | "slash_command|remove" | "slash_command|verify" | "slash_command|html" | "slash_command|query" | "slash_command|invite" | "slash_command|ban" | "slash_command|ignore" | "slash_command|topic" | "slash_command|help" | "slash_command|devtools" | "slash_command|unban" | "slash_command|unignore" | "slash_command|category_other" | "slash_command|addwidget" | "slash_command|addwidget_iframe_missing_src" | "slash_command|addwidget_invalid_protocol" | "slash_command|addwidget_missing_url" | "slash_command|addwidget_no_permissions" | "slash_command|category_actions" | "slash_command|category_admin" | "slash_command|category_advanced" | "slash_command|category_effects" | "slash_command|category_messages" | "slash_command|command_error" | "slash_command|converttodm" | "slash_command|converttoroom" | "slash_command|could_not_find_room" | "slash_command|deop" | "slash_command|discardsession" | "slash_command|error_invalid_rendering_type" | "slash_command|error_invalid_room" | "slash_command|error_invalid_runfn" | "slash_command|error_invalid_user_in_room" | "slash_command|help_dialog_title" | "slash_command|holdcall" | "slash_command|ignore_dialog_description" | "slash_command|ignore_dialog_title" | "slash_command|invite_3pid_needs_is_error" | "slash_command|invite_3pid_use_default_is_title" | "slash_command|invite_3pid_use_default_is_title_description" | "slash_command|invite_failed" | "slash_command|jumptodate" | "slash_command|jumptodate_invalid_input" | "slash_command|lenny" | "slash_command|me" | "slash_command|msg" | "slash_command|myavatar" | "slash_command|myroomavatar" | "slash_command|myroomnick" | "slash_command|nick" | "slash_command|no_active_call" | "slash_command|op" | "slash_command|part_unknown_alias" | "slash_command|plain" | "slash_command|query_not_found_phone_number" | "slash_command|rageshake" | "slash_command|rainbow" | "slash_command|rainbowme" | "slash_command|remakeolm" | "slash_command|roomavatar" | "slash_command|roomname" | "slash_command|server_error" | "slash_command|server_error_detail" | "slash_command|shrug" | "slash_command|spoiler" | "slash_command|tableflip" | "slash_command|topic_none" | "slash_command|topic_room_error" | "slash_command|tovirtual" | "slash_command|tovirtual_not_found" | "slash_command|unflip" | "slash_command|unholdcall" | "slash_command|unignore_dialog_description" | "slash_command|unignore_dialog_title" | "slash_command|unknown_command" | "slash_command|unknown_command_button" | "slash_command|unknown_command_detail" | "slash_command|unknown_command_help" | "slash_command|unknown_command_hint" | "slash_command|upgraderoom" | "slash_command|upgraderoom_permission_error" | "slash_command|usage" | "slash_command|verify_mismatch" | "slash_command|verify_nop" | "slash_command|verify_nop_warning_mismatch" | "slash_command|verify_success_description" | "slash_command|verify_success_title" | "slash_command|verify_unknown_pair" | "slash_command|whois" | "space_settings|title" | "spotlight|public_rooms|network_dropdown_add_dialog_description" | "spotlight|public_rooms|network_dropdown_add_dialog_placeholder" | "spotlight|public_rooms|network_dropdown_add_dialog_title" | "spotlight|public_rooms|network_dropdown_add_server_option" | "spotlight|public_rooms|network_dropdown_available_invalid" | "spotlight|public_rooms|network_dropdown_available_invalid_forbidden" | "spotlight|public_rooms|network_dropdown_available_valid" | "spotlight|public_rooms|network_dropdown_remove_server_adornment" | "spotlight|public_rooms|network_dropdown_required_invalid" | "spotlight|public_rooms|network_dropdown_selected_label" | "spotlight|public_rooms|network_dropdown_selected_label_instance" | "spotlight|public_rooms|network_dropdown_your_server_description" | "spotlight_dialog|cant_find_person_helpful_hint" | "spotlight_dialog|cant_find_room_helpful_hint" | "spotlight_dialog|copy_link_text" | "spotlight_dialog|count_of_members" | "spotlight_dialog|create_new_room_button" | "spotlight_dialog|failed_querying_public_rooms" | "spotlight_dialog|failed_querying_public_spaces" | "spotlight_dialog|group_chat_section_title" | "spotlight_dialog|heading_with_query" | "spotlight_dialog|heading_without_query" | "spotlight_dialog|join_button_text" | "spotlight_dialog|keyboard_scroll_hint" | "spotlight_dialog|message_search_section_title" | "spotlight_dialog|other_rooms_in_space" | "spotlight_dialog|public_rooms_label" | "spotlight_dialog|public_spaces_label" | "spotlight_dialog|recent_searches_section_title" | "spotlight_dialog|recently_viewed_section_title" | "spotlight_dialog|remove_filter" | "spotlight_dialog|result_may_be_hidden_privacy_warning" | "spotlight_dialog|result_may_be_hidden_warning" | "spotlight_dialog|search_dialog" | "spotlight_dialog|search_messages_hint" | "spotlight_dialog|spaces_title" | "spotlight_dialog|start_group_chat_button" | "stickers|empty" | "stickers|empty_add_prompt" | "terms|integration_manager" | "terms|intro" | "terms|column_document" | "terms|column_service" | "terms|column_summary" | "terms|identity_server_no_terms_description_1" | "terms|identity_server_no_terms_description_2" | "terms|identity_server_no_terms_title" | "terms|inline_intro_text" | "terms|summary_identity_server_1" | "terms|summary_identity_server_2" | "terms|tac_button" | "terms|tac_description" | "terms|tac_title" | "terms|tos" | "threads_activity_centre|header" | "threads_activity_centre|release_announcement_description" | "threads_activity_centre|release_announcement_header" | "threads_activity_centre|no_rooms_with_threads_notifs" | "threads_activity_centre|no_rooms_with_unread_threads" | "unsupported_browser|title" | "unsupported_browser|description" | "update_room_access_modal|title" | "update_room_access_modal|description" | "update_room_access_modal|no_change" | "update_room_access_modal|dont_change_description" | "upload_file|title" | "upload_file|error_title" | "upload_file|cancel_all_button" | "upload_file|error_file_too_large" | "upload_file|error_files_too_large" | "upload_file|error_some_files_too_large" | "upload_file|title_progress" | "upload_file|upload_all_button" | "upload_file|upload_n_others_button" | "user_info|redact|confirm_button" | "user_info|dehydrated_device_enabled" | "user_info|room_encrypted" | "user_info|share_button" | "user_info|admin_tools_section" | "user_info|ban_button_room" | "user_info|ban_button_space" | "user_info|ban_room_confirm_title" | "user_info|ban_space_everything" | "user_info|ban_space_specific" | "user_info|count_of_sessions" | "user_info|count_of_verified_sessions" | "user_info|deactivate_confirm_action" | "user_info|deactivate_confirm_description" | "user_info|deactivate_confirm_title" | "user_info|demote_button" | "user_info|demote_self_confirm_description_space" | "user_info|demote_self_confirm_room" | "user_info|demote_self_confirm_title" | "user_info|disinvite_button_room" | "user_info|disinvite_button_room_name" | "user_info|disinvite_button_space" | "user_info|edit_own_devices" | "user_info|error_ban_user" | "user_info|error_deactivate" | "user_info|error_kicking_user" | "user_info|error_mute_user" | "user_info|error_revoke_3pid_invite_description" | "user_info|error_revoke_3pid_invite_title" | "user_info|hide_sessions" | "user_info|hide_verified_sessions" | "user_info|ignore_button" | "user_info|ignore_confirm_description" | "user_info|ignore_confirm_title" | "user_info|invited_by" | "user_info|jump_to_rr_button" | "user_info|kick_button_room" | "user_info|kick_button_room_name" | "user_info|kick_button_space" | "user_info|kick_button_space_everything" | "user_info|kick_space_specific" | "user_info|kick_space_warning" | "user_info|promote_warning" | "user_info|redact_button" | "user_info|revoke_invite" | "user_info|room_encrypted_detail" | "user_info|room_unencrypted" | "user_info|room_unencrypted_detail" | "user_info|send_message" | "user_info|unban_button_room" | "user_info|unban_button_space" | "user_info|unban_room_confirm_title" | "user_info|unban_space_everything" | "user_info|unban_space_specific" | "user_info|unban_space_warning" | "user_info|unignore_button" | "user_info|verify_button" | "user_info|verify_explainer" | "user_info|redact|confirm_description_1" | "user_info|redact|confirm_description_2" | "user_info|redact|confirm_keep_state_explainer" | "user_info|redact|confirm_keep_state_label" | "user_info|redact|confirm_title" | "user_info|redact|no_recent_messages_description" | "user_info|redact|no_recent_messages_title" | "user_menu|settings" | "user_menu|link_new_device" | "user_menu|link_new_device_not_supported" | "user_menu|link_new_device_not_supported_caption" | "user_menu|switch_theme_dark" | "user_menu|switch_theme_light" | "voice_message|cant_start_broadcast_description" | "voice_message|cant_start_broadcast_title" | "widget|error_loading" | "widget|unencrypted_warning" | "widget|added_by" | "widget|close_to_view_right_panel" | "widget|cookie_warning" | "widget|error_hangup_description" | "widget|error_hangup_title" | "widget|error_mixed_content" | "widget|error_need_invite_permission" | "widget|error_need_kick_permission" | "widget|error_need_to_be_logged_in" | "widget|error_unable_start_audio_stream_description" | "widget|error_unable_start_audio_stream_title" | "widget|modal_data_warning" | "widget|modal_title_default" | "widget|no_name" | "widget|popout" | "widget|set_room_layout" | "widget|shared_data_avatar" | "widget|shared_data_device_id" | "widget|shared_data_lang" | "widget|shared_data_mxid" | "widget|shared_data_name" | "widget|shared_data_room_id" | "widget|shared_data_theme" | "widget|shared_data_url" | "widget|shared_data_warning" | "widget|shared_data_warning_im" | "widget|shared_data_widget_id" | "widget|unmaximise" | "widget|unpin_to_view_right_panel" | "widget|context_menu|remove" | "widget|context_menu|screenshot" | "widget|context_menu|delete" | "widget|context_menu|revoke" | "widget|context_menu|delete_warning" | "widget|context_menu|move_left" | "widget|context_menu|move_right" | "widget|context_menu|start_audio_stream" | "widget|capabilities_dialog|title" | "widget|capabilities_dialog|content_starting_text" | "widget|capabilities_dialog|decline_all_permission" | "widget|capabilities_dialog|remember_Selection" | "widget|capability|capability" | "widget|capability|always_on_screen_generic" | "widget|capability|always_on_screen_viewing_another_room" | "widget|capability|any_room" | "widget|capability|byline_empty_state_key" | "widget|capability|byline_state_key" | "widget|capability|change_avatar_active_room" | "widget|capability|change_avatar_this_room" | "widget|capability|change_name_active_room" | "widget|capability|change_name_this_room" | "widget|capability|change_topic_active_room" | "widget|capability|change_topic_this_room" | "widget|capability|receive_membership_active_room" | "widget|capability|receive_membership_this_room" | "widget|capability|remove_ban_invite_leave_active_room" | "widget|capability|remove_ban_invite_leave_this_room" | "widget|capability|see_avatar_change_active_room" | "widget|capability|see_avatar_change_this_room" | "widget|capability|see_event_type_sent_active_room" | "widget|capability|see_event_type_sent_this_room" | "widget|capability|see_images_sent_active_room" | "widget|capability|see_images_sent_this_room" | "widget|capability|see_messages_sent_active_room" | "widget|capability|see_messages_sent_this_room" | "widget|capability|see_msgtype_sent_active_room" | "widget|capability|see_msgtype_sent_this_room" | "widget|capability|see_name_change_active_room" | "widget|capability|see_name_change_this_room" | "widget|capability|see_sent_emotes_active_room" | "widget|capability|see_sent_emotes_this_room" | "widget|capability|see_sent_files_active_room" | "widget|capability|see_sent_files_this_room" | "widget|capability|see_sticker_posted_active_room" | "widget|capability|see_sticker_posted_this_room" | "widget|capability|see_text_messages_sent_active_room" | "widget|capability|see_text_messages_sent_this_room" | "widget|capability|see_topic_change_active_room" | "widget|capability|see_topic_change_this_room" | "widget|capability|see_videos_sent_active_room" | "widget|capability|see_videos_sent_this_room" | "widget|capability|send_emotes_active_room" | "widget|capability|send_emotes_this_room" | "widget|capability|send_event_type_active_room" | "widget|capability|send_event_type_this_room" | "widget|capability|send_files_active_room" | "widget|capability|send_files_this_room" | "widget|capability|send_images_active_room" | "widget|capability|send_images_this_room" | "widget|capability|send_messages_active_room" | "widget|capability|send_messages_this_room" | "widget|capability|send_msgtype_active_room" | "widget|capability|send_msgtype_this_room" | "widget|capability|send_stickers_active_room" | "widget|capability|send_stickers_active_room_as_you" | "widget|capability|send_stickers_this_room" | "widget|capability|send_stickers_this_room_as_you" | "widget|capability|send_text_messages_active_room" | "widget|capability|send_text_messages_this_room" | "widget|capability|send_videos_active_room" | "widget|capability|send_videos_this_room" | "widget|capability|specific_room" | "widget|capability|switch_room" | "widget|capability|switch_room_message_user" | "widget|open_id_permissions_dialog|title" | "widget|open_id_permissions_dialog|remember_selection" | "widget|open_id_permissions_dialog|starting_text" | "zxcvbn|suggestions|allUppercase" | "zxcvbn|suggestions|anotherWord" | "zxcvbn|suggestions|associatedYears" | "zxcvbn|suggestions|capitalization" | "zxcvbn|suggestions|dates" | "zxcvbn|suggestions|l33t" | "zxcvbn|suggestions|longerKeyboardPattern" | "zxcvbn|suggestions|noNeed" | "zxcvbn|suggestions|pwned" | "zxcvbn|suggestions|recentYears" | "zxcvbn|suggestions|repeated" | "zxcvbn|suggestions|reverseWords" | "zxcvbn|suggestions|sequences" | "zxcvbn|suggestions|useWords" | "zxcvbn|warnings|common" | "zxcvbn|warnings|dates" | "zxcvbn|warnings|pwned" | "zxcvbn|warnings|recentYears" | "zxcvbn|warnings|sequences" | "zxcvbn|warnings|commonNames" | "zxcvbn|warnings|extendedRepeat" | "zxcvbn|warnings|keyPattern" | "zxcvbn|warnings|namesByThemselves" | "zxcvbn|warnings|similarToCommon" | "zxcvbn|warnings|simpleRepeat" | "zxcvbn|warnings|straightRow" | "zxcvbn|warnings|topHundred" | "zxcvbn|warnings|topTen" | "zxcvbn|warnings|userInputs" | "zxcvbn|warnings|wordByItself";
        labelStrongPassword: "a11y_jump_first_unread_room" | "cannot_invite_without_identity_server" | "cannot_reach_homeserver" | "cannot_reach_homeserver_detail" | "cant_load_page" | "chat_card_back_action_label" | "console_dev_note" | "console_scam_warning" | "console_wait" | "dialog_close_label" | "empty_room" | "empty_room_was_name" | "error_app_open_in_another_tab" | "error_app_open_in_another_tab_title" | "error_app_opened_in_another_window" | "error_database_closed_title" | "error_user_not_logged_in" | "failed_load_async_component" | "in_space" | "in_space1_and_space2" | "in_space_and_n_other_spaces" | "info_tooltip_title" | "inviting_user1_and_user2" | "inviting_user_and_n_others" | "items_and_n_others" | "language_dropdown_label" | "member_list_back_action_label" | "message_edit_dialog_title" | "migrating_crypto" | "name_and_id" | "no_more_results" | "room_summary_card_back_action_label" | "thread_view_back_action_label" | "truncated_list_n_more" | "unsupported_server_description" | "unsupported_server_title" | "upload_failed_generic" | "upload_failed_size" | "upload_failed_title" | "emoji|categories" | "emoji|category_activities" | "emoji|category_animals_nature" | "emoji|category_flags" | "emoji|category_food_drink" | "emoji|category_frequently_used" | "emoji|category_objects" | "emoji|category_smileys_people" | "emoji|category_symbols" | "emoji|category_travel_places" | "emoji|quick_reactions" | "time|left" | "time|about_day_ago" | "time|about_hour_ago" | "time|about_minute_ago" | "time|date_at_time" | "time|few_seconds_ago" | "time|hours_minutes_seconds_left" | "time|in_about_day" | "time|in_about_hour" | "time|in_about_minute" | "time|in_few_seconds" | "time|in_n_days" | "time|in_n_hours" | "time|in_n_minutes" | "time|minutes_seconds_left" | "time|n_days_ago" | "time|n_hours_ago" | "time|n_minutes_ago" | "time|seconds_left" | "time|short_days" | "time|short_days_hours_minutes_seconds" | "time|short_hours" | "time|short_hours_minutes_seconds" | "time|short_minutes" | "time|short_minutes_seconds" | "time|short_seconds" | "error|sync" | "error|unknown" | "error|admin_contact" | "error|connection" | "error|admin_contact_short" | "error|dialog_description_default" | "error|download_media" | "error|edit_history_unsupported" | "error|failed_copy" | "error|hs_blocked" | "error|mau" | "error|mixed_content" | "error|non_urgent_echo_failure_toast" | "error|resource_limits" | "error|something_went_wrong" | "error|storage_evicted_description_1" | "error|storage_evicted_description_2" | "error|storage_evicted_title" | "error|tls" | "error|unknown_error_code" | "error|update_power_level" | "error|session_restore|title" | "error|session_restore|clear_storage_button" | "error|session_restore|clear_storage_description" | "error|session_restore|description_1" | "error|session_restore|description_2" | "error|session_restore|description_3" | "feedback|sent" | "feedback|can_contact_label" | "feedback|comment_label" | "feedback|existing_issue_link" | "feedback|may_contact_label" | "feedback|platform_username" | "feedback|pro_type" | "feedback|send_feedback_action" | "timeline|m.sticker" | "timeline|m.poll.start" | "timeline|io.element.widgets.layout" | "timeline|m.room.topic" | "timeline|m.room.tombstone" | "timeline|creation_summary_dm" | "timeline|creation_summary_room" | "timeline|disambiguated_profile" | "timeline|download_action_decrypting" | "timeline|download_action_downloading" | "timeline|download_failed" | "timeline|download_failed_description" | "timeline|error_no_renderer" | "timeline|error_rendering_message" | "timeline|historical_messages_unavailable" | "timeline|in_room_name" | "timeline|late_event_separator" | "timeline|message_timestamp_received_at" | "timeline|message_timestamp_sent_at" | "timeline|no_permission_messages_before_invite" | "timeline|no_permission_messages_before_join" | "timeline|pending_moderation" | "timeline|pending_moderation_reason" | "timeline|read_receipt_title" | "timeline|read_receipts_label" | "timeline|redaction" | "timeline|self_redaction" | "timeline|send_state_encrypting" | "timeline|send_state_failed" | "timeline|send_state_sending" | "timeline|send_state_sent" | "timeline|thread_info_basic" | "timeline|undecryptable_tooltip" | "timeline|summary|left" | "timeline|summary|invited" | "timeline|summary|joined" | "timeline|summary|format" | "timeline|summary|redacted" | "timeline|summary|banned" | "timeline|summary|banned_multiple" | "timeline|summary|changed_avatar" | "timeline|summary|changed_avatar_multiple" | "timeline|summary|changed_name" | "timeline|summary|changed_name_multiple" | "timeline|summary|hidden_event" | "timeline|summary|hidden_event_multiple" | "timeline|summary|invite_withdrawn" | "timeline|summary|invite_withdrawn_multiple" | "timeline|summary|invited_multiple" | "timeline|summary|joined_and_left" | "timeline|summary|joined_and_left_multiple" | "timeline|summary|joined_multiple" | "timeline|summary|kicked" | "timeline|summary|kicked_multiple" | "timeline|summary|left_multiple" | "timeline|summary|no_change" | "timeline|summary|no_change_multiple" | "timeline|summary|pinned_events" | "timeline|summary|pinned_events_multiple" | "timeline|summary|redacted_multiple" | "timeline|summary|rejected_invite" | "timeline|summary|rejected_invite_multiple" | "timeline|summary|rejoined" | "timeline|summary|rejoined_multiple" | "timeline|summary|server_acls" | "timeline|summary|server_acls_multiple" | "timeline|summary|unbanned" | "timeline|summary|unbanned_multiple" | "timeline|m.widget|removed" | "timeline|m.widget|added" | "timeline|m.widget|jitsi_ended" | "timeline|m.widget|jitsi_join_right_prompt" | "timeline|m.widget|jitsi_join_top_prompt" | "timeline|m.widget|jitsi_started" | "timeline|m.widget|jitsi_updated" | "timeline|m.widget|modified" | "timeline|m.poll.end|ended" | "timeline|m.poll.end|sender_ended" | "timeline|m.location|location" | "timeline|m.location|full" | "timeline|m.location|self_location" | "timeline|m.beacon_info|view_live_location" | "timeline|m.room.history_visibility|shared" | "timeline|m.room.history_visibility|unknown" | "timeline|m.room.history_visibility|invited" | "timeline|m.room.history_visibility|joined" | "timeline|m.room.history_visibility|world_readable" | "timeline|m.key.verification.request|user_wants_to_verify" | "timeline|m.key.verification.request|you_started" | "timeline|m.video|error_decrypting" | "timeline|io.element.voice_broadcast_info|user" | "timeline|io.element.voice_broadcast_info|you" | "timeline|m.room.power_levels|changed" | "timeline|m.room.power_levels|user_from_to" | "timeline|m.call|video_call_ended" | "timeline|m.call|video_call_started" | "timeline|m.call|video_call_started_text" | "timeline|m.call|video_call_started_unsupported" | "timeline|m.room.canonical_alias|set" | "timeline|m.room.canonical_alias|removed" | "timeline|m.room.canonical_alias|changed" | "timeline|m.room.canonical_alias|alt_added" | "timeline|m.room.canonical_alias|alt_removed" | "timeline|m.room.canonical_alias|changed_alternative" | "timeline|m.room.canonical_alias|changed_main_and_alternative" | "timeline|m.room.create|continuation" | "timeline|m.room.create|see_older_messages" | "timeline|m.room.create|unknown_predecessor" | "timeline|m.room.create|unknown_predecessor_guess_server" | "timeline|m.room.join_rules|public" | "timeline|m.room.join_rules|unknown" | "timeline|m.room.join_rules|invite" | "timeline|m.room.join_rules|knock" | "timeline|m.room.join_rules|restricted" | "timeline|m.room.join_rules|restricted_settings" | "timeline|m.room.member|join" | "timeline|m.room.member|left" | "timeline|m.room.member|invite" | "timeline|m.room.member|ban" | "timeline|m.room.member|kick" | "timeline|m.room.member|no_change" | "timeline|m.room.member|accepted_3pid_invite" | "timeline|m.room.member|accepted_invite" | "timeline|m.room.member|ban_reason" | "timeline|m.room.member|change_avatar" | "timeline|m.room.member|change_name" | "timeline|m.room.member|change_name_avatar" | "timeline|m.room.member|kick_reason" | "timeline|m.room.member|left_reason" | "timeline|m.room.member|reject_invite" | "timeline|m.room.member|remove_avatar" | "timeline|m.room.member|remove_name" | "timeline|m.room.member|set_avatar" | "timeline|m.room.member|set_name" | "timeline|m.room.member|unban" | "timeline|m.room.member|withdrew_invite" | "timeline|m.room.member|withdrew_invite_reason" | "timeline|m.room.third_party_invite|sent" | "timeline|m.room.third_party_invite|revoked" | "timeline|m.room.name|set" | "timeline|m.room.name|remove" | "timeline|m.room.name|change" | "timeline|m.room.avatar|removed" | "timeline|m.room.avatar|changed" | "timeline|m.room.avatar|changed_img" | "timeline|m.room.avatar|lightbox_title" | "timeline|m.room.pinned_events|changed" | "timeline|m.room.pinned_events|changed_link" | "timeline|m.room.pinned_events|pinned" | "timeline|m.room.pinned_events|pinned_link" | "timeline|m.room.pinned_events|unpinned" | "timeline|m.room.pinned_events|unpinned_link" | "timeline|m.room.encryption|disabled" | "timeline|m.room.encryption|enabled" | "timeline|m.room.encryption|disable_attempt" | "timeline|m.room.encryption|enabled_dm" | "timeline|m.room.encryption|enabled_local" | "timeline|m.room.encryption|parameters_changed" | "timeline|m.room.encryption|unsupported" | "timeline|m.room.guest_access|unknown" | "timeline|m.room.guest_access|can_join" | "timeline|m.room.guest_access|forbidden" | "timeline|m.room.server_acl|set" | "timeline|m.room.server_acl|changed" | "timeline|m.room.server_acl|all_servers_banned" | "timeline|m.call.invite|answered_elsewhere" | "timeline|m.call.invite|call_back_prompt" | "timeline|m.call.invite|declined" | "timeline|m.call.invite|failed_connect_media" | "timeline|m.call.invite|failed_connection" | "timeline|m.call.invite|failed_opponent_media" | "timeline|m.call.invite|missed_call" | "timeline|m.call.invite|no_answer" | "timeline|m.call.invite|unknown_error" | "timeline|m.call.invite|unknown_failure" | "timeline|m.call.invite|unknown_state" | "timeline|m.call.invite|video_call" | "timeline|m.call.invite|video_call_unsupported" | "timeline|m.call.invite|voice_call" | "timeline|m.call.invite|voice_call_unsupported" | "timeline|m.call.hangup|dm" | "timeline|m.image|error" | "timeline|m.image|sent" | "timeline|m.image|error_decrypting" | "timeline|m.image|error_downloading" | "timeline|m.image|show_image" | "timeline|m.file|error_decrypting" | "timeline|m.file|decrypt_label" | "timeline|m.file|download_label" | "timeline|m.file|error_invalid" | "timeline|m.audio|error_downloading_audio" | "timeline|m.audio|error_processing_audio" | "timeline|m.audio|error_processing_voice_message" | "timeline|m.audio|unnamed_audio" | "timeline|context_menu|report" | "timeline|context_menu|collapse_reply_thread" | "timeline|context_menu|external_url" | "timeline|context_menu|open_in_osm" | "timeline|context_menu|resent_unsent_reactions" | "timeline|context_menu|show_url_preview" | "timeline|context_menu|view_related_event" | "timeline|context_menu|view_source" | "timeline|decryption_failure|blocked" | "timeline|decryption_failure|historical_event_no_key_backup" | "timeline|decryption_failure|historical_event_unverified_device" | "timeline|decryption_failure|historical_event_user_not_joined" | "timeline|decryption_failure|unable_to_decrypt" | "timeline|edits|tooltip_label" | "timeline|edits|tooltip_sub" | "timeline|edits|tooltip_title" | "timeline|load_error|title" | "timeline|load_error|no_permission" | "timeline|load_error|unable_to_find" | "timeline|m.poll|count_of_votes" | "timeline|mab|label" | "timeline|mab|collapse_reply_chain" | "timeline|mab|copy_link_thread" | "timeline|mab|expand_reply_chain" | "timeline|mab|view_in_room" | "timeline|mjolnir|changed_rule_glob" | "timeline|mjolnir|changed_rule_rooms" | "timeline|mjolnir|changed_rule_servers" | "timeline|mjolnir|changed_rule_users" | "timeline|mjolnir|created_rule" | "timeline|mjolnir|created_rule_rooms" | "timeline|mjolnir|created_rule_servers" | "timeline|mjolnir|created_rule_users" | "timeline|mjolnir|message_hidden" | "timeline|mjolnir|removed_rule" | "timeline|mjolnir|removed_rule_rooms" | "timeline|mjolnir|removed_rule_servers" | "timeline|mjolnir|removed_rule_users" | "timeline|mjolnir|updated_invalid_rule" | "timeline|mjolnir|updated_rule" | "timeline|mjolnir|updated_rule_rooms" | "timeline|mjolnir|updated_rule_servers" | "timeline|mjolnir|updated_rule_users" | "timeline|reactions|label" | "timeline|reactions|add_reaction_prompt" | "timeline|reactions|custom_reaction_fallback_label" | "timeline|reactions|tooltip_caption" | "timeline|redacted|tooltip" | "timeline|reply|error_loading" | "timeline|reply|in_reply_to" | "timeline|reply|in_reply_to_for_export" | "timeline|scalar_starter_link|dialog_description" | "timeline|scalar_starter_link|dialog_title" | "timeline|typing_indicator|more_users" | "timeline|typing_indicator|one_user" | "timeline|typing_indicator|two_users" | "timeline|url_preview|close" | "timeline|url_preview|show_n_more" | "notifications|default" | "notifications|all_messages" | "notifications|all_messages_description" | "notifications|class_global" | "notifications|class_other" | "notifications|email_pusher_app_display_name" | "notifications|enable_prompt_toast_description" | "notifications|enable_prompt_toast_title" | "notifications|enable_prompt_toast_title_from_message_send" | "notifications|error_change_title" | "notifications|keyword" | "notifications|keyword_new" | "notifications|level_activity" | "notifications|level_highlight" | "notifications|level_muted" | "notifications|level_none" | "notifications|level_notification" | "notifications|level_unsent" | "notifications|mark_all_read" | "notifications|mentions_and_keywords" | "notifications|mentions_and_keywords_description" | "notifications|mentions_keywords" | "notifications|message_didnt_send" | "notifications|mute_description" | "action|search" | "action|join" | "action|add" | "action|show" | "action|pause" | "action|play" | "action|stop" | "action|reload" | "action|start" | "action|view" | "action|cancel" | "action|remove" | "action|clear" | "action|copy" | "action|verify" | "action|complete" | "action|change" | "action|click" | "action|close" | "action|reset" | "action|submit" | "action|forward" | "action|next" | "action|done" | "action|resume" | "action|refresh" | "action|disconnect" | "action|update" | "action|confirm" | "action|ok" | "action|invite" | "action|leave" | "action|ignore" | "action|register" | "action|reject" | "action|delete" | "action|pin" | "action|download" | "action|upload" | "action|save" | "action|apply" | "action|call" | "action|collapse" | "action|accept" | "action|yes" | "action|no" | "action|go" | "action|upgrade" | "action|rename" | "action|continue" | "action|skip" | "action|disable" | "action|enable" | "action|report_content" | "action|share" | "action|upload_file" | "action|reply" | "action|set_avatar" | "action|unban" | "action|view_source" | "action|add_existing_room" | "action|add_people" | "action|approve" | "action|ask_to_join" | "action|back" | "action|click_to_copy" | "action|copy_link" | "action|create" | "action|create_a_room" | "action|decline" | "action|deny" | "action|dismiss" | "action|edit" | "action|enter_fullscreen" | "action|exit_fullscreeen" | "action|expand" | "action|explore_public_rooms" | "action|explore_rooms" | "action|export" | "action|go_back" | "action|got_it" | "action|hide_advanced" | "action|hold" | "action|import" | "action|invite_to_space" | "action|invites_list" | "action|learn_more" | "action|leave_room" | "action|logout" | "action|manage" | "action|maximise" | "action|mention" | "action|minimise" | "action|new_room" | "action|new_video_room" | "action|proceed" | "action|quote" | "action|react" | "action|reply_in_thread" | "action|resend" | "action|restore" | "action|retry" | "action|review" | "action|revoke" | "action|send_report" | "action|show_advanced" | "action|show_all" | "action|sign_in" | "action|sign_out" | "action|start_chat" | "action|start_new_chat" | "action|subscribe" | "action|transfer" | "action|trust" | "action|try_again" | "action|unignore" | "action|unpin" | "action|unsubscribe" | "action|view_all" | "action|view_list" | "action|view_message" | "action|zoom_in" | "action|zoom_out" | "forward|sending" | "forward|sent" | "forward|filter_placeholder" | "forward|message_preview_heading" | "forward|no_perms_title" | "forward|open_room" | "forward|send_label" | "auth|sso" | "auth|3pid_in_use" | "auth|account_clash" | "auth|account_clash_previous_account" | "auth|account_deactivated" | "auth|autodiscovery_generic_failure" | "auth|autodiscovery_hs_incompatible" | "auth|autodiscovery_invalid" | "auth|autodiscovery_invalid_hs" | "auth|autodiscovery_invalid_hs_base_url" | "auth|autodiscovery_invalid_is" | "auth|autodiscovery_invalid_is_base_url" | "auth|autodiscovery_invalid_is_response" | "auth|autodiscovery_invalid_json" | "auth|autodiscovery_no_well_known" | "auth|autodiscovery_unexpected_error_hs" | "auth|autodiscovery_unexpected_error_is" | "auth|captcha_description" | "auth|change_password_action" | "auth|change_password_confirm_invalid" | "auth|change_password_confirm_label" | "auth|change_password_current_label" | "auth|change_password_empty" | "auth|change_password_error" | "auth|change_password_mismatch" | "auth|change_password_new_label" | "auth|check_email_explainer" | "auth|check_email_resend_prompt" | "auth|check_email_resend_tooltip" | "auth|check_email_wrong_email_button" | "auth|check_email_wrong_email_prompt" | "auth|continue_with_idp" | "auth|continue_with_sso" | "auth|country_dropdown" | "auth|create_account_prompt" | "auth|create_account_title" | "auth|email_discovery_text" | "auth|email_field_label" | "auth|email_field_label_invalid" | "auth|email_field_label_required" | "auth|email_help_text" | "auth|email_phone_discovery_text" | "auth|enter_email_explainer" | "auth|enter_email_heading" | "auth|failed_connect_identity_server" | "auth|failed_connect_identity_server_other" | "auth|failed_connect_identity_server_register" | "auth|failed_connect_identity_server_reset_password" | "auth|failed_homeserver_discovery" | "auth|failed_query_registration_methods" | "auth|failed_soft_logout_auth" | "auth|failed_soft_logout_homeserver" | "auth|footer_powered_by_matrix" | "auth|forgot_password_email_invalid" | "auth|forgot_password_email_required" | "auth|forgot_password_prompt" | "auth|forgot_password_send_email" | "auth|identifier_label" | "auth|incorrect_credentials" | "auth|incorrect_credentials_detail" | "auth|incorrect_password" | "auth|log_in_new_account" | "auth|misconfigured_body" | "auth|misconfigured_title" | "auth|msisdn_field_description" | "auth|msisdn_field_label" | "auth|msisdn_field_number_invalid" | "auth|msisdn_field_required_invalid" | "auth|no_hs_url_provided" | "auth|password_field_keep_going_prompt" | "auth|password_field_label" | "auth|password_field_strong_label" | "auth|password_field_weak_label" | "auth|phone_label" | "auth|phone_optional_label" | "auth|register_action" | "auth|registration_disabled" | "auth|registration_msisdn_field_required_invalid" | "auth|registration_successful" | "auth|registration_username_in_use" | "auth|registration_username_unable_check" | "auth|registration_username_validation" | "auth|reset_password_action" | "auth|reset_password_button" | "auth|reset_password_email_field_description" | "auth|reset_password_email_field_required_invalid" | "auth|reset_password_email_not_associated" | "auth|reset_password_email_not_found_title" | "auth|reset_password_title" | "auth|server_picker_custom" | "auth|server_picker_description" | "auth|server_picker_description_matrix.org" | "auth|server_picker_dialog_title" | "auth|server_picker_explainer" | "auth|server_picker_failed_validate_homeserver" | "auth|server_picker_intro" | "auth|server_picker_invalid_url" | "auth|server_picker_learn_more" | "auth|server_picker_matrix.org" | "auth|server_picker_required" | "auth|server_picker_title" | "auth|server_picker_title_default" | "auth|server_picker_title_registration" | "auth|session_logged_out_description" | "auth|session_logged_out_title" | "auth|set_email_prompt" | "auth|sign_in_description" | "auth|sign_in_instead" | "auth|sign_in_instead_prompt" | "auth|sign_in_or_register" | "auth|sign_in_or_register_description" | "auth|sign_in_prompt" | "auth|sign_in_with_sso" | "auth|signing_in" | "auth|soft_logout_heading" | "auth|soft_logout_intro_password" | "auth|soft_logout_intro_sso" | "auth|soft_logout_intro_unsupported_auth" | "auth|soft_logout_subheading" | "auth|soft_logout_warning" | "auth|sso_failed_missing_storage" | "auth|sso_or_username_password" | "auth|sync_footer_subtitle" | "auth|syncing" | "auth|unsupported_auth" | "auth|unsupported_auth_email" | "auth|unsupported_auth_msisdn" | "auth|username_field_required_invalid" | "auth|username_in_use" | "auth|verify_email_explainer" | "auth|verify_email_heading" | "auth|logout_dialog|description" | "auth|logout_dialog|megolm_export" | "auth|logout_dialog|setup_key_backup_title" | "auth|logout_dialog|setup_secure_backup_description_1" | "auth|logout_dialog|setup_secure_backup_description_2" | "auth|logout_dialog|skip_key_backup" | "auth|logout_dialog|use_key_backup" | "auth|oidc|error_title" | "auth|oidc|generic_auth_error" | "auth|oidc|logout_redirect_warning" | "auth|oidc|missing_or_invalid_stored_state" | "auth|qr_code_login|approve_access_warning" | "auth|qr_code_login|check_code_explainer" | "auth|qr_code_login|check_code_heading" | "auth|qr_code_login|check_code_input_label" | "auth|qr_code_login|check_code_mismatch" | "auth|qr_code_login|completing_setup" | "auth|qr_code_login|confirm_code_match" | "auth|qr_code_login|error_etag_missing" | "auth|qr_code_login|error_expired" | "auth|qr_code_login|error_expired_title" | "auth|qr_code_login|error_insecure_channel_detected" | "auth|qr_code_login|error_insecure_channel_detected_instructions" | "auth|qr_code_login|error_insecure_channel_detected_instructions_1" | "auth|qr_code_login|error_insecure_channel_detected_instructions_2" | "auth|qr_code_login|error_insecure_channel_detected_instructions_3" | "auth|qr_code_login|error_insecure_channel_detected_title" | "auth|qr_code_login|error_other_device_already_signed_in" | "auth|qr_code_login|error_other_device_already_signed_in_title" | "auth|qr_code_login|error_rate_limited" | "auth|qr_code_login|error_unexpected" | "auth|qr_code_login|error_unsupported_protocol" | "auth|qr_code_login|error_unsupported_protocol_title" | "auth|qr_code_login|error_user_cancelled" | "auth|qr_code_login|error_user_cancelled_title" | "auth|qr_code_login|error_user_declined" | "auth|qr_code_login|error_user_declined_title" | "auth|qr_code_login|follow_remaining_instructions" | "auth|qr_code_login|open_element_other_device" | "auth|qr_code_login|point_the_camera" | "auth|qr_code_login|scan_code_instruction" | "auth|qr_code_login|scan_qr_code" | "auth|qr_code_login|security_code" | "auth|qr_code_login|security_code_prompt" | "auth|qr_code_login|select_qr_code" | "auth|qr_code_login|sign_in_new_device" | "auth|qr_code_login|waiting_for_device" | "auth|registration|continue_without_email_description" | "auth|registration|continue_without_email_field_label" | "auth|registration|continue_without_email_title" | "auth|reset_password|confirm_new_password" | "auth|reset_password|devices_logout_success" | "auth|reset_password|other_devices_logout_warning_1" | "auth|reset_password|other_devices_logout_warning_2" | "auth|reset_password|password_not_entered" | "auth|reset_password|passwords_mismatch" | "auth|reset_password|rate_limit_error" | "auth|reset_password|rate_limit_error_with_time" | "auth|reset_password|reset_successful" | "auth|reset_password|return_to_login" | "auth|reset_password|sign_out_other_devices" | "auth|set_email|description" | "auth|set_email|verification_pending_description" | "auth|set_email|verification_pending_title" | "auth|soft_logout|clear_data_button" | "auth|soft_logout|clear_data_description" | "auth|soft_logout|clear_data_title" | "auth|uia|code" | "auth|uia|email" | "auth|uia|msisdn" | "auth|uia|terms" | "auth|uia|email_auth_header" | "auth|uia|email_resend_prompt" | "auth|uia|email_resent" | "auth|uia|fallback_button" | "auth|uia|msisdn_token_incorrect" | "auth|uia|msisdn_token_prompt" | "auth|uia|password_prompt" | "auth|uia|recaptcha_missing_params" | "auth|uia|registration_token_label" | "auth|uia|registration_token_prompt" | "auth|uia|sso_body" | "auth|uia|sso_failed" | "auth|uia|sso_postauth_body" | "auth|uia|sso_postauth_title" | "auth|uia|sso_preauth_body" | "auth|uia|sso_title" | "auth|uia|terms_invalid" | "update|checking" | "update|unavailable" | "update|changelog" | "update|check_action" | "update|downloading" | "update|error_encountered" | "update|error_unable_load_commit" | "update|new_version_available" | "update|no_update" | "update|release_notes_toast_title" | "update|see_changes_button" | "update|toast_description" | "update|toast_title" | "room|show_labs_settings" | "room|kick_reason" | "room|3pid_invite_email_not_found_account" | "room|3pid_invite_email_not_found_account_room" | "room|3pid_invite_error_description" | "room|3pid_invite_error_invite_action" | "room|3pid_invite_error_invite_subtitle" | "room|3pid_invite_error_public_subtitle" | "room|3pid_invite_error_title" | "room|3pid_invite_error_title_room" | "room|3pid_invite_no_is_subtitle" | "room|banned_by" | "room|banned_from_room_by" | "room|creating_room_text" | "room|dm_invite_action" | "room|dm_invite_subtitle" | "room|dm_invite_title" | "room|drop_file_prompt" | "room|edit_topic" | "room|error_3pid_invite_email_lookup" | "room|error_cancel_knock_title" | "room|error_join_403" | "room|error_join_404_1" | "room|error_join_404_2" | "room|error_join_404_invite" | "room|error_join_404_invite_same_hs" | "room|error_join_connection" | "room|error_join_incompatible_version_1" | "room|error_join_incompatible_version_2" | "room|error_join_title" | "room|error_jump_to_date" | "room|error_jump_to_date_connection" | "room|error_jump_to_date_details" | "room|error_jump_to_date_not_found" | "room|error_jump_to_date_send_logs_prompt" | "room|error_jump_to_date_title" | "room|face_pile_summary" | "room|face_pile_tooltip_label" | "room|face_pile_tooltip_shortcut" | "room|face_pile_tooltip_shortcut_joined" | "room|failed_reject_invite" | "room|forget_room" | "room|forget_space" | "room|header_face_pile_tooltip" | "room|header_untrusted_label" | "room|inaccessible" | "room|inaccessible_name" | "room|inaccessible_subtitle_1" | "room|inaccessible_subtitle_2" | "room|invite_email_mismatch_suggestion" | "room|invite_reject_ignore" | "room|invite_sent_to_email" | "room|invite_sent_to_email_room" | "room|invite_subtitle" | "room|invite_this_room" | "room|invite_title" | "room|inviter_unknown" | "room|invites_you_text" | "room|join_button_account" | "room|join_failed_enable_video_rooms" | "room|join_failed_needs_invite" | "room|join_the_discussion" | "room|join_title" | "room|join_title_account" | "room|joining" | "room|joining_room" | "room|joining_space" | "room|jump_read_marker" | "room|jump_to_bottom_button" | "room|jump_to_date" | "room|jump_to_date_beginning" | "room|jump_to_date_prompt" | "room|kicked_by" | "room|kicked_from_room_by" | "room|knock_cancel_action" | "room|knock_denied_subtitle" | "room|knock_denied_title" | "room|knock_message_field_placeholder" | "room|knock_prompt" | "room|knock_prompt_name" | "room|knock_send_action" | "room|knock_sent" | "room|knock_sent_subtitle" | "room|knock_subtitle" | "room|leave_error_title" | "room|leave_server_notices_description" | "room|leave_server_notices_title" | "room|leave_unexpected_error" | "room|link_email_to_receive_3pid_invite" | "room|loading_preview" | "room|no_peek_join_prompt" | "room|no_peek_no_name_join_prompt" | "room|not_found_subtitle" | "room|not_found_title" | "room|not_found_title_name" | "room|peek_join_prompt" | "room|read_topic" | "room|rejecting" | "room|rejoin_button" | "room|unknown_status_code_for_timeline_jump" | "room|unread_notifications_predecessor" | "room|upgrade_error_description" | "room|upgrade_error_title" | "room|upgrade_warning_bar" | "room|upgrade_warning_bar_admins" | "room|upgrade_warning_bar_unstable" | "room|upgrade_warning_bar_upgraded" | "room|view_failed_enable_video_rooms" | "room|waiting_for_join_subtitle" | "room|waiting_for_join_title" | "room|search|summary" | "room|search|placeholder" | "room|search|all_rooms_button" | "room|search|result_count" | "room|search|this_room_button" | "room|header|close_call_button" | "room|header|forget_room_button" | "room|header|hide_widgets_button" | "room|header|n_people_asking_to_join" | "room|header|release_announcement_description" | "room|header|release_announcement_header" | "room|header|room_is_public" | "room|header|show_widgets_button" | "room|header|video_call_button_ec" | "room|header|video_call_button_jitsi" | "room|header|video_call_button_legacy" | "room|header|video_call_ec_change_layout" | "room|header|video_call_ec_layout_freedom" | "room|header|video_call_ec_layout_spotlight" | "room|header|video_room_view_chat_button" | "room|upload|uploading_multiple_file" | "room|upload|uploading_single_file" | "room|context_menu|title" | "room|context_menu|forget" | "room|context_menu|copy_link" | "room|context_menu|favourite" | "room|context_menu|low_priority" | "room|context_menu|mark_read" | "room|context_menu|mark_unread" | "room|context_menu|mentions_only" | "room|context_menu|notifications_default" | "room|context_menu|notifications_mute" | "room|context_menu|unfavourite" | "room|intro|topic" | "room|intro|dm_caption" | "room|intro|enable_encryption_prompt" | "room|intro|encrypted_3pid_dm_pending_join" | "room|intro|no_avatar_label" | "room|intro|no_topic" | "room|intro|private_unencrypted_warning" | "room|intro|room_invite" | "room|intro|send_message_start_dm" | "room|intro|start_of_dm_history" | "room|intro|start_of_room" | "room|intro|topic_edit" | "room|intro|unencrypted_warning" | "room|intro|user_created" | "room|intro|you_created" | "room|pinned_message_banner|title" | "room|pinned_message_banner|description" | "room|pinned_message_banner|button_close_list" | "room|pinned_message_banner|button_view_all" | "room|pinned_message_banner|go_to_message" | "room|status_bar|delete_all" | "room|status_bar|exceeded_resource_limit" | "room|status_bar|homeserver_blocked" | "room|status_bar|monthly_user_limit_reached" | "room|status_bar|requires_consent_agreement" | "room|status_bar|retry_all" | "room|status_bar|select_messages_to_retry" | "room|status_bar|server_connectivity_lost_description" | "room|status_bar|server_connectivity_lost_title" | "room|status_bar|some_messages_not_sent" | "invite|ask_anyway_description" | "invite|ask_anyway_label" | "invite|ask_anyway_never_warn_label" | "invite|email_caption" | "invite|email_limit_one" | "invite|email_use_default_is" | "invite|email_use_is" | "invite|error_already_invited_room" | "invite|error_already_invited_space" | "invite|error_already_joined_room" | "invite|error_already_joined_space" | "invite|error_bad_state" | "invite|error_dm" | "invite|error_find_room" | "invite|error_find_user_description" | "invite|error_find_user_title" | "invite|error_invite" | "invite|error_permissions_room" | "invite|error_permissions_space" | "invite|error_profile_undisclosed" | "invite|error_transfer_multiple_target" | "invite|error_unfederated_room" | "invite|error_unfederated_space" | "invite|error_unknown" | "invite|error_user_not_found" | "invite|error_version_unsupported_room" | "invite|error_version_unsupported_space" | "invite|failed_generic" | "invite|failed_title" | "invite|invalid_address" | "invite|name_email_mxid_share_room" | "invite|name_email_mxid_share_space" | "invite|name_mxid_share_room" | "invite|name_mxid_share_space" | "invite|recents_section" | "invite|room_failed_partial" | "invite|room_failed_partial_title" | "invite|room_failed_title" | "invite|send_link_prompt" | "invite|start_conversation_name_email_mxid_prompt" | "invite|start_conversation_name_mxid_prompt" | "invite|suggestions_disclaimer" | "invite|suggestions_disclaimer_prompt" | "invite|suggestions_section" | "invite|to_room" | "invite|to_space" | "invite|transfer_dial_pad_tab" | "invite|transfer_user_directory_tab" | "invite|unable_find_profiles_description_default" | "invite|unable_find_profiles_invite_label_default" | "invite|unable_find_profiles_invite_never_warn_label_default" | "invite|unable_find_profiles_title" | "invite|unban_first_title" | "presence|idle" | "presence|offline" | "presence|online" | "presence|unknown" | "presence|away" | "presence|busy" | "presence|idle_for" | "presence|offline_for" | "presence|online_for" | "presence|unknown_for" | "presence|unreachable" | "redact|error" | "redact|confirm_button" | "redact|confirm_description" | "redact|confirm_description_state" | "redact|ongoing" | "redact|reason_label" | "encryption|unsupported" | "encryption|bootstrap_title" | "encryption|cancel_entering_passphrase_description" | "encryption|cancel_entering_passphrase_title" | "encryption|confirm_encryption_setup_body" | "encryption|confirm_encryption_setup_title" | "encryption|cross_signing_not_ready" | "encryption|cross_signing_ready" | "encryption|cross_signing_ready_no_backup" | "encryption|cross_signing_room_normal" | "encryption|cross_signing_room_verified" | "encryption|cross_signing_room_warning" | "encryption|cross_signing_unsupported" | "encryption|cross_signing_untrusted" | "encryption|cross_signing_user_normal" | "encryption|cross_signing_user_verified" | "encryption|cross_signing_user_warning" | "encryption|event_shield_reason_authenticity_not_guaranteed" | "encryption|event_shield_reason_mismatched_sender_key" | "encryption|event_shield_reason_unknown_device" | "encryption|event_shield_reason_unsigned_device" | "encryption|event_shield_reason_unverified_identity" | "encryption|export_unsupported" | "encryption|import_invalid_keyfile" | "encryption|import_invalid_passphrase" | "encryption|incompatible_database_description" | "encryption|incompatible_database_disable" | "encryption|incompatible_database_sign_out_description" | "encryption|incompatible_database_title" | "encryption|key_signature_upload_cancelled" | "encryption|key_signature_upload_completed" | "encryption|key_signature_upload_failed" | "encryption|key_signature_upload_failed_body" | "encryption|key_signature_upload_failed_cross_signing_key_signature" | "encryption|key_signature_upload_failed_device_cross_signing_key_signature" | "encryption|key_signature_upload_failed_key_signature" | "encryption|key_signature_upload_failed_master_key_signature" | "encryption|key_signature_upload_failed_title" | "encryption|key_signature_upload_success_title" | "encryption|not_supported" | "encryption|old_version_detected_description" | "encryption|old_version_detected_title" | "encryption|reset_all_button" | "encryption|set_up_toast_description" | "encryption|set_up_toast_title" | "encryption|unable_to_setup_keys_error" | "encryption|upgrade_toast_title" | "encryption|verification_requested_toast_title" | "encryption|verify_toast_description" | "encryption|verify_toast_title" | "encryption|access_secret_storage_dialog|separator" | "encryption|access_secret_storage_dialog|enter_phrase_or_key_prompt" | "encryption|access_secret_storage_dialog|reset_title" | "encryption|access_secret_storage_dialog|reset_warning_1" | "encryption|access_secret_storage_dialog|reset_warning_2" | "encryption|access_secret_storage_dialog|restoring" | "encryption|access_secret_storage_dialog|security_key_title" | "encryption|access_secret_storage_dialog|security_phrase_incorrect_error" | "encryption|access_secret_storage_dialog|security_phrase_title" | "encryption|access_secret_storage_dialog|use_security_key_prompt" | "encryption|access_secret_storage_dialog|key_validation_text|invalid_security_key" | "encryption|access_secret_storage_dialog|key_validation_text|recovery_key_is_correct" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_file_type" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_security_key" | "encryption|destroy_cross_signing_dialog|title" | "encryption|destroy_cross_signing_dialog|warning" | "encryption|destroy_cross_signing_dialog|primary_button_text" | "encryption|messages_not_secure|title" | "encryption|messages_not_secure|heading" | "encryption|messages_not_secure|cause_1" | "encryption|messages_not_secure|cause_2" | "encryption|messages_not_secure|cause_3" | "encryption|messages_not_secure|cause_4" | "encryption|new_recovery_method_detected|title" | "encryption|new_recovery_method_detected|warning" | "encryption|new_recovery_method_detected|description_1" | "encryption|new_recovery_method_detected|description_2" | "encryption|recovery_method_removed|title" | "encryption|recovery_method_removed|warning" | "encryption|recovery_method_removed|description_1" | "encryption|recovery_method_removed|description_2" | "encryption|setup_secure_backup|title" | "encryption|setup_secure_backup|explainer" | "encryption|udd|title" | "encryption|udd|interactive_verification_button" | "encryption|udd|manual_verification_button" | "encryption|udd|other_ask_verify_text" | "encryption|udd|other_new_session_text" | "encryption|udd|own_ask_verify_text" | "encryption|udd|own_new_session_text" | "encryption|verification|cancelled" | "encryption|verification|explainer" | "encryption|verification|accepting" | "encryption|verification|cancelled_self" | "encryption|verification|cancelled_user" | "encryption|verification|cancelling" | "encryption|verification|complete_action" | "encryption|verification|complete_description" | "encryption|verification|complete_title" | "encryption|verification|error_starting_description" | "encryption|verification|error_starting_title" | "encryption|verification|in_person" | "encryption|verification|incoming_sas_device_dialog_text_1" | "encryption|verification|incoming_sas_device_dialog_text_2" | "encryption|verification|incoming_sas_dialog_title" | "encryption|verification|incoming_sas_dialog_waiting" | "encryption|verification|incoming_sas_user_dialog_text_1" | "encryption|verification|incoming_sas_user_dialog_text_2" | "encryption|verification|manual_device_verification_device_id_label" | "encryption|verification|manual_device_verification_device_key_label" | "encryption|verification|manual_device_verification_device_name_label" | "encryption|verification|manual_device_verification_footer" | "encryption|verification|manual_device_verification_self_text" | "encryption|verification|manual_device_verification_user_text" | "encryption|verification|no_key_or_device" | "encryption|verification|no_support_qr_emoji" | "encryption|verification|other_party_cancelled" | "encryption|verification|prompt_encrypted" | "encryption|verification|prompt_self" | "encryption|verification|prompt_unencrypted" | "encryption|verification|prompt_user" | "encryption|verification|qr_or_sas" | "encryption|verification|qr_or_sas_header" | "encryption|verification|qr_prompt" | "encryption|verification|qr_reciprocate_same_shield_device" | "encryption|verification|qr_reciprocate_same_shield_user" | "encryption|verification|request_toast_accept" | "encryption|verification|request_toast_accept_user" | "encryption|verification|request_toast_decline_counter" | "encryption|verification|request_toast_detail" | "encryption|verification|reset_proceed_prompt" | "encryption|verification|sas_caption_self" | "encryption|verification|sas_caption_user" | "encryption|verification|sas_description" | "encryption|verification|sas_emoji_caption_self" | "encryption|verification|sas_emoji_caption_user" | "encryption|verification|sas_match" | "encryption|verification|sas_no_match" | "encryption|verification|sas_prompt" | "encryption|verification|scan_qr" | "encryption|verification|scan_qr_explainer" | "encryption|verification|self_verification_hint" | "encryption|verification|start_button" | "encryption|verification|successful_device" | "encryption|verification|successful_own_device" | "encryption|verification|successful_user" | "encryption|verification|timed_out" | "encryption|verification|unsupported_method" | "encryption|verification|unverified_session_toast_accept" | "encryption|verification|unverified_session_toast_title" | "encryption|verification|unverified_sessions_toast_description" | "encryption|verification|unverified_sessions_toast_reject" | "encryption|verification|unverified_sessions_toast_title" | "encryption|verification|verification_description" | "encryption|verification|verification_dialog_title_device" | "encryption|verification|verification_dialog_title_user" | "encryption|verification|verification_skip_warning" | "encryption|verification|verification_success_with_backup" | "encryption|verification|verification_success_without_backup" | "encryption|verification|verify_emoji" | "encryption|verification|verify_emoji_prompt" | "encryption|verification|verify_emoji_prompt_qr" | "encryption|verification|verify_later" | "encryption|verification|verify_reset_warning_1" | "encryption|verification|verify_reset_warning_2" | "encryption|verification|verify_using_device" | "encryption|verification|verify_using_key" | "encryption|verification|verify_using_key_or_phrase" | "encryption|verification|waiting_for_user_accept" | "encryption|verification|waiting_other_device" | "encryption|verification|waiting_other_device_details" | "encryption|verification|waiting_other_user" | "encryption|verification|after_new_login|device_verified" | "encryption|verification|after_new_login|reset_confirmation" | "encryption|verification|after_new_login|skip_verification" | "encryption|verification|after_new_login|unable_to_verify" | "encryption|verification|after_new_login|verify_this_device" | "threads|mark_all_read" | "threads|all_threads" | "threads|all_threads_description" | "threads|count_of_reply" | "threads|empty_description" | "threads|empty_title" | "threads|error_start_thread_existing_relation" | "threads|my_threads" | "threads|my_threads_description" | "threads|open_thread" | "threads|show_thread_filter" | "space|invite" | "space|joining_space" | "space|failed_load_rooms" | "space|failed_remove_rooms" | "space|incompatible_server_hierarchy" | "space|invite_description" | "space|invite_link" | "space|invite_this_space" | "space|landing_welcome" | "space|leave_dialog_action" | "space|leave_dialog_description" | "space|leave_dialog_only_admin_room_warning" | "space|leave_dialog_only_admin_warning" | "space|leave_dialog_option_all" | "space|leave_dialog_option_intro" | "space|leave_dialog_option_none" | "space|leave_dialog_option_specific" | "space|leave_dialog_public_rejoin_warning" | "space|leave_dialog_title" | "space|mark_suggested" | "space|no_search_result_hint" | "space|room_filter_placeholder" | "space|search_children" | "space|search_placeholder" | "space|select_room_below" | "space|share_public" | "space|suggested" | "space|suggested_tooltip" | "space|title_when_query_available" | "space|title_when_query_unavailable" | "space|unmark_suggested" | "space|user_lacks_permission" | "space|context_menu|home" | "space|context_menu|options" | "space|context_menu|devtools_open_timeline" | "space|context_menu|explore" | "space|context_menu|manage_and_explore" | "space|add_existing_room_space|create" | "space|add_existing_room_space|create_prompt" | "space|add_existing_room_space|dm_heading" | "space|add_existing_room_space|error_heading" | "space|add_existing_room_space|progress_text" | "space|add_existing_room_space|space_dropdown_label" | "space|add_existing_room_space|space_dropdown_title" | "space|add_existing_room_space|subspace_moved_note" | "space|add_existing_subspace|filter_placeholder" | "space|add_existing_subspace|create_prompt" | "space|add_existing_subspace|space_dropdown_title" | "space|add_existing_subspace|create_button" | "space|preferences|sections_section" | "space|preferences|show_people_in_space" | "spaces|error_no_permission_add_room" | "spaces|error_no_permission_add_space" | "spaces|error_no_permission_create_room" | "spaces|error_no_permission_invite" | "common|emoji" | "common|name" | "common|attachment" | "common|beta" | "common|error" | "common|message" | "common|feedback" | "common|location" | "common|timeline" | "common|advanced" | "common|cancel" | "common|appearance" | "common|mute" | "common|unmute" | "common|private" | "common|public" | "common|loading" | "common|video" | "common|image" | "common|encrypted" | "common|offline" | "common|off" | "common|on" | "common|username" | "common|home" | "common|options" | "common|success" | "common|description" | "common|user" | "common|profile" | "common|password" | "common|access_token" | "common|capabilities" | "common|room" | "common|matrix" | "common|joined" | "common|presence" | "common|rooms" | "common|thread" | "common|unavailable" | "common|verified" | "common|device" | "common|version" | "common|application" | "common|trusted" | "common|threads" | "common|guest" | "common|server" | "common|save" | "common|space" | "common|dark" | "common|light" | "common|help" | "common|spaces" | "common|legal" | "common|security" | "common|warning" | "common|settings" | "common|android" | "common|ios" | "common|labs" | "common|theme" | "common|edited" | "common|analytics" | "common|credits" | "common|identity_server" | "common|integration_manager" | "common|reactions" | "common|view_message" | "common|low_priority" | "common|preferences" | "common|accessibility" | "common|all_rooms" | "common|and_n_others" | "common|are_you_sure" | "common|authentication" | "common|avatar" | "common|camera" | "common|cameras" | "common|copied" | "common|cross_signing" | "common|deselect_all" | "common|email_address" | "common|encryption_enabled" | "common|extensions" | "common|faq" | "common|favourites" | "common|filter_results" | "common|forward_message" | "common|general" | "common|go_to_settings" | "common|historical" | "common|homeserver" | "common|lobby" | "common|message_layout" | "common|microphone" | "common|model" | "common|modern" | "common|n_members" | "common|n_rooms" | "common|no_results" | "common|no_results_found" | "common|not_trusted" | "common|orphan_rooms" | "common|people" | "common|preview_message" | "common|privacy" | "common|private_room" | "common|private_space" | "common|public_room" | "common|public_space" | "common|qr_code" | "common|random" | "common|report_a_bug" | "common|room_name" | "common|saved" | "common|saving" | "common|secure_backup" | "common|select_all" | "common|setup_secure_messages" | "common|show_more" | "common|someone" | "common|sticker" | "common|stickerpack" | "common|suggestions" | "common|support" | "common|system_alerts" | "common|unencrypted" | "common|unnamed_room" | "common|unnamed_space" | "common|unsent" | "common|unverified" | "common|updating" | "common|user_avatar" | "common|verification_cancelled" | "common|video_room" | "common|welcome" | "settings|warning" | "settings|notifications|mentions_keywords" | "settings|all_rooms_home" | "settings|all_rooms_home_description" | "settings|always_show_message_timestamps" | "settings|automatic_language_detection_syntax_highlight" | "settings|autoplay_gifs" | "settings|autoplay_videos" | "settings|big_emoji" | "settings|code_block_expand_default" | "settings|code_block_line_numbers" | "settings|disable_historical_profile" | "settings|emoji_autocomplete" | "settings|enable_markdown" | "settings|enable_markdown_description" | "settings|image_thumbnails" | "settings|inline_url_previews_default" | "settings|inline_url_previews_room" | "settings|inline_url_previews_room_account" | "settings|insert_trailing_colon_mentions" | "settings|jump_to_bottom_on_send" | "settings|prompt_invite" | "settings|replace_plain_emoji" | "settings|send_read_receipts" | "settings|send_read_receipts_unsupported" | "settings|send_typing_notifications" | "settings|show_avatar_changes" | "settings|show_breadcrumbs" | "settings|show_chat_effects" | "settings|show_displayname_changes" | "settings|show_join_leave" | "settings|show_nsfw_content" | "settings|show_read_receipts" | "settings|show_redaction_placeholder" | "settings|show_stickers_button" | "settings|show_typing_notifications" | "settings|showbold" | "settings|start_automatically" | "settings|tac_only_notifications" | "settings|use_12_hour_format" | "settings|use_command_enter_send_message" | "settings|use_command_f_search" | "settings|use_control_enter_send_message" | "settings|use_control_f_search" | "settings|warn_quit" | "settings|notifications|voip" | "settings|notifications|error_loading" | "settings|notifications|dialog_title" | "settings|notifications|error_title" | "settings|notifications|default_setting_description" | "settings|notifications|default_setting_section" | "settings|notifications|desktop_notification_message_preview" | "settings|notifications|email_description" | "settings|notifications|email_section" | "settings|notifications|email_select" | "settings|notifications|enable_audible_notifications_session" | "settings|notifications|enable_desktop_notifications_session" | "settings|notifications|enable_email_notifications" | "settings|notifications|enable_notifications_account" | "settings|notifications|enable_notifications_account_detail" | "settings|notifications|enable_notifications_device" | "settings|notifications|error_permissions_denied" | "settings|notifications|error_permissions_missing" | "settings|notifications|error_saving" | "settings|notifications|error_saving_detail" | "settings|notifications|error_updating" | "settings|notifications|invites" | "settings|notifications|keywords" | "settings|notifications|keywords_prompt" | "settings|notifications|labs_notice_prompt" | "settings|notifications|mentions_keywords_only" | "settings|notifications|messages_containing_keywords" | "settings|notifications|noisy" | "settings|notifications|notices" | "settings|notifications|notify_at_room" | "settings|notifications|notify_keyword" | "settings|notifications|notify_mention" | "settings|notifications|other_section" | "settings|notifications|people_mentions_keywords" | "settings|notifications|play_sound_for_description" | "settings|notifications|play_sound_for_section" | "settings|notifications|push_targets" | "settings|notifications|quick_actions_mark_all_read" | "settings|notifications|quick_actions_reset" | "settings|notifications|quick_actions_section" | "settings|notifications|room_activity" | "settings|notifications|rule_call" | "settings|notifications|rule_contains_display_name" | "settings|notifications|rule_contains_user_name" | "settings|notifications|rule_encrypted" | "settings|notifications|rule_encrypted_room_one_to_one" | "settings|notifications|rule_invite_for_me" | "settings|notifications|rule_message" | "settings|notifications|rule_room_one_to_one" | "settings|notifications|rule_roomnotif" | "settings|notifications|rule_suppress_notices" | "settings|notifications|rule_tombstone" | "settings|notifications|show_message_desktop_notification" | "settings|appearance|dialog_title" | "settings|appearance|bundled_emoji_font" | "settings|appearance|compact_layout" | "settings|appearance|compact_layout_description" | "settings|appearance|custom_font" | "settings|appearance|custom_font_description" | "settings|appearance|custom_font_name" | "settings|appearance|custom_font_size" | "settings|appearance|custom_theme_add" | "settings|appearance|custom_theme_downloading" | "settings|appearance|custom_theme_error_downloading" | "settings|appearance|custom_theme_help" | "settings|appearance|custom_theme_invalid" | "settings|appearance|font_size" | "settings|appearance|font_size_default" | "settings|appearance|high_contrast" | "settings|appearance|image_size_default" | "settings|appearance|image_size_large" | "settings|appearance|layout_bubbles" | "settings|appearance|layout_irc" | "settings|appearance|match_system_theme" | "settings|appearance|timeline_image_size" | "settings|account|title" | "settings|account|dialog_title" | "settings|sessions|url" | "settings|sessions|title" | "settings|sessions|browser" | "settings|sessions|session_id" | "settings|sessions|dialog_title" | "settings|sessions|sign_out" | "settings|sessions|best_security_note" | "settings|sessions|confirm_sign_out" | "settings|sessions|confirm_sign_out_body" | "settings|sessions|confirm_sign_out_continue" | "settings|sessions|confirm_sign_out_sso" | "settings|sessions|current_session" | "settings|sessions|desktop_session" | "settings|sessions|details_heading" | "settings|sessions|device_unverified_description" | "settings|sessions|device_unverified_description_current" | "settings|sessions|device_verified_description" | "settings|sessions|device_verified_description_current" | "settings|sessions|error_pusher_state" | "settings|sessions|error_set_name" | "settings|sessions|filter_all" | "settings|sessions|filter_inactive" | "settings|sessions|filter_inactive_description" | "settings|sessions|filter_label" | "settings|sessions|filter_unverified_description" | "settings|sessions|filter_verified_description" | "settings|sessions|hide_details" | "settings|sessions|inactive_days" | "settings|sessions|inactive_sessions" | "settings|sessions|inactive_sessions_explainer_1" | "settings|sessions|inactive_sessions_explainer_2" | "settings|sessions|inactive_sessions_list_description" | "settings|sessions|ip" | "settings|sessions|last_activity" | "settings|sessions|mobile_session" | "settings|sessions|n_sessions_selected" | "settings|sessions|no_inactive_sessions" | "settings|sessions|no_sessions" | "settings|sessions|no_unverified_sessions" | "settings|sessions|no_verified_sessions" | "settings|sessions|os" | "settings|sessions|other_sessions_heading" | "settings|sessions|push_heading" | "settings|sessions|push_subheading" | "settings|sessions|push_toggle" | "settings|sessions|rename_form_caption" | "settings|sessions|rename_form_heading" | "settings|sessions|rename_form_learn_more" | "settings|sessions|rename_form_learn_more_description_1" | "settings|sessions|rename_form_learn_more_description_2" | "settings|sessions|security_recommendations" | "settings|sessions|security_recommendations_description" | "settings|sessions|show_details" | "settings|sessions|sign_in_with_qr" | "settings|sessions|sign_in_with_qr_button" | "settings|sessions|sign_in_with_qr_description" | "settings|sessions|sign_out_all_other_sessions" | "settings|sessions|sign_out_confirm_description" | "settings|sessions|sign_out_n_sessions" | "settings|sessions|unknown_session" | "settings|sessions|unverified_session" | "settings|sessions|unverified_session_explainer_1" | "settings|sessions|unverified_session_explainer_2" | "settings|sessions|unverified_session_explainer_3" | "settings|sessions|unverified_sessions" | "settings|sessions|unverified_sessions_explainer_1" | "settings|sessions|unverified_sessions_explainer_2" | "settings|sessions|unverified_sessions_list_description" | "settings|sessions|verified_session" | "settings|sessions|verified_sessions" | "settings|sessions|verified_sessions_explainer_1" | "settings|sessions|verified_sessions_explainer_2" | "settings|sessions|verified_sessions_list_description" | "settings|sessions|verify_session" | "settings|sessions|web_session" | "settings|security|session_id" | "settings|security|session_key" | "settings|security|dialog_title" | "settings|security|4s_public_key_in_account_data" | "settings|security|4s_public_key_status" | "settings|security|analytics_description" | "settings|security|backup_key_cached_status" | "settings|security|backup_key_stored_status" | "settings|security|backup_key_unexpected_type" | "settings|security|backup_key_well_formed" | "settings|security|backup_keys_description" | "settings|security|bulk_options_accept_all_invites" | "settings|security|bulk_options_reject_all_invites" | "settings|security|bulk_options_section" | "settings|security|cross_signing_cached" | "settings|security|cross_signing_homeserver_support" | "settings|security|cross_signing_homeserver_support_exists" | "settings|security|cross_signing_in_4s" | "settings|security|cross_signing_in_memory" | "settings|security|cross_signing_master_private_Key" | "settings|security|cross_signing_not_cached" | "settings|security|cross_signing_not_found" | "settings|security|cross_signing_not_in_4s" | "settings|security|cross_signing_not_stored" | "settings|security|cross_signing_private_keys" | "settings|security|cross_signing_public_keys" | "settings|security|cross_signing_self_signing_private_key" | "settings|security|cross_signing_user_signing_private_key" | "settings|security|cryptography_section" | "settings|security|dehydrated_device_description" | "settings|security|dehydrated_device_enabled" | "settings|security|delete_backup" | "settings|security|delete_backup_confirm_description" | "settings|security|e2ee_default_disabled_warning" | "settings|security|enable_message_search" | "settings|security|encryption_section" | "settings|security|error_loading_key_backup_status" | "settings|security|export_megolm_keys" | "settings|security|ignore_users_empty" | "settings|security|ignore_users_section" | "settings|security|import_megolm_keys" | "settings|security|key_backup_active" | "settings|security|key_backup_active_version" | "settings|security|key_backup_active_version_none" | "settings|security|key_backup_algorithm" | "settings|security|key_backup_can_be_restored" | "settings|security|key_backup_complete" | "settings|security|key_backup_connect" | "settings|security|key_backup_connect_prompt" | "settings|security|key_backup_in_progress" | "settings|security|key_backup_inactive" | "settings|security|key_backup_inactive_warning" | "settings|security|key_backup_latest_version" | "settings|security|message_search_disable_warning" | "settings|security|message_search_disabled" | "settings|security|message_search_enabled" | "settings|security|message_search_failed" | "settings|security|message_search_indexed_messages" | "settings|security|message_search_indexed_rooms" | "settings|security|message_search_indexing" | "settings|security|message_search_indexing_idle" | "settings|security|message_search_intro" | "settings|security|message_search_room_progress" | "settings|security|message_search_section" | "settings|security|message_search_sleep_time" | "settings|security|message_search_space_used" | "settings|security|message_search_unsupported" | "settings|security|message_search_unsupported_web" | "settings|security|record_session_details" | "settings|security|restore_key_backup" | "settings|security|secret_storage_not_ready" | "settings|security|secret_storage_ready" | "settings|security|secret_storage_status" | "settings|security|send_analytics" | "settings|security|strict_encryption" | "settings|voip|title" | "settings|voip|dialog_title" | "settings|voip|allow_p2p" | "settings|voip|allow_p2p_description" | "settings|voip|audio_input_empty" | "settings|voip|audio_output" | "settings|voip|audio_output_empty" | "settings|voip|auto_gain_control" | "settings|voip|connection_section" | "settings|voip|echo_cancellation" | "settings|voip|enable_fallback_ice_server" | "settings|voip|enable_fallback_ice_server_description" | "settings|voip|mirror_local_feed" | "settings|voip|missing_permissions_prompt" | "settings|voip|noise_suppression" | "settings|voip|request_permissions" | "settings|voip|video_input_empty" | "settings|voip|video_section" | "settings|voip|voice_agc" | "settings|voip|voice_processing" | "settings|voip|voice_section" | "settings|labs|dialog_title" | "settings|keyboard|title" | "settings|keyboard|dialog_title" | "settings|labs_mjolnir|dialog_title" | "settings|preferences|dialog_title" | "settings|preferences|Electron.enableHardwareAcceleration" | "settings|preferences|always_show_menu_bar" | "settings|preferences|autocomplete_delay" | "settings|preferences|code_blocks_heading" | "settings|preferences|compact_modern" | "settings|preferences|composer_heading" | "settings|preferences|default_timezone" | "settings|preferences|enable_hardware_acceleration" | "settings|preferences|enable_tray_icon" | "settings|preferences|keyboard_heading" | "settings|preferences|keyboard_view_shortcuts_button" | "settings|preferences|media_heading" | "settings|preferences|presence_description" | "settings|preferences|rm_lifetime" | "settings|preferences|rm_lifetime_offscreen" | "settings|preferences|room_directory_heading" | "settings|preferences|room_list_heading" | "settings|preferences|show_avatars_pills" | "settings|preferences|show_checklist_shortcuts" | "settings|preferences|show_polls_button" | "settings|preferences|surround_text" | "settings|preferences|time_heading" | "settings|preferences|user_timezone" | "settings|general|username" | "settings|general|display_name" | "settings|general|account_management_section" | "settings|general|account_section" | "settings|general|add_email_dialog_title" | "settings|general|add_email_failed_verification" | "settings|general|add_email_instructions" | "settings|general|add_msisdn_confirm_body" | "settings|general|add_msisdn_confirm_button" | "settings|general|add_msisdn_confirm_sso_button" | "settings|general|add_msisdn_dialog_title" | "settings|general|add_msisdn_instructions" | "settings|general|add_msisdn_misconfigured" | "settings|general|allow_spellcheck" | "settings|general|application_language" | "settings|general|application_language_reload_hint" | "settings|general|avatar_remove_progress" | "settings|general|avatar_save_progress" | "settings|general|avatar_upload_error_text" | "settings|general|avatar_upload_error_text_generic" | "settings|general|avatar_upload_error_title" | "settings|general|confirm_adding_email_body" | "settings|general|confirm_adding_email_title" | "settings|general|deactivate_confirm_body" | "settings|general|deactivate_confirm_body_sso" | "settings|general|deactivate_confirm_content" | "settings|general|deactivate_confirm_content_1" | "settings|general|deactivate_confirm_content_2" | "settings|general|deactivate_confirm_content_3" | "settings|general|deactivate_confirm_content_4" | "settings|general|deactivate_confirm_content_5" | "settings|general|deactivate_confirm_content_6" | "settings|general|deactivate_confirm_continue" | "settings|general|deactivate_confirm_erase_label" | "settings|general|deactivate_section" | "settings|general|deactivate_warning" | "settings|general|discovery_email_empty" | "settings|general|discovery_email_verification_instructions" | "settings|general|discovery_msisdn_empty" | "settings|general|discovery_needs_terms" | "settings|general|discovery_needs_terms_title" | "settings|general|display_name_error" | "settings|general|email_address_in_use" | "settings|general|email_address_label" | "settings|general|email_not_verified" | "settings|general|email_verification_instructions" | "settings|general|emails_heading" | "settings|general|error_add_email" | "settings|general|error_deactivate_communication" | "settings|general|error_deactivate_invalid_auth" | "settings|general|error_deactivate_no_auth" | "settings|general|error_email_verification" | "settings|general|error_invalid_email" | "settings|general|error_invalid_email_detail" | "settings|general|error_msisdn_verification" | "settings|general|error_password_change_403" | "settings|general|error_password_change_http" | "settings|general|error_password_change_title" | "settings|general|error_password_change_unknown" | "settings|general|error_remove_3pid" | "settings|general|error_revoke_email_discovery" | "settings|general|error_revoke_msisdn_discovery" | "settings|general|error_share_email_discovery" | "settings|general|error_share_msisdn_discovery" | "settings|general|identity_server_no_token" | "settings|general|identity_server_not_set" | "settings|general|language_section" | "settings|general|msisdn_in_use" | "settings|general|msisdn_label" | "settings|general|msisdn_verification_field_label" | "settings|general|msisdn_verification_instructions" | "settings|general|msisdns_heading" | "settings|general|name_placeholder" | "settings|general|oidc_manage_button" | "settings|general|password_change_section" | "settings|general|password_change_success" | "settings|general|personal_info" | "settings|general|profile_subtitle" | "settings|general|profile_subtitle_oidc" | "settings|general|remove_email_prompt" | "settings|general|remove_msisdn_prompt" | "settings|general|spell_check_locale_placeholder" | "settings|general|unable_to_load_emails" | "settings|general|unable_to_load_msisdns" | "settings|discovery|title" | "settings|key_backup|backup_in_progress" | "settings|key_backup|backup_starting" | "settings|key_backup|backup_success" | "settings|key_backup|cannot_create_backup" | "settings|key_backup|create_title" | "settings|key_backup|setup_secure_backup|description" | "settings|key_backup|setup_secure_backup|backup_setup_success_description" | "settings|key_backup|setup_secure_backup|backup_setup_success_title" | "settings|key_backup|setup_secure_backup|cancel_warning" | "settings|key_backup|setup_secure_backup|confirm_security_phrase" | "settings|key_backup|setup_secure_backup|download_or_copy" | "settings|key_backup|setup_secure_backup|enter_phrase_description" | "settings|key_backup|setup_secure_backup|enter_phrase_title" | "settings|key_backup|setup_secure_backup|enter_phrase_to_confirm" | "settings|key_backup|setup_secure_backup|generate_security_key_description" | "settings|key_backup|setup_secure_backup|generate_security_key_title" | "settings|key_backup|setup_secure_backup|pass_phrase_match_failed" | "settings|key_backup|setup_secure_backup|pass_phrase_match_success" | "settings|key_backup|setup_secure_backup|phrase_strong_enough" | "settings|key_backup|setup_secure_backup|requires_key_restore" | "settings|key_backup|setup_secure_backup|requires_password_confirmation" | "settings|key_backup|setup_secure_backup|requires_server_authentication" | "settings|key_backup|setup_secure_backup|secret_storage_query_failure" | "settings|key_backup|setup_secure_backup|security_key_safety_reminder" | "settings|key_backup|setup_secure_backup|session_upgrade_description" | "settings|key_backup|setup_secure_backup|set_phrase_again" | "settings|key_backup|setup_secure_backup|settings_reminder" | "settings|key_backup|setup_secure_backup|title_confirm_phrase" | "settings|key_backup|setup_secure_backup|title_save_key" | "settings|key_backup|setup_secure_backup|title_set_phrase" | "settings|key_backup|setup_secure_backup|title_upgrade_encryption" | "settings|key_backup|setup_secure_backup|unable_to_setup" | "settings|key_backup|setup_secure_backup|use_different_passphrase" | "settings|key_backup|setup_secure_backup|use_phrase_only_you_know" | "settings|key_export_import|phrase_strong_enough" | "settings|key_export_import|confirm_passphrase" | "settings|key_export_import|enter_passphrase" | "settings|key_export_import|export_description_1" | "settings|key_export_import|export_description_2" | "settings|key_export_import|export_title" | "settings|key_export_import|file_to_import" | "settings|key_export_import|import_description_1" | "settings|key_export_import|import_description_2" | "settings|key_export_import|import_title" | "settings|key_export_import|phrase_cannot_be_empty" | "settings|key_export_import|phrase_must_match" | "settings|sidebar|title" | "settings|sidebar|dialog_title" | "settings|sidebar|metaspaces_favourites_description" | "settings|sidebar|metaspaces_home_all_rooms" | "settings|sidebar|metaspaces_home_all_rooms_description" | "settings|sidebar|metaspaces_home_description" | "settings|sidebar|metaspaces_orphans" | "settings|sidebar|metaspaces_orphans_description" | "settings|sidebar|metaspaces_people_description" | "settings|sidebar|metaspaces_subsection" | "settings|sidebar|metaspaces_video_rooms" | "settings|sidebar|metaspaces_video_rooms_description" | "settings|sidebar|metaspaces_video_rooms_description_invite_extension" | "settings|sidebar|spaces_explainer" | "voip|connecting" | "voip|hangup" | "voip|answered_elsewhere" | "voip|user_busy" | "voip|element_call" | "voip|unsupported_browser" | "voip|video_call_started" | "voip|unsupported" | "voip|video_call" | "voip|voice_call" | "voip|expand" | "voip|maximise" | "voip|already_in_call" | "voip|already_in_call_person" | "voip|answered_elsewhere_description" | "voip|call_failed" | "voip|call_failed_description" | "voip|call_failed_media" | "voip|call_failed_media_applications" | "voip|call_failed_media_connected" | "voip|call_failed_media_permissions" | "voip|call_failed_microphone" | "voip|call_held" | "voip|call_held_resume" | "voip|call_held_switch" | "voip|call_toast_unknown_room" | "voip|camera_disabled" | "voip|camera_enabled" | "voip|cannot_call_yourself_description" | "voip|change_input_device" | "voip|close_lobby" | "voip|connection_lost" | "voip|connection_lost_description" | "voip|consulting" | "voip|default_device" | "voip|dial" | "voip|dialpad" | "voip|disable_camera" | "voip|disable_microphone" | "voip|disabled_no_one_here" | "voip|disabled_no_perms_start_video_call" | "voip|disabled_no_perms_start_voice_call" | "voip|disabled_ongoing_call" | "voip|enable_camera" | "voip|enable_microphone" | "voip|failed_call_live_broadcast_description" | "voip|failed_call_live_broadcast_title" | "voip|get_call_link" | "voip|hide_sidebar_button" | "voip|input_devices" | "voip|jitsi_call" | "voip|join_button_tooltip_call_full" | "voip|join_button_tooltip_connecting" | "voip|legacy_call" | "voip|maximise_call" | "voip|minimise_call" | "voip|misconfigured_server" | "voip|misconfigured_server_description" | "voip|misconfigured_server_fallback" | "voip|misconfigured_server_fallback_accept" | "voip|more_button" | "voip|msisdn_lookup_failed" | "voip|msisdn_lookup_failed_description" | "voip|msisdn_transfer_failed" | "voip|n_people_joined" | "voip|no_audio_input_description" | "voip|no_audio_input_title" | "voip|no_media_perms_description" | "voip|no_media_perms_title" | "voip|no_permission_conference" | "voip|no_permission_conference_description" | "voip|on_hold" | "voip|output_devices" | "voip|screenshare_monitor" | "voip|screenshare_title" | "voip|screenshare_window" | "voip|show_sidebar_button" | "voip|silence" | "voip|silenced" | "voip|start_screenshare" | "voip|stop_screenshare" | "voip|too_many_calls" | "voip|too_many_calls_description" | "voip|transfer_consult_first_label" | "voip|transfer_failed" | "voip|transfer_failed_description" | "voip|unable_to_access_audio_input_description" | "voip|unable_to_access_audio_input_title" | "voip|unable_to_access_media" | "voip|unable_to_access_microphone" | "voip|unknown_caller" | "voip|unknown_person" | "voip|unsilence" | "voip|user_busy_description" | "voip|user_is_presenting" | "voip|video_call_using" | "voip|you_are_presenting" | "voip|metaspace_video_rooms|conference_room_section" | "voice_broadcast|pause" | "voice_broadcast|play" | "voice_broadcast|action" | "voice_broadcast|resume" | "voice_broadcast|live" | "voice_broadcast|failed_generic" | "voice_broadcast|30s_backward" | "voice_broadcast|30s_forward" | "voice_broadcast|buffering" | "voice_broadcast|confirm_listen_affirm" | "voice_broadcast|confirm_listen_description" | "voice_broadcast|confirm_listen_title" | "voice_broadcast|confirm_stop_affirm" | "voice_broadcast|confirm_stop_description" | "voice_broadcast|confirm_stop_title" | "voice_broadcast|connection_error" | "voice_broadcast|failed_already_recording_description" | "voice_broadcast|failed_already_recording_title" | "voice_broadcast|failed_decrypt" | "voice_broadcast|failed_insufficient_permission_description" | "voice_broadcast|failed_insufficient_permission_title" | "voice_broadcast|failed_no_connection_description" | "voice_broadcast|failed_no_connection_title" | "voice_broadcast|failed_others_already_recording_description" | "voice_broadcast|failed_others_already_recording_title" | "voice_broadcast|go_live" | "labs|notifications" | "labs|dehydration" | "labs|voice_broadcast" | "labs|mjolnir" | "labs|ask_to_join" | "labs|jump_to_date" | "labs|allow_screen_share_only_mode" | "labs|automatic_debug_logs" | "labs|automatic_debug_logs_decryption" | "labs|automatic_debug_logs_key_backup" | "labs|beta_description" | "labs|beta_feature" | "labs|beta_feedback_leave_button" | "labs|beta_feedback_title" | "labs|beta_section" | "labs|bridge_state" | "labs|bridge_state_channel" | "labs|bridge_state_creator" | "labs|bridge_state_manager" | "labs|bridge_state_workspace" | "labs|click_for_info" | "labs|currently_experimental" | "labs|custom_themes" | "labs|dynamic_room_predecessors" | "labs|dynamic_room_predecessors_description" | "labs|element_call_video_rooms" | "labs|experimental_description" | "labs|experimental_section" | "labs|feature_disable_call_per_sender_encryption" | "labs|feature_wysiwyg_composer_description" | "labs|group_calls" | "labs|group_developer" | "labs|group_encryption" | "labs|group_experimental" | "labs|group_messaging" | "labs|group_moderation" | "labs|group_profile" | "labs|group_rooms" | "labs|group_spaces" | "labs|group_themes" | "labs|group_threads" | "labs|group_ui" | "labs|group_voip" | "labs|group_widgets" | "labs|hidebold" | "labs|html_topic" | "labs|join_beta" | "labs|join_beta_reload" | "labs|jump_to_date_msc_support" | "labs|latex_maths" | "labs|leave_beta" | "labs|leave_beta_reload" | "labs|location_share_live" | "labs|location_share_live_description" | "labs|msc3531_hide_messages_pending_moderation" | "labs|new_room_decoration_ui" | "labs|new_room_decoration_ui_beta_caption" | "labs|new_room_decoration_ui_beta_title" | "labs|notification_settings" | "labs|notification_settings_beta_caption" | "labs|notification_settings_beta_title" | "labs|oidc_native_flow" | "labs|oidc_native_flow_description" | "labs|pinning" | "labs|release_announcement" | "labs|render_reaction_images" | "labs|render_reaction_images_description" | "labs|report_to_moderators" | "labs|report_to_moderators_description" | "labs|sliding_sync" | "labs|sliding_sync_description" | "labs|sliding_sync_disabled_notice" | "labs|sliding_sync_server_no_support" | "labs|under_active_development" | "labs|unrealiable_e2e" | "labs|video_rooms" | "labs|video_rooms_a_new_way_to_chat" | "labs|video_rooms_always_on_voip_channels" | "labs|video_rooms_beta" | "labs|video_rooms_faq1_answer" | "labs|video_rooms_faq1_question" | "labs|video_rooms_faq2_answer" | "labs|video_rooms_faq2_question" | "labs|video_rooms_feedbackSubheading" | "labs|voice_broadcast_force_small_chunks" | "labs|wysiwyg_composer" | "theme|light_high_contrast" | "theme|match_system" | "a11y|recent_rooms" | "a11y|emoji_picker" | "a11y|user_menu" | "a11y|room_name" | "a11y|jump_first_invite" | "a11y|message_composer" | "a11y|n_unread_messages" | "a11y|n_unread_messages_mentions" | "a11y|room_status_bar" | "a11y|seek_bar_label" | "a11y|unread_messages" | "analytics|learn_more" | "analytics|accept_button" | "analytics|bullet_1" | "analytics|bullet_2" | "analytics|consent_migration" | "analytics|disable_prompt" | "analytics|enable_prompt" | "analytics|privacy_policy" | "analytics|pseudonymous_usage_data" | "analytics|shared_data_heading" | "bug_reporting|title" | "bug_reporting|description" | "bug_reporting|unsupported_browser" | "bug_reporting|additional_context" | "bug_reporting|before_submitting" | "bug_reporting|collecting_information" | "bug_reporting|collecting_logs" | "bug_reporting|create_new_issue" | "bug_reporting|download_logs" | "bug_reporting|downloading_logs" | "bug_reporting|error_empty" | "bug_reporting|failed_send_logs" | "bug_reporting|github_issue" | "bug_reporting|introduction" | "bug_reporting|log_request" | "bug_reporting|logs_sent" | "bug_reporting|matrix_security_issue" | "bug_reporting|preparing_download" | "bug_reporting|preparing_logs" | "bug_reporting|send_logs" | "bug_reporting|submit_debug_logs" | "bug_reporting|textarea_label" | "bug_reporting|thank_you" | "bug_reporting|uploading_logs" | "bug_reporting|waiting_for_server" | "chat_effects|confetti_description" | "chat_effects|confetti_message" | "chat_effects|fireworks_description" | "chat_effects|fireworks_message" | "chat_effects|hearts_description" | "chat_effects|hearts_message" | "chat_effects|rainfall_description" | "chat_effects|rainfall_message" | "chat_effects|snowfall_description" | "chat_effects|snowfall_message" | "chat_effects|spaceinvaders_description" | "chat_effects|spaceinvaders_message" | "composer|placeholder" | "composer|close_sticker_picker" | "composer|edit_composer_label" | "composer|format_bold" | "composer|format_code_block" | "composer|format_decrease_indent" | "composer|format_increase_indent" | "composer|format_inline_code" | "composer|format_insert_link" | "composer|format_italic" | "composer|format_italics" | "composer|format_link" | "composer|format_ordered_list" | "composer|format_strikethrough" | "composer|format_underline" | "composer|format_unordered_list" | "composer|formatting_toolbar_label" | "composer|mode_plain" | "composer|mode_rich_text" | "composer|no_perms_notice" | "composer|placeholder_encrypted" | "composer|placeholder_reply" | "composer|placeholder_reply_encrypted" | "composer|placeholder_thread" | "composer|placeholder_thread_encrypted" | "composer|poll_button" | "composer|poll_button_no_perms_description" | "composer|poll_button_no_perms_title" | "composer|replying_title" | "composer|room_upgraded_link" | "composer|room_upgraded_notice" | "composer|send_button_title" | "composer|send_button_voice_message" | "composer|send_voice_message" | "composer|stop_voice_message" | "composer|voice_message_button" | "composer|autocomplete|@room_description" | "composer|autocomplete|command_a11y" | "composer|autocomplete|command_description" | "composer|autocomplete|emoji_a11y" | "composer|autocomplete|notification_a11y" | "composer|autocomplete|notification_description" | "composer|autocomplete|room_a11y" | "composer|autocomplete|space_a11y" | "composer|autocomplete|user_a11y" | "composer|autocomplete|user_description" | "composer|link_modal|link_field_label" | "composer|link_modal|text_field_label" | "composer|link_modal|title_create" | "composer|link_modal|title_edit" | "create_room|error_title" | "create_room|action_create_room" | "create_room|action_create_video_room" | "create_room|encrypted_video_room_warning" | "create_room|encrypted_warning" | "create_room|encryption_forced" | "create_room|encryption_label" | "create_room|generic_error" | "create_room|join_rule_change_notice" | "create_room|join_rule_invite" | "create_room|join_rule_invite_label" | "create_room|join_rule_knock_label" | "create_room|join_rule_public_label" | "create_room|join_rule_public_parent_space_label" | "create_room|join_rule_restricted" | "create_room|join_rule_restricted_label" | "create_room|name_validation_required" | "create_room|room_visibility_label" | "create_room|title_private_room" | "create_room|title_public_room" | "create_room|title_video_room" | "create_room|topic_label" | "create_room|unfederated" | "create_room|unfederated_label_default_off" | "create_room|unfederated_label_default_on" | "create_room|unsupported_version" | "create_space|label" | "create_space|explainer" | "create_space|private_space" | "create_space|add_details_prompt" | "create_space|add_details_prompt_2" | "create_space|add_existing_rooms_description" | "create_space|add_existing_rooms_heading" | "create_space|address_label" | "create_space|address_placeholder" | "create_space|creating" | "create_space|creating_rooms" | "create_space|done_action" | "create_space|done_action_first_room" | "create_space|failed_create_initial_rooms" | "create_space|failed_invite_users" | "create_space|invite_teammates_by_username" | "create_space|invite_teammates_description" | "create_space|invite_teammates_heading" | "create_space|inviting_users" | "create_space|name_required" | "create_space|personal_space" | "create_space|personal_space_description" | "create_space|private_description" | "create_space|private_heading" | "create_space|private_personal_description" | "create_space|private_personal_heading" | "create_space|private_space_description" | "create_space|public_description" | "create_space|public_heading" | "create_space|search_public_button" | "create_space|setup_rooms_community_description" | "create_space|setup_rooms_community_heading" | "create_space|setup_rooms_description" | "create_space|setup_rooms_private_description" | "create_space|setup_rooms_private_heading" | "create_space|share_description" | "create_space|share_heading" | "create_space|skip_action" | "create_space|subspace_adding" | "create_space|subspace_beta_notice" | "create_space|subspace_dropdown_title" | "create_space|subspace_existing_space_prompt" | "create_space|subspace_join_rule_invite_description" | "create_space|subspace_join_rule_invite_only" | "create_space|subspace_join_rule_label" | "create_space|subspace_join_rule_public_description" | "create_space|subspace_join_rule_restricted_description" | "credits|default_cover_photo" | "credits|twemoji" | "credits|twemoji_colr" | "devtools|id" | "devtools|value" | "devtools|title" | "devtools|timeout" | "devtools|state_key" | "devtools|room_id" | "devtools|event_id" | "devtools|event_type" | "devtools|methods" | "devtools|phase" | "devtools|spaces" | "devtools|toolbox" | "devtools|event_content" | "devtools|active_widgets" | "devtools|category_other" | "devtools|category_room" | "devtools|caution_colon" | "devtools|client_versions" | "devtools|developer_mode" | "devtools|developer_tools" | "devtools|edit_setting" | "devtools|edit_values" | "devtools|empty_string" | "devtools|event_sent" | "devtools|explore_account_data" | "devtools|explore_room_account_data" | "devtools|explore_room_state" | "devtools|failed_to_find_widget" | "devtools|failed_to_load" | "devtools|failed_to_save" | "devtools|failed_to_send" | "devtools|invalid_json" | "devtools|level" | "devtools|low_bandwidth_mode" | "devtools|low_bandwidth_mode_description" | "devtools|main_timeline" | "devtools|no_receipt_found" | "devtools|no_verification_requests_found" | "devtools|notification_state" | "devtools|notifications_debug" | "devtools|number_of_users" | "devtools|original_event_source" | "devtools|other_user" | "devtools|phase_cancelled" | "devtools|phase_ready" | "devtools|phase_requested" | "devtools|phase_started" | "devtools|phase_transaction" | "devtools|room_encrypted" | "devtools|room_not_encrypted" | "devtools|room_notifications_dot" | "devtools|room_notifications_highlight" | "devtools|room_notifications_last_event" | "devtools|room_notifications_sender" | "devtools|room_notifications_thread_id" | "devtools|room_notifications_total" | "devtools|room_notifications_type" | "devtools|room_status" | "devtools|room_unread_status_count" | "devtools|save_setting_values" | "devtools|see_history" | "devtools|send_custom_account_data_event" | "devtools|send_custom_room_account_data_event" | "devtools|send_custom_state_event" | "devtools|send_custom_timeline_event" | "devtools|server_info" | "devtools|server_versions" | "devtools|settable_global" | "devtools|settable_room" | "devtools|setting_colon" | "devtools|setting_definition" | "devtools|setting_id" | "devtools|settings_explorer" | "devtools|show_hidden_events" | "devtools|thread_root_id" | "devtools|threads_timeline" | "devtools|timeout_none" | "devtools|toggle_event" | "devtools|use_at_own_risk" | "devtools|user_read_up_to" | "devtools|user_read_up_to_ignore_synthetic" | "devtools|user_read_up_to_private" | "devtools|user_read_up_to_private_ignore_synthetic" | "devtools|value_colon" | "devtools|value_in_this_room" | "devtools|value_this_room_colon" | "devtools|values_explicit" | "devtools|values_explicit_colon" | "devtools|values_explicit_room" | "devtools|values_explicit_this_room_colon" | "devtools|verification_explorer" | "devtools|view_servers_in_room" | "devtools|view_source_decrypted_event_source" | "devtools|view_source_decrypted_event_source_unavailable" | "devtools|widget_screenshots" | "emoji_picker|cancel_search_label" | "error_database_closed_description|for_desktop" | "error_database_closed_description|for_web" | "error_dialog|error_loading_user_profile" | "error_dialog|forget_room_failed" | "error_dialog|copy_room_link_failed|title" | "error_dialog|copy_room_link_failed|description" | "error_dialog|search_failed|title" | "error_dialog|search_failed|server_unavailable" | "event_preview|m.sticker" | "event_preview|m.text" | "event_preview|m.emote" | "event_preview|io.element.voice_broadcast_info|user" | "event_preview|io.element.voice_broadcast_info|you" | "event_preview|m.reaction|user" | "event_preview|m.reaction|you" | "event_preview|m.call.invite|user" | "event_preview|m.call.invite|you" | "event_preview|m.call.invite|dm_receive" | "event_preview|m.call.invite|dm_send" | "event_preview|m.call.answer|user" | "event_preview|m.call.answer|you" | "event_preview|m.call.answer|dm" | "event_preview|m.call.hangup|user" | "event_preview|m.call.hangup|you" | "export_chat|html" | "export_chat|title" | "export_chat|text" | "export_chat|json" | "export_chat|messages" | "export_chat|format" | "export_chat|cancelled" | "export_chat|topic" | "export_chat|cancelled_detail" | "export_chat|confirm_stop" | "export_chat|creating_html" | "export_chat|creating_output" | "export_chat|creator_summary" | "export_chat|current_timeline" | "export_chat|enter_number_between_min_max" | "export_chat|error_fetching_file" | "export_chat|export_info" | "export_chat|export_successful" | "export_chat|exported_n_events_in_time" | "export_chat|exporting_your_data" | "export_chat|fetched_n_events" | "export_chat|fetched_n_events_in_time" | "export_chat|fetched_n_events_with_total" | "export_chat|fetching_events" | "export_chat|file_attached" | "export_chat|from_the_beginning" | "export_chat|generating_zip" | "export_chat|html_title" | "export_chat|include_attachments" | "export_chat|media_omitted" | "export_chat|media_omitted_file_size" | "export_chat|next_page" | "export_chat|num_messages" | "export_chat|num_messages_min_max" | "export_chat|number_of_messages" | "export_chat|previous_page" | "export_chat|processing" | "export_chat|processing_event_n" | "export_chat|select_option" | "export_chat|size_limit" | "export_chat|size_limit_min_max" | "export_chat|size_limit_postfix" | "export_chat|starting_export" | "export_chat|successful" | "export_chat|successful_detail" | "export_chat|unload_confirm" | "file_panel|empty_description" | "file_panel|empty_heading" | "file_panel|guest_note" | "file_panel|peek_note" | "identity_server|url" | "identity_server|change" | "identity_server|checking" | "identity_server|disconnect" | "identity_server|error_invalid" | "identity_server|suggestions" | "identity_server|change_prompt" | "identity_server|change_server_prompt" | "identity_server|description_connected" | "identity_server|description_disconnected" | "identity_server|description_optional" | "identity_server|disconnect_anyway" | "identity_server|disconnect_offline_warning" | "identity_server|disconnect_personal_data_warning_1" | "identity_server|disconnect_personal_data_warning_2" | "identity_server|disconnect_server" | "identity_server|disconnect_warning" | "identity_server|do_not_use" | "identity_server|error_connection" | "identity_server|error_invalid_or_terms" | "identity_server|no_terms" | "identity_server|suggestions_1" | "identity_server|suggestions_2" | "identity_server|suggestions_3" | "identity_server|url_field_label" | "identity_server|url_not_https" | "integration_manager|connecting" | "integration_manager|explainer" | "integration_manager|error_connecting" | "integration_manager|error_connecting_heading" | "integration_manager|manage_title" | "integration_manager|use_im" | "integration_manager|use_im_default" | "integrations|disabled_dialog_description" | "integrations|disabled_dialog_title" | "integrations|impossible_dialog_description" | "integrations|impossible_dialog_title" | "keyboard|number" | "keyboard|search" | "keyboard|shift" | "keyboard|end" | "keyboard|home" | "keyboard|enter" | "keyboard|space" | "keyboard|alt" | "keyboard|control" | "keyboard|toggle_space_panel" | "keyboard|upload_file" | "keyboard|activate_button" | "keyboard|autocomplete_cancel" | "keyboard|autocomplete_force" | "keyboard|autocomplete_navigate_next" | "keyboard|autocomplete_navigate_prev" | "keyboard|backspace" | "keyboard|cancel_reply" | "keyboard|category_autocomplete" | "keyboard|category_calls" | "keyboard|category_navigation" | "keyboard|category_room_list" | "keyboard|close_dialog_menu" | "keyboard|composer_jump_end" | "keyboard|composer_jump_start" | "keyboard|composer_navigate_next_history" | "keyboard|composer_navigate_prev_history" | "keyboard|composer_new_line" | "keyboard|composer_redo" | "keyboard|composer_toggle_bold" | "keyboard|composer_toggle_code_block" | "keyboard|composer_toggle_italics" | "keyboard|composer_toggle_link" | "keyboard|composer_toggle_quote" | "keyboard|composer_undo" | "keyboard|dismiss_read_marker_and_jump_bottom" | "keyboard|escape" | "keyboard|go_home_view" | "keyboard|jump_first_message" | "keyboard|jump_last_message" | "keyboard|jump_room_search" | "keyboard|jump_to_read_marker" | "keyboard|keyboard_shortcuts_tab" | "keyboard|navigate_next_history" | "keyboard|navigate_next_message_edit" | "keyboard|navigate_prev_history" | "keyboard|navigate_prev_message_edit" | "keyboard|next_landmark" | "keyboard|next_room" | "keyboard|next_unread_room" | "keyboard|open_user_settings" | "keyboard|page_down" | "keyboard|page_up" | "keyboard|prev_landmark" | "keyboard|prev_room" | "keyboard|prev_unread_room" | "keyboard|room_list_collapse_section" | "keyboard|room_list_expand_section" | "keyboard|room_list_navigate_down" | "keyboard|room_list_navigate_up" | "keyboard|room_list_select_room" | "keyboard|scroll_down_timeline" | "keyboard|scroll_up_timeline" | "keyboard|send_sticker" | "keyboard|switch_to_space" | "keyboard|toggle_hidden_events" | "keyboard|toggle_microphone_mute" | "keyboard|toggle_right_panel" | "keyboard|toggle_top_left_menu" | "keyboard|toggle_webcam_mute" | "labs_mjolnir|title" | "labs_mjolnir|something_went_wrong" | "labs_mjolnir|ban_reason" | "labs_mjolnir|room_name" | "labs_mjolnir|advanced_warning" | "labs_mjolnir|error_adding_ignore" | "labs_mjolnir|error_adding_list_description" | "labs_mjolnir|error_adding_list_title" | "labs_mjolnir|error_removing_ignore" | "labs_mjolnir|error_removing_list_description" | "labs_mjolnir|error_removing_list_title" | "labs_mjolnir|explainer_1" | "labs_mjolnir|explainer_2" | "labs_mjolnir|lists" | "labs_mjolnir|lists_description_1" | "labs_mjolnir|lists_description_2" | "labs_mjolnir|lists_heading" | "labs_mjolnir|lists_new_label" | "labs_mjolnir|no_lists" | "labs_mjolnir|personal_description" | "labs_mjolnir|personal_empty" | "labs_mjolnir|personal_heading" | "labs_mjolnir|personal_new_label" | "labs_mjolnir|personal_new_placeholder" | "labs_mjolnir|personal_section" | "labs_mjolnir|room_topic" | "labs_mjolnir|rules_empty" | "labs_mjolnir|rules_server" | "labs_mjolnir|rules_title" | "labs_mjolnir|rules_user" | "labs_mjolnir|view_rules" | "leave_room_dialog|last_person_warning" | "leave_room_dialog|leave_room_question" | "leave_room_dialog|leave_space_question" | "leave_room_dialog|room_leave_admin_warning" | "leave_room_dialog|room_leave_mod_warning" | "leave_room_dialog|room_rejoin_warning" | "leave_room_dialog|space_rejoin_warning" | "left_panel|open_dial_pad" | "lightbox|title" | "lightbox|rotate_left" | "lightbox|rotate_right" | "location_sharing|failed_generic" | "location_sharing|MapStyleUrlNotConfigured" | "location_sharing|MapStyleUrlNotReachable" | "location_sharing|WebGLNotEnabled" | "location_sharing|click_drop_pin" | "location_sharing|click_move_pin" | "location_sharing|close_sidebar" | "location_sharing|error_fetch_location" | "location_sharing|error_no_perms_description" | "location_sharing|error_no_perms_title" | "location_sharing|error_send_description" | "location_sharing|error_send_title" | "location_sharing|error_sharing_live_location" | "location_sharing|error_sharing_live_location_try_again" | "location_sharing|error_stopping_live_location" | "location_sharing|error_stopping_live_location_try_again" | "location_sharing|expand_map" | "location_sharing|failed_load_map" | "location_sharing|failed_permission" | "location_sharing|failed_timeout" | "location_sharing|failed_unknown" | "location_sharing|find_my_location" | "location_sharing|live_description" | "location_sharing|live_enable_description" | "location_sharing|live_enable_heading" | "location_sharing|live_location_active" | "location_sharing|live_location_enabled" | "location_sharing|live_location_ended" | "location_sharing|live_location_error" | "location_sharing|live_locations_empty" | "location_sharing|live_share_button" | "location_sharing|live_toggle_label" | "location_sharing|live_until" | "location_sharing|live_update_time" | "location_sharing|loading_live_location" | "location_sharing|location_not_available" | "location_sharing|map_feedback" | "location_sharing|mapbox_logo" | "location_sharing|reset_bearing" | "location_sharing|share_button" | "location_sharing|share_type_live" | "location_sharing|share_type_own" | "location_sharing|share_type_pin" | "location_sharing|share_type_prompt" | "location_sharing|stop_and_close" | "location_sharing|toggle_attribution" | "member_list|filter_placeholder" | "member_list|invite_button_no_perms_tooltip" | "member_list|invited_list_heading" | "member_list|power_label" | "mobile_guide|toast_description" | "mobile_guide|toast_title" | "mobile_guide|toast_accept" | "notif_panel|empty_description" | "notif_panel|empty_heading" | "notifier|io.element.voice_broadcast_chunk" | "notifier|m.key.verification.request" | "onboarding|create_room" | "onboarding|explore_rooms" | "onboarding|no_avatar_label" | "onboarding|apple_trademarks" | "onboarding|community_messaging_action" | "onboarding|community_messaging_description" | "onboarding|community_messaging_title" | "onboarding|complete_these" | "onboarding|download_app" | "onboarding|download_app_action" | "onboarding|download_app_description" | "onboarding|download_app_store" | "onboarding|download_brand" | "onboarding|download_brand_desktop" | "onboarding|download_f_droid" | "onboarding|download_google_play" | "onboarding|enable_notifications" | "onboarding|enable_notifications_action" | "onboarding|enable_notifications_description" | "onboarding|find_community_members" | "onboarding|find_coworkers" | "onboarding|find_friends" | "onboarding|find_friends_action" | "onboarding|find_friends_description" | "onboarding|find_people" | "onboarding|free_e2ee_messaging_unlimited_voip" | "onboarding|get_stuff_done" | "onboarding|google_trademarks" | "onboarding|has_avatar_label" | "onboarding|intro_byline" | "onboarding|intro_welcome" | "onboarding|only_n_steps_to_go" | "onboarding|personal_messaging_action" | "onboarding|personal_messaging_title" | "onboarding|qr_or_app_links" | "onboarding|send_dm" | "onboarding|set_up_profile" | "onboarding|set_up_profile_action" | "onboarding|set_up_profile_description" | "onboarding|use_case_community_messaging" | "onboarding|use_case_heading1" | "onboarding|use_case_heading2" | "onboarding|use_case_heading3" | "onboarding|use_case_personal_messaging" | "onboarding|use_case_work_messaging" | "onboarding|welcome_detail" | "onboarding|welcome_to_brand" | "onboarding|welcome_user" | "onboarding|work_messaging_action" | "onboarding|work_messaging_title" | "onboarding|you_did_it" | "onboarding|you_made_it" | "pill|permalink_other_room" | "pill|permalink_this_room" | "poll|topic_label" | "poll|create_poll_action" | "poll|create_poll_title" | "poll|disclosed_notes" | "poll|edit_poll_title" | "poll|end_description" | "poll|end_message" | "poll|end_message_no_votes" | "poll|end_title" | "poll|error_ending_description" | "poll|error_ending_title" | "poll|error_voting_description" | "poll|error_voting_title" | "poll|failed_send_poll_description" | "poll|failed_send_poll_title" | "poll|notes" | "poll|options_add_button" | "poll|options_heading" | "poll|options_label" | "poll|options_placeholder" | "poll|topic_heading" | "poll|topic_placeholder" | "poll|total_decryption_errors" | "poll|total_n_votes" | "poll|total_n_votes_voted" | "poll|total_no_votes" | "poll|total_not_ended" | "poll|type_closed" | "poll|type_heading" | "poll|type_open" | "poll|unable_edit_description" | "poll|unable_edit_title" | "power_level|default" | "power_level|custom" | "power_level|label" | "power_level|restricted" | "power_level|admin" | "power_level|custom_level" | "power_level|mod" | "power_level|moderator" | "quick_settings|title" | "quick_settings|all_settings" | "quick_settings|metaspace_section" | "quick_settings|sidebar_settings" | "quit_warning|call_in_progress" | "quit_warning|file_upload_in_progress" | "reject_invitation_dialog|failed" | "reject_invitation_dialog|title" | "reject_invitation_dialog|confirmation" | "report_content|description" | "report_content|disagree" | "report_content|error_create_room_moderation_bot" | "report_content|hide_messages_from_user" | "report_content|ignore_user" | "report_content|illegal_content" | "report_content|missing_reason" | "report_content|nature" | "report_content|nature_disagreement" | "report_content|nature_illegal" | "report_content|nature_nonstandard_admin" | "report_content|nature_nonstandard_admin_encrypted" | "report_content|nature_other" | "report_content|nature_spam" | "report_content|nature_toxic" | "report_content|other_label" | "report_content|report_content_to_homeserver" | "report_content|report_entire_room" | "report_content|spam_or_propaganda" | "report_content|toxic_behaviour" | "restore_key_backup_dialog|enter_phrase_description" | "restore_key_backup_dialog|enter_phrase_title" | "restore_key_backup_dialog|count_of_decryption_failures" | "restore_key_backup_dialog|count_of_successfully_restored_keys" | "restore_key_backup_dialog|enter_key_description" | "restore_key_backup_dialog|enter_key_title" | "restore_key_backup_dialog|incorrect_security_phrase_dialog" | "restore_key_backup_dialog|incorrect_security_phrase_title" | "restore_key_backup_dialog|key_backup_warning" | "restore_key_backup_dialog|key_fetch_in_progress" | "restore_key_backup_dialog|key_forgotten_text" | "restore_key_backup_dialog|key_is_invalid" | "restore_key_backup_dialog|key_is_valid" | "restore_key_backup_dialog|keys_restored_title" | "restore_key_backup_dialog|load_error_content" | "restore_key_backup_dialog|load_keys_progress" | "restore_key_backup_dialog|no_backup_error" | "restore_key_backup_dialog|phrase_forgotten_text" | "restore_key_backup_dialog|recovery_key_mismatch_description" | "restore_key_backup_dialog|recovery_key_mismatch_title" | "restore_key_backup_dialog|restore_failed_error" | "right_panel|info" | "right_panel|add_integrations" | "right_panel|add_topic" | "right_panel|export_chat_button" | "right_panel|extensions_empty_description" | "right_panel|extensions_empty_title" | "right_panel|files_button" | "right_panel|pinned_messages_button" | "right_panel|polls_button" | "right_panel|widgets_section" | "right_panel|poll|loading" | "right_panel|poll|active_heading" | "right_panel|poll|empty_active" | "right_panel|poll|empty_active_load_more" | "right_panel|poll|empty_active_load_more_n_days" | "right_panel|poll|empty_past" | "right_panel|poll|empty_past_load_more" | "right_panel|poll|empty_past_load_more_n_days" | "right_panel|poll|final_result" | "right_panel|poll|load_more" | "right_panel|poll|past_heading" | "right_panel|poll|view_in_timeline" | "right_panel|poll|view_poll" | "right_panel|pinned_messages|view" | "right_panel|pinned_messages|header" | "right_panel|pinned_messages|menu" | "right_panel|pinned_messages|title" | "right_panel|pinned_messages|empty_description" | "right_panel|pinned_messages|empty_title" | "right_panel|pinned_messages|limits" | "right_panel|pinned_messages|reply_thread" | "right_panel|pinned_messages|unpin_all|button" | "right_panel|pinned_messages|unpin_all|content" | "right_panel|pinned_messages|unpin_all|title" | "right_panel|room_summary_card|title" | "right_panel|thread_list|context_menu_label" | "right_panel|video_room_chat|title" | "room_list|show_n_more" | "room_list|add_room_label" | "room_list|add_space_label" | "room_list|breadcrumbs_empty" | "room_list|breadcrumbs_label" | "room_list|failed_add_tag" | "room_list|failed_remove_tag" | "room_list|failed_set_dm_tag" | "room_list|home_menu_label" | "room_list|join_public_room_label" | "room_list|joining_rooms_status" | "room_list|notification_options" | "room_list|redacting_messages_status" | "room_list|show_less" | "room_list|show_previews" | "room_list|sort_by" | "room_list|sort_by_activity" | "room_list|sort_by_alphabet" | "room_list|sort_unread_first" | "room_list|space_menu_label" | "room_list|sublist_options" | "room_list|suggested_rooms_heading" | "room_settings|title" | "room_settings|security|strict_encryption" | "room_settings|alias_not_specified" | "room_settings|delete_avatar_label" | "room_settings|upload_avatar_label" | "room_settings|advanced|room_id" | "room_settings|advanced|room_version" | "room_settings|advanced|unfederated" | "room_settings|advanced|error_upgrade_description" | "room_settings|advanced|error_upgrade_title" | "room_settings|advanced|information_section_room" | "room_settings|advanced|information_section_space" | "room_settings|advanced|room_predecessor" | "room_settings|advanced|room_upgrade_button" | "room_settings|advanced|room_upgrade_warning" | "room_settings|advanced|room_version_section" | "room_settings|advanced|space_predecessor" | "room_settings|advanced|space_upgrade_button" | "room_settings|advanced|upgrade_button" | "room_settings|advanced|upgrade_dialog_description" | "room_settings|advanced|upgrade_dialog_description_1" | "room_settings|advanced|upgrade_dialog_description_2" | "room_settings|advanced|upgrade_dialog_description_3" | "room_settings|advanced|upgrade_dialog_description_4" | "room_settings|advanced|upgrade_dialog_title" | "room_settings|advanced|upgrade_dwarning_ialog_title_public" | "room_settings|advanced|upgrade_warning_dialog_description" | "room_settings|advanced|upgrade_warning_dialog_explainer" | "room_settings|advanced|upgrade_warning_dialog_footer" | "room_settings|advanced|upgrade_warning_dialog_invite_label" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt_link" | "room_settings|advanced|upgrade_warning_dialog_title" | "room_settings|advanced|upgrade_warning_dialog_title_private" | "room_settings|notifications|browse_button" | "room_settings|notifications|custom_sound_prompt" | "room_settings|notifications|notification_sound" | "room_settings|notifications|settings_link" | "room_settings|notifications|sounds_section" | "room_settings|notifications|upload_sound_label" | "room_settings|notifications|uploaded_sound" | "room_settings|visibility|title" | "room_settings|visibility|alias_section" | "room_settings|visibility|error_failed_save" | "room_settings|visibility|error_update_guest_access" | "room_settings|visibility|error_update_history_visibility" | "room_settings|visibility|guest_access_explainer" | "room_settings|visibility|guest_access_explainer_public_space" | "room_settings|visibility|guest_access_label" | "room_settings|visibility|history_visibility_anyone_space" | "room_settings|visibility|history_visibility_anyone_space_description" | "room_settings|visibility|history_visibility_anyone_space_recommendation" | "room_settings|security|title" | "room_settings|security|encryption_forced" | "room_settings|security|join_rule_invite" | "room_settings|security|join_rule_restricted" | "room_settings|security|enable_encryption_confirm_description" | "room_settings|security|enable_encryption_confirm_title" | "room_settings|security|enable_encryption_public_room_confirm_description_1" | "room_settings|security|enable_encryption_public_room_confirm_description_2" | "room_settings|security|enable_encryption_public_room_confirm_title" | "room_settings|security|encrypted_room_public_confirm_description_1" | "room_settings|security|encrypted_room_public_confirm_description_2" | "room_settings|security|encrypted_room_public_confirm_title" | "room_settings|security|encryption_permanent" | "room_settings|security|error_join_rule_change_title" | "room_settings|security|error_join_rule_change_unknown" | "room_settings|security|guest_access_warning" | "room_settings|security|history_visibility_invited" | "room_settings|security|history_visibility_joined" | "room_settings|security|history_visibility_legend" | "room_settings|security|history_visibility_shared" | "room_settings|security|history_visibility_warning" | "room_settings|security|history_visibility_world_readable" | "room_settings|security|join_rule_description" | "room_settings|security|join_rule_invite_description" | "room_settings|security|join_rule_knock" | "room_settings|security|join_rule_knock_description" | "room_settings|security|join_rule_public_description" | "room_settings|security|join_rule_restricted_description" | "room_settings|security|join_rule_restricted_description_active_space" | "room_settings|security|join_rule_restricted_description_prompt" | "room_settings|security|join_rule_restricted_description_spaces" | "room_settings|security|join_rule_restricted_dialog_description" | "room_settings|security|join_rule_restricted_dialog_empty_warning" | "room_settings|security|join_rule_restricted_dialog_filter_placeholder" | "room_settings|security|join_rule_restricted_dialog_heading_known" | "room_settings|security|join_rule_restricted_dialog_heading_other" | "room_settings|security|join_rule_restricted_dialog_heading_room" | "room_settings|security|join_rule_restricted_dialog_heading_space" | "room_settings|security|join_rule_restricted_dialog_heading_unknown" | "room_settings|security|join_rule_restricted_dialog_title" | "room_settings|security|join_rule_restricted_n_more" | "room_settings|security|join_rule_restricted_summary" | "room_settings|security|join_rule_restricted_upgrade_description" | "room_settings|security|join_rule_restricted_upgrade_warning" | "room_settings|security|join_rule_upgrade_awaiting_room" | "room_settings|security|join_rule_upgrade_required" | "room_settings|security|join_rule_upgrade_sending_invites" | "room_settings|security|join_rule_upgrade_updating_spaces" | "room_settings|security|join_rule_upgrade_upgrading_room" | "room_settings|security|public_without_alias_warning" | "room_settings|security|publish_room" | "room_settings|security|publish_space" | "room_settings|voip|call_type_section" | "room_settings|voip|enable_element_call_caption" | "room_settings|voip|enable_element_call_label" | "room_settings|voip|enable_element_call_no_permissions_tooltip" | "room_settings|general|save" | "room_settings|general|other_section" | "room_settings|general|alias_field_has_domain_invalid" | "room_settings|general|alias_field_has_localpart_invalid" | "room_settings|general|alias_field_matches_invalid" | "room_settings|general|alias_field_placeholder_default" | "room_settings|general|alias_field_required_invalid" | "room_settings|general|alias_field_safe_localpart_invalid" | "room_settings|general|alias_field_taken_invalid" | "room_settings|general|alias_field_taken_invalid_domain" | "room_settings|general|alias_field_taken_valid" | "room_settings|general|alias_heading" | "room_settings|general|aliases_items_label" | "room_settings|general|aliases_no_items_label" | "room_settings|general|aliases_section" | "room_settings|general|avatar_field_label" | "room_settings|general|canonical_alias_field_label" | "room_settings|general|default_url_previews_off" | "room_settings|general|default_url_previews_on" | "room_settings|general|description_space" | "room_settings|general|error_creating_alias_description" | "room_settings|general|error_creating_alias_title" | "room_settings|general|error_deleting_alias_description" | "room_settings|general|error_deleting_alias_description_forbidden" | "room_settings|general|error_deleting_alias_title" | "room_settings|general|error_save_space_settings" | "room_settings|general|error_updating_alias_description" | "room_settings|general|error_updating_canonical_alias_description" | "room_settings|general|error_updating_canonical_alias_title" | "room_settings|general|leave_space" | "room_settings|general|local_alias_field_label" | "room_settings|general|local_aliases_explainer_room" | "room_settings|general|local_aliases_explainer_space" | "room_settings|general|local_aliases_section" | "room_settings|general|name_field_label" | "room_settings|general|new_alias_placeholder" | "room_settings|general|no_aliases_room" | "room_settings|general|no_aliases_space" | "room_settings|general|publish_toggle" | "room_settings|general|published_aliases_description" | "room_settings|general|published_aliases_explainer_room" | "room_settings|general|published_aliases_explainer_space" | "room_settings|general|published_aliases_section" | "room_settings|general|topic_field_label" | "room_settings|general|url_preview_encryption_warning" | "room_settings|general|url_preview_explainer" | "room_settings|general|url_previews_section" | "room_settings|general|user_url_previews_default_off" | "room_settings|general|user_url_previews_default_on" | "room_settings|people|knock_empty" | "room_settings|people|knock_section" | "room_settings|people|see_less" | "room_settings|people|see_more" | "room_settings|access|title" | "room_settings|access|description_space" | "room_settings|bridges|title" | "room_settings|bridges|description" | "room_settings|bridges|empty" | "room_settings|permissions|title" | "room_settings|permissions|m.widget" | "room_settings|permissions|invite" | "room_settings|permissions|ban" | "room_settings|permissions|users_default" | "room_settings|permissions|events_default" | "room_settings|permissions|state_default" | "room_settings|permissions|kick" | "room_settings|permissions|redact" | "room_settings|permissions|m.room.history_visibility" | "room_settings|permissions|io.element.voice_broadcast_info" | "room_settings|permissions|m.reaction" | "room_settings|permissions|m.room.power_levels" | "room_settings|permissions|m.call" | "room_settings|permissions|m.room.canonical_alias" | "room_settings|permissions|m.room.name" | "room_settings|permissions|m.room.topic" | "room_settings|permissions|m.room.avatar" | "room_settings|permissions|m.room.pinned_events" | "room_settings|permissions|m.room.encryption" | "room_settings|permissions|m.room.server_acl" | "room_settings|permissions|m.room.tombstone" | "room_settings|permissions|m.space.child" | "room_settings|permissions|m.room.redaction" | "room_settings|permissions|ban_reason" | "room_settings|permissions|banned_by" | "room_settings|permissions|add_privileged_user_description" | "room_settings|permissions|add_privileged_user_filter_placeholder" | "room_settings|permissions|add_privileged_user_heading" | "room_settings|permissions|banned_users_section" | "room_settings|permissions|error_changing_pl_description" | "room_settings|permissions|error_changing_pl_reqs_description" | "room_settings|permissions|error_changing_pl_reqs_title" | "room_settings|permissions|error_changing_pl_title" | "room_settings|permissions|error_unbanning" | "room_settings|permissions|m.call.member" | "room_settings|permissions|m.room.avatar_space" | "room_settings|permissions|m.room.canonical_alias_space" | "room_settings|permissions|m.room.name_space" | "room_settings|permissions|m.room.topic_space" | "room_settings|permissions|muted_users_section" | "room_settings|permissions|no_privileged_users" | "room_settings|permissions|notifications.room" | "room_settings|permissions|permissions_section" | "room_settings|permissions|permissions_section_description_room" | "room_settings|permissions|permissions_section_description_space" | "room_settings|permissions|privileged_users_section" | "room_settings|permissions|send_event_type" | "scalar|error_create" | "scalar|error_membership" | "scalar|error_missing_room_id" | "scalar|error_missing_room_id_request" | "scalar|error_missing_user_id_request" | "scalar|error_permission" | "scalar|error_power_level_invalid" | "scalar|error_room_not_visible" | "scalar|error_room_unknown" | "scalar|error_send_request" | "scalar|failed_read_event" | "scalar|failed_send_event" | "server_offline|title" | "server_offline|description" | "server_offline|description_1" | "server_offline|description_2" | "server_offline|description_3" | "server_offline|description_4" | "server_offline|description_5" | "server_offline|description_6" | "server_offline|description_7" | "server_offline|description_8" | "server_offline|empty_timeline" | "server_offline|recent_changes_heading" | "seshat|reset_title" | "seshat|error_initialising" | "seshat|reset_button" | "seshat|reset_description" | "seshat|reset_explainer" | "seshat|warning_kind_files" | "seshat|warning_kind_files_app" | "seshat|warning_kind_search" | "seshat|warning_kind_search_app" | "setting|help_about|title" | "setting|help_about|versions" | "setting|help_about|identity_server" | "setting|help_about|dialog_title" | "setting|help_about|homeserver" | "setting|help_about|access_token_detail" | "setting|help_about|brand_version" | "setting|help_about|clear_cache_reload" | "setting|help_about|crypto_version" | "setting|help_about|help_link" | "share|link_title" | "share|permalink_message" | "share|permalink_most_recent" | "share|share_call" | "share|share_call_subtitle" | "share|title_link" | "share|title_message" | "share|title_room" | "share|title_user" | "slash_command|join" | "slash_command|view" | "slash_command|remove" | "slash_command|verify" | "slash_command|html" | "slash_command|query" | "slash_command|invite" | "slash_command|ban" | "slash_command|ignore" | "slash_command|topic" | "slash_command|help" | "slash_command|devtools" | "slash_command|unban" | "slash_command|unignore" | "slash_command|category_other" | "slash_command|addwidget" | "slash_command|addwidget_iframe_missing_src" | "slash_command|addwidget_invalid_protocol" | "slash_command|addwidget_missing_url" | "slash_command|addwidget_no_permissions" | "slash_command|category_actions" | "slash_command|category_admin" | "slash_command|category_advanced" | "slash_command|category_effects" | "slash_command|category_messages" | "slash_command|command_error" | "slash_command|converttodm" | "slash_command|converttoroom" | "slash_command|could_not_find_room" | "slash_command|deop" | "slash_command|discardsession" | "slash_command|error_invalid_rendering_type" | "slash_command|error_invalid_room" | "slash_command|error_invalid_runfn" | "slash_command|error_invalid_user_in_room" | "slash_command|help_dialog_title" | "slash_command|holdcall" | "slash_command|ignore_dialog_description" | "slash_command|ignore_dialog_title" | "slash_command|invite_3pid_needs_is_error" | "slash_command|invite_3pid_use_default_is_title" | "slash_command|invite_3pid_use_default_is_title_description" | "slash_command|invite_failed" | "slash_command|jumptodate" | "slash_command|jumptodate_invalid_input" | "slash_command|lenny" | "slash_command|me" | "slash_command|msg" | "slash_command|myavatar" | "slash_command|myroomavatar" | "slash_command|myroomnick" | "slash_command|nick" | "slash_command|no_active_call" | "slash_command|op" | "slash_command|part_unknown_alias" | "slash_command|plain" | "slash_command|query_not_found_phone_number" | "slash_command|rageshake" | "slash_command|rainbow" | "slash_command|rainbowme" | "slash_command|remakeolm" | "slash_command|roomavatar" | "slash_command|roomname" | "slash_command|server_error" | "slash_command|server_error_detail" | "slash_command|shrug" | "slash_command|spoiler" | "slash_command|tableflip" | "slash_command|topic_none" | "slash_command|topic_room_error" | "slash_command|tovirtual" | "slash_command|tovirtual_not_found" | "slash_command|unflip" | "slash_command|unholdcall" | "slash_command|unignore_dialog_description" | "slash_command|unignore_dialog_title" | "slash_command|unknown_command" | "slash_command|unknown_command_button" | "slash_command|unknown_command_detail" | "slash_command|unknown_command_help" | "slash_command|unknown_command_hint" | "slash_command|upgraderoom" | "slash_command|upgraderoom_permission_error" | "slash_command|usage" | "slash_command|verify_mismatch" | "slash_command|verify_nop" | "slash_command|verify_nop_warning_mismatch" | "slash_command|verify_success_description" | "slash_command|verify_success_title" | "slash_command|verify_unknown_pair" | "slash_command|whois" | "space_settings|title" | "spotlight|public_rooms|network_dropdown_add_dialog_description" | "spotlight|public_rooms|network_dropdown_add_dialog_placeholder" | "spotlight|public_rooms|network_dropdown_add_dialog_title" | "spotlight|public_rooms|network_dropdown_add_server_option" | "spotlight|public_rooms|network_dropdown_available_invalid" | "spotlight|public_rooms|network_dropdown_available_invalid_forbidden" | "spotlight|public_rooms|network_dropdown_available_valid" | "spotlight|public_rooms|network_dropdown_remove_server_adornment" | "spotlight|public_rooms|network_dropdown_required_invalid" | "spotlight|public_rooms|network_dropdown_selected_label" | "spotlight|public_rooms|network_dropdown_selected_label_instance" | "spotlight|public_rooms|network_dropdown_your_server_description" | "spotlight_dialog|cant_find_person_helpful_hint" | "spotlight_dialog|cant_find_room_helpful_hint" | "spotlight_dialog|copy_link_text" | "spotlight_dialog|count_of_members" | "spotlight_dialog|create_new_room_button" | "spotlight_dialog|failed_querying_public_rooms" | "spotlight_dialog|failed_querying_public_spaces" | "spotlight_dialog|group_chat_section_title" | "spotlight_dialog|heading_with_query" | "spotlight_dialog|heading_without_query" | "spotlight_dialog|join_button_text" | "spotlight_dialog|keyboard_scroll_hint" | "spotlight_dialog|message_search_section_title" | "spotlight_dialog|other_rooms_in_space" | "spotlight_dialog|public_rooms_label" | "spotlight_dialog|public_spaces_label" | "spotlight_dialog|recent_searches_section_title" | "spotlight_dialog|recently_viewed_section_title" | "spotlight_dialog|remove_filter" | "spotlight_dialog|result_may_be_hidden_privacy_warning" | "spotlight_dialog|result_may_be_hidden_warning" | "spotlight_dialog|search_dialog" | "spotlight_dialog|search_messages_hint" | "spotlight_dialog|spaces_title" | "spotlight_dialog|start_group_chat_button" | "stickers|empty" | "stickers|empty_add_prompt" | "terms|integration_manager" | "terms|intro" | "terms|column_document" | "terms|column_service" | "terms|column_summary" | "terms|identity_server_no_terms_description_1" | "terms|identity_server_no_terms_description_2" | "terms|identity_server_no_terms_title" | "terms|inline_intro_text" | "terms|summary_identity_server_1" | "terms|summary_identity_server_2" | "terms|tac_button" | "terms|tac_description" | "terms|tac_title" | "terms|tos" | "threads_activity_centre|header" | "threads_activity_centre|release_announcement_description" | "threads_activity_centre|release_announcement_header" | "threads_activity_centre|no_rooms_with_threads_notifs" | "threads_activity_centre|no_rooms_with_unread_threads" | "unsupported_browser|title" | "unsupported_browser|description" | "update_room_access_modal|title" | "update_room_access_modal|description" | "update_room_access_modal|no_change" | "update_room_access_modal|dont_change_description" | "upload_file|title" | "upload_file|error_title" | "upload_file|cancel_all_button" | "upload_file|error_file_too_large" | "upload_file|error_files_too_large" | "upload_file|error_some_files_too_large" | "upload_file|title_progress" | "upload_file|upload_all_button" | "upload_file|upload_n_others_button" | "user_info|redact|confirm_button" | "user_info|dehydrated_device_enabled" | "user_info|room_encrypted" | "user_info|share_button" | "user_info|admin_tools_section" | "user_info|ban_button_room" | "user_info|ban_button_space" | "user_info|ban_room_confirm_title" | "user_info|ban_space_everything" | "user_info|ban_space_specific" | "user_info|count_of_sessions" | "user_info|count_of_verified_sessions" | "user_info|deactivate_confirm_action" | "user_info|deactivate_confirm_description" | "user_info|deactivate_confirm_title" | "user_info|demote_button" | "user_info|demote_self_confirm_description_space" | "user_info|demote_self_confirm_room" | "user_info|demote_self_confirm_title" | "user_info|disinvite_button_room" | "user_info|disinvite_button_room_name" | "user_info|disinvite_button_space" | "user_info|edit_own_devices" | "user_info|error_ban_user" | "user_info|error_deactivate" | "user_info|error_kicking_user" | "user_info|error_mute_user" | "user_info|error_revoke_3pid_invite_description" | "user_info|error_revoke_3pid_invite_title" | "user_info|hide_sessions" | "user_info|hide_verified_sessions" | "user_info|ignore_button" | "user_info|ignore_confirm_description" | "user_info|ignore_confirm_title" | "user_info|invited_by" | "user_info|jump_to_rr_button" | "user_info|kick_button_room" | "user_info|kick_button_room_name" | "user_info|kick_button_space" | "user_info|kick_button_space_everything" | "user_info|kick_space_specific" | "user_info|kick_space_warning" | "user_info|promote_warning" | "user_info|redact_button" | "user_info|revoke_invite" | "user_info|room_encrypted_detail" | "user_info|room_unencrypted" | "user_info|room_unencrypted_detail" | "user_info|send_message" | "user_info|unban_button_room" | "user_info|unban_button_space" | "user_info|unban_room_confirm_title" | "user_info|unban_space_everything" | "user_info|unban_space_specific" | "user_info|unban_space_warning" | "user_info|unignore_button" | "user_info|verify_button" | "user_info|verify_explainer" | "user_info|redact|confirm_description_1" | "user_info|redact|confirm_description_2" | "user_info|redact|confirm_keep_state_explainer" | "user_info|redact|confirm_keep_state_label" | "user_info|redact|confirm_title" | "user_info|redact|no_recent_messages_description" | "user_info|redact|no_recent_messages_title" | "user_menu|settings" | "user_menu|link_new_device" | "user_menu|link_new_device_not_supported" | "user_menu|link_new_device_not_supported_caption" | "user_menu|switch_theme_dark" | "user_menu|switch_theme_light" | "voice_message|cant_start_broadcast_description" | "voice_message|cant_start_broadcast_title" | "widget|error_loading" | "widget|unencrypted_warning" | "widget|added_by" | "widget|close_to_view_right_panel" | "widget|cookie_warning" | "widget|error_hangup_description" | "widget|error_hangup_title" | "widget|error_mixed_content" | "widget|error_need_invite_permission" | "widget|error_need_kick_permission" | "widget|error_need_to_be_logged_in" | "widget|error_unable_start_audio_stream_description" | "widget|error_unable_start_audio_stream_title" | "widget|modal_data_warning" | "widget|modal_title_default" | "widget|no_name" | "widget|popout" | "widget|set_room_layout" | "widget|shared_data_avatar" | "widget|shared_data_device_id" | "widget|shared_data_lang" | "widget|shared_data_mxid" | "widget|shared_data_name" | "widget|shared_data_room_id" | "widget|shared_data_theme" | "widget|shared_data_url" | "widget|shared_data_warning" | "widget|shared_data_warning_im" | "widget|shared_data_widget_id" | "widget|unmaximise" | "widget|unpin_to_view_right_panel" | "widget|context_menu|remove" | "widget|context_menu|screenshot" | "widget|context_menu|delete" | "widget|context_menu|revoke" | "widget|context_menu|delete_warning" | "widget|context_menu|move_left" | "widget|context_menu|move_right" | "widget|context_menu|start_audio_stream" | "widget|capabilities_dialog|title" | "widget|capabilities_dialog|content_starting_text" | "widget|capabilities_dialog|decline_all_permission" | "widget|capabilities_dialog|remember_Selection" | "widget|capability|capability" | "widget|capability|always_on_screen_generic" | "widget|capability|always_on_screen_viewing_another_room" | "widget|capability|any_room" | "widget|capability|byline_empty_state_key" | "widget|capability|byline_state_key" | "widget|capability|change_avatar_active_room" | "widget|capability|change_avatar_this_room" | "widget|capability|change_name_active_room" | "widget|capability|change_name_this_room" | "widget|capability|change_topic_active_room" | "widget|capability|change_topic_this_room" | "widget|capability|receive_membership_active_room" | "widget|capability|receive_membership_this_room" | "widget|capability|remove_ban_invite_leave_active_room" | "widget|capability|remove_ban_invite_leave_this_room" | "widget|capability|see_avatar_change_active_room" | "widget|capability|see_avatar_change_this_room" | "widget|capability|see_event_type_sent_active_room" | "widget|capability|see_event_type_sent_this_room" | "widget|capability|see_images_sent_active_room" | "widget|capability|see_images_sent_this_room" | "widget|capability|see_messages_sent_active_room" | "widget|capability|see_messages_sent_this_room" | "widget|capability|see_msgtype_sent_active_room" | "widget|capability|see_msgtype_sent_this_room" | "widget|capability|see_name_change_active_room" | "widget|capability|see_name_change_this_room" | "widget|capability|see_sent_emotes_active_room" | "widget|capability|see_sent_emotes_this_room" | "widget|capability|see_sent_files_active_room" | "widget|capability|see_sent_files_this_room" | "widget|capability|see_sticker_posted_active_room" | "widget|capability|see_sticker_posted_this_room" | "widget|capability|see_text_messages_sent_active_room" | "widget|capability|see_text_messages_sent_this_room" | "widget|capability|see_topic_change_active_room" | "widget|capability|see_topic_change_this_room" | "widget|capability|see_videos_sent_active_room" | "widget|capability|see_videos_sent_this_room" | "widget|capability|send_emotes_active_room" | "widget|capability|send_emotes_this_room" | "widget|capability|send_event_type_active_room" | "widget|capability|send_event_type_this_room" | "widget|capability|send_files_active_room" | "widget|capability|send_files_this_room" | "widget|capability|send_images_active_room" | "widget|capability|send_images_this_room" | "widget|capability|send_messages_active_room" | "widget|capability|send_messages_this_room" | "widget|capability|send_msgtype_active_room" | "widget|capability|send_msgtype_this_room" | "widget|capability|send_stickers_active_room" | "widget|capability|send_stickers_active_room_as_you" | "widget|capability|send_stickers_this_room" | "widget|capability|send_stickers_this_room_as_you" | "widget|capability|send_text_messages_active_room" | "widget|capability|send_text_messages_this_room" | "widget|capability|send_videos_active_room" | "widget|capability|send_videos_this_room" | "widget|capability|specific_room" | "widget|capability|switch_room" | "widget|capability|switch_room_message_user" | "widget|open_id_permissions_dialog|title" | "widget|open_id_permissions_dialog|remember_selection" | "widget|open_id_permissions_dialog|starting_text" | "zxcvbn|suggestions|allUppercase" | "zxcvbn|suggestions|anotherWord" | "zxcvbn|suggestions|associatedYears" | "zxcvbn|suggestions|capitalization" | "zxcvbn|suggestions|dates" | "zxcvbn|suggestions|l33t" | "zxcvbn|suggestions|longerKeyboardPattern" | "zxcvbn|suggestions|noNeed" | "zxcvbn|suggestions|pwned" | "zxcvbn|suggestions|recentYears" | "zxcvbn|suggestions|repeated" | "zxcvbn|suggestions|reverseWords" | "zxcvbn|suggestions|sequences" | "zxcvbn|suggestions|useWords" | "zxcvbn|warnings|common" | "zxcvbn|warnings|dates" | "zxcvbn|warnings|pwned" | "zxcvbn|warnings|recentYears" | "zxcvbn|warnings|sequences" | "zxcvbn|warnings|commonNames" | "zxcvbn|warnings|extendedRepeat" | "zxcvbn|warnings|keyPattern" | "zxcvbn|warnings|namesByThemselves" | "zxcvbn|warnings|similarToCommon" | "zxcvbn|warnings|simpleRepeat" | "zxcvbn|warnings|straightRow" | "zxcvbn|warnings|topHundred" | "zxcvbn|warnings|topTen" | "zxcvbn|warnings|userInputs" | "zxcvbn|warnings|wordByItself";
        labelAllowedButUnsafe: "a11y_jump_first_unread_room" | "cannot_invite_without_identity_server" | "cannot_reach_homeserver" | "cannot_reach_homeserver_detail" | "cant_load_page" | "chat_card_back_action_label" | "console_dev_note" | "console_scam_warning" | "console_wait" | "dialog_close_label" | "empty_room" | "empty_room_was_name" | "error_app_open_in_another_tab" | "error_app_open_in_another_tab_title" | "error_app_opened_in_another_window" | "error_database_closed_title" | "error_user_not_logged_in" | "failed_load_async_component" | "in_space" | "in_space1_and_space2" | "in_space_and_n_other_spaces" | "info_tooltip_title" | "inviting_user1_and_user2" | "inviting_user_and_n_others" | "items_and_n_others" | "language_dropdown_label" | "member_list_back_action_label" | "message_edit_dialog_title" | "migrating_crypto" | "name_and_id" | "no_more_results" | "room_summary_card_back_action_label" | "thread_view_back_action_label" | "truncated_list_n_more" | "unsupported_server_description" | "unsupported_server_title" | "upload_failed_generic" | "upload_failed_size" | "upload_failed_title" | "emoji|categories" | "emoji|category_activities" | "emoji|category_animals_nature" | "emoji|category_flags" | "emoji|category_food_drink" | "emoji|category_frequently_used" | "emoji|category_objects" | "emoji|category_smileys_people" | "emoji|category_symbols" | "emoji|category_travel_places" | "emoji|quick_reactions" | "time|left" | "time|about_day_ago" | "time|about_hour_ago" | "time|about_minute_ago" | "time|date_at_time" | "time|few_seconds_ago" | "time|hours_minutes_seconds_left" | "time|in_about_day" | "time|in_about_hour" | "time|in_about_minute" | "time|in_few_seconds" | "time|in_n_days" | "time|in_n_hours" | "time|in_n_minutes" | "time|minutes_seconds_left" | "time|n_days_ago" | "time|n_hours_ago" | "time|n_minutes_ago" | "time|seconds_left" | "time|short_days" | "time|short_days_hours_minutes_seconds" | "time|short_hours" | "time|short_hours_minutes_seconds" | "time|short_minutes" | "time|short_minutes_seconds" | "time|short_seconds" | "error|sync" | "error|unknown" | "error|admin_contact" | "error|connection" | "error|admin_contact_short" | "error|dialog_description_default" | "error|download_media" | "error|edit_history_unsupported" | "error|failed_copy" | "error|hs_blocked" | "error|mau" | "error|mixed_content" | "error|non_urgent_echo_failure_toast" | "error|resource_limits" | "error|something_went_wrong" | "error|storage_evicted_description_1" | "error|storage_evicted_description_2" | "error|storage_evicted_title" | "error|tls" | "error|unknown_error_code" | "error|update_power_level" | "error|session_restore|title" | "error|session_restore|clear_storage_button" | "error|session_restore|clear_storage_description" | "error|session_restore|description_1" | "error|session_restore|description_2" | "error|session_restore|description_3" | "feedback|sent" | "feedback|can_contact_label" | "feedback|comment_label" | "feedback|existing_issue_link" | "feedback|may_contact_label" | "feedback|platform_username" | "feedback|pro_type" | "feedback|send_feedback_action" | "timeline|m.sticker" | "timeline|m.poll.start" | "timeline|io.element.widgets.layout" | "timeline|m.room.topic" | "timeline|m.room.tombstone" | "timeline|creation_summary_dm" | "timeline|creation_summary_room" | "timeline|disambiguated_profile" | "timeline|download_action_decrypting" | "timeline|download_action_downloading" | "timeline|download_failed" | "timeline|download_failed_description" | "timeline|error_no_renderer" | "timeline|error_rendering_message" | "timeline|historical_messages_unavailable" | "timeline|in_room_name" | "timeline|late_event_separator" | "timeline|message_timestamp_received_at" | "timeline|message_timestamp_sent_at" | "timeline|no_permission_messages_before_invite" | "timeline|no_permission_messages_before_join" | "timeline|pending_moderation" | "timeline|pending_moderation_reason" | "timeline|read_receipt_title" | "timeline|read_receipts_label" | "timeline|redaction" | "timeline|self_redaction" | "timeline|send_state_encrypting" | "timeline|send_state_failed" | "timeline|send_state_sending" | "timeline|send_state_sent" | "timeline|thread_info_basic" | "timeline|undecryptable_tooltip" | "timeline|summary|left" | "timeline|summary|invited" | "timeline|summary|joined" | "timeline|summary|format" | "timeline|summary|redacted" | "timeline|summary|banned" | "timeline|summary|banned_multiple" | "timeline|summary|changed_avatar" | "timeline|summary|changed_avatar_multiple" | "timeline|summary|changed_name" | "timeline|summary|changed_name_multiple" | "timeline|summary|hidden_event" | "timeline|summary|hidden_event_multiple" | "timeline|summary|invite_withdrawn" | "timeline|summary|invite_withdrawn_multiple" | "timeline|summary|invited_multiple" | "timeline|summary|joined_and_left" | "timeline|summary|joined_and_left_multiple" | "timeline|summary|joined_multiple" | "timeline|summary|kicked" | "timeline|summary|kicked_multiple" | "timeline|summary|left_multiple" | "timeline|summary|no_change" | "timeline|summary|no_change_multiple" | "timeline|summary|pinned_events" | "timeline|summary|pinned_events_multiple" | "timeline|summary|redacted_multiple" | "timeline|summary|rejected_invite" | "timeline|summary|rejected_invite_multiple" | "timeline|summary|rejoined" | "timeline|summary|rejoined_multiple" | "timeline|summary|server_acls" | "timeline|summary|server_acls_multiple" | "timeline|summary|unbanned" | "timeline|summary|unbanned_multiple" | "timeline|m.widget|removed" | "timeline|m.widget|added" | "timeline|m.widget|jitsi_ended" | "timeline|m.widget|jitsi_join_right_prompt" | "timeline|m.widget|jitsi_join_top_prompt" | "timeline|m.widget|jitsi_started" | "timeline|m.widget|jitsi_updated" | "timeline|m.widget|modified" | "timeline|m.poll.end|ended" | "timeline|m.poll.end|sender_ended" | "timeline|m.location|location" | "timeline|m.location|full" | "timeline|m.location|self_location" | "timeline|m.beacon_info|view_live_location" | "timeline|m.room.history_visibility|shared" | "timeline|m.room.history_visibility|unknown" | "timeline|m.room.history_visibility|invited" | "timeline|m.room.history_visibility|joined" | "timeline|m.room.history_visibility|world_readable" | "timeline|m.key.verification.request|user_wants_to_verify" | "timeline|m.key.verification.request|you_started" | "timeline|m.video|error_decrypting" | "timeline|io.element.voice_broadcast_info|user" | "timeline|io.element.voice_broadcast_info|you" | "timeline|m.room.power_levels|changed" | "timeline|m.room.power_levels|user_from_to" | "timeline|m.call|video_call_ended" | "timeline|m.call|video_call_started" | "timeline|m.call|video_call_started_text" | "timeline|m.call|video_call_started_unsupported" | "timeline|m.room.canonical_alias|set" | "timeline|m.room.canonical_alias|removed" | "timeline|m.room.canonical_alias|changed" | "timeline|m.room.canonical_alias|alt_added" | "timeline|m.room.canonical_alias|alt_removed" | "timeline|m.room.canonical_alias|changed_alternative" | "timeline|m.room.canonical_alias|changed_main_and_alternative" | "timeline|m.room.create|continuation" | "timeline|m.room.create|see_older_messages" | "timeline|m.room.create|unknown_predecessor" | "timeline|m.room.create|unknown_predecessor_guess_server" | "timeline|m.room.join_rules|public" | "timeline|m.room.join_rules|unknown" | "timeline|m.room.join_rules|invite" | "timeline|m.room.join_rules|knock" | "timeline|m.room.join_rules|restricted" | "timeline|m.room.join_rules|restricted_settings" | "timeline|m.room.member|join" | "timeline|m.room.member|left" | "timeline|m.room.member|invite" | "timeline|m.room.member|ban" | "timeline|m.room.member|kick" | "timeline|m.room.member|no_change" | "timeline|m.room.member|accepted_3pid_invite" | "timeline|m.room.member|accepted_invite" | "timeline|m.room.member|ban_reason" | "timeline|m.room.member|change_avatar" | "timeline|m.room.member|change_name" | "timeline|m.room.member|change_name_avatar" | "timeline|m.room.member|kick_reason" | "timeline|m.room.member|left_reason" | "timeline|m.room.member|reject_invite" | "timeline|m.room.member|remove_avatar" | "timeline|m.room.member|remove_name" | "timeline|m.room.member|set_avatar" | "timeline|m.room.member|set_name" | "timeline|m.room.member|unban" | "timeline|m.room.member|withdrew_invite" | "timeline|m.room.member|withdrew_invite_reason" | "timeline|m.room.third_party_invite|sent" | "timeline|m.room.third_party_invite|revoked" | "timeline|m.room.name|set" | "timeline|m.room.name|remove" | "timeline|m.room.name|change" | "timeline|m.room.avatar|removed" | "timeline|m.room.avatar|changed" | "timeline|m.room.avatar|changed_img" | "timeline|m.room.avatar|lightbox_title" | "timeline|m.room.pinned_events|changed" | "timeline|m.room.pinned_events|changed_link" | "timeline|m.room.pinned_events|pinned" | "timeline|m.room.pinned_events|pinned_link" | "timeline|m.room.pinned_events|unpinned" | "timeline|m.room.pinned_events|unpinned_link" | "timeline|m.room.encryption|disabled" | "timeline|m.room.encryption|enabled" | "timeline|m.room.encryption|disable_attempt" | "timeline|m.room.encryption|enabled_dm" | "timeline|m.room.encryption|enabled_local" | "timeline|m.room.encryption|parameters_changed" | "timeline|m.room.encryption|unsupported" | "timeline|m.room.guest_access|unknown" | "timeline|m.room.guest_access|can_join" | "timeline|m.room.guest_access|forbidden" | "timeline|m.room.server_acl|set" | "timeline|m.room.server_acl|changed" | "timeline|m.room.server_acl|all_servers_banned" | "timeline|m.call.invite|answered_elsewhere" | "timeline|m.call.invite|call_back_prompt" | "timeline|m.call.invite|declined" | "timeline|m.call.invite|failed_connect_media" | "timeline|m.call.invite|failed_connection" | "timeline|m.call.invite|failed_opponent_media" | "timeline|m.call.invite|missed_call" | "timeline|m.call.invite|no_answer" | "timeline|m.call.invite|unknown_error" | "timeline|m.call.invite|unknown_failure" | "timeline|m.call.invite|unknown_state" | "timeline|m.call.invite|video_call" | "timeline|m.call.invite|video_call_unsupported" | "timeline|m.call.invite|voice_call" | "timeline|m.call.invite|voice_call_unsupported" | "timeline|m.call.hangup|dm" | "timeline|m.image|error" | "timeline|m.image|sent" | "timeline|m.image|error_decrypting" | "timeline|m.image|error_downloading" | "timeline|m.image|show_image" | "timeline|m.file|error_decrypting" | "timeline|m.file|decrypt_label" | "timeline|m.file|download_label" | "timeline|m.file|error_invalid" | "timeline|m.audio|error_downloading_audio" | "timeline|m.audio|error_processing_audio" | "timeline|m.audio|error_processing_voice_message" | "timeline|m.audio|unnamed_audio" | "timeline|context_menu|report" | "timeline|context_menu|collapse_reply_thread" | "timeline|context_menu|external_url" | "timeline|context_menu|open_in_osm" | "timeline|context_menu|resent_unsent_reactions" | "timeline|context_menu|show_url_preview" | "timeline|context_menu|view_related_event" | "timeline|context_menu|view_source" | "timeline|decryption_failure|blocked" | "timeline|decryption_failure|historical_event_no_key_backup" | "timeline|decryption_failure|historical_event_unverified_device" | "timeline|decryption_failure|historical_event_user_not_joined" | "timeline|decryption_failure|unable_to_decrypt" | "timeline|edits|tooltip_label" | "timeline|edits|tooltip_sub" | "timeline|edits|tooltip_title" | "timeline|load_error|title" | "timeline|load_error|no_permission" | "timeline|load_error|unable_to_find" | "timeline|m.poll|count_of_votes" | "timeline|mab|label" | "timeline|mab|collapse_reply_chain" | "timeline|mab|copy_link_thread" | "timeline|mab|expand_reply_chain" | "timeline|mab|view_in_room" | "timeline|mjolnir|changed_rule_glob" | "timeline|mjolnir|changed_rule_rooms" | "timeline|mjolnir|changed_rule_servers" | "timeline|mjolnir|changed_rule_users" | "timeline|mjolnir|created_rule" | "timeline|mjolnir|created_rule_rooms" | "timeline|mjolnir|created_rule_servers" | "timeline|mjolnir|created_rule_users" | "timeline|mjolnir|message_hidden" | "timeline|mjolnir|removed_rule" | "timeline|mjolnir|removed_rule_rooms" | "timeline|mjolnir|removed_rule_servers" | "timeline|mjolnir|removed_rule_users" | "timeline|mjolnir|updated_invalid_rule" | "timeline|mjolnir|updated_rule" | "timeline|mjolnir|updated_rule_rooms" | "timeline|mjolnir|updated_rule_servers" | "timeline|mjolnir|updated_rule_users" | "timeline|reactions|label" | "timeline|reactions|add_reaction_prompt" | "timeline|reactions|custom_reaction_fallback_label" | "timeline|reactions|tooltip_caption" | "timeline|redacted|tooltip" | "timeline|reply|error_loading" | "timeline|reply|in_reply_to" | "timeline|reply|in_reply_to_for_export" | "timeline|scalar_starter_link|dialog_description" | "timeline|scalar_starter_link|dialog_title" | "timeline|typing_indicator|more_users" | "timeline|typing_indicator|one_user" | "timeline|typing_indicator|two_users" | "timeline|url_preview|close" | "timeline|url_preview|show_n_more" | "notifications|default" | "notifications|all_messages" | "notifications|all_messages_description" | "notifications|class_global" | "notifications|class_other" | "notifications|email_pusher_app_display_name" | "notifications|enable_prompt_toast_description" | "notifications|enable_prompt_toast_title" | "notifications|enable_prompt_toast_title_from_message_send" | "notifications|error_change_title" | "notifications|keyword" | "notifications|keyword_new" | "notifications|level_activity" | "notifications|level_highlight" | "notifications|level_muted" | "notifications|level_none" | "notifications|level_notification" | "notifications|level_unsent" | "notifications|mark_all_read" | "notifications|mentions_and_keywords" | "notifications|mentions_and_keywords_description" | "notifications|mentions_keywords" | "notifications|message_didnt_send" | "notifications|mute_description" | "action|search" | "action|join" | "action|add" | "action|show" | "action|pause" | "action|play" | "action|stop" | "action|reload" | "action|start" | "action|view" | "action|cancel" | "action|remove" | "action|clear" | "action|copy" | "action|verify" | "action|complete" | "action|change" | "action|click" | "action|close" | "action|reset" | "action|submit" | "action|forward" | "action|next" | "action|done" | "action|resume" | "action|refresh" | "action|disconnect" | "action|update" | "action|confirm" | "action|ok" | "action|invite" | "action|leave" | "action|ignore" | "action|register" | "action|reject" | "action|delete" | "action|pin" | "action|download" | "action|upload" | "action|save" | "action|apply" | "action|call" | "action|collapse" | "action|accept" | "action|yes" | "action|no" | "action|go" | "action|upgrade" | "action|rename" | "action|continue" | "action|skip" | "action|disable" | "action|enable" | "action|report_content" | "action|share" | "action|upload_file" | "action|reply" | "action|set_avatar" | "action|unban" | "action|view_source" | "action|add_existing_room" | "action|add_people" | "action|approve" | "action|ask_to_join" | "action|back" | "action|click_to_copy" | "action|copy_link" | "action|create" | "action|create_a_room" | "action|decline" | "action|deny" | "action|dismiss" | "action|edit" | "action|enter_fullscreen" | "action|exit_fullscreeen" | "action|expand" | "action|explore_public_rooms" | "action|explore_rooms" | "action|export" | "action|go_back" | "action|got_it" | "action|hide_advanced" | "action|hold" | "action|import" | "action|invite_to_space" | "action|invites_list" | "action|learn_more" | "action|leave_room" | "action|logout" | "action|manage" | "action|maximise" | "action|mention" | "action|minimise" | "action|new_room" | "action|new_video_room" | "action|proceed" | "action|quote" | "action|react" | "action|reply_in_thread" | "action|resend" | "action|restore" | "action|retry" | "action|review" | "action|revoke" | "action|send_report" | "action|show_advanced" | "action|show_all" | "action|sign_in" | "action|sign_out" | "action|start_chat" | "action|start_new_chat" | "action|subscribe" | "action|transfer" | "action|trust" | "action|try_again" | "action|unignore" | "action|unpin" | "action|unsubscribe" | "action|view_all" | "action|view_list" | "action|view_message" | "action|zoom_in" | "action|zoom_out" | "forward|sending" | "forward|sent" | "forward|filter_placeholder" | "forward|message_preview_heading" | "forward|no_perms_title" | "forward|open_room" | "forward|send_label" | "auth|sso" | "auth|3pid_in_use" | "auth|account_clash" | "auth|account_clash_previous_account" | "auth|account_deactivated" | "auth|autodiscovery_generic_failure" | "auth|autodiscovery_hs_incompatible" | "auth|autodiscovery_invalid" | "auth|autodiscovery_invalid_hs" | "auth|autodiscovery_invalid_hs_base_url" | "auth|autodiscovery_invalid_is" | "auth|autodiscovery_invalid_is_base_url" | "auth|autodiscovery_invalid_is_response" | "auth|autodiscovery_invalid_json" | "auth|autodiscovery_no_well_known" | "auth|autodiscovery_unexpected_error_hs" | "auth|autodiscovery_unexpected_error_is" | "auth|captcha_description" | "auth|change_password_action" | "auth|change_password_confirm_invalid" | "auth|change_password_confirm_label" | "auth|change_password_current_label" | "auth|change_password_empty" | "auth|change_password_error" | "auth|change_password_mismatch" | "auth|change_password_new_label" | "auth|check_email_explainer" | "auth|check_email_resend_prompt" | "auth|check_email_resend_tooltip" | "auth|check_email_wrong_email_button" | "auth|check_email_wrong_email_prompt" | "auth|continue_with_idp" | "auth|continue_with_sso" | "auth|country_dropdown" | "auth|create_account_prompt" | "auth|create_account_title" | "auth|email_discovery_text" | "auth|email_field_label" | "auth|email_field_label_invalid" | "auth|email_field_label_required" | "auth|email_help_text" | "auth|email_phone_discovery_text" | "auth|enter_email_explainer" | "auth|enter_email_heading" | "auth|failed_connect_identity_server" | "auth|failed_connect_identity_server_other" | "auth|failed_connect_identity_server_register" | "auth|failed_connect_identity_server_reset_password" | "auth|failed_homeserver_discovery" | "auth|failed_query_registration_methods" | "auth|failed_soft_logout_auth" | "auth|failed_soft_logout_homeserver" | "auth|footer_powered_by_matrix" | "auth|forgot_password_email_invalid" | "auth|forgot_password_email_required" | "auth|forgot_password_prompt" | "auth|forgot_password_send_email" | "auth|identifier_label" | "auth|incorrect_credentials" | "auth|incorrect_credentials_detail" | "auth|incorrect_password" | "auth|log_in_new_account" | "auth|misconfigured_body" | "auth|misconfigured_title" | "auth|msisdn_field_description" | "auth|msisdn_field_label" | "auth|msisdn_field_number_invalid" | "auth|msisdn_field_required_invalid" | "auth|no_hs_url_provided" | "auth|password_field_keep_going_prompt" | "auth|password_field_label" | "auth|password_field_strong_label" | "auth|password_field_weak_label" | "auth|phone_label" | "auth|phone_optional_label" | "auth|register_action" | "auth|registration_disabled" | "auth|registration_msisdn_field_required_invalid" | "auth|registration_successful" | "auth|registration_username_in_use" | "auth|registration_username_unable_check" | "auth|registration_username_validation" | "auth|reset_password_action" | "auth|reset_password_button" | "auth|reset_password_email_field_description" | "auth|reset_password_email_field_required_invalid" | "auth|reset_password_email_not_associated" | "auth|reset_password_email_not_found_title" | "auth|reset_password_title" | "auth|server_picker_custom" | "auth|server_picker_description" | "auth|server_picker_description_matrix.org" | "auth|server_picker_dialog_title" | "auth|server_picker_explainer" | "auth|server_picker_failed_validate_homeserver" | "auth|server_picker_intro" | "auth|server_picker_invalid_url" | "auth|server_picker_learn_more" | "auth|server_picker_matrix.org" | "auth|server_picker_required" | "auth|server_picker_title" | "auth|server_picker_title_default" | "auth|server_picker_title_registration" | "auth|session_logged_out_description" | "auth|session_logged_out_title" | "auth|set_email_prompt" | "auth|sign_in_description" | "auth|sign_in_instead" | "auth|sign_in_instead_prompt" | "auth|sign_in_or_register" | "auth|sign_in_or_register_description" | "auth|sign_in_prompt" | "auth|sign_in_with_sso" | "auth|signing_in" | "auth|soft_logout_heading" | "auth|soft_logout_intro_password" | "auth|soft_logout_intro_sso" | "auth|soft_logout_intro_unsupported_auth" | "auth|soft_logout_subheading" | "auth|soft_logout_warning" | "auth|sso_failed_missing_storage" | "auth|sso_or_username_password" | "auth|sync_footer_subtitle" | "auth|syncing" | "auth|unsupported_auth" | "auth|unsupported_auth_email" | "auth|unsupported_auth_msisdn" | "auth|username_field_required_invalid" | "auth|username_in_use" | "auth|verify_email_explainer" | "auth|verify_email_heading" | "auth|logout_dialog|description" | "auth|logout_dialog|megolm_export" | "auth|logout_dialog|setup_key_backup_title" | "auth|logout_dialog|setup_secure_backup_description_1" | "auth|logout_dialog|setup_secure_backup_description_2" | "auth|logout_dialog|skip_key_backup" | "auth|logout_dialog|use_key_backup" | "auth|oidc|error_title" | "auth|oidc|generic_auth_error" | "auth|oidc|logout_redirect_warning" | "auth|oidc|missing_or_invalid_stored_state" | "auth|qr_code_login|approve_access_warning" | "auth|qr_code_login|check_code_explainer" | "auth|qr_code_login|check_code_heading" | "auth|qr_code_login|check_code_input_label" | "auth|qr_code_login|check_code_mismatch" | "auth|qr_code_login|completing_setup" | "auth|qr_code_login|confirm_code_match" | "auth|qr_code_login|error_etag_missing" | "auth|qr_code_login|error_expired" | "auth|qr_code_login|error_expired_title" | "auth|qr_code_login|error_insecure_channel_detected" | "auth|qr_code_login|error_insecure_channel_detected_instructions" | "auth|qr_code_login|error_insecure_channel_detected_instructions_1" | "auth|qr_code_login|error_insecure_channel_detected_instructions_2" | "auth|qr_code_login|error_insecure_channel_detected_instructions_3" | "auth|qr_code_login|error_insecure_channel_detected_title" | "auth|qr_code_login|error_other_device_already_signed_in" | "auth|qr_code_login|error_other_device_already_signed_in_title" | "auth|qr_code_login|error_rate_limited" | "auth|qr_code_login|error_unexpected" | "auth|qr_code_login|error_unsupported_protocol" | "auth|qr_code_login|error_unsupported_protocol_title" | "auth|qr_code_login|error_user_cancelled" | "auth|qr_code_login|error_user_cancelled_title" | "auth|qr_code_login|error_user_declined" | "auth|qr_code_login|error_user_declined_title" | "auth|qr_code_login|follow_remaining_instructions" | "auth|qr_code_login|open_element_other_device" | "auth|qr_code_login|point_the_camera" | "auth|qr_code_login|scan_code_instruction" | "auth|qr_code_login|scan_qr_code" | "auth|qr_code_login|security_code" | "auth|qr_code_login|security_code_prompt" | "auth|qr_code_login|select_qr_code" | "auth|qr_code_login|sign_in_new_device" | "auth|qr_code_login|waiting_for_device" | "auth|registration|continue_without_email_description" | "auth|registration|continue_without_email_field_label" | "auth|registration|continue_without_email_title" | "auth|reset_password|confirm_new_password" | "auth|reset_password|devices_logout_success" | "auth|reset_password|other_devices_logout_warning_1" | "auth|reset_password|other_devices_logout_warning_2" | "auth|reset_password|password_not_entered" | "auth|reset_password|passwords_mismatch" | "auth|reset_password|rate_limit_error" | "auth|reset_password|rate_limit_error_with_time" | "auth|reset_password|reset_successful" | "auth|reset_password|return_to_login" | "auth|reset_password|sign_out_other_devices" | "auth|set_email|description" | "auth|set_email|verification_pending_description" | "auth|set_email|verification_pending_title" | "auth|soft_logout|clear_data_button" | "auth|soft_logout|clear_data_description" | "auth|soft_logout|clear_data_title" | "auth|uia|code" | "auth|uia|email" | "auth|uia|msisdn" | "auth|uia|terms" | "auth|uia|email_auth_header" | "auth|uia|email_resend_prompt" | "auth|uia|email_resent" | "auth|uia|fallback_button" | "auth|uia|msisdn_token_incorrect" | "auth|uia|msisdn_token_prompt" | "auth|uia|password_prompt" | "auth|uia|recaptcha_missing_params" | "auth|uia|registration_token_label" | "auth|uia|registration_token_prompt" | "auth|uia|sso_body" | "auth|uia|sso_failed" | "auth|uia|sso_postauth_body" | "auth|uia|sso_postauth_title" | "auth|uia|sso_preauth_body" | "auth|uia|sso_title" | "auth|uia|terms_invalid" | "update|checking" | "update|unavailable" | "update|changelog" | "update|check_action" | "update|downloading" | "update|error_encountered" | "update|error_unable_load_commit" | "update|new_version_available" | "update|no_update" | "update|release_notes_toast_title" | "update|see_changes_button" | "update|toast_description" | "update|toast_title" | "room|show_labs_settings" | "room|kick_reason" | "room|3pid_invite_email_not_found_account" | "room|3pid_invite_email_not_found_account_room" | "room|3pid_invite_error_description" | "room|3pid_invite_error_invite_action" | "room|3pid_invite_error_invite_subtitle" | "room|3pid_invite_error_public_subtitle" | "room|3pid_invite_error_title" | "room|3pid_invite_error_title_room" | "room|3pid_invite_no_is_subtitle" | "room|banned_by" | "room|banned_from_room_by" | "room|creating_room_text" | "room|dm_invite_action" | "room|dm_invite_subtitle" | "room|dm_invite_title" | "room|drop_file_prompt" | "room|edit_topic" | "room|error_3pid_invite_email_lookup" | "room|error_cancel_knock_title" | "room|error_join_403" | "room|error_join_404_1" | "room|error_join_404_2" | "room|error_join_404_invite" | "room|error_join_404_invite_same_hs" | "room|error_join_connection" | "room|error_join_incompatible_version_1" | "room|error_join_incompatible_version_2" | "room|error_join_title" | "room|error_jump_to_date" | "room|error_jump_to_date_connection" | "room|error_jump_to_date_details" | "room|error_jump_to_date_not_found" | "room|error_jump_to_date_send_logs_prompt" | "room|error_jump_to_date_title" | "room|face_pile_summary" | "room|face_pile_tooltip_label" | "room|face_pile_tooltip_shortcut" | "room|face_pile_tooltip_shortcut_joined" | "room|failed_reject_invite" | "room|forget_room" | "room|forget_space" | "room|header_face_pile_tooltip" | "room|header_untrusted_label" | "room|inaccessible" | "room|inaccessible_name" | "room|inaccessible_subtitle_1" | "room|inaccessible_subtitle_2" | "room|invite_email_mismatch_suggestion" | "room|invite_reject_ignore" | "room|invite_sent_to_email" | "room|invite_sent_to_email_room" | "room|invite_subtitle" | "room|invite_this_room" | "room|invite_title" | "room|inviter_unknown" | "room|invites_you_text" | "room|join_button_account" | "room|join_failed_enable_video_rooms" | "room|join_failed_needs_invite" | "room|join_the_discussion" | "room|join_title" | "room|join_title_account" | "room|joining" | "room|joining_room" | "room|joining_space" | "room|jump_read_marker" | "room|jump_to_bottom_button" | "room|jump_to_date" | "room|jump_to_date_beginning" | "room|jump_to_date_prompt" | "room|kicked_by" | "room|kicked_from_room_by" | "room|knock_cancel_action" | "room|knock_denied_subtitle" | "room|knock_denied_title" | "room|knock_message_field_placeholder" | "room|knock_prompt" | "room|knock_prompt_name" | "room|knock_send_action" | "room|knock_sent" | "room|knock_sent_subtitle" | "room|knock_subtitle" | "room|leave_error_title" | "room|leave_server_notices_description" | "room|leave_server_notices_title" | "room|leave_unexpected_error" | "room|link_email_to_receive_3pid_invite" | "room|loading_preview" | "room|no_peek_join_prompt" | "room|no_peek_no_name_join_prompt" | "room|not_found_subtitle" | "room|not_found_title" | "room|not_found_title_name" | "room|peek_join_prompt" | "room|read_topic" | "room|rejecting" | "room|rejoin_button" | "room|unknown_status_code_for_timeline_jump" | "room|unread_notifications_predecessor" | "room|upgrade_error_description" | "room|upgrade_error_title" | "room|upgrade_warning_bar" | "room|upgrade_warning_bar_admins" | "room|upgrade_warning_bar_unstable" | "room|upgrade_warning_bar_upgraded" | "room|view_failed_enable_video_rooms" | "room|waiting_for_join_subtitle" | "room|waiting_for_join_title" | "room|search|summary" | "room|search|placeholder" | "room|search|all_rooms_button" | "room|search|result_count" | "room|search|this_room_button" | "room|header|close_call_button" | "room|header|forget_room_button" | "room|header|hide_widgets_button" | "room|header|n_people_asking_to_join" | "room|header|release_announcement_description" | "room|header|release_announcement_header" | "room|header|room_is_public" | "room|header|show_widgets_button" | "room|header|video_call_button_ec" | "room|header|video_call_button_jitsi" | "room|header|video_call_button_legacy" | "room|header|video_call_ec_change_layout" | "room|header|video_call_ec_layout_freedom" | "room|header|video_call_ec_layout_spotlight" | "room|header|video_room_view_chat_button" | "room|upload|uploading_multiple_file" | "room|upload|uploading_single_file" | "room|context_menu|title" | "room|context_menu|forget" | "room|context_menu|copy_link" | "room|context_menu|favourite" | "room|context_menu|low_priority" | "room|context_menu|mark_read" | "room|context_menu|mark_unread" | "room|context_menu|mentions_only" | "room|context_menu|notifications_default" | "room|context_menu|notifications_mute" | "room|context_menu|unfavourite" | "room|intro|topic" | "room|intro|dm_caption" | "room|intro|enable_encryption_prompt" | "room|intro|encrypted_3pid_dm_pending_join" | "room|intro|no_avatar_label" | "room|intro|no_topic" | "room|intro|private_unencrypted_warning" | "room|intro|room_invite" | "room|intro|send_message_start_dm" | "room|intro|start_of_dm_history" | "room|intro|start_of_room" | "room|intro|topic_edit" | "room|intro|unencrypted_warning" | "room|intro|user_created" | "room|intro|you_created" | "room|pinned_message_banner|title" | "room|pinned_message_banner|description" | "room|pinned_message_banner|button_close_list" | "room|pinned_message_banner|button_view_all" | "room|pinned_message_banner|go_to_message" | "room|status_bar|delete_all" | "room|status_bar|exceeded_resource_limit" | "room|status_bar|homeserver_blocked" | "room|status_bar|monthly_user_limit_reached" | "room|status_bar|requires_consent_agreement" | "room|status_bar|retry_all" | "room|status_bar|select_messages_to_retry" | "room|status_bar|server_connectivity_lost_description" | "room|status_bar|server_connectivity_lost_title" | "room|status_bar|some_messages_not_sent" | "invite|ask_anyway_description" | "invite|ask_anyway_label" | "invite|ask_anyway_never_warn_label" | "invite|email_caption" | "invite|email_limit_one" | "invite|email_use_default_is" | "invite|email_use_is" | "invite|error_already_invited_room" | "invite|error_already_invited_space" | "invite|error_already_joined_room" | "invite|error_already_joined_space" | "invite|error_bad_state" | "invite|error_dm" | "invite|error_find_room" | "invite|error_find_user_description" | "invite|error_find_user_title" | "invite|error_invite" | "invite|error_permissions_room" | "invite|error_permissions_space" | "invite|error_profile_undisclosed" | "invite|error_transfer_multiple_target" | "invite|error_unfederated_room" | "invite|error_unfederated_space" | "invite|error_unknown" | "invite|error_user_not_found" | "invite|error_version_unsupported_room" | "invite|error_version_unsupported_space" | "invite|failed_generic" | "invite|failed_title" | "invite|invalid_address" | "invite|name_email_mxid_share_room" | "invite|name_email_mxid_share_space" | "invite|name_mxid_share_room" | "invite|name_mxid_share_space" | "invite|recents_section" | "invite|room_failed_partial" | "invite|room_failed_partial_title" | "invite|room_failed_title" | "invite|send_link_prompt" | "invite|start_conversation_name_email_mxid_prompt" | "invite|start_conversation_name_mxid_prompt" | "invite|suggestions_disclaimer" | "invite|suggestions_disclaimer_prompt" | "invite|suggestions_section" | "invite|to_room" | "invite|to_space" | "invite|transfer_dial_pad_tab" | "invite|transfer_user_directory_tab" | "invite|unable_find_profiles_description_default" | "invite|unable_find_profiles_invite_label_default" | "invite|unable_find_profiles_invite_never_warn_label_default" | "invite|unable_find_profiles_title" | "invite|unban_first_title" | "presence|idle" | "presence|offline" | "presence|online" | "presence|unknown" | "presence|away" | "presence|busy" | "presence|idle_for" | "presence|offline_for" | "presence|online_for" | "presence|unknown_for" | "presence|unreachable" | "redact|error" | "redact|confirm_button" | "redact|confirm_description" | "redact|confirm_description_state" | "redact|ongoing" | "redact|reason_label" | "encryption|unsupported" | "encryption|bootstrap_title" | "encryption|cancel_entering_passphrase_description" | "encryption|cancel_entering_passphrase_title" | "encryption|confirm_encryption_setup_body" | "encryption|confirm_encryption_setup_title" | "encryption|cross_signing_not_ready" | "encryption|cross_signing_ready" | "encryption|cross_signing_ready_no_backup" | "encryption|cross_signing_room_normal" | "encryption|cross_signing_room_verified" | "encryption|cross_signing_room_warning" | "encryption|cross_signing_unsupported" | "encryption|cross_signing_untrusted" | "encryption|cross_signing_user_normal" | "encryption|cross_signing_user_verified" | "encryption|cross_signing_user_warning" | "encryption|event_shield_reason_authenticity_not_guaranteed" | "encryption|event_shield_reason_mismatched_sender_key" | "encryption|event_shield_reason_unknown_device" | "encryption|event_shield_reason_unsigned_device" | "encryption|event_shield_reason_unverified_identity" | "encryption|export_unsupported" | "encryption|import_invalid_keyfile" | "encryption|import_invalid_passphrase" | "encryption|incompatible_database_description" | "encryption|incompatible_database_disable" | "encryption|incompatible_database_sign_out_description" | "encryption|incompatible_database_title" | "encryption|key_signature_upload_cancelled" | "encryption|key_signature_upload_completed" | "encryption|key_signature_upload_failed" | "encryption|key_signature_upload_failed_body" | "encryption|key_signature_upload_failed_cross_signing_key_signature" | "encryption|key_signature_upload_failed_device_cross_signing_key_signature" | "encryption|key_signature_upload_failed_key_signature" | "encryption|key_signature_upload_failed_master_key_signature" | "encryption|key_signature_upload_failed_title" | "encryption|key_signature_upload_success_title" | "encryption|not_supported" | "encryption|old_version_detected_description" | "encryption|old_version_detected_title" | "encryption|reset_all_button" | "encryption|set_up_toast_description" | "encryption|set_up_toast_title" | "encryption|unable_to_setup_keys_error" | "encryption|upgrade_toast_title" | "encryption|verification_requested_toast_title" | "encryption|verify_toast_description" | "encryption|verify_toast_title" | "encryption|access_secret_storage_dialog|separator" | "encryption|access_secret_storage_dialog|enter_phrase_or_key_prompt" | "encryption|access_secret_storage_dialog|reset_title" | "encryption|access_secret_storage_dialog|reset_warning_1" | "encryption|access_secret_storage_dialog|reset_warning_2" | "encryption|access_secret_storage_dialog|restoring" | "encryption|access_secret_storage_dialog|security_key_title" | "encryption|access_secret_storage_dialog|security_phrase_incorrect_error" | "encryption|access_secret_storage_dialog|security_phrase_title" | "encryption|access_secret_storage_dialog|use_security_key_prompt" | "encryption|access_secret_storage_dialog|key_validation_text|invalid_security_key" | "encryption|access_secret_storage_dialog|key_validation_text|recovery_key_is_correct" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_file_type" | "encryption|access_secret_storage_dialog|key_validation_text|wrong_security_key" | "encryption|destroy_cross_signing_dialog|title" | "encryption|destroy_cross_signing_dialog|warning" | "encryption|destroy_cross_signing_dialog|primary_button_text" | "encryption|messages_not_secure|title" | "encryption|messages_not_secure|heading" | "encryption|messages_not_secure|cause_1" | "encryption|messages_not_secure|cause_2" | "encryption|messages_not_secure|cause_3" | "encryption|messages_not_secure|cause_4" | "encryption|new_recovery_method_detected|title" | "encryption|new_recovery_method_detected|warning" | "encryption|new_recovery_method_detected|description_1" | "encryption|new_recovery_method_detected|description_2" | "encryption|recovery_method_removed|title" | "encryption|recovery_method_removed|warning" | "encryption|recovery_method_removed|description_1" | "encryption|recovery_method_removed|description_2" | "encryption|setup_secure_backup|title" | "encryption|setup_secure_backup|explainer" | "encryption|udd|title" | "encryption|udd|interactive_verification_button" | "encryption|udd|manual_verification_button" | "encryption|udd|other_ask_verify_text" | "encryption|udd|other_new_session_text" | "encryption|udd|own_ask_verify_text" | "encryption|udd|own_new_session_text" | "encryption|verification|cancelled" | "encryption|verification|explainer" | "encryption|verification|accepting" | "encryption|verification|cancelled_self" | "encryption|verification|cancelled_user" | "encryption|verification|cancelling" | "encryption|verification|complete_action" | "encryption|verification|complete_description" | "encryption|verification|complete_title" | "encryption|verification|error_starting_description" | "encryption|verification|error_starting_title" | "encryption|verification|in_person" | "encryption|verification|incoming_sas_device_dialog_text_1" | "encryption|verification|incoming_sas_device_dialog_text_2" | "encryption|verification|incoming_sas_dialog_title" | "encryption|verification|incoming_sas_dialog_waiting" | "encryption|verification|incoming_sas_user_dialog_text_1" | "encryption|verification|incoming_sas_user_dialog_text_2" | "encryption|verification|manual_device_verification_device_id_label" | "encryption|verification|manual_device_verification_device_key_label" | "encryption|verification|manual_device_verification_device_name_label" | "encryption|verification|manual_device_verification_footer" | "encryption|verification|manual_device_verification_self_text" | "encryption|verification|manual_device_verification_user_text" | "encryption|verification|no_key_or_device" | "encryption|verification|no_support_qr_emoji" | "encryption|verification|other_party_cancelled" | "encryption|verification|prompt_encrypted" | "encryption|verification|prompt_self" | "encryption|verification|prompt_unencrypted" | "encryption|verification|prompt_user" | "encryption|verification|qr_or_sas" | "encryption|verification|qr_or_sas_header" | "encryption|verification|qr_prompt" | "encryption|verification|qr_reciprocate_same_shield_device" | "encryption|verification|qr_reciprocate_same_shield_user" | "encryption|verification|request_toast_accept" | "encryption|verification|request_toast_accept_user" | "encryption|verification|request_toast_decline_counter" | "encryption|verification|request_toast_detail" | "encryption|verification|reset_proceed_prompt" | "encryption|verification|sas_caption_self" | "encryption|verification|sas_caption_user" | "encryption|verification|sas_description" | "encryption|verification|sas_emoji_caption_self" | "encryption|verification|sas_emoji_caption_user" | "encryption|verification|sas_match" | "encryption|verification|sas_no_match" | "encryption|verification|sas_prompt" | "encryption|verification|scan_qr" | "encryption|verification|scan_qr_explainer" | "encryption|verification|self_verification_hint" | "encryption|verification|start_button" | "encryption|verification|successful_device" | "encryption|verification|successful_own_device" | "encryption|verification|successful_user" | "encryption|verification|timed_out" | "encryption|verification|unsupported_method" | "encryption|verification|unverified_session_toast_accept" | "encryption|verification|unverified_session_toast_title" | "encryption|verification|unverified_sessions_toast_description" | "encryption|verification|unverified_sessions_toast_reject" | "encryption|verification|unverified_sessions_toast_title" | "encryption|verification|verification_description" | "encryption|verification|verification_dialog_title_device" | "encryption|verification|verification_dialog_title_user" | "encryption|verification|verification_skip_warning" | "encryption|verification|verification_success_with_backup" | "encryption|verification|verification_success_without_backup" | "encryption|verification|verify_emoji" | "encryption|verification|verify_emoji_prompt" | "encryption|verification|verify_emoji_prompt_qr" | "encryption|verification|verify_later" | "encryption|verification|verify_reset_warning_1" | "encryption|verification|verify_reset_warning_2" | "encryption|verification|verify_using_device" | "encryption|verification|verify_using_key" | "encryption|verification|verify_using_key_or_phrase" | "encryption|verification|waiting_for_user_accept" | "encryption|verification|waiting_other_device" | "encryption|verification|waiting_other_device_details" | "encryption|verification|waiting_other_user" | "encryption|verification|after_new_login|device_verified" | "encryption|verification|after_new_login|reset_confirmation" | "encryption|verification|after_new_login|skip_verification" | "encryption|verification|after_new_login|unable_to_verify" | "encryption|verification|after_new_login|verify_this_device" | "threads|mark_all_read" | "threads|all_threads" | "threads|all_threads_description" | "threads|count_of_reply" | "threads|empty_description" | "threads|empty_title" | "threads|error_start_thread_existing_relation" | "threads|my_threads" | "threads|my_threads_description" | "threads|open_thread" | "threads|show_thread_filter" | "space|invite" | "space|joining_space" | "space|failed_load_rooms" | "space|failed_remove_rooms" | "space|incompatible_server_hierarchy" | "space|invite_description" | "space|invite_link" | "space|invite_this_space" | "space|landing_welcome" | "space|leave_dialog_action" | "space|leave_dialog_description" | "space|leave_dialog_only_admin_room_warning" | "space|leave_dialog_only_admin_warning" | "space|leave_dialog_option_all" | "space|leave_dialog_option_intro" | "space|leave_dialog_option_none" | "space|leave_dialog_option_specific" | "space|leave_dialog_public_rejoin_warning" | "space|leave_dialog_title" | "space|mark_suggested" | "space|no_search_result_hint" | "space|room_filter_placeholder" | "space|search_children" | "space|search_placeholder" | "space|select_room_below" | "space|share_public" | "space|suggested" | "space|suggested_tooltip" | "space|title_when_query_available" | "space|title_when_query_unavailable" | "space|unmark_suggested" | "space|user_lacks_permission" | "space|context_menu|home" | "space|context_menu|options" | "space|context_menu|devtools_open_timeline" | "space|context_menu|explore" | "space|context_menu|manage_and_explore" | "space|add_existing_room_space|create" | "space|add_existing_room_space|create_prompt" | "space|add_existing_room_space|dm_heading" | "space|add_existing_room_space|error_heading" | "space|add_existing_room_space|progress_text" | "space|add_existing_room_space|space_dropdown_label" | "space|add_existing_room_space|space_dropdown_title" | "space|add_existing_room_space|subspace_moved_note" | "space|add_existing_subspace|filter_placeholder" | "space|add_existing_subspace|create_prompt" | "space|add_existing_subspace|space_dropdown_title" | "space|add_existing_subspace|create_button" | "space|preferences|sections_section" | "space|preferences|show_people_in_space" | "spaces|error_no_permission_add_room" | "spaces|error_no_permission_add_space" | "spaces|error_no_permission_create_room" | "spaces|error_no_permission_invite" | "common|emoji" | "common|name" | "common|attachment" | "common|beta" | "common|error" | "common|message" | "common|feedback" | "common|location" | "common|timeline" | "common|advanced" | "common|cancel" | "common|appearance" | "common|mute" | "common|unmute" | "common|private" | "common|public" | "common|loading" | "common|video" | "common|image" | "common|encrypted" | "common|offline" | "common|off" | "common|on" | "common|username" | "common|home" | "common|options" | "common|success" | "common|description" | "common|user" | "common|profile" | "common|password" | "common|access_token" | "common|capabilities" | "common|room" | "common|matrix" | "common|joined" | "common|presence" | "common|rooms" | "common|thread" | "common|unavailable" | "common|verified" | "common|device" | "common|version" | "common|application" | "common|trusted" | "common|threads" | "common|guest" | "common|server" | "common|save" | "common|space" | "common|dark" | "common|light" | "common|help" | "common|spaces" | "common|legal" | "common|security" | "common|warning" | "common|settings" | "common|android" | "common|ios" | "common|labs" | "common|theme" | "common|edited" | "common|analytics" | "common|credits" | "common|identity_server" | "common|integration_manager" | "common|reactions" | "common|view_message" | "common|low_priority" | "common|preferences" | "common|accessibility" | "common|all_rooms" | "common|and_n_others" | "common|are_you_sure" | "common|authentication" | "common|avatar" | "common|camera" | "common|cameras" | "common|copied" | "common|cross_signing" | "common|deselect_all" | "common|email_address" | "common|encryption_enabled" | "common|extensions" | "common|faq" | "common|favourites" | "common|filter_results" | "common|forward_message" | "common|general" | "common|go_to_settings" | "common|historical" | "common|homeserver" | "common|lobby" | "common|message_layout" | "common|microphone" | "common|model" | "common|modern" | "common|n_members" | "common|n_rooms" | "common|no_results" | "common|no_results_found" | "common|not_trusted" | "common|orphan_rooms" | "common|people" | "common|preview_message" | "common|privacy" | "common|private_room" | "common|private_space" | "common|public_room" | "common|public_space" | "common|qr_code" | "common|random" | "common|report_a_bug" | "common|room_name" | "common|saved" | "common|saving" | "common|secure_backup" | "common|select_all" | "common|setup_secure_messages" | "common|show_more" | "common|someone" | "common|sticker" | "common|stickerpack" | "common|suggestions" | "common|support" | "common|system_alerts" | "common|unencrypted" | "common|unnamed_room" | "common|unnamed_space" | "common|unsent" | "common|unverified" | "common|updating" | "common|user_avatar" | "common|verification_cancelled" | "common|video_room" | "common|welcome" | "settings|warning" | "settings|notifications|mentions_keywords" | "settings|all_rooms_home" | "settings|all_rooms_home_description" | "settings|always_show_message_timestamps" | "settings|automatic_language_detection_syntax_highlight" | "settings|autoplay_gifs" | "settings|autoplay_videos" | "settings|big_emoji" | "settings|code_block_expand_default" | "settings|code_block_line_numbers" | "settings|disable_historical_profile" | "settings|emoji_autocomplete" | "settings|enable_markdown" | "settings|enable_markdown_description" | "settings|image_thumbnails" | "settings|inline_url_previews_default" | "settings|inline_url_previews_room" | "settings|inline_url_previews_room_account" | "settings|insert_trailing_colon_mentions" | "settings|jump_to_bottom_on_send" | "settings|prompt_invite" | "settings|replace_plain_emoji" | "settings|send_read_receipts" | "settings|send_read_receipts_unsupported" | "settings|send_typing_notifications" | "settings|show_avatar_changes" | "settings|show_breadcrumbs" | "settings|show_chat_effects" | "settings|show_displayname_changes" | "settings|show_join_leave" | "settings|show_nsfw_content" | "settings|show_read_receipts" | "settings|show_redaction_placeholder" | "settings|show_stickers_button" | "settings|show_typing_notifications" | "settings|showbold" | "settings|start_automatically" | "settings|tac_only_notifications" | "settings|use_12_hour_format" | "settings|use_command_enter_send_message" | "settings|use_command_f_search" | "settings|use_control_enter_send_message" | "settings|use_control_f_search" | "settings|warn_quit" | "settings|notifications|voip" | "settings|notifications|error_loading" | "settings|notifications|dialog_title" | "settings|notifications|error_title" | "settings|notifications|default_setting_description" | "settings|notifications|default_setting_section" | "settings|notifications|desktop_notification_message_preview" | "settings|notifications|email_description" | "settings|notifications|email_section" | "settings|notifications|email_select" | "settings|notifications|enable_audible_notifications_session" | "settings|notifications|enable_desktop_notifications_session" | "settings|notifications|enable_email_notifications" | "settings|notifications|enable_notifications_account" | "settings|notifications|enable_notifications_account_detail" | "settings|notifications|enable_notifications_device" | "settings|notifications|error_permissions_denied" | "settings|notifications|error_permissions_missing" | "settings|notifications|error_saving" | "settings|notifications|error_saving_detail" | "settings|notifications|error_updating" | "settings|notifications|invites" | "settings|notifications|keywords" | "settings|notifications|keywords_prompt" | "settings|notifications|labs_notice_prompt" | "settings|notifications|mentions_keywords_only" | "settings|notifications|messages_containing_keywords" | "settings|notifications|noisy" | "settings|notifications|notices" | "settings|notifications|notify_at_room" | "settings|notifications|notify_keyword" | "settings|notifications|notify_mention" | "settings|notifications|other_section" | "settings|notifications|people_mentions_keywords" | "settings|notifications|play_sound_for_description" | "settings|notifications|play_sound_for_section" | "settings|notifications|push_targets" | "settings|notifications|quick_actions_mark_all_read" | "settings|notifications|quick_actions_reset" | "settings|notifications|quick_actions_section" | "settings|notifications|room_activity" | "settings|notifications|rule_call" | "settings|notifications|rule_contains_display_name" | "settings|notifications|rule_contains_user_name" | "settings|notifications|rule_encrypted" | "settings|notifications|rule_encrypted_room_one_to_one" | "settings|notifications|rule_invite_for_me" | "settings|notifications|rule_message" | "settings|notifications|rule_room_one_to_one" | "settings|notifications|rule_roomnotif" | "settings|notifications|rule_suppress_notices" | "settings|notifications|rule_tombstone" | "settings|notifications|show_message_desktop_notification" | "settings|appearance|dialog_title" | "settings|appearance|bundled_emoji_font" | "settings|appearance|compact_layout" | "settings|appearance|compact_layout_description" | "settings|appearance|custom_font" | "settings|appearance|custom_font_description" | "settings|appearance|custom_font_name" | "settings|appearance|custom_font_size" | "settings|appearance|custom_theme_add" | "settings|appearance|custom_theme_downloading" | "settings|appearance|custom_theme_error_downloading" | "settings|appearance|custom_theme_help" | "settings|appearance|custom_theme_invalid" | "settings|appearance|font_size" | "settings|appearance|font_size_default" | "settings|appearance|high_contrast" | "settings|appearance|image_size_default" | "settings|appearance|image_size_large" | "settings|appearance|layout_bubbles" | "settings|appearance|layout_irc" | "settings|appearance|match_system_theme" | "settings|appearance|timeline_image_size" | "settings|account|title" | "settings|account|dialog_title" | "settings|sessions|url" | "settings|sessions|title" | "settings|sessions|browser" | "settings|sessions|session_id" | "settings|sessions|dialog_title" | "settings|sessions|sign_out" | "settings|sessions|best_security_note" | "settings|sessions|confirm_sign_out" | "settings|sessions|confirm_sign_out_body" | "settings|sessions|confirm_sign_out_continue" | "settings|sessions|confirm_sign_out_sso" | "settings|sessions|current_session" | "settings|sessions|desktop_session" | "settings|sessions|details_heading" | "settings|sessions|device_unverified_description" | "settings|sessions|device_unverified_description_current" | "settings|sessions|device_verified_description" | "settings|sessions|device_verified_description_current" | "settings|sessions|error_pusher_state" | "settings|sessions|error_set_name" | "settings|sessions|filter_all" | "settings|sessions|filter_inactive" | "settings|sessions|filter_inactive_description" | "settings|sessions|filter_label" | "settings|sessions|filter_unverified_description" | "settings|sessions|filter_verified_description" | "settings|sessions|hide_details" | "settings|sessions|inactive_days" | "settings|sessions|inactive_sessions" | "settings|sessions|inactive_sessions_explainer_1" | "settings|sessions|inactive_sessions_explainer_2" | "settings|sessions|inactive_sessions_list_description" | "settings|sessions|ip" | "settings|sessions|last_activity" | "settings|sessions|mobile_session" | "settings|sessions|n_sessions_selected" | "settings|sessions|no_inactive_sessions" | "settings|sessions|no_sessions" | "settings|sessions|no_unverified_sessions" | "settings|sessions|no_verified_sessions" | "settings|sessions|os" | "settings|sessions|other_sessions_heading" | "settings|sessions|push_heading" | "settings|sessions|push_subheading" | "settings|sessions|push_toggle" | "settings|sessions|rename_form_caption" | "settings|sessions|rename_form_heading" | "settings|sessions|rename_form_learn_more" | "settings|sessions|rename_form_learn_more_description_1" | "settings|sessions|rename_form_learn_more_description_2" | "settings|sessions|security_recommendations" | "settings|sessions|security_recommendations_description" | "settings|sessions|show_details" | "settings|sessions|sign_in_with_qr" | "settings|sessions|sign_in_with_qr_button" | "settings|sessions|sign_in_with_qr_description" | "settings|sessions|sign_out_all_other_sessions" | "settings|sessions|sign_out_confirm_description" | "settings|sessions|sign_out_n_sessions" | "settings|sessions|unknown_session" | "settings|sessions|unverified_session" | "settings|sessions|unverified_session_explainer_1" | "settings|sessions|unverified_session_explainer_2" | "settings|sessions|unverified_session_explainer_3" | "settings|sessions|unverified_sessions" | "settings|sessions|unverified_sessions_explainer_1" | "settings|sessions|unverified_sessions_explainer_2" | "settings|sessions|unverified_sessions_list_description" | "settings|sessions|verified_session" | "settings|sessions|verified_sessions" | "settings|sessions|verified_sessions_explainer_1" | "settings|sessions|verified_sessions_explainer_2" | "settings|sessions|verified_sessions_list_description" | "settings|sessions|verify_session" | "settings|sessions|web_session" | "settings|security|session_id" | "settings|security|session_key" | "settings|security|dialog_title" | "settings|security|4s_public_key_in_account_data" | "settings|security|4s_public_key_status" | "settings|security|analytics_description" | "settings|security|backup_key_cached_status" | "settings|security|backup_key_stored_status" | "settings|security|backup_key_unexpected_type" | "settings|security|backup_key_well_formed" | "settings|security|backup_keys_description" | "settings|security|bulk_options_accept_all_invites" | "settings|security|bulk_options_reject_all_invites" | "settings|security|bulk_options_section" | "settings|security|cross_signing_cached" | "settings|security|cross_signing_homeserver_support" | "settings|security|cross_signing_homeserver_support_exists" | "settings|security|cross_signing_in_4s" | "settings|security|cross_signing_in_memory" | "settings|security|cross_signing_master_private_Key" | "settings|security|cross_signing_not_cached" | "settings|security|cross_signing_not_found" | "settings|security|cross_signing_not_in_4s" | "settings|security|cross_signing_not_stored" | "settings|security|cross_signing_private_keys" | "settings|security|cross_signing_public_keys" | "settings|security|cross_signing_self_signing_private_key" | "settings|security|cross_signing_user_signing_private_key" | "settings|security|cryptography_section" | "settings|security|dehydrated_device_description" | "settings|security|dehydrated_device_enabled" | "settings|security|delete_backup" | "settings|security|delete_backup_confirm_description" | "settings|security|e2ee_default_disabled_warning" | "settings|security|enable_message_search" | "settings|security|encryption_section" | "settings|security|error_loading_key_backup_status" | "settings|security|export_megolm_keys" | "settings|security|ignore_users_empty" | "settings|security|ignore_users_section" | "settings|security|import_megolm_keys" | "settings|security|key_backup_active" | "settings|security|key_backup_active_version" | "settings|security|key_backup_active_version_none" | "settings|security|key_backup_algorithm" | "settings|security|key_backup_can_be_restored" | "settings|security|key_backup_complete" | "settings|security|key_backup_connect" | "settings|security|key_backup_connect_prompt" | "settings|security|key_backup_in_progress" | "settings|security|key_backup_inactive" | "settings|security|key_backup_inactive_warning" | "settings|security|key_backup_latest_version" | "settings|security|message_search_disable_warning" | "settings|security|message_search_disabled" | "settings|security|message_search_enabled" | "settings|security|message_search_failed" | "settings|security|message_search_indexed_messages" | "settings|security|message_search_indexed_rooms" | "settings|security|message_search_indexing" | "settings|security|message_search_indexing_idle" | "settings|security|message_search_intro" | "settings|security|message_search_room_progress" | "settings|security|message_search_section" | "settings|security|message_search_sleep_time" | "settings|security|message_search_space_used" | "settings|security|message_search_unsupported" | "settings|security|message_search_unsupported_web" | "settings|security|record_session_details" | "settings|security|restore_key_backup" | "settings|security|secret_storage_not_ready" | "settings|security|secret_storage_ready" | "settings|security|secret_storage_status" | "settings|security|send_analytics" | "settings|security|strict_encryption" | "settings|voip|title" | "settings|voip|dialog_title" | "settings|voip|allow_p2p" | "settings|voip|allow_p2p_description" | "settings|voip|audio_input_empty" | "settings|voip|audio_output" | "settings|voip|audio_output_empty" | "settings|voip|auto_gain_control" | "settings|voip|connection_section" | "settings|voip|echo_cancellation" | "settings|voip|enable_fallback_ice_server" | "settings|voip|enable_fallback_ice_server_description" | "settings|voip|mirror_local_feed" | "settings|voip|missing_permissions_prompt" | "settings|voip|noise_suppression" | "settings|voip|request_permissions" | "settings|voip|video_input_empty" | "settings|voip|video_section" | "settings|voip|voice_agc" | "settings|voip|voice_processing" | "settings|voip|voice_section" | "settings|labs|dialog_title" | "settings|keyboard|title" | "settings|keyboard|dialog_title" | "settings|labs_mjolnir|dialog_title" | "settings|preferences|dialog_title" | "settings|preferences|Electron.enableHardwareAcceleration" | "settings|preferences|always_show_menu_bar" | "settings|preferences|autocomplete_delay" | "settings|preferences|code_blocks_heading" | "settings|preferences|compact_modern" | "settings|preferences|composer_heading" | "settings|preferences|default_timezone" | "settings|preferences|enable_hardware_acceleration" | "settings|preferences|enable_tray_icon" | "settings|preferences|keyboard_heading" | "settings|preferences|keyboard_view_shortcuts_button" | "settings|preferences|media_heading" | "settings|preferences|presence_description" | "settings|preferences|rm_lifetime" | "settings|preferences|rm_lifetime_offscreen" | "settings|preferences|room_directory_heading" | "settings|preferences|room_list_heading" | "settings|preferences|show_avatars_pills" | "settings|preferences|show_checklist_shortcuts" | "settings|preferences|show_polls_button" | "settings|preferences|surround_text" | "settings|preferences|time_heading" | "settings|preferences|user_timezone" | "settings|general|username" | "settings|general|display_name" | "settings|general|account_management_section" | "settings|general|account_section" | "settings|general|add_email_dialog_title" | "settings|general|add_email_failed_verification" | "settings|general|add_email_instructions" | "settings|general|add_msisdn_confirm_body" | "settings|general|add_msisdn_confirm_button" | "settings|general|add_msisdn_confirm_sso_button" | "settings|general|add_msisdn_dialog_title" | "settings|general|add_msisdn_instructions" | "settings|general|add_msisdn_misconfigured" | "settings|general|allow_spellcheck" | "settings|general|application_language" | "settings|general|application_language_reload_hint" | "settings|general|avatar_remove_progress" | "settings|general|avatar_save_progress" | "settings|general|avatar_upload_error_text" | "settings|general|avatar_upload_error_text_generic" | "settings|general|avatar_upload_error_title" | "settings|general|confirm_adding_email_body" | "settings|general|confirm_adding_email_title" | "settings|general|deactivate_confirm_body" | "settings|general|deactivate_confirm_body_sso" | "settings|general|deactivate_confirm_content" | "settings|general|deactivate_confirm_content_1" | "settings|general|deactivate_confirm_content_2" | "settings|general|deactivate_confirm_content_3" | "settings|general|deactivate_confirm_content_4" | "settings|general|deactivate_confirm_content_5" | "settings|general|deactivate_confirm_content_6" | "settings|general|deactivate_confirm_continue" | "settings|general|deactivate_confirm_erase_label" | "settings|general|deactivate_section" | "settings|general|deactivate_warning" | "settings|general|discovery_email_empty" | "settings|general|discovery_email_verification_instructions" | "settings|general|discovery_msisdn_empty" | "settings|general|discovery_needs_terms" | "settings|general|discovery_needs_terms_title" | "settings|general|display_name_error" | "settings|general|email_address_in_use" | "settings|general|email_address_label" | "settings|general|email_not_verified" | "settings|general|email_verification_instructions" | "settings|general|emails_heading" | "settings|general|error_add_email" | "settings|general|error_deactivate_communication" | "settings|general|error_deactivate_invalid_auth" | "settings|general|error_deactivate_no_auth" | "settings|general|error_email_verification" | "settings|general|error_invalid_email" | "settings|general|error_invalid_email_detail" | "settings|general|error_msisdn_verification" | "settings|general|error_password_change_403" | "settings|general|error_password_change_http" | "settings|general|error_password_change_title" | "settings|general|error_password_change_unknown" | "settings|general|error_remove_3pid" | "settings|general|error_revoke_email_discovery" | "settings|general|error_revoke_msisdn_discovery" | "settings|general|error_share_email_discovery" | "settings|general|error_share_msisdn_discovery" | "settings|general|identity_server_no_token" | "settings|general|identity_server_not_set" | "settings|general|language_section" | "settings|general|msisdn_in_use" | "settings|general|msisdn_label" | "settings|general|msisdn_verification_field_label" | "settings|general|msisdn_verification_instructions" | "settings|general|msisdns_heading" | "settings|general|name_placeholder" | "settings|general|oidc_manage_button" | "settings|general|password_change_section" | "settings|general|password_change_success" | "settings|general|personal_info" | "settings|general|profile_subtitle" | "settings|general|profile_subtitle_oidc" | "settings|general|remove_email_prompt" | "settings|general|remove_msisdn_prompt" | "settings|general|spell_check_locale_placeholder" | "settings|general|unable_to_load_emails" | "settings|general|unable_to_load_msisdns" | "settings|discovery|title" | "settings|key_backup|backup_in_progress" | "settings|key_backup|backup_starting" | "settings|key_backup|backup_success" | "settings|key_backup|cannot_create_backup" | "settings|key_backup|create_title" | "settings|key_backup|setup_secure_backup|description" | "settings|key_backup|setup_secure_backup|backup_setup_success_description" | "settings|key_backup|setup_secure_backup|backup_setup_success_title" | "settings|key_backup|setup_secure_backup|cancel_warning" | "settings|key_backup|setup_secure_backup|confirm_security_phrase" | "settings|key_backup|setup_secure_backup|download_or_copy" | "settings|key_backup|setup_secure_backup|enter_phrase_description" | "settings|key_backup|setup_secure_backup|enter_phrase_title" | "settings|key_backup|setup_secure_backup|enter_phrase_to_confirm" | "settings|key_backup|setup_secure_backup|generate_security_key_description" | "settings|key_backup|setup_secure_backup|generate_security_key_title" | "settings|key_backup|setup_secure_backup|pass_phrase_match_failed" | "settings|key_backup|setup_secure_backup|pass_phrase_match_success" | "settings|key_backup|setup_secure_backup|phrase_strong_enough" | "settings|key_backup|setup_secure_backup|requires_key_restore" | "settings|key_backup|setup_secure_backup|requires_password_confirmation" | "settings|key_backup|setup_secure_backup|requires_server_authentication" | "settings|key_backup|setup_secure_backup|secret_storage_query_failure" | "settings|key_backup|setup_secure_backup|security_key_safety_reminder" | "settings|key_backup|setup_secure_backup|session_upgrade_description" | "settings|key_backup|setup_secure_backup|set_phrase_again" | "settings|key_backup|setup_secure_backup|settings_reminder" | "settings|key_backup|setup_secure_backup|title_confirm_phrase" | "settings|key_backup|setup_secure_backup|title_save_key" | "settings|key_backup|setup_secure_backup|title_set_phrase" | "settings|key_backup|setup_secure_backup|title_upgrade_encryption" | "settings|key_backup|setup_secure_backup|unable_to_setup" | "settings|key_backup|setup_secure_backup|use_different_passphrase" | "settings|key_backup|setup_secure_backup|use_phrase_only_you_know" | "settings|key_export_import|phrase_strong_enough" | "settings|key_export_import|confirm_passphrase" | "settings|key_export_import|enter_passphrase" | "settings|key_export_import|export_description_1" | "settings|key_export_import|export_description_2" | "settings|key_export_import|export_title" | "settings|key_export_import|file_to_import" | "settings|key_export_import|import_description_1" | "settings|key_export_import|import_description_2" | "settings|key_export_import|import_title" | "settings|key_export_import|phrase_cannot_be_empty" | "settings|key_export_import|phrase_must_match" | "settings|sidebar|title" | "settings|sidebar|dialog_title" | "settings|sidebar|metaspaces_favourites_description" | "settings|sidebar|metaspaces_home_all_rooms" | "settings|sidebar|metaspaces_home_all_rooms_description" | "settings|sidebar|metaspaces_home_description" | "settings|sidebar|metaspaces_orphans" | "settings|sidebar|metaspaces_orphans_description" | "settings|sidebar|metaspaces_people_description" | "settings|sidebar|metaspaces_subsection" | "settings|sidebar|metaspaces_video_rooms" | "settings|sidebar|metaspaces_video_rooms_description" | "settings|sidebar|metaspaces_video_rooms_description_invite_extension" | "settings|sidebar|spaces_explainer" | "voip|connecting" | "voip|hangup" | "voip|answered_elsewhere" | "voip|user_busy" | "voip|element_call" | "voip|unsupported_browser" | "voip|video_call_started" | "voip|unsupported" | "voip|video_call" | "voip|voice_call" | "voip|expand" | "voip|maximise" | "voip|already_in_call" | "voip|already_in_call_person" | "voip|answered_elsewhere_description" | "voip|call_failed" | "voip|call_failed_description" | "voip|call_failed_media" | "voip|call_failed_media_applications" | "voip|call_failed_media_connected" | "voip|call_failed_media_permissions" | "voip|call_failed_microphone" | "voip|call_held" | "voip|call_held_resume" | "voip|call_held_switch" | "voip|call_toast_unknown_room" | "voip|camera_disabled" | "voip|camera_enabled" | "voip|cannot_call_yourself_description" | "voip|change_input_device" | "voip|close_lobby" | "voip|connection_lost" | "voip|connection_lost_description" | "voip|consulting" | "voip|default_device" | "voip|dial" | "voip|dialpad" | "voip|disable_camera" | "voip|disable_microphone" | "voip|disabled_no_one_here" | "voip|disabled_no_perms_start_video_call" | "voip|disabled_no_perms_start_voice_call" | "voip|disabled_ongoing_call" | "voip|enable_camera" | "voip|enable_microphone" | "voip|failed_call_live_broadcast_description" | "voip|failed_call_live_broadcast_title" | "voip|get_call_link" | "voip|hide_sidebar_button" | "voip|input_devices" | "voip|jitsi_call" | "voip|join_button_tooltip_call_full" | "voip|join_button_tooltip_connecting" | "voip|legacy_call" | "voip|maximise_call" | "voip|minimise_call" | "voip|misconfigured_server" | "voip|misconfigured_server_description" | "voip|misconfigured_server_fallback" | "voip|misconfigured_server_fallback_accept" | "voip|more_button" | "voip|msisdn_lookup_failed" | "voip|msisdn_lookup_failed_description" | "voip|msisdn_transfer_failed" | "voip|n_people_joined" | "voip|no_audio_input_description" | "voip|no_audio_input_title" | "voip|no_media_perms_description" | "voip|no_media_perms_title" | "voip|no_permission_conference" | "voip|no_permission_conference_description" | "voip|on_hold" | "voip|output_devices" | "voip|screenshare_monitor" | "voip|screenshare_title" | "voip|screenshare_window" | "voip|show_sidebar_button" | "voip|silence" | "voip|silenced" | "voip|start_screenshare" | "voip|stop_screenshare" | "voip|too_many_calls" | "voip|too_many_calls_description" | "voip|transfer_consult_first_label" | "voip|transfer_failed" | "voip|transfer_failed_description" | "voip|unable_to_access_audio_input_description" | "voip|unable_to_access_audio_input_title" | "voip|unable_to_access_media" | "voip|unable_to_access_microphone" | "voip|unknown_caller" | "voip|unknown_person" | "voip|unsilence" | "voip|user_busy_description" | "voip|user_is_presenting" | "voip|video_call_using" | "voip|you_are_presenting" | "voip|metaspace_video_rooms|conference_room_section" | "voice_broadcast|pause" | "voice_broadcast|play" | "voice_broadcast|action" | "voice_broadcast|resume" | "voice_broadcast|live" | "voice_broadcast|failed_generic" | "voice_broadcast|30s_backward" | "voice_broadcast|30s_forward" | "voice_broadcast|buffering" | "voice_broadcast|confirm_listen_affirm" | "voice_broadcast|confirm_listen_description" | "voice_broadcast|confirm_listen_title" | "voice_broadcast|confirm_stop_affirm" | "voice_broadcast|confirm_stop_description" | "voice_broadcast|confirm_stop_title" | "voice_broadcast|connection_error" | "voice_broadcast|failed_already_recording_description" | "voice_broadcast|failed_already_recording_title" | "voice_broadcast|failed_decrypt" | "voice_broadcast|failed_insufficient_permission_description" | "voice_broadcast|failed_insufficient_permission_title" | "voice_broadcast|failed_no_connection_description" | "voice_broadcast|failed_no_connection_title" | "voice_broadcast|failed_others_already_recording_description" | "voice_broadcast|failed_others_already_recording_title" | "voice_broadcast|go_live" | "labs|notifications" | "labs|dehydration" | "labs|voice_broadcast" | "labs|mjolnir" | "labs|ask_to_join" | "labs|jump_to_date" | "labs|allow_screen_share_only_mode" | "labs|automatic_debug_logs" | "labs|automatic_debug_logs_decryption" | "labs|automatic_debug_logs_key_backup" | "labs|beta_description" | "labs|beta_feature" | "labs|beta_feedback_leave_button" | "labs|beta_feedback_title" | "labs|beta_section" | "labs|bridge_state" | "labs|bridge_state_channel" | "labs|bridge_state_creator" | "labs|bridge_state_manager" | "labs|bridge_state_workspace" | "labs|click_for_info" | "labs|currently_experimental" | "labs|custom_themes" | "labs|dynamic_room_predecessors" | "labs|dynamic_room_predecessors_description" | "labs|element_call_video_rooms" | "labs|experimental_description" | "labs|experimental_section" | "labs|feature_disable_call_per_sender_encryption" | "labs|feature_wysiwyg_composer_description" | "labs|group_calls" | "labs|group_developer" | "labs|group_encryption" | "labs|group_experimental" | "labs|group_messaging" | "labs|group_moderation" | "labs|group_profile" | "labs|group_rooms" | "labs|group_spaces" | "labs|group_themes" | "labs|group_threads" | "labs|group_ui" | "labs|group_voip" | "labs|group_widgets" | "labs|hidebold" | "labs|html_topic" | "labs|join_beta" | "labs|join_beta_reload" | "labs|jump_to_date_msc_support" | "labs|latex_maths" | "labs|leave_beta" | "labs|leave_beta_reload" | "labs|location_share_live" | "labs|location_share_live_description" | "labs|msc3531_hide_messages_pending_moderation" | "labs|new_room_decoration_ui" | "labs|new_room_decoration_ui_beta_caption" | "labs|new_room_decoration_ui_beta_title" | "labs|notification_settings" | "labs|notification_settings_beta_caption" | "labs|notification_settings_beta_title" | "labs|oidc_native_flow" | "labs|oidc_native_flow_description" | "labs|pinning" | "labs|release_announcement" | "labs|render_reaction_images" | "labs|render_reaction_images_description" | "labs|report_to_moderators" | "labs|report_to_moderators_description" | "labs|sliding_sync" | "labs|sliding_sync_description" | "labs|sliding_sync_disabled_notice" | "labs|sliding_sync_server_no_support" | "labs|under_active_development" | "labs|unrealiable_e2e" | "labs|video_rooms" | "labs|video_rooms_a_new_way_to_chat" | "labs|video_rooms_always_on_voip_channels" | "labs|video_rooms_beta" | "labs|video_rooms_faq1_answer" | "labs|video_rooms_faq1_question" | "labs|video_rooms_faq2_answer" | "labs|video_rooms_faq2_question" | "labs|video_rooms_feedbackSubheading" | "labs|voice_broadcast_force_small_chunks" | "labs|wysiwyg_composer" | "theme|light_high_contrast" | "theme|match_system" | "a11y|recent_rooms" | "a11y|emoji_picker" | "a11y|user_menu" | "a11y|room_name" | "a11y|jump_first_invite" | "a11y|message_composer" | "a11y|n_unread_messages" | "a11y|n_unread_messages_mentions" | "a11y|room_status_bar" | "a11y|seek_bar_label" | "a11y|unread_messages" | "analytics|learn_more" | "analytics|accept_button" | "analytics|bullet_1" | "analytics|bullet_2" | "analytics|consent_migration" | "analytics|disable_prompt" | "analytics|enable_prompt" | "analytics|privacy_policy" | "analytics|pseudonymous_usage_data" | "analytics|shared_data_heading" | "bug_reporting|title" | "bug_reporting|description" | "bug_reporting|unsupported_browser" | "bug_reporting|additional_context" | "bug_reporting|before_submitting" | "bug_reporting|collecting_information" | "bug_reporting|collecting_logs" | "bug_reporting|create_new_issue" | "bug_reporting|download_logs" | "bug_reporting|downloading_logs" | "bug_reporting|error_empty" | "bug_reporting|failed_send_logs" | "bug_reporting|github_issue" | "bug_reporting|introduction" | "bug_reporting|log_request" | "bug_reporting|logs_sent" | "bug_reporting|matrix_security_issue" | "bug_reporting|preparing_download" | "bug_reporting|preparing_logs" | "bug_reporting|send_logs" | "bug_reporting|submit_debug_logs" | "bug_reporting|textarea_label" | "bug_reporting|thank_you" | "bug_reporting|uploading_logs" | "bug_reporting|waiting_for_server" | "chat_effects|confetti_description" | "chat_effects|confetti_message" | "chat_effects|fireworks_description" | "chat_effects|fireworks_message" | "chat_effects|hearts_description" | "chat_effects|hearts_message" | "chat_effects|rainfall_description" | "chat_effects|rainfall_message" | "chat_effects|snowfall_description" | "chat_effects|snowfall_message" | "chat_effects|spaceinvaders_description" | "chat_effects|spaceinvaders_message" | "composer|placeholder" | "composer|close_sticker_picker" | "composer|edit_composer_label" | "composer|format_bold" | "composer|format_code_block" | "composer|format_decrease_indent" | "composer|format_increase_indent" | "composer|format_inline_code" | "composer|format_insert_link" | "composer|format_italic" | "composer|format_italics" | "composer|format_link" | "composer|format_ordered_list" | "composer|format_strikethrough" | "composer|format_underline" | "composer|format_unordered_list" | "composer|formatting_toolbar_label" | "composer|mode_plain" | "composer|mode_rich_text" | "composer|no_perms_notice" | "composer|placeholder_encrypted" | "composer|placeholder_reply" | "composer|placeholder_reply_encrypted" | "composer|placeholder_thread" | "composer|placeholder_thread_encrypted" | "composer|poll_button" | "composer|poll_button_no_perms_description" | "composer|poll_button_no_perms_title" | "composer|replying_title" | "composer|room_upgraded_link" | "composer|room_upgraded_notice" | "composer|send_button_title" | "composer|send_button_voice_message" | "composer|send_voice_message" | "composer|stop_voice_message" | "composer|voice_message_button" | "composer|autocomplete|@room_description" | "composer|autocomplete|command_a11y" | "composer|autocomplete|command_description" | "composer|autocomplete|emoji_a11y" | "composer|autocomplete|notification_a11y" | "composer|autocomplete|notification_description" | "composer|autocomplete|room_a11y" | "composer|autocomplete|space_a11y" | "composer|autocomplete|user_a11y" | "composer|autocomplete|user_description" | "composer|link_modal|link_field_label" | "composer|link_modal|text_field_label" | "composer|link_modal|title_create" | "composer|link_modal|title_edit" | "create_room|error_title" | "create_room|action_create_room" | "create_room|action_create_video_room" | "create_room|encrypted_video_room_warning" | "create_room|encrypted_warning" | "create_room|encryption_forced" | "create_room|encryption_label" | "create_room|generic_error" | "create_room|join_rule_change_notice" | "create_room|join_rule_invite" | "create_room|join_rule_invite_label" | "create_room|join_rule_knock_label" | "create_room|join_rule_public_label" | "create_room|join_rule_public_parent_space_label" | "create_room|join_rule_restricted" | "create_room|join_rule_restricted_label" | "create_room|name_validation_required" | "create_room|room_visibility_label" | "create_room|title_private_room" | "create_room|title_public_room" | "create_room|title_video_room" | "create_room|topic_label" | "create_room|unfederated" | "create_room|unfederated_label_default_off" | "create_room|unfederated_label_default_on" | "create_room|unsupported_version" | "create_space|label" | "create_space|explainer" | "create_space|private_space" | "create_space|add_details_prompt" | "create_space|add_details_prompt_2" | "create_space|add_existing_rooms_description" | "create_space|add_existing_rooms_heading" | "create_space|address_label" | "create_space|address_placeholder" | "create_space|creating" | "create_space|creating_rooms" | "create_space|done_action" | "create_space|done_action_first_room" | "create_space|failed_create_initial_rooms" | "create_space|failed_invite_users" | "create_space|invite_teammates_by_username" | "create_space|invite_teammates_description" | "create_space|invite_teammates_heading" | "create_space|inviting_users" | "create_space|name_required" | "create_space|personal_space" | "create_space|personal_space_description" | "create_space|private_description" | "create_space|private_heading" | "create_space|private_personal_description" | "create_space|private_personal_heading" | "create_space|private_space_description" | "create_space|public_description" | "create_space|public_heading" | "create_space|search_public_button" | "create_space|setup_rooms_community_description" | "create_space|setup_rooms_community_heading" | "create_space|setup_rooms_description" | "create_space|setup_rooms_private_description" | "create_space|setup_rooms_private_heading" | "create_space|share_description" | "create_space|share_heading" | "create_space|skip_action" | "create_space|subspace_adding" | "create_space|subspace_beta_notice" | "create_space|subspace_dropdown_title" | "create_space|subspace_existing_space_prompt" | "create_space|subspace_join_rule_invite_description" | "create_space|subspace_join_rule_invite_only" | "create_space|subspace_join_rule_label" | "create_space|subspace_join_rule_public_description" | "create_space|subspace_join_rule_restricted_description" | "credits|default_cover_photo" | "credits|twemoji" | "credits|twemoji_colr" | "devtools|id" | "devtools|value" | "devtools|title" | "devtools|timeout" | "devtools|state_key" | "devtools|room_id" | "devtools|event_id" | "devtools|event_type" | "devtools|methods" | "devtools|phase" | "devtools|spaces" | "devtools|toolbox" | "devtools|event_content" | "devtools|active_widgets" | "devtools|category_other" | "devtools|category_room" | "devtools|caution_colon" | "devtools|client_versions" | "devtools|developer_mode" | "devtools|developer_tools" | "devtools|edit_setting" | "devtools|edit_values" | "devtools|empty_string" | "devtools|event_sent" | "devtools|explore_account_data" | "devtools|explore_room_account_data" | "devtools|explore_room_state" | "devtools|failed_to_find_widget" | "devtools|failed_to_load" | "devtools|failed_to_save" | "devtools|failed_to_send" | "devtools|invalid_json" | "devtools|level" | "devtools|low_bandwidth_mode" | "devtools|low_bandwidth_mode_description" | "devtools|main_timeline" | "devtools|no_receipt_found" | "devtools|no_verification_requests_found" | "devtools|notification_state" | "devtools|notifications_debug" | "devtools|number_of_users" | "devtools|original_event_source" | "devtools|other_user" | "devtools|phase_cancelled" | "devtools|phase_ready" | "devtools|phase_requested" | "devtools|phase_started" | "devtools|phase_transaction" | "devtools|room_encrypted" | "devtools|room_not_encrypted" | "devtools|room_notifications_dot" | "devtools|room_notifications_highlight" | "devtools|room_notifications_last_event" | "devtools|room_notifications_sender" | "devtools|room_notifications_thread_id" | "devtools|room_notifications_total" | "devtools|room_notifications_type" | "devtools|room_status" | "devtools|room_unread_status_count" | "devtools|save_setting_values" | "devtools|see_history" | "devtools|send_custom_account_data_event" | "devtools|send_custom_room_account_data_event" | "devtools|send_custom_state_event" | "devtools|send_custom_timeline_event" | "devtools|server_info" | "devtools|server_versions" | "devtools|settable_global" | "devtools|settable_room" | "devtools|setting_colon" | "devtools|setting_definition" | "devtools|setting_id" | "devtools|settings_explorer" | "devtools|show_hidden_events" | "devtools|thread_root_id" | "devtools|threads_timeline" | "devtools|timeout_none" | "devtools|toggle_event" | "devtools|use_at_own_risk" | "devtools|user_read_up_to" | "devtools|user_read_up_to_ignore_synthetic" | "devtools|user_read_up_to_private" | "devtools|user_read_up_to_private_ignore_synthetic" | "devtools|value_colon" | "devtools|value_in_this_room" | "devtools|value_this_room_colon" | "devtools|values_explicit" | "devtools|values_explicit_colon" | "devtools|values_explicit_room" | "devtools|values_explicit_this_room_colon" | "devtools|verification_explorer" | "devtools|view_servers_in_room" | "devtools|view_source_decrypted_event_source" | "devtools|view_source_decrypted_event_source_unavailable" | "devtools|widget_screenshots" | "emoji_picker|cancel_search_label" | "error_database_closed_description|for_desktop" | "error_database_closed_description|for_web" | "error_dialog|error_loading_user_profile" | "error_dialog|forget_room_failed" | "error_dialog|copy_room_link_failed|title" | "error_dialog|copy_room_link_failed|description" | "error_dialog|search_failed|title" | "error_dialog|search_failed|server_unavailable" | "event_preview|m.sticker" | "event_preview|m.text" | "event_preview|m.emote" | "event_preview|io.element.voice_broadcast_info|user" | "event_preview|io.element.voice_broadcast_info|you" | "event_preview|m.reaction|user" | "event_preview|m.reaction|you" | "event_preview|m.call.invite|user" | "event_preview|m.call.invite|you" | "event_preview|m.call.invite|dm_receive" | "event_preview|m.call.invite|dm_send" | "event_preview|m.call.answer|user" | "event_preview|m.call.answer|you" | "event_preview|m.call.answer|dm" | "event_preview|m.call.hangup|user" | "event_preview|m.call.hangup|you" | "export_chat|html" | "export_chat|title" | "export_chat|text" | "export_chat|json" | "export_chat|messages" | "export_chat|format" | "export_chat|cancelled" | "export_chat|topic" | "export_chat|cancelled_detail" | "export_chat|confirm_stop" | "export_chat|creating_html" | "export_chat|creating_output" | "export_chat|creator_summary" | "export_chat|current_timeline" | "export_chat|enter_number_between_min_max" | "export_chat|error_fetching_file" | "export_chat|export_info" | "export_chat|export_successful" | "export_chat|exported_n_events_in_time" | "export_chat|exporting_your_data" | "export_chat|fetched_n_events" | "export_chat|fetched_n_events_in_time" | "export_chat|fetched_n_events_with_total" | "export_chat|fetching_events" | "export_chat|file_attached" | "export_chat|from_the_beginning" | "export_chat|generating_zip" | "export_chat|html_title" | "export_chat|include_attachments" | "export_chat|media_omitted" | "export_chat|media_omitted_file_size" | "export_chat|next_page" | "export_chat|num_messages" | "export_chat|num_messages_min_max" | "export_chat|number_of_messages" | "export_chat|previous_page" | "export_chat|processing" | "export_chat|processing_event_n" | "export_chat|select_option" | "export_chat|size_limit" | "export_chat|size_limit_min_max" | "export_chat|size_limit_postfix" | "export_chat|starting_export" | "export_chat|successful" | "export_chat|successful_detail" | "export_chat|unload_confirm" | "file_panel|empty_description" | "file_panel|empty_heading" | "file_panel|guest_note" | "file_panel|peek_note" | "identity_server|url" | "identity_server|change" | "identity_server|checking" | "identity_server|disconnect" | "identity_server|error_invalid" | "identity_server|suggestions" | "identity_server|change_prompt" | "identity_server|change_server_prompt" | "identity_server|description_connected" | "identity_server|description_disconnected" | "identity_server|description_optional" | "identity_server|disconnect_anyway" | "identity_server|disconnect_offline_warning" | "identity_server|disconnect_personal_data_warning_1" | "identity_server|disconnect_personal_data_warning_2" | "identity_server|disconnect_server" | "identity_server|disconnect_warning" | "identity_server|do_not_use" | "identity_server|error_connection" | "identity_server|error_invalid_or_terms" | "identity_server|no_terms" | "identity_server|suggestions_1" | "identity_server|suggestions_2" | "identity_server|suggestions_3" | "identity_server|url_field_label" | "identity_server|url_not_https" | "integration_manager|connecting" | "integration_manager|explainer" | "integration_manager|error_connecting" | "integration_manager|error_connecting_heading" | "integration_manager|manage_title" | "integration_manager|use_im" | "integration_manager|use_im_default" | "integrations|disabled_dialog_description" | "integrations|disabled_dialog_title" | "integrations|impossible_dialog_description" | "integrations|impossible_dialog_title" | "keyboard|number" | "keyboard|search" | "keyboard|shift" | "keyboard|end" | "keyboard|home" | "keyboard|enter" | "keyboard|space" | "keyboard|alt" | "keyboard|control" | "keyboard|toggle_space_panel" | "keyboard|upload_file" | "keyboard|activate_button" | "keyboard|autocomplete_cancel" | "keyboard|autocomplete_force" | "keyboard|autocomplete_navigate_next" | "keyboard|autocomplete_navigate_prev" | "keyboard|backspace" | "keyboard|cancel_reply" | "keyboard|category_autocomplete" | "keyboard|category_calls" | "keyboard|category_navigation" | "keyboard|category_room_list" | "keyboard|close_dialog_menu" | "keyboard|composer_jump_end" | "keyboard|composer_jump_start" | "keyboard|composer_navigate_next_history" | "keyboard|composer_navigate_prev_history" | "keyboard|composer_new_line" | "keyboard|composer_redo" | "keyboard|composer_toggle_bold" | "keyboard|composer_toggle_code_block" | "keyboard|composer_toggle_italics" | "keyboard|composer_toggle_link" | "keyboard|composer_toggle_quote" | "keyboard|composer_undo" | "keyboard|dismiss_read_marker_and_jump_bottom" | "keyboard|escape" | "keyboard|go_home_view" | "keyboard|jump_first_message" | "keyboard|jump_last_message" | "keyboard|jump_room_search" | "keyboard|jump_to_read_marker" | "keyboard|keyboard_shortcuts_tab" | "keyboard|navigate_next_history" | "keyboard|navigate_next_message_edit" | "keyboard|navigate_prev_history" | "keyboard|navigate_prev_message_edit" | "keyboard|next_landmark" | "keyboard|next_room" | "keyboard|next_unread_room" | "keyboard|open_user_settings" | "keyboard|page_down" | "keyboard|page_up" | "keyboard|prev_landmark" | "keyboard|prev_room" | "keyboard|prev_unread_room" | "keyboard|room_list_collapse_section" | "keyboard|room_list_expand_section" | "keyboard|room_list_navigate_down" | "keyboard|room_list_navigate_up" | "keyboard|room_list_select_room" | "keyboard|scroll_down_timeline" | "keyboard|scroll_up_timeline" | "keyboard|send_sticker" | "keyboard|switch_to_space" | "keyboard|toggle_hidden_events" | "keyboard|toggle_microphone_mute" | "keyboard|toggle_right_panel" | "keyboard|toggle_top_left_menu" | "keyboard|toggle_webcam_mute" | "labs_mjolnir|title" | "labs_mjolnir|something_went_wrong" | "labs_mjolnir|ban_reason" | "labs_mjolnir|room_name" | "labs_mjolnir|advanced_warning" | "labs_mjolnir|error_adding_ignore" | "labs_mjolnir|error_adding_list_description" | "labs_mjolnir|error_adding_list_title" | "labs_mjolnir|error_removing_ignore" | "labs_mjolnir|error_removing_list_description" | "labs_mjolnir|error_removing_list_title" | "labs_mjolnir|explainer_1" | "labs_mjolnir|explainer_2" | "labs_mjolnir|lists" | "labs_mjolnir|lists_description_1" | "labs_mjolnir|lists_description_2" | "labs_mjolnir|lists_heading" | "labs_mjolnir|lists_new_label" | "labs_mjolnir|no_lists" | "labs_mjolnir|personal_description" | "labs_mjolnir|personal_empty" | "labs_mjolnir|personal_heading" | "labs_mjolnir|personal_new_label" | "labs_mjolnir|personal_new_placeholder" | "labs_mjolnir|personal_section" | "labs_mjolnir|room_topic" | "labs_mjolnir|rules_empty" | "labs_mjolnir|rules_server" | "labs_mjolnir|rules_title" | "labs_mjolnir|rules_user" | "labs_mjolnir|view_rules" | "leave_room_dialog|last_person_warning" | "leave_room_dialog|leave_room_question" | "leave_room_dialog|leave_space_question" | "leave_room_dialog|room_leave_admin_warning" | "leave_room_dialog|room_leave_mod_warning" | "leave_room_dialog|room_rejoin_warning" | "leave_room_dialog|space_rejoin_warning" | "left_panel|open_dial_pad" | "lightbox|title" | "lightbox|rotate_left" | "lightbox|rotate_right" | "location_sharing|failed_generic" | "location_sharing|MapStyleUrlNotConfigured" | "location_sharing|MapStyleUrlNotReachable" | "location_sharing|WebGLNotEnabled" | "location_sharing|click_drop_pin" | "location_sharing|click_move_pin" | "location_sharing|close_sidebar" | "location_sharing|error_fetch_location" | "location_sharing|error_no_perms_description" | "location_sharing|error_no_perms_title" | "location_sharing|error_send_description" | "location_sharing|error_send_title" | "location_sharing|error_sharing_live_location" | "location_sharing|error_sharing_live_location_try_again" | "location_sharing|error_stopping_live_location" | "location_sharing|error_stopping_live_location_try_again" | "location_sharing|expand_map" | "location_sharing|failed_load_map" | "location_sharing|failed_permission" | "location_sharing|failed_timeout" | "location_sharing|failed_unknown" | "location_sharing|find_my_location" | "location_sharing|live_description" | "location_sharing|live_enable_description" | "location_sharing|live_enable_heading" | "location_sharing|live_location_active" | "location_sharing|live_location_enabled" | "location_sharing|live_location_ended" | "location_sharing|live_location_error" | "location_sharing|live_locations_empty" | "location_sharing|live_share_button" | "location_sharing|live_toggle_label" | "location_sharing|live_until" | "location_sharing|live_update_time" | "location_sharing|loading_live_location" | "location_sharing|location_not_available" | "location_sharing|map_feedback" | "location_sharing|mapbox_logo" | "location_sharing|reset_bearing" | "location_sharing|share_button" | "location_sharing|share_type_live" | "location_sharing|share_type_own" | "location_sharing|share_type_pin" | "location_sharing|share_type_prompt" | "location_sharing|stop_and_close" | "location_sharing|toggle_attribution" | "member_list|filter_placeholder" | "member_list|invite_button_no_perms_tooltip" | "member_list|invited_list_heading" | "member_list|power_label" | "mobile_guide|toast_description" | "mobile_guide|toast_title" | "mobile_guide|toast_accept" | "notif_panel|empty_description" | "notif_panel|empty_heading" | "notifier|io.element.voice_broadcast_chunk" | "notifier|m.key.verification.request" | "onboarding|create_room" | "onboarding|explore_rooms" | "onboarding|no_avatar_label" | "onboarding|apple_trademarks" | "onboarding|community_messaging_action" | "onboarding|community_messaging_description" | "onboarding|community_messaging_title" | "onboarding|complete_these" | "onboarding|download_app" | "onboarding|download_app_action" | "onboarding|download_app_description" | "onboarding|download_app_store" | "onboarding|download_brand" | "onboarding|download_brand_desktop" | "onboarding|download_f_droid" | "onboarding|download_google_play" | "onboarding|enable_notifications" | "onboarding|enable_notifications_action" | "onboarding|enable_notifications_description" | "onboarding|find_community_members" | "onboarding|find_coworkers" | "onboarding|find_friends" | "onboarding|find_friends_action" | "onboarding|find_friends_description" | "onboarding|find_people" | "onboarding|free_e2ee_messaging_unlimited_voip" | "onboarding|get_stuff_done" | "onboarding|google_trademarks" | "onboarding|has_avatar_label" | "onboarding|intro_byline" | "onboarding|intro_welcome" | "onboarding|only_n_steps_to_go" | "onboarding|personal_messaging_action" | "onboarding|personal_messaging_title" | "onboarding|qr_or_app_links" | "onboarding|send_dm" | "onboarding|set_up_profile" | "onboarding|set_up_profile_action" | "onboarding|set_up_profile_description" | "onboarding|use_case_community_messaging" | "onboarding|use_case_heading1" | "onboarding|use_case_heading2" | "onboarding|use_case_heading3" | "onboarding|use_case_personal_messaging" | "onboarding|use_case_work_messaging" | "onboarding|welcome_detail" | "onboarding|welcome_to_brand" | "onboarding|welcome_user" | "onboarding|work_messaging_action" | "onboarding|work_messaging_title" | "onboarding|you_did_it" | "onboarding|you_made_it" | "pill|permalink_other_room" | "pill|permalink_this_room" | "poll|topic_label" | "poll|create_poll_action" | "poll|create_poll_title" | "poll|disclosed_notes" | "poll|edit_poll_title" | "poll|end_description" | "poll|end_message" | "poll|end_message_no_votes" | "poll|end_title" | "poll|error_ending_description" | "poll|error_ending_title" | "poll|error_voting_description" | "poll|error_voting_title" | "poll|failed_send_poll_description" | "poll|failed_send_poll_title" | "poll|notes" | "poll|options_add_button" | "poll|options_heading" | "poll|options_label" | "poll|options_placeholder" | "poll|topic_heading" | "poll|topic_placeholder" | "poll|total_decryption_errors" | "poll|total_n_votes" | "poll|total_n_votes_voted" | "poll|total_no_votes" | "poll|total_not_ended" | "poll|type_closed" | "poll|type_heading" | "poll|type_open" | "poll|unable_edit_description" | "poll|unable_edit_title" | "power_level|default" | "power_level|custom" | "power_level|label" | "power_level|restricted" | "power_level|admin" | "power_level|custom_level" | "power_level|mod" | "power_level|moderator" | "quick_settings|title" | "quick_settings|all_settings" | "quick_settings|metaspace_section" | "quick_settings|sidebar_settings" | "quit_warning|call_in_progress" | "quit_warning|file_upload_in_progress" | "reject_invitation_dialog|failed" | "reject_invitation_dialog|title" | "reject_invitation_dialog|confirmation" | "report_content|description" | "report_content|disagree" | "report_content|error_create_room_moderation_bot" | "report_content|hide_messages_from_user" | "report_content|ignore_user" | "report_content|illegal_content" | "report_content|missing_reason" | "report_content|nature" | "report_content|nature_disagreement" | "report_content|nature_illegal" | "report_content|nature_nonstandard_admin" | "report_content|nature_nonstandard_admin_encrypted" | "report_content|nature_other" | "report_content|nature_spam" | "report_content|nature_toxic" | "report_content|other_label" | "report_content|report_content_to_homeserver" | "report_content|report_entire_room" | "report_content|spam_or_propaganda" | "report_content|toxic_behaviour" | "restore_key_backup_dialog|enter_phrase_description" | "restore_key_backup_dialog|enter_phrase_title" | "restore_key_backup_dialog|count_of_decryption_failures" | "restore_key_backup_dialog|count_of_successfully_restored_keys" | "restore_key_backup_dialog|enter_key_description" | "restore_key_backup_dialog|enter_key_title" | "restore_key_backup_dialog|incorrect_security_phrase_dialog" | "restore_key_backup_dialog|incorrect_security_phrase_title" | "restore_key_backup_dialog|key_backup_warning" | "restore_key_backup_dialog|key_fetch_in_progress" | "restore_key_backup_dialog|key_forgotten_text" | "restore_key_backup_dialog|key_is_invalid" | "restore_key_backup_dialog|key_is_valid" | "restore_key_backup_dialog|keys_restored_title" | "restore_key_backup_dialog|load_error_content" | "restore_key_backup_dialog|load_keys_progress" | "restore_key_backup_dialog|no_backup_error" | "restore_key_backup_dialog|phrase_forgotten_text" | "restore_key_backup_dialog|recovery_key_mismatch_description" | "restore_key_backup_dialog|recovery_key_mismatch_title" | "restore_key_backup_dialog|restore_failed_error" | "right_panel|info" | "right_panel|add_integrations" | "right_panel|add_topic" | "right_panel|export_chat_button" | "right_panel|extensions_empty_description" | "right_panel|extensions_empty_title" | "right_panel|files_button" | "right_panel|pinned_messages_button" | "right_panel|polls_button" | "right_panel|widgets_section" | "right_panel|poll|loading" | "right_panel|poll|active_heading" | "right_panel|poll|empty_active" | "right_panel|poll|empty_active_load_more" | "right_panel|poll|empty_active_load_more_n_days" | "right_panel|poll|empty_past" | "right_panel|poll|empty_past_load_more" | "right_panel|poll|empty_past_load_more_n_days" | "right_panel|poll|final_result" | "right_panel|poll|load_more" | "right_panel|poll|past_heading" | "right_panel|poll|view_in_timeline" | "right_panel|poll|view_poll" | "right_panel|pinned_messages|view" | "right_panel|pinned_messages|header" | "right_panel|pinned_messages|menu" | "right_panel|pinned_messages|title" | "right_panel|pinned_messages|empty_description" | "right_panel|pinned_messages|empty_title" | "right_panel|pinned_messages|limits" | "right_panel|pinned_messages|reply_thread" | "right_panel|pinned_messages|unpin_all|button" | "right_panel|pinned_messages|unpin_all|content" | "right_panel|pinned_messages|unpin_all|title" | "right_panel|room_summary_card|title" | "right_panel|thread_list|context_menu_label" | "right_panel|video_room_chat|title" | "room_list|show_n_more" | "room_list|add_room_label" | "room_list|add_space_label" | "room_list|breadcrumbs_empty" | "room_list|breadcrumbs_label" | "room_list|failed_add_tag" | "room_list|failed_remove_tag" | "room_list|failed_set_dm_tag" | "room_list|home_menu_label" | "room_list|join_public_room_label" | "room_list|joining_rooms_status" | "room_list|notification_options" | "room_list|redacting_messages_status" | "room_list|show_less" | "room_list|show_previews" | "room_list|sort_by" | "room_list|sort_by_activity" | "room_list|sort_by_alphabet" | "room_list|sort_unread_first" | "room_list|space_menu_label" | "room_list|sublist_options" | "room_list|suggested_rooms_heading" | "room_settings|title" | "room_settings|security|strict_encryption" | "room_settings|alias_not_specified" | "room_settings|delete_avatar_label" | "room_settings|upload_avatar_label" | "room_settings|advanced|room_id" | "room_settings|advanced|room_version" | "room_settings|advanced|unfederated" | "room_settings|advanced|error_upgrade_description" | "room_settings|advanced|error_upgrade_title" | "room_settings|advanced|information_section_room" | "room_settings|advanced|information_section_space" | "room_settings|advanced|room_predecessor" | "room_settings|advanced|room_upgrade_button" | "room_settings|advanced|room_upgrade_warning" | "room_settings|advanced|room_version_section" | "room_settings|advanced|space_predecessor" | "room_settings|advanced|space_upgrade_button" | "room_settings|advanced|upgrade_button" | "room_settings|advanced|upgrade_dialog_description" | "room_settings|advanced|upgrade_dialog_description_1" | "room_settings|advanced|upgrade_dialog_description_2" | "room_settings|advanced|upgrade_dialog_description_3" | "room_settings|advanced|upgrade_dialog_description_4" | "room_settings|advanced|upgrade_dialog_title" | "room_settings|advanced|upgrade_dwarning_ialog_title_public" | "room_settings|advanced|upgrade_warning_dialog_description" | "room_settings|advanced|upgrade_warning_dialog_explainer" | "room_settings|advanced|upgrade_warning_dialog_footer" | "room_settings|advanced|upgrade_warning_dialog_invite_label" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt" | "room_settings|advanced|upgrade_warning_dialog_report_bug_prompt_link" | "room_settings|advanced|upgrade_warning_dialog_title" | "room_settings|advanced|upgrade_warning_dialog_title_private" | "room_settings|notifications|browse_button" | "room_settings|notifications|custom_sound_prompt" | "room_settings|notifications|notification_sound" | "room_settings|notifications|settings_link" | "room_settings|notifications|sounds_section" | "room_settings|notifications|upload_sound_label" | "room_settings|notifications|uploaded_sound" | "room_settings|visibility|title" | "room_settings|visibility|alias_section" | "room_settings|visibility|error_failed_save" | "room_settings|visibility|error_update_guest_access" | "room_settings|visibility|error_update_history_visibility" | "room_settings|visibility|guest_access_explainer" | "room_settings|visibility|guest_access_explainer_public_space" | "room_settings|visibility|guest_access_label" | "room_settings|visibility|history_visibility_anyone_space" | "room_settings|visibility|history_visibility_anyone_space_description" | "room_settings|visibility|history_visibility_anyone_space_recommendation" | "room_settings|security|title" | "room_settings|security|encryption_forced" | "room_settings|security|join_rule_invite" | "room_settings|security|join_rule_restricted" | "room_settings|security|enable_encryption_confirm_description" | "room_settings|security|enable_encryption_confirm_title" | "room_settings|security|enable_encryption_public_room_confirm_description_1" | "room_settings|security|enable_encryption_public_room_confirm_description_2" | "room_settings|security|enable_encryption_public_room_confirm_title" | "room_settings|security|encrypted_room_public_confirm_description_1" | "room_settings|security|encrypted_room_public_confirm_description_2" | "room_settings|security|encrypted_room_public_confirm_title" | "room_settings|security|encryption_permanent" | "room_settings|security|error_join_rule_change_title" | "room_settings|security|error_join_rule_change_unknown" | "room_settings|security|guest_access_warning" | "room_settings|security|history_visibility_invited" | "room_settings|security|history_visibility_joined" | "room_settings|security|history_visibility_legend" | "room_settings|security|history_visibility_shared" | "room_settings|security|history_visibility_warning" | "room_settings|security|history_visibility_world_readable" | "room_settings|security|join_rule_description" | "room_settings|security|join_rule_invite_description" | "room_settings|security|join_rule_knock" | "room_settings|security|join_rule_knock_description" | "room_settings|security|join_rule_public_description" | "room_settings|security|join_rule_restricted_description" | "room_settings|security|join_rule_restricted_description_active_space" | "room_settings|security|join_rule_restricted_description_prompt" | "room_settings|security|join_rule_restricted_description_spaces" | "room_settings|security|join_rule_restricted_dialog_description" | "room_settings|security|join_rule_restricted_dialog_empty_warning" | "room_settings|security|join_rule_restricted_dialog_filter_placeholder" | "room_settings|security|join_rule_restricted_dialog_heading_known" | "room_settings|security|join_rule_restricted_dialog_heading_other" | "room_settings|security|join_rule_restricted_dialog_heading_room" | "room_settings|security|join_rule_restricted_dialog_heading_space" | "room_settings|security|join_rule_restricted_dialog_heading_unknown" | "room_settings|security|join_rule_restricted_dialog_title" | "room_settings|security|join_rule_restricted_n_more" | "room_settings|security|join_rule_restricted_summary" | "room_settings|security|join_rule_restricted_upgrade_description" | "room_settings|security|join_rule_restricted_upgrade_warning" | "room_settings|security|join_rule_upgrade_awaiting_room" | "room_settings|security|join_rule_upgrade_required" | "room_settings|security|join_rule_upgrade_sending_invites" | "room_settings|security|join_rule_upgrade_updating_spaces" | "room_settings|security|join_rule_upgrade_upgrading_room" | "room_settings|security|public_without_alias_warning" | "room_settings|security|publish_room" | "room_settings|security|publish_space" | "room_settings|voip|call_type_section" | "room_settings|voip|enable_element_call_caption" | "room_settings|voip|enable_element_call_label" | "room_settings|voip|enable_element_call_no_permissions_tooltip" | "room_settings|general|save" | "room_settings|general|other_section" | "room_settings|general|alias_field_has_domain_invalid" | "room_settings|general|alias_field_has_localpart_invalid" | "room_settings|general|alias_field_matches_invalid" | "room_settings|general|alias_field_placeholder_default" | "room_settings|general|alias_field_required_invalid" | "room_settings|general|alias_field_safe_localpart_invalid" | "room_settings|general|alias_field_taken_invalid" | "room_settings|general|alias_field_taken_invalid_domain" | "room_settings|general|alias_field_taken_valid" | "room_settings|general|alias_heading" | "room_settings|general|aliases_items_label" | "room_settings|general|aliases_no_items_label" | "room_settings|general|aliases_section" | "room_settings|general|avatar_field_label" | "room_settings|general|canonical_alias_field_label" | "room_settings|general|default_url_previews_off" | "room_settings|general|default_url_previews_on" | "room_settings|general|description_space" | "room_settings|general|error_creating_alias_description" | "room_settings|general|error_creating_alias_title" | "room_settings|general|error_deleting_alias_description" | "room_settings|general|error_deleting_alias_description_forbidden" | "room_settings|general|error_deleting_alias_title" | "room_settings|general|error_save_space_settings" | "room_settings|general|error_updating_alias_description" | "room_settings|general|error_updating_canonical_alias_description" | "room_settings|general|error_updating_canonical_alias_title" | "room_settings|general|leave_space" | "room_settings|general|local_alias_field_label" | "room_settings|general|local_aliases_explainer_room" | "room_settings|general|local_aliases_explainer_space" | "room_settings|general|local_aliases_section" | "room_settings|general|name_field_label" | "room_settings|general|new_alias_placeholder" | "room_settings|general|no_aliases_room" | "room_settings|general|no_aliases_space" | "room_settings|general|publish_toggle" | "room_settings|general|published_aliases_description" | "room_settings|general|published_aliases_explainer_room" | "room_settings|general|published_aliases_explainer_space" | "room_settings|general|published_aliases_section" | "room_settings|general|topic_field_label" | "room_settings|general|url_preview_encryption_warning" | "room_settings|general|url_preview_explainer" | "room_settings|general|url_previews_section" | "room_settings|general|user_url_previews_default_off" | "room_settings|general|user_url_previews_default_on" | "room_settings|people|knock_empty" | "room_settings|people|knock_section" | "room_settings|people|see_less" | "room_settings|people|see_more" | "room_settings|access|title" | "room_settings|access|description_space" | "room_settings|bridges|title" | "room_settings|bridges|description" | "room_settings|bridges|empty" | "room_settings|permissions|title" | "room_settings|permissions|m.widget" | "room_settings|permissions|invite" | "room_settings|permissions|ban" | "room_settings|permissions|users_default" | "room_settings|permissions|events_default" | "room_settings|permissions|state_default" | "room_settings|permissions|kick" | "room_settings|permissions|redact" | "room_settings|permissions|m.room.history_visibility" | "room_settings|permissions|io.element.voice_broadcast_info" | "room_settings|permissions|m.reaction" | "room_settings|permissions|m.room.power_levels" | "room_settings|permissions|m.call" | "room_settings|permissions|m.room.canonical_alias" | "room_settings|permissions|m.room.name" | "room_settings|permissions|m.room.topic" | "room_settings|permissions|m.room.avatar" | "room_settings|permissions|m.room.pinned_events" | "room_settings|permissions|m.room.encryption" | "room_settings|permissions|m.room.server_acl" | "room_settings|permissions|m.room.tombstone" | "room_settings|permissions|m.space.child" | "room_settings|permissions|m.room.redaction" | "room_settings|permissions|ban_reason" | "room_settings|permissions|banned_by" | "room_settings|permissions|add_privileged_user_description" | "room_settings|permissions|add_privileged_user_filter_placeholder" | "room_settings|permissions|add_privileged_user_heading" | "room_settings|permissions|banned_users_section" | "room_settings|permissions|error_changing_pl_description" | "room_settings|permissions|error_changing_pl_reqs_description" | "room_settings|permissions|error_changing_pl_reqs_title" | "room_settings|permissions|error_changing_pl_title" | "room_settings|permissions|error_unbanning" | "room_settings|permissions|m.call.member" | "room_settings|permissions|m.room.avatar_space" | "room_settings|permissions|m.room.canonical_alias_space" | "room_settings|permissions|m.room.name_space" | "room_settings|permissions|m.room.topic_space" | "room_settings|permissions|muted_users_section" | "room_settings|permissions|no_privileged_users" | "room_settings|permissions|notifications.room" | "room_settings|permissions|permissions_section" | "room_settings|permissions|permissions_section_description_room" | "room_settings|permissions|permissions_section_description_space" | "room_settings|permissions|privileged_users_section" | "room_settings|permissions|send_event_type" | "scalar|error_create" | "scalar|error_membership" | "scalar|error_missing_room_id" | "scalar|error_missing_room_id_request" | "scalar|error_missing_user_id_request" | "scalar|error_permission" | "scalar|error_power_level_invalid" | "scalar|error_room_not_visible" | "scalar|error_room_unknown" | "scalar|error_send_request" | "scalar|failed_read_event" | "scalar|failed_send_event" | "server_offline|title" | "server_offline|description" | "server_offline|description_1" | "server_offline|description_2" | "server_offline|description_3" | "server_offline|description_4" | "server_offline|description_5" | "server_offline|description_6" | "server_offline|description_7" | "server_offline|description_8" | "server_offline|empty_timeline" | "server_offline|recent_changes_heading" | "seshat|reset_title" | "seshat|error_initialising" | "seshat|reset_button" | "seshat|reset_description" | "seshat|reset_explainer" | "seshat|warning_kind_files" | "seshat|warning_kind_files_app" | "seshat|warning_kind_search" | "seshat|warning_kind_search_app" | "setting|help_about|title" | "setting|help_about|versions" | "setting|help_about|identity_server" | "setting|help_about|dialog_title" | "setting|help_about|homeserver" | "setting|help_about|access_token_detail" | "setting|help_about|brand_version" | "setting|help_about|clear_cache_reload" | "setting|help_about|crypto_version" | "setting|help_about|help_link" | "share|link_title" | "share|permalink_message" | "share|permalink_most_recent" | "share|share_call" | "share|share_call_subtitle" | "share|title_link" | "share|title_message" | "share|title_room" | "share|title_user" | "slash_command|join" | "slash_command|view" | "slash_command|remove" | "slash_command|verify" | "slash_command|html" | "slash_command|query" | "slash_command|invite" | "slash_command|ban" | "slash_command|ignore" | "slash_command|topic" | "slash_command|help" | "slash_command|devtools" | "slash_command|unban" | "slash_command|unignore" | "slash_command|category_other" | "slash_command|addwidget" | "slash_command|addwidget_iframe_missing_src" | "slash_command|addwidget_invalid_protocol" | "slash_command|addwidget_missing_url" | "slash_command|addwidget_no_permissions" | "slash_command|category_actions" | "slash_command|category_admin" | "slash_command|category_advanced" | "slash_command|category_effects" | "slash_command|category_messages" | "slash_command|command_error" | "slash_command|converttodm" | "slash_command|converttoroom" | "slash_command|could_not_find_room" | "slash_command|deop" | "slash_command|discardsession" | "slash_command|error_invalid_rendering_type" | "slash_command|error_invalid_room" | "slash_command|error_invalid_runfn" | "slash_command|error_invalid_user_in_room" | "slash_command|help_dialog_title" | "slash_command|holdcall" | "slash_command|ignore_dialog_description" | "slash_command|ignore_dialog_title" | "slash_command|invite_3pid_needs_is_error" | "slash_command|invite_3pid_use_default_is_title" | "slash_command|invite_3pid_use_default_is_title_description" | "slash_command|invite_failed" | "slash_command|jumptodate" | "slash_command|jumptodate_invalid_input" | "slash_command|lenny" | "slash_command|me" | "slash_command|msg" | "slash_command|myavatar" | "slash_command|myroomavatar" | "slash_command|myroomnick" | "slash_command|nick" | "slash_command|no_active_call" | "slash_command|op" | "slash_command|part_unknown_alias" | "slash_command|plain" | "slash_command|query_not_found_phone_number" | "slash_command|rageshake" | "slash_command|rainbow" | "slash_command|rainbowme" | "slash_command|remakeolm" | "slash_command|roomavatar" | "slash_command|roomname" | "slash_command|server_error" | "slash_command|server_error_detail" | "slash_command|shrug" | "slash_command|spoiler" | "slash_command|tableflip" | "slash_command|topic_none" | "slash_command|topic_room_error" | "slash_command|tovirtual" | "slash_command|tovirtual_not_found" | "slash_command|unflip" | "slash_command|unholdcall" | "slash_command|unignore_dialog_description" | "slash_command|unignore_dialog_title" | "slash_command|unknown_command" | "slash_command|unknown_command_button" | "slash_command|unknown_command_detail" | "slash_command|unknown_command_help" | "slash_command|unknown_command_hint" | "slash_command|upgraderoom" | "slash_command|upgraderoom_permission_error" | "slash_command|usage" | "slash_command|verify_mismatch" | "slash_command|verify_nop" | "slash_command|verify_nop_warning_mismatch" | "slash_command|verify_success_description" | "slash_command|verify_success_title" | "slash_command|verify_unknown_pair" | "slash_command|whois" | "space_settings|title" | "spotlight|public_rooms|network_dropdown_add_dialog_description" | "spotlight|public_rooms|network_dropdown_add_dialog_placeholder" | "spotlight|public_rooms|network_dropdown_add_dialog_title" | "spotlight|public_rooms|network_dropdown_add_server_option" | "spotlight|public_rooms|network_dropdown_available_invalid" | "spotlight|public_rooms|network_dropdown_available_invalid_forbidden" | "spotlight|public_rooms|network_dropdown_available_valid" | "spotlight|public_rooms|network_dropdown_remove_server_adornment" | "spotlight|public_rooms|network_dropdown_required_invalid" | "spotlight|public_rooms|network_dropdown_selected_label" | "spotlight|public_rooms|network_dropdown_selected_label_instance" | "spotlight|public_rooms|network_dropdown_your_server_description" | "spotlight_dialog|cant_find_person_helpful_hint" | "spotlight_dialog|cant_find_room_helpful_hint" | "spotlight_dialog|copy_link_text" | "spotlight_dialog|count_of_members" | "spotlight_dialog|create_new_room_button" | "spotlight_dialog|failed_querying_public_rooms" | "spotlight_dialog|failed_querying_public_spaces" | "spotlight_dialog|group_chat_section_title" | "spotlight_dialog|heading_with_query" | "spotlight_dialog|heading_without_query" | "spotlight_dialog|join_button_text" | "spotlight_dialog|keyboard_scroll_hint" | "spotlight_dialog|message_search_section_title" | "spotlight_dialog|other_rooms_in_space" | "spotlight_dialog|public_rooms_label" | "spotlight_dialog|public_spaces_label" | "spotlight_dialog|recent_searches_section_title" | "spotlight_dialog|recently_viewed_section_title" | "spotlight_dialog|remove_filter" | "spotlight_dialog|result_may_be_hidden_privacy_warning" | "spotlight_dialog|result_may_be_hidden_warning" | "spotlight_dialog|search_dialog" | "spotlight_dialog|search_messages_hint" | "spotlight_dialog|spaces_title" | "spotlight_dialog|start_group_chat_button" | "stickers|empty" | "stickers|empty_add_prompt" | "terms|integration_manager" | "terms|intro" | "terms|column_document" | "terms|column_service" | "terms|column_summary" | "terms|identity_server_no_terms_description_1" | "terms|identity_server_no_terms_description_2" | "terms|identity_server_no_terms_title" | "terms|inline_intro_text" | "terms|summary_identity_server_1" | "terms|summary_identity_server_2" | "terms|tac_button" | "terms|tac_description" | "terms|tac_title" | "terms|tos" | "threads_activity_centre|header" | "threads_activity_centre|release_announcement_description" | "threads_activity_centre|release_announcement_header" | "threads_activity_centre|no_rooms_with_threads_notifs" | "threads_activity_centre|no_rooms_with_unread_threads" | "unsupported_browser|title" | "unsupported_browser|description" | "update_room_access_modal|title" | "update_room_access_modal|description" | "update_room_access_modal|no_change" | "update_room_access_modal|dont_change_description" | "upload_file|title" | "upload_file|error_title" | "upload_file|cancel_all_button" | "upload_file|error_file_too_large" | "upload_file|error_files_too_large" | "upload_file|error_some_files_too_large" | "upload_file|title_progress" | "upload_file|upload_all_button" | "upload_file|upload_n_others_button" | "user_info|redact|confirm_button" | "user_info|dehydrated_device_enabled" | "user_info|room_encrypted" | "user_info|share_button" | "user_info|admin_tools_section" | "user_info|ban_button_room" | "user_info|ban_button_space" | "user_info|ban_room_confirm_title" | "user_info|ban_space_everything" | "user_info|ban_space_specific" | "user_info|count_of_sessions" | "user_info|count_of_verified_sessions" | "user_info|deactivate_confirm_action" | "user_info|deactivate_confirm_description" | "user_info|deactivate_confirm_title" | "user_info|demote_button" | "user_info|demote_self_confirm_description_space" | "user_info|demote_self_confirm_room" | "user_info|demote_self_confirm_title" | "user_info|disinvite_button_room" | "user_info|disinvite_button_room_name" | "user_info|disinvite_button_space" | "user_info|edit_own_devices" | "user_info|error_ban_user" | "user_info|error_deactivate" | "user_info|error_kicking_user" | "user_info|error_mute_user" | "user_info|error_revoke_3pid_invite_description" | "user_info|error_revoke_3pid_invite_title" | "user_info|hide_sessions" | "user_info|hide_verified_sessions" | "user_info|ignore_button" | "user_info|ignore_confirm_description" | "user_info|ignore_confirm_title" | "user_info|invited_by" | "user_info|jump_to_rr_button" | "user_info|kick_button_room" | "user_info|kick_button_room_name" | "user_info|kick_button_space" | "user_info|kick_button_space_everything" | "user_info|kick_space_specific" | "user_info|kick_space_warning" | "user_info|promote_warning" | "user_info|redact_button" | "user_info|revoke_invite" | "user_info|room_encrypted_detail" | "user_info|room_unencrypted" | "user_info|room_unencrypted_detail" | "user_info|send_message" | "user_info|unban_button_room" | "user_info|unban_button_space" | "user_info|unban_room_confirm_title" | "user_info|unban_space_everything" | "user_info|unban_space_specific" | "user_info|unban_space_warning" | "user_info|unignore_button" | "user_info|verify_button" | "user_info|verify_explainer" | "user_info|redact|confirm_description_1" | "user_info|redact|confirm_description_2" | "user_info|redact|confirm_keep_state_explainer" | "user_info|redact|confirm_keep_state_label" | "user_info|redact|confirm_title" | "user_info|redact|no_recent_messages_description" | "user_info|redact|no_recent_messages_title" | "user_menu|settings" | "user_menu|link_new_device" | "user_menu|link_new_device_not_supported" | "user_menu|link_new_device_not_supported_caption" | "user_menu|switch_theme_dark" | "user_menu|switch_theme_light" | "voice_message|cant_start_broadcast_description" | "voice_message|cant_start_broadcast_title" | "widget|error_loading" | "widget|unencrypted_warning" | "widget|added_by" | "widget|close_to_view_right_panel" | "widget|cookie_warning" | "widget|error_hangup_description" | "widget|error_hangup_title" | "widget|error_mixed_content" | "widget|error_need_invite_permission" | "widget|error_need_kick_permission" | "widget|error_need_to_be_logged_in" | "widget|error_unable_start_audio_stream_description" | "widget|error_unable_start_audio_stream_title" | "widget|modal_data_warning" | "widget|modal_title_default" | "widget|no_name" | "widget|popout" | "widget|set_room_layout" | "widget|shared_data_avatar" | "widget|shared_data_device_id" | "widget|shared_data_lang" | "widget|shared_data_mxid" | "widget|shared_data_name" | "widget|shared_data_room_id" | "widget|shared_data_theme" | "widget|shared_data_url" | "widget|shared_data_warning" | "widget|shared_data_warning_im" | "widget|shared_data_widget_id" | "widget|unmaximise" | "widget|unpin_to_view_right_panel" | "widget|context_menu|remove" | "widget|context_menu|screenshot" | "widget|context_menu|delete" | "widget|context_menu|revoke" | "widget|context_menu|delete_warning" | "widget|context_menu|move_left" | "widget|context_menu|move_right" | "widget|context_menu|start_audio_stream" | "widget|capabilities_dialog|title" | "widget|capabilities_dialog|content_starting_text" | "widget|capabilities_dialog|decline_all_permission" | "widget|capabilities_dialog|remember_Selection" | "widget|capability|capability" | "widget|capability|always_on_screen_generic" | "widget|capability|always_on_screen_viewing_another_room" | "widget|capability|any_room" | "widget|capability|byline_empty_state_key" | "widget|capability|byline_state_key" | "widget|capability|change_avatar_active_room" | "widget|capability|change_avatar_this_room" | "widget|capability|change_name_active_room" | "widget|capability|change_name_this_room" | "widget|capability|change_topic_active_room" | "widget|capability|change_topic_this_room" | "widget|capability|receive_membership_active_room" | "widget|capability|receive_membership_this_room" | "widget|capability|remove_ban_invite_leave_active_room" | "widget|capability|remove_ban_invite_leave_this_room" | "widget|capability|see_avatar_change_active_room" | "widget|capability|see_avatar_change_this_room" | "widget|capability|see_event_type_sent_active_room" | "widget|capability|see_event_type_sent_this_room" | "widget|capability|see_images_sent_active_room" | "widget|capability|see_images_sent_this_room" | "widget|capability|see_messages_sent_active_room" | "widget|capability|see_messages_sent_this_room" | "widget|capability|see_msgtype_sent_active_room" | "widget|capability|see_msgtype_sent_this_room" | "widget|capability|see_name_change_active_room" | "widget|capability|see_name_change_this_room" | "widget|capability|see_sent_emotes_active_room" | "widget|capability|see_sent_emotes_this_room" | "widget|capability|see_sent_files_active_room" | "widget|capability|see_sent_files_this_room" | "widget|capability|see_sticker_posted_active_room" | "widget|capability|see_sticker_posted_this_room" | "widget|capability|see_text_messages_sent_active_room" | "widget|capability|see_text_messages_sent_this_room" | "widget|capability|see_topic_change_active_room" | "widget|capability|see_topic_change_this_room" | "widget|capability|see_videos_sent_active_room" | "widget|capability|see_videos_sent_this_room" | "widget|capability|send_emotes_active_room" | "widget|capability|send_emotes_this_room" | "widget|capability|send_event_type_active_room" | "widget|capability|send_event_type_this_room" | "widget|capability|send_files_active_room" | "widget|capability|send_files_this_room" | "widget|capability|send_images_active_room" | "widget|capability|send_images_this_room" | "widget|capability|send_messages_active_room" | "widget|capability|send_messages_this_room" | "widget|capability|send_msgtype_active_room" | "widget|capability|send_msgtype_this_room" | "widget|capability|send_stickers_active_room" | "widget|capability|send_stickers_active_room_as_you" | "widget|capability|send_stickers_this_room" | "widget|capability|send_stickers_this_room_as_you" | "widget|capability|send_text_messages_active_room" | "widget|capability|send_text_messages_this_room" | "widget|capability|send_videos_active_room" | "widget|capability|send_videos_this_room" | "widget|capability|specific_room" | "widget|capability|switch_room" | "widget|capability|switch_room_message_user" | "widget|open_id_permissions_dialog|title" | "widget|open_id_permissions_dialog|remember_selection" | "widget|open_id_permissions_dialog|starting_text" | "zxcvbn|suggestions|allUppercase" | "zxcvbn|suggestions|anotherWord" | "zxcvbn|suggestions|associatedYears" | "zxcvbn|suggestions|capitalization" | "zxcvbn|suggestions|dates" | "zxcvbn|suggestions|l33t" | "zxcvbn|suggestions|longerKeyboardPattern" | "zxcvbn|suggestions|noNeed" | "zxcvbn|suggestions|pwned" | "zxcvbn|suggestions|recentYears" | "zxcvbn|suggestions|repeated" | "zxcvbn|suggestions|reverseWords" | "zxcvbn|suggestions|sequences" | "zxcvbn|suggestions|useWords" | "zxcvbn|warnings|common" | "zxcvbn|warnings|dates" | "zxcvbn|warnings|pwned" | "zxcvbn|warnings|recentYears" | "zxcvbn|warnings|sequences" | "zxcvbn|warnings|commonNames" | "zxcvbn|warnings|extendedRepeat" | "zxcvbn|warnings|keyPattern" | "zxcvbn|warnings|namesByThemselves" | "zxcvbn|warnings|similarToCommon" | "zxcvbn|warnings|simpleRepeat" | "zxcvbn|warnings|straightRow" | "zxcvbn|warnings|topHundred" | "zxcvbn|warnings|topTen" | "zxcvbn|warnings|userInputs" | "zxcvbn|warnings|wordByItself";
    };
    readonly validate: (fieldState: IFieldState) => Promise<IValidationResult>;
    onValidate: (fieldState: IFieldState) => Promise<IValidationResult>;
    render(): React.ReactNode;
}
export default PassphraseField;
